@@ -34,39 +34,47 @@ Utilities
  __version__   -- Dipy version
 
 """
-import sys
 
 from dipy.version import version as __version__
 
-# Plumb in version etc info stuff
-from .pkg_info import get_pkg_info as _get_pkg_info
-
 
 def get_info():
     from os.path import dirname
-    return _get_pkg_info(dirname(__file__))
+    import sys
 
+    import numpy
+
+    import dipy
+
+    return {
+        "pkg_path": dirname(__file__),
+        "commit_hash": dipy.version.git_revision,
+        "sys_version": sys.version,
+        "sys_executable": sys.executable,
+        "sys_platform": sys.platform,
+        "np_version": numpy.__version__,
+        "dipy_version": dipy.__version__,
+    }
 
-del sys
 
 submodules = [
-    'align',
-    'core',
-    'data',
-    'denoise',
-    'direction',
-    'io',
-    'nn',
-    'reconst',
-    'segment',
-    'sims',
-    'stats',
-    'tracking',
-    'utils',
-    'viz',
-    'workflows',
-    'tests',
-    'testing'
+    "align",
+    "core",
+    "data",
+    "denoise",
+    "direction",
+    "io",
+    "nn",
+    "reconst",
+    "segment",
+    "sims",
+    "stats",
+    "tracking",
+    "utils",
+    "viz",
+    "workflows",
+    "tests",
+    "testing",
 ]
 
-__all__ = submodules + ['__version__', 'setup_test', 'get_info']
+__all__ = submodules + ["__version__", "setup_test", "get_info"]
