@@ -1,18 +1,28 @@
 import logging
-from dipy.align import floating
+
 import numpy as np
 import numpy.linalg as npl
 from scipy.ndimage import gaussian_filter
 
+from dipy.align import floating
+from dipy.testing.decorators import warning_for_keywords
+
 logger = logging.getLogger(__name__)
 
+
 class ScaleSpace:
-    def __init__(self, image, num_levels,
-                 image_grid2world=None,
-                 input_spacing=None,
-                 sigma_factor=0.2,
-                 mask0=False):
-        """ ScaleSpace.
+    @warning_for_keywords()
+    def __init__(
+        self,
+        image,
+        num_levels,
+        *,
+        image_grid2world=None,
+        input_spacing=None,
+        sigma_factor=0.2,
+        mask0=False,
+    ):
+        """ScaleSpace.
 
         Computes the Scale Space representation of an image. The scale space is
         simply a list of images produced by smoothing the input image with a
@@ -51,7 +61,7 @@ class ScaleSpace:
             mask = np.asarray(image > 0, dtype=np.int32)
 
         # Normalize input image to [0,1]
-        img = (image - np.min(image))/(np.max(image) - np.min(image))
+        img = (image - np.min(image)) / (np.max(image) - np.min(image))
         if mask0:
             img *= mask
 
@@ -74,7 +84,7 @@ class ScaleSpace:
         # Compute the rest of the levels
         min_spacing = np.min(input_spacing)
         for i in range(1, num_levels):
-            scaling_factor = 2 ** i
+            scaling_factor = 2**i
             # Note: the minimum below is present in ANTS to prevent the scaling
             # from being too large (making the sub-sampled image to be too
             # small) this makes the sub-sampled image at least 32 voxels at
@@ -97,8 +107,9 @@ class ScaleSpace:
 
             # Filter along each direction with the appropriate sigma
             filtered = gaussian_filter(image, sigmas)
-            filtered = ((filtered - np.min(filtered)) /
-                        (np.max(filtered) - np.min(filtered)))
+            filtered = (filtered - np.min(filtered)) / (
+                np.max(filtered) - np.min(filtered)
+            )
             if mask0:
                 filtered *= mask
 
@@ -132,8 +143,9 @@ class ScaleSpace:
             the expand factors (a scalar for each voxel dimension)
 
         """
-        factors = (np.array(self.spacings[to_level]) /
-                   np.array(self.spacings[from_level]))
+        factors = np.array(self.spacings[to_level]) / np.array(
+            self.spacings[from_level]
+        )
         return factors
 
     def print_level(self, level):
@@ -147,11 +159,11 @@ class ScaleSpace:
             the scale space level to be printed
 
         """
-        logger.info('Domain shape: ' + str(self.get_domain_shape(level)))
-        logger.info('Spacing: ' + str(self.get_spacing(level)))
-        logger.info('Scaling: ' + str(self.get_scaling(level)))
-        logger.info('Affine: ' + str(self.get_affine(level)))
-        logger.info('Sigmas: ' + str(self.get_sigmas(level)))
+        logger.info(f"Domain shape: {self.get_domain_shape(level)}")
+        logger.info(f"Spacing: {self.get_spacing(level)}")
+        logger.info(f"Scaling: {self.get_scaling(level)}")
+        logger.info(f"Affine: {self.get_affine(level)}")
+        logger.info(f"Sigmas: {self.get_sigmas(level)}")
 
     def _get_attribute(self, attribute, level):
         """Return an attribute from the Scale Space at a given level.
@@ -175,7 +187,7 @@ class ScaleSpace:
         """
         if 0 <= level < self.num_levels:
             return attribute[level]
-        raise ValueError('Invalid pyramid level: '+str(level))
+        raise ValueError(f"Invalid pyramid level: {level}")
 
     def get_image(self, level):
         """Smoothed image at a given level.
@@ -318,11 +330,18 @@ class ScaleSpace:
 
 
 class IsotropicScaleSpace(ScaleSpace):
-    def __init__(self, image, factors, sigmas,
-                 image_grid2world=None,
-                 input_spacing=None,
-                 mask0=False):
-        """ IsotropicScaleSpace.
+    @warning_for_keywords()
+    def __init__(
+        self,
+        image,
+        factors,
+        sigmas,
+        *,
+        image_grid2world=None,
+        input_spacing=None,
+        mask0=False,
+    ):
+        """IsotropicScaleSpace.
 
         Computes the Scale Space representation of an image using isotropic
         smoothing kernels for all scales. The scale space is simply a list
@@ -363,8 +382,9 @@ class IsotropicScaleSpace(ScaleSpace):
             mask = np.asarray(image > 0, dtype=np.int32)
 
         # Normalize input image to [0,1]
-        img = ((image.astype(np.float64) - np.min(image)) /
-               (np.max(image) - np.min(image)))
+        img = (image.astype(np.float64) - np.min(image)) / (
+            np.max(image) - np.min(image)
+        )
         if mask0:
             img *= mask
 
@@ -416,8 +436,9 @@ class IsotropicScaleSpace(ScaleSpace):
 
             # Filter along each direction with the appropriate sigma
             filtered = gaussian_filter(image.astype(np.float64), new_sigmas)
-            filtered = ((filtered.astype(np.float64) - np.min(filtered)) /
-                        (np.max(filtered) - np.min(filtered)))
+            filtered = (filtered.astype(np.float64) - np.min(filtered)) / (
+                np.max(filtered) - np.min(filtered)
+            )
             if mask0:
                 filtered *= mask
 
