@@ -3,16 +3,18 @@ import warnings
 import numpy as np
 from scipy.optimize import linear_sum_assignment
 
-from dipy.align.streamlinear import slr_with_qbx
-from dipy.align.cpd import DeformableRegistration
-from dipy.tracking.streamline import (unlist_streamlines,
-                                      Streamlines)
-from dipy.stats.analysis import assignment_map
-from dipy.tracking.streamline import length
 from dipy.align.bundlemin import distance_matrix_mdf
-from dipy.viz.plotting import bundle_shape_profile
+from dipy.align.cpd import DeformableRegistration
+from dipy.align.streamlinear import slr_with_qbx
 from dipy.segment.clustering import QuickBundles
 from dipy.segment.metricspeed import AveragePointwiseEuclideanMetric
+from dipy.stats.analysis import assignment_map
+from dipy.testing.decorators import warning_for_keywords
+from dipy.tracking.streamline import Streamlines, length, unlist_streamlines
+from dipy.utils.optpkg import optional_package
+from dipy.viz.plotting import bundle_shape_profile
+
+pd, have_pd, _ = optional_package("pandas")
 
 
 def average_bundle_length(bundle):
@@ -30,7 +32,7 @@ def average_bundle_length(bundle):
 
     """
     metric = AveragePointwiseEuclideanMetric()
-    qb = QuickBundles(threshold=85., metric=metric)
+    qb = QuickBundles(threshold=85.0, metric=metric)
     clusters = qb.cluster(bundle)
     centroids = Streamlines(clusters.centroids)
 
@@ -58,36 +60,39 @@ def find_missing(lst, cb):
     return [x for x in range(0, len(cb)) if x not in lst]
 
 
-def bundlewarp(static, moving, dist=None, alpha=0.3, beta=20, max_iter=15,
-               affine=True):
+@warning_for_keywords()
+def bundlewarp(
+    static, moving, *, dist=None, alpha=0.5, beta=20, max_iter=15, affine=True
+):
     """Register two bundles using nonlinear method.
 
+     See :footcite:p:`Chandio2023` for further details about the method.
+
     Parameters
     ----------
     static : Streamlines
-        Reference/fixed bundle
+        Reference/fixed bundle.
 
     moving : Streamlines
-        Target bundle that will be moved/registered to match the static bundle
+        Target bundle that will be moved/registered to match the static bundle.
 
-    dist : float, optional.
-        Precomputed distance matrix (default None)
+    dist : float, optional
+        Precomputed distance matrix.
 
     alpha : float, optional
         Represents the trade-off between regularizing the deformation and
         having points match very closely. Lower value of alpha means high
-        deformations (default 0.3)
+        deformations.
 
     beta : int, optional
         Represents the strength of the interaction between points
-        Gaussian kernel size (default 20)
+        Gaussian kernel size.
 
     max_iter : int, optional
-        Maximum number of iterations for deformation process in ml-CPD method
-        (default 15)
+        Maximum number of iterations for deformation process in ml-CPD method.
 
     affine : boolean, optional
-        If False, use rigid registration as starting point (default True)
+        If False, use rigid registration as starting point.
 
     Returns
     -------
@@ -108,19 +113,19 @@ def bundlewarp(static, moving, dist=None, alpha=0.3, beta=20, max_iter=15,
 
     References
     ----------
-    .. [Chandio2023] Chandio et al. "BundleWarp, streamline-based nonlinear
-            registration of white matter tracts." bioRxiv (2023): 2023-01.
+    .. footbibliography::
 
     """
     if alpha <= 0.01:
-        warnings.warn("Using alpha<=0.01 will result in extreme deformations")
+        warnings.warn(
+            "Using alpha<=0.01 will result in extreme deformations", stacklevel=2
+        )
 
     if average_bundle_length(static) <= 50:
         beta = 10
 
-    x0 = 'affine' if affine else 'rigid'
-    moving_aligned, _, _, _ = slr_with_qbx(static, moving, x0=x0,
-                                           rm_small_clusters=0)
+    x0 = "affine" if affine else "rigid"
+    moving_aligned, _, _, _ = slr_with_qbx(static, moving, x0=x0, rm_small_clusters=0)
 
     if dist is not None:
         print("using pre-computed distances")
@@ -139,11 +144,9 @@ def bundlewarp(static, moving, dist=None, alpha=0.3, beta=20, max_iter=15,
     all_matched = False
 
     while all_matched is False:
-
         num = len(all_pairs)
 
         if num < len(moving):
-
             ml = find_missing(all_pairs, moving)
 
             dist2 = dist[:][ml]
@@ -175,20 +178,22 @@ def bundlewarp(static, moving, dist=None, alpha=0.3, beta=20, max_iter=15,
     # Append deformed streamlines in deformed_bundle
 
     for _, pairs in enumerate(matched_pairs):
-
         s1 = static[int(pairs[1])]
         s2 = moving_aligned[int(pairs[0])]
 
         static_s = s1
         moving_s = s2
 
-        reg = DeformableRegistration(X=static_s, Y=moving_s, alpha=alpha,
-                                     beta=beta, max_iterations=max_iter)
+        reg = DeformableRegistration(
+            X=static_s, Y=moving_s, alpha=alpha, beta=beta, max_iterations=max_iter
+        )
         ty, pr = reg.register()
         ty = ty.astype(float)
         deformed_bundle.append(ty)
         warp.append(pr)
 
+    warp = pd.DataFrame(warp, columns=["gaussian_kernel", "transforms"])
+
     # Returns deformed bundle, affinely moved bundle, distance matrix,
     # streamline correspondences, and warp field
     return deformed_bundle, moving_aligned, dist, matched_pairs, warp
@@ -214,12 +219,18 @@ def bundlewarp_vector_filed(moving_aligned, deformed_bundle):
     directions : List
         Unitary vector directions
     colors : List
+        Colors for bundle warping field vectors. Colors follow the convention
+        used in DTI-derived maps (e.g. color FA) :footcite:p:`Pajevic1999`.
+
+    References
+    ----------
+    .. footbibliography::
     """
     points_aligned, _ = unlist_streamlines(moving_aligned)
     points_deformed, _ = unlist_streamlines(deformed_bundle)
     vector_field = points_deformed - points_aligned
 
-    offsets = np.sqrt(np.sum((vector_field)**2, 1))  # vector field modules
+    offsets = np.sqrt(np.sum((vector_field) ** 2, 1))  # vector field modules
 
     # Normalize vectors to be unitary (directions)
     directions = vector_field / np.array([offsets]).T
@@ -231,8 +242,10 @@ def bundlewarp_vector_filed(moving_aligned, deformed_bundle):
     return offsets, directions, colors
 
 
-def bundlewarp_shape_analysis(moving_aligned, deformed_bundle, no_disks=10,
-                              plotting=False):
+@warning_for_keywords()
+def bundlewarp_shape_analysis(
+    moving_aligned, deformed_bundle, *, no_disks=10, plotting=False
+):
     """Calculate bundle shape difference profile.
 
     Bundle shape difference analysis using magnitude from BundleWarp
@@ -267,8 +280,9 @@ def bundlewarp_shape_analysis(moving_aligned, deformed_bundle, no_disks=10,
         Float array containing standard deviations
     """
     n = no_disks
-    offsets, directions, colors = bundlewarp_vector_filed(moving_aligned,
-                                                          deformed_bundle)
+    offsets, directions, colors = bundlewarp_vector_filed(
+        moving_aligned, deformed_bundle
+    )
 
     indx = assignment_map(deformed_bundle, deformed_bundle, n)
     indx = np.array(indx)
@@ -279,15 +293,13 @@ def bundlewarp_shape_analysis(moving_aligned, deformed_bundle, no_disks=10,
 
     disks_color = []
     for _, ind in enumerate(indx):
-
         disks_color.append(tuple(colors[ind]))
 
-    x = np.array(range(1, n+1))
+    x = np.array(range(1, n + 1))
     shape_profile = np.zeros(n)
     stdv = np.zeros(n)
 
     for i in range(n):
-
         mask = indx == i
         if sum(mask):
             shape_profile[i] = np.mean(offsets[mask])
