@@ -1,10 +1,12 @@
 import numpy as np
-from numpy.testing import (assert_equal,
-                           assert_array_equal,
-                           assert_array_almost_equal,
-                           assert_raises)
-from dipy.align import floating
-from dipy.align import expectmax as em
+from numpy.testing import (
+    assert_array_almost_equal,
+    assert_array_equal,
+    assert_equal,
+    assert_raises,
+)
+
+from dipy.align import expectmax as em, floating
 from dipy.testing.decorators import set_random_number_generator
 
 
@@ -34,9 +36,9 @@ def test_compute_em_demons_step_2d(rng):
     x_0 = np.asarray(range(sh[0]))
     x_1 = np.asarray(range(sh[1]))
     X = np.ndarray(sh + (2,), dtype=np.float64)
-    O = np.ones(sh)
-    X[..., 0] = x_0[:, None] * O
-    X[..., 1] = x_1[None, :] * O
+    _O = np.ones(sh)
+    X[..., 0] = x_0[:, None] * _O
+    X[..., 1] = x_1[None, :] * _O
 
     # Compute the gradient fields of F and G
     grad_F = X - c_f
@@ -57,7 +59,7 @@ def test_compute_em_demons_step_2d(rng):
     # Set arbitrary values for $\sigma_i$ (eq. 4 in [Vercauteren09])
     # The original Demons algorithm used simply |F(x) - G(x)| as an
     # estimator, so let's use it as well
-    sigma_i_sq = (F - G)**2
+    sigma_i_sq = (F - G) ** 2
 
     # Select some pixels to have special values
     random_labels = rng.integers(0, 5, sh[0] * sh[1])
@@ -76,10 +78,12 @@ def test_compute_em_demons_step_2d(rng):
     # Pixels with gradient!=0 and sigma_i_sq=0
     sqnrm = sq_norm_grad_G[random_labels == 1]
     sigma_i_sq[random_labels == 1] = 0
-    expected[random_labels == 1, 0] = (delta_field[random_labels == 1] *
-                                       grad_G[random_labels == 1, 0] / sqnrm)
-    expected[random_labels == 1, 1] = (delta_field[random_labels == 1] *
-                                       grad_G[random_labels == 1, 1] / sqnrm)
+    expected[random_labels == 1, 0] = (
+        delta_field[random_labels == 1] * grad_G[random_labels == 1, 0] / sqnrm
+    )
+    expected[random_labels == 1, 1] = (
+        delta_field[random_labels == 1] * grad_G[random_labels == 1, 1] / sqnrm
+    )
 
     # Pixels with gradient=0 and sigma_i_sq=0
     sigma_i_sq[random_labels == 2] = 0
@@ -100,46 +104,53 @@ def test_compute_em_demons_step_2d(rng):
     # Now compute it using the implementation under test
 
     actual = np.empty_like(expected, dtype=floating)
-    em.compute_em_demons_step_2d(np.array(delta_field, dtype=floating),
-                                 np.array(sigma_i_sq, dtype=floating),
-                                 np.array(grad_G, dtype=floating),
-                                 sigma_x_sq,
-                                 actual)
+    em.compute_em_demons_step_2d(
+        np.array(delta_field, dtype=floating),
+        np.array(sigma_i_sq, dtype=floating),
+        np.array(grad_G, dtype=floating),
+        sigma_x_sq,
+        actual,
+    )
 
     # Test sigma_i_sq == inf
     try:
-        assert_array_almost_equal(actual[random_labels == 0],
-                                  expected[random_labels == 0])
-    except AssertionError:
-        raise AssertionError("Failed for sigma_i_sq == inf")
+        assert_array_almost_equal(
+            actual[random_labels == 0], expected[random_labels == 0]
+        )
+    except AssertionError as e:
+        raise AssertionError("Failed for sigma_i_sq == inf") from e
 
     # Test sigma_i_sq == 0 and gradient != 0
     try:
-        assert_array_almost_equal(actual[random_labels == 1],
-                                  expected[random_labels == 1])
-    except AssertionError:
-        raise AssertionError("Failed for sigma_i_sq == 0 and gradient != 0")
+        assert_array_almost_equal(
+            actual[random_labels == 1], expected[random_labels == 1]
+        )
+    except AssertionError as e:
+        raise AssertionError("Failed for sigma_i_sq == 0 and gradient != 0") from e
 
     # Test sigma_i_sq == 0 and gradient == 0
     try:
-        assert_array_almost_equal(actual[random_labels == 2],
-                                  expected[random_labels == 2])
-    except AssertionError:
-        raise AssertionError("Failed for sigma_i_sq == 0 and gradient == 0")
+        assert_array_almost_equal(
+            actual[random_labels == 2], expected[random_labels == 2]
+        )
+    except AssertionError as e:
+        raise AssertionError("Failed for sigma_i_sq == 0 and gradient == 0") from e
 
     # Test sigma_i_sq != 0 and gradient == 0
     try:
-        assert_array_almost_equal(actual[random_labels == 3],
-                                  expected[random_labels == 3])
-    except AssertionError:
-        raise AssertionError("Failed for sigma_i_sq != 0 and gradient == 0 ")
+        assert_array_almost_equal(
+            actual[random_labels == 3], expected[random_labels == 3]
+        )
+    except AssertionError as e:
+        raise AssertionError("Failed for sigma_i_sq != 0 and gradient == 0 ") from e
 
     # Test sigma_i_sq != 0 and gradient != 0
     try:
-        assert_array_almost_equal(actual[random_labels == 4],
-                                  expected[random_labels == 4])
-    except AssertionError:
-        raise AssertionError("Failed for sigma_i_sq != 0 and gradient != 0")
+        assert_array_almost_equal(
+            actual[random_labels == 4], expected[random_labels == 4]
+        )
+    except AssertionError as e:
+        raise AssertionError("Failed for sigma_i_sq != 0 and gradient != 0") from e
 
 
 @set_random_number_generator(1346491)
@@ -170,10 +181,10 @@ def test_compute_em_demons_step_3d(rng):
     x_1 = np.asarray(range(sh[1]))
     x_2 = np.asarray(range(sh[2]))
     X = np.ndarray(sh + (3,), dtype=np.float64)
-    O = np.ones(sh)
-    X[..., 0] = x_0[:, None, None] * O
-    X[..., 1] = x_1[None, :, None] * O
-    X[..., 2] = x_2[None, None, :] * O
+    _O = np.ones(sh)
+    X[..., 0] = x_0[:, None, None] * _O
+    X[..., 1] = x_1[None, :, None] * _O
+    X[..., 2] = x_2[None, None, :] * _O
 
     # Compute the gradient fields of F and G
     grad_F = X - c_f
@@ -194,7 +205,7 @@ def test_compute_em_demons_step_3d(rng):
     # Set arbitrary values for $\sigma_i$ (eq. 4 in [Vercauteren09])
     # The original Demons algorithm used simply |F(x) - G(x)| as an
     # estimator, so let's use it as well
-    sigma_i_sq = (F - G)**2
+    sigma_i_sq = (F - G) ** 2
 
     # Select some pixels to have special values
     random_labels = rng.integers(0, 5, sh[0] * sh[1] * sh[2])
@@ -213,12 +224,15 @@ def test_compute_em_demons_step_3d(rng):
     # Pixels with gradient!=0 and sigma_i_sq=0
     sqnrm = sq_norm_grad_G[random_labels == 1]
     sigma_i_sq[random_labels == 1] = 0
-    expected[random_labels == 1, 0] = (delta_field[random_labels == 1] *
-                                       grad_G[random_labels == 1, 0] / sqnrm)
-    expected[random_labels == 1, 1] = (delta_field[random_labels == 1] *
-                                       grad_G[random_labels == 1, 1] / sqnrm)
-    expected[random_labels == 1, 2] = (delta_field[random_labels == 1] *
-                                       grad_G[random_labels == 1, 2] / sqnrm)
+    expected[random_labels == 1, 0] = (
+        delta_field[random_labels == 1] * grad_G[random_labels == 1, 0] / sqnrm
+    )
+    expected[random_labels == 1, 1] = (
+        delta_field[random_labels == 1] * grad_G[random_labels == 1, 1] / sqnrm
+    )
+    expected[random_labels == 1, 2] = (
+        delta_field[random_labels == 1] * grad_G[random_labels == 1, 2] / sqnrm
+    )
 
     # Pixels with gradient=0 and sigma_i_sq=0
     sigma_i_sq[random_labels == 2] = 0
@@ -238,46 +252,53 @@ def test_compute_em_demons_step_3d(rng):
 
     # Now compute it using the implementation under test
     actual = np.empty_like(expected, dtype=floating)
-    em.compute_em_demons_step_3d(np.array(delta_field, dtype=floating),
-                                 np.array(sigma_i_sq, dtype=floating),
-                                 np.array(grad_G, dtype=floating),
-                                 sigma_x_sq,
-                                 actual)
+    em.compute_em_demons_step_3d(
+        np.array(delta_field, dtype=floating),
+        np.array(sigma_i_sq, dtype=floating),
+        np.array(grad_G, dtype=floating),
+        sigma_x_sq,
+        actual,
+    )
 
     # Test sigma_i_sq == inf
     try:
-        assert_array_almost_equal(actual[random_labels == 0],
-                                  expected[random_labels == 0])
-    except AssertionError:
-        raise AssertionError("Failed for sigma_i_sq == inf")
+        assert_array_almost_equal(
+            actual[random_labels == 0], expected[random_labels == 0]
+        )
+    except AssertionError as e:
+        raise AssertionError("Failed for sigma_i_sq == inf") from e
 
     # Test sigma_i_sq == 0 and gradient != 0
     try:
-        assert_array_almost_equal(actual[random_labels == 1],
-                                  expected[random_labels == 1])
-    except AssertionError:
-        raise AssertionError("Failed for sigma_i_sq == 0 and gradient != 0")
+        assert_array_almost_equal(
+            actual[random_labels == 1], expected[random_labels == 1]
+        )
+    except AssertionError as e:
+        raise AssertionError("Failed for sigma_i_sq == 0 and gradient != 0") from e
 
     # Test sigma_i_sq == 0 and gradient == 0
     try:
-        assert_array_almost_equal(actual[random_labels == 2],
-                                  expected[random_labels == 2])
-    except AssertionError:
-        raise AssertionError("Failed for sigma_i_sq == 0 and gradient == 0")
+        assert_array_almost_equal(
+            actual[random_labels == 2], expected[random_labels == 2]
+        )
+    except AssertionError as e:
+        raise AssertionError("Failed for sigma_i_sq == 0 and gradient == 0") from e
 
     # Test sigma_i_sq != 0 and gradient == 0
     try:
-        assert_array_almost_equal(actual[random_labels == 3],
-                                  expected[random_labels == 3])
-    except AssertionError:
-        raise AssertionError("Failed for sigma_i_sq != 0 and gradient == 0 ")
+        assert_array_almost_equal(
+            actual[random_labels == 3], expected[random_labels == 3]
+        )
+    except AssertionError as e:
+        raise AssertionError("Failed for sigma_i_sq != 0 and gradient == 0 ") from e
 
     # Test sigma_i_sq != 0 and gradient != 0
     try:
-        assert_array_almost_equal(actual[random_labels == 4],
-                                  expected[random_labels == 4])
-    except AssertionError:
-        raise AssertionError("Failed for sigma_i_sq != 0 and gradient != 0")
+        assert_array_almost_equal(
+            actual[random_labels == 4], expected[random_labels == 4]
+        )
+    except AssertionError as e:
+        raise AssertionError("Failed for sigma_i_sq != 0 and gradient != 0") from e
 
 
 @set_random_number_generator(1246592)
@@ -293,12 +314,12 @@ def test_quantize_positive_2d(rng):
     delta = (max_positive - min_positive + epsilon) / (num_levels - 1)
     true_levels = np.zeros((num_levels,), dtype=np.float32)
     # put the intensities at the centers of the bins
-    true_levels[1:] = np.linspace(min_positive + delta * 0.5,
-                                  max_positive - delta * 0.5, num_levels - 1)
+    true_levels[1:] = np.linspace(
+        min_positive + delta * 0.5, max_positive - delta * 0.5, num_levels - 1
+    )
     # generate a target quantization image
     true_quantization = np.empty(img_shape, dtype=np.int32)
-    random_labels = rng.integers(0, num_levels,
-                                      np.size(true_quantization))
+    random_labels = rng.integers(0, num_levels, np.size(true_quantization))
 
     # make sure there is at least one element equal to 0, 1 and num_levels-1
     random_labels[0] = 0
@@ -333,12 +354,10 @@ def test_quantize_positive_2d(rng):
     assert_raises(ValueError, em.quantize_positive_2d, input_image, 0)
     assert_raises(ValueError, em.quantize_positive_2d, input_image, 1)
 
-    out, levels, hist = em.quantize_positive_2d(
-        np.zeros(img_shape, dtype=floating), 2)
+    out, levels, hist = em.quantize_positive_2d(np.zeros(img_shape, dtype=floating), 2)
     assert_equal(out, np.zeros(img_shape, dtype=np.int32))
 
-    out, levels, hist = em.quantize_positive_2d(
-        np.ones(img_shape, dtype=floating), 2)
+    out, levels, hist = em.quantize_positive_2d(np.ones(img_shape, dtype=floating), 2)
     assert_equal(out, np.ones(img_shape, dtype=np.int32))
 
 
@@ -355,13 +374,12 @@ def test_quantize_positive_3d(rng):
     delta = (max_positive - min_positive + epsilon) / (num_levels - 1)
     true_levels = np.zeros((num_levels,), dtype=np.float32)
     # put the intensities at the centers of the bins
-    true_levels[1:] = np.linspace(min_positive + delta * 0.5,
-                                  max_positive - delta * 0.5,
-                                  num_levels - 1)
+    true_levels[1:] = np.linspace(
+        min_positive + delta * 0.5, max_positive - delta * 0.5, num_levels - 1
+    )
     # generate a target quantization image
     true_quantization = np.empty(img_shape, dtype=np.int32)
-    random_labels = rng.integers(0, num_levels,
-                                      np.size(true_quantization))
+    random_labels = rng.integers(0, num_levels, np.size(true_quantization))
 
     # make sure there is at least one element equal to 0, 1 and num_levels-1
     random_labels[0] = 0
@@ -396,12 +414,10 @@ def test_quantize_positive_3d(rng):
     assert_raises(ValueError, em.quantize_positive_3d, input_image, 0)
     assert_raises(ValueError, em.quantize_positive_3d, input_image, 1)
 
-    out, levels, hist = em.quantize_positive_3d(np.zeros(img_shape,
-                                                         dtype=floating), 2)
+    out, levels, hist = em.quantize_positive_3d(np.zeros(img_shape, dtype=floating), 2)
     assert_equal(out, np.zeros(img_shape, dtype=np.int32))
 
-    out, levels, hist = em.quantize_positive_3d(np.ones(img_shape,
-                                                        dtype=floating), 2)
+    out, levels, hist = em.quantize_positive_3d(np.ones(img_shape, dtype=floating), 2)
     assert_equal(out, np.ones(img_shape, dtype=np.int32))
 
 
@@ -420,10 +436,10 @@ def test_compute_masked_class_stats_2d(rng):
     values *= labels
     values += labels
 
-    expected_means = [0, values[0, 0]] + \
-        [values[labels == i].mean() for i in range(2, 10)]
-    expected_vars = [np.inf, np.inf] + \
-        [values[labels == i].var() for i in range(2, 10)]
+    expected_means = [0, values[0, 0]] + [
+        values[labels == i].mean() for i in range(2, 10)
+    ]
+    expected_vars = [np.inf, np.inf] + [values[labels == i].var() for i in range(2, 10)]
 
     mask = np.ones(shape, dtype=np.int32)
     means, std_dev = em.compute_masked_class_stats_2d(mask, values, 10, labels)
@@ -443,15 +459,14 @@ def test_compute_masked_class_stats_3d(rng):
     labels[0, 0, 0] = 1
 
     # Create random values
-    values = rng.standard_normal((shape[0], shape[1],
-                                  shape[2])).astype(floating)
+    values = rng.standard_normal((shape[0], shape[1], shape[2])).astype(floating)
     values *= labels
     values += labels
 
-    expected_means = [0, values[0, 0, 0]] + \
-        [values[labels == i].mean() for i in range(2, 10)]
-    expected_vars = [np.inf, np.inf] + \
-        [values[labels == i].var() for i in range(2, 10)]
+    expected_means = [0, values[0, 0, 0]] + [
+        values[labels == i].mean() for i in range(2, 10)
+    ]
+    expected_vars = [np.inf, np.inf] + [values[labels == i].var() for i in range(2, 10)]
 
     mask = np.ones(shape, dtype=np.int32)
     means, std_dev = em.compute_masked_class_stats_3d(mask, values, 10, labels)
