@@ -1,38 +1,45 @@
-import numpy as np
-import scipy as sp
 from functools import reduce
 from operator import mul
-from dipy.core.ndindex import ndindex
-from dipy.core.interpolation import (interpolate_scalar_2d,
-                                     interpolate_scalar_3d)
-from dipy.data import get_fnames
+
+import numpy as np
+from numpy.testing import (
+    assert_almost_equal,
+    assert_array_almost_equal,
+    assert_array_equal,
+    assert_equal,
+    assert_raises,
+)
+import scipy as sp
+
 from dipy.align import vector_fields as vf
+from dipy.align.parzenhist import (
+    ParzenJointHistogram,
+    cubic_spline,
+    cubic_spline_derivative,
+    sample_domain_regular,
+)
 from dipy.align.transforms import regtransforms
-from dipy.align.parzenhist import (ParzenJointHistogram,
-                                   cubic_spline,
-                                   cubic_spline_derivative,
-                                   sample_domain_regular)
-from numpy.testing import (assert_array_equal,
-                           assert_array_almost_equal,
-                           assert_almost_equal,
-                           assert_equal,
-                           assert_raises)
+from dipy.core.interpolation import interpolate_scalar_2d, interpolate_scalar_3d
+from dipy.core.ndindex import ndindex
+from dipy.data import get_fnames
 from dipy.testing.decorators import set_random_number_generator
 
-factors = {('TRANSLATION', 2): 2.0,
-           ('ROTATION', 2): 0.1,
-           ('RIGID', 2): 0.1,
-           ('SCALING', 2): 0.01,
-           ('AFFINE', 2): 0.1,
-           ('TRANSLATION', 3): 2.0,
-           ('ROTATION', 3): 0.1,
-           ('RIGID', 3): 0.1,
-           ('SCALING', 3): 0.1,
-           ('AFFINE', 3): 0.1}
+factors = {
+    ("TRANSLATION", 2): 2.0,
+    ("ROTATION", 2): 0.1,
+    ("RIGID", 2): 0.1,
+    ("SCALING", 2): 0.01,
+    ("AFFINE", 2): 0.1,
+    ("TRANSLATION", 3): 2.0,
+    ("ROTATION", 3): 0.1,
+    ("RIGID", 3): 0.1,
+    ("SCALING", 3): 0.1,
+    ("AFFINE", 3): 0.1,
+}
 
 
 def create_random_image_pair(sh, nvals, rng=None):
-    r""" Create a pair of images with an arbitrary, non-uniform joint PDF
+    r"""Create a pair of images with an arbitrary, non-uniform joint PDF
 
     Parameters
     ----------
@@ -86,7 +93,7 @@ def test_cubic_spline():
             absx = np.abs(x)
             sqrx = x * x
             if absx < 1:
-                expected.append((4.0 - 6 * sqrx + 3.0 * (absx ** 3)) / 6.0)
+                expected.append((4.0 - 6 * sqrx + 3.0 * (absx**3)) / 6.0)
             elif absx < 2:
                 expected.append(((2 - absx) ** 3) / 6.0)
             else:
@@ -130,17 +137,17 @@ def test_parzen_joint_histogram():
                 P = ParzenJointHistogram(nbins)
                 # Make a pair of 4-pixel images, introduce +/- 1 values
                 # that will be excluded using a mask
-                static = np.array([min_int - 1.0, min_int,
-                                   max_int, max_int + 1.0])
+                static = np.array([min_int - 1.0, min_int, max_int, max_int + 1.0])
                 # Multiply by an arbitrary value (make the ranges different)
-                moving = fact * np.array([min_int, min_int - 1.0,
-                                          max_int + 1.0, max_int])
+                moving = fact * np.array(
+                    [min_int, min_int - 1.0, max_int + 1.0, max_int]
+                )
                 # Create a mask to exclude the invalid values (beyond min and
                 # max computed above)
                 static_mask = np.array([0, 1, 1, 0])
                 moving_mask = np.array([1, 0, 0, 1])
 
-                P.setup(static, moving, static_mask, moving_mask)
+                P.setup(static, moving, smask=static_mask, mmask=moving_mask)
 
                 # Test bin_normalize_static at the boundary
                 normalized = P.bin_normalize_static(min_int)
@@ -166,13 +173,13 @@ def test_parzen_joint_histogram():
                 delta_s = (max_int - min_int) / (nbins - 2 * P.padding)
                 delta_m = fact * (max_int - min_int) / (nbins - 2 * P.padding)
                 for i in range(nbins - 2 * P.padding):
-                    normalized = P.bin_normalize_static(min_int +
-                                                        (i + 0.5) * delta_s)
+                    normalized = P.bin_normalize_static(min_int + (i + 0.5) * delta_s)
                     index = P.bin_index(normalized)
                     assert_equal(index, P.padding + i)
 
-                    normalized = P.bin_normalize_moving(fact * min_int +
-                                                        (i + 0.5) * delta_m)
+                    normalized = P.bin_normalize_moving(
+                        fact * min_int + (i + 0.5) * delta_m
+                    )
                     index = P.bin_index(normalized)
                     assert_equal(index, P.padding + i)
 
@@ -245,24 +252,20 @@ def test_parzen_densities(rng):
         expected_mmarginal_dense /= expected_mmarginal_dense.sum()
         expected_mmarginal_sparse = expected_joint_sparse.sum(0)
         expected_mmarginal_sparse /= expected_mmarginal_sparse.sum()
-        assert_array_almost_equal(actual_mmarginal_dense,
-                                  expected_mmarginal_dense)
-        assert_array_almost_equal(actual_mmarginal_sparse,
-                                  expected_mmarginal_sparse)
+        assert_array_almost_equal(actual_mmarginal_dense, expected_mmarginal_dense)
+        assert_array_almost_equal(actual_mmarginal_sparse, expected_mmarginal_sparse)
 
         # Verify static marginals
         expected_smarginal_dense = expected_joint_dense.sum(1)
         expected_smarginal_dense /= expected_smarginal_dense.sum()
         expected_smarginal_sparse = expected_joint_sparse.sum(1)
         expected_smarginal_sparse /= expected_smarginal_sparse.sum()
-        assert_array_almost_equal(actual_smarginal_dense,
-                                  expected_smarginal_dense)
-        assert_array_almost_equal(actual_smarginal_sparse,
-                                  expected_smarginal_sparse)
+        assert_array_almost_equal(actual_smarginal_dense, expected_smarginal_dense)
+        assert_array_almost_equal(actual_smarginal_sparse, expected_smarginal_sparse)
 
 
 def setup_random_transform(transform, rfactor, nslices=45, sigma=1, rng=None):
-    r""" Creates a pair of images related to each other by an affine transform
+    r"""Creates a pair of images related to each other by an affine transform
 
     We transform the static image with a random transform so that the
     returned ground-truth transform will produce the static image
@@ -292,7 +295,7 @@ def setup_random_transform(transform, rfactor, nslices=45, sigma=1, rng=None):
         raise ValueError("Transform and requested volume have different dims.")
     zero_slices = nslices // 3
 
-    fname = get_fnames('t1_coronal_slice')
+    fname = get_fnames(name="t1_coronal_slice")
     moving_slice = np.load(fname)
     moving_slice = moving_slice[40:180, 50:210]
 
@@ -304,7 +307,7 @@ def setup_random_transform(transform, rfactor, nslices=45, sigma=1, rng=None):
         dim = 3
         transform_method = vf.transform_3d_affine
         moving = np.zeros(shape=moving_slice.shape + (nslices,))
-        moving[..., zero_slices:(2 * zero_slices)] = moving_slice[..., None]
+        moving[..., zero_slices : (2 * zero_slices)] = moving_slice[..., None]
 
     moving = sp.ndimage.gaussian_filter(moving, sigma)
 
@@ -318,7 +321,7 @@ def setup_random_transform(transform, rfactor, nslices=45, sigma=1, rng=None):
 
     M = transform.param_to_matrix(theta)
     shape = np.array(moving.shape, dtype=np.int32)
-    static = np.array(transform_method(moving.astype(np.float32), shape, M))
+    static = np.array(transform_method(moving.astype(np.float32), shape, affine=M))
     static = static.astype(np.float64)
     static_g2w = np.eye(dim + 1)
     smask = np.ones_like(static, dtype=np.int32)
@@ -361,31 +364,39 @@ def test_joint_pdf_gradients_dense(rng):
         factor = factors[ttype]
         theta = transform.get_identity_parameters()
 
-        static, moving, static_g2w, moving_g2w, smask, mmask, M = \
-            setup_random_transform(transform, factor, nslices, 5.0,
-                                   rng=rng)
+        static, moving, static_g2w, moving_g2w, smask, mmask, M = (
+            setup_random_transform(transform, factor, nslices, 5.0, rng=rng)
+        )
         parzen_hist = ParzenJointHistogram(32)
-        parzen_hist.setup(static, moving, smask, mmask)
+        parzen_hist.setup(static, moving, smask=smask, mmask=mmask)
 
         # Compute the gradient at theta with the implementation under test
         M = transform.param_to_matrix(theta)
         shape = np.array(static.shape, dtype=np.int32)
 
-        moved = transform_method(moving.astype(np.float32), shape, M)
+        moved = transform_method(moving.astype(np.float32), shape, affine=M)
         moved = np.array(moved)
-        parzen_hist.update_pdfs_dense(static.astype(np.float64),
-                                      moved.astype(np.float64))
+        parzen_hist.update_pdfs_dense(
+            static.astype(np.float64), moved.astype(np.float64)
+        )
         # Get the joint distribution evaluated at theta
         J0 = np.copy(parzen_hist.joint)
         grid_to_space = np.eye(dim + 1)
         spacing = np.ones(dim, dtype=np.float64)
-        mgrad, inside = vf.gradient(moving.astype(np.float32), moving_g2w,
-                                    spacing, shape, grid_to_space)
+        mgrad, inside = vf.gradient(
+            moving.astype(np.float32), moving_g2w, spacing, shape, grid_to_space
+        )
         params = transform.get_identity_parameters()
         parzen_hist.update_gradient_dense(
-            params, transform, static.astype(np.float64),
-            moved.astype(np.float64), grid_to_space,
-            mgrad, smask, mmask)
+            params,
+            transform,
+            static.astype(np.float64),
+            moved.astype(np.float64),
+            grid_to_space,
+            mgrad,
+            smask=smask,
+            mmask=mmask,
+        )
         actual = np.copy(parzen_hist.joint_grad)
         # Now we have the gradient of the joint distribution w.r.t. the
         # transform parameters
@@ -399,29 +410,30 @@ def test_joint_pdf_gradients_dense(rng):
             # Update the joint distribution with the transformed moving image
             M = transform.param_to_matrix(dtheta)
             shape = np.array(static.shape, dtype=np.int32)
-            moved = transform_method(moving.astype(np.float32), shape, M)
+            moved = transform_method(moving.astype(np.float32), shape, affine=M)
             moved = np.array(moved)
-            parzen_hist.update_pdfs_dense(static.astype(np.float64),
-                                          moved.astype(np.float64))
+            parzen_hist.update_pdfs_dense(
+                static.astype(np.float64), moved.astype(np.float64)
+            )
             J1 = np.copy(parzen_hist.joint)
             expected[..., i] = (J1 - J0) / h
 
         # Dot product and norms of gradients of each joint histogram cell
         # i.e. the derivatives of each cell w.r.t. all parameters
         P = (expected * actual).sum(2)
-        enorms = np.sqrt((expected ** 2).sum(2))
-        anorms = np.sqrt((actual ** 2).sum(2))
+        enorms = np.sqrt((expected**2).sum(2))
+        anorms = np.sqrt((actual**2).sum(2))
         prodnorms = enorms * anorms
         # Cosine of angle between the expected and actual gradients.
         # Exclude very small gradients
-        P[prodnorms > 1e-6] /= (prodnorms[prodnorms > 1e-6])
+        P[prodnorms > 1e-6] /= prodnorms[prodnorms > 1e-6]
         P[prodnorms <= 1e-6] = 0
         # Verify that a large proportion of the gradients point almost in
         # the same direction. Disregard very small gradients
         mean_cosine = P[P != 0].mean()
         std_cosine = P[P != 0].std()
-        assert(mean_cosine > 0.9)
-        assert(std_cosine < 0.25)
+        assert mean_cosine > 0.9
+        assert std_cosine < 0.25
 
 
 @set_random_number_generator(3147702)
@@ -447,23 +459,24 @@ def test_joint_pdf_gradients_sparse(rng):
         factor = factors[ttype]
         theta = transform.get_identity_parameters()
 
-        static, moving, static_g2w, moving_g2w, smask, mmask, M = \
-            setup_random_transform(transform, factor, nslices, 5.0,
-                                   rng=rng)
+        static, moving, static_g2w, moving_g2w, smask, mmask, M = (
+            setup_random_transform(transform, factor, nslices, 5.0, rng=rng)
+        )
         parzen_hist = ParzenJointHistogram(32)
-        parzen_hist.setup(static, moving, smask, mmask)
+        parzen_hist.setup(static, moving, smask=smask, mmask=mmask)
 
         # Sample the fixed-image domain
         k = 3
         sigma = 0.25
         shape = np.array(static.shape, dtype=np.int32)
-        samples = sample_domain_regular(k, shape, static_g2w, sigma, rng)
+        samples = sample_domain_regular(k, shape, static_g2w, sigma=sigma, rng=rng)
         samples = np.array(samples)
         samples = np.hstack((samples, np.ones(samples.shape[0])[:, None]))
         sp_to_static = np.linalg.inv(static_g2w)
         samples_static_grid = sp_to_static.dot(samples.T).T[..., :dim]
-        intensities_static, inside = interp_method(static.astype(np.float32),
-                                                   samples_static_grid)
+        intensities_static, inside = interp_method(
+            static.astype(np.float32), samples_static_grid
+        )
         # The routines in vector_fields operate, mostly, with float32 because
         # they were thought to be used for non-linear registration. We may need
         # to write some float64 counterparts for affine registration, where
@@ -474,20 +487,26 @@ def test_joint_pdf_gradients_sparse(rng):
         M = transform.param_to_matrix(theta)
         sp_to_moving = np.linalg.inv(moving_g2w).dot(M)
         samples_moving_grid = sp_to_moving.dot(samples.T).T[..., :dim]
-        intensities_moving, inside = interp_method(moving.astype(np.float32),
-                                                   samples_moving_grid)
+        intensities_moving, inside = interp_method(
+            moving.astype(np.float32), samples_moving_grid
+        )
         intensities_moving = np.array(intensities_moving, dtype=np.float64)
         parzen_hist.update_pdfs_sparse(intensities_static, intensities_moving)
         # Get the joint distribution evaluated at theta
         J0 = np.copy(parzen_hist.joint)
 
         spacing = np.ones(dim + 1, dtype=np.float64)
-        mgrad, inside = vf.sparse_gradient(moving.astype(np.float32),
-                                           sp_to_moving, spacing, samples)
+        mgrad, inside = vf.sparse_gradient(
+            moving.astype(np.float32), sp_to_moving, spacing, samples
+        )
         parzen_hist.update_gradient_sparse(
-            theta, transform, intensities_static,
-            intensities_moving, samples[..., :dim],
-            mgrad)
+            theta,
+            transform,
+            intensities_static,
+            intensities_moving,
+            samples[..., :dim],
+            mgrad,
+        )
         # Get the gradient of the joint distribution w.r.t. the transform
         # parameters
         actual = np.copy(parzen_hist.joint_grad)
@@ -502,30 +521,30 @@ def test_joint_pdf_gradients_sparse(rng):
             M = transform.param_to_matrix(dtheta)
             sp_to_moving = np.linalg.inv(moving_g2w).dot(M)
             samples_moving_grid = sp_to_moving.dot(samples.T).T
-            intensities_moving, inside = \
-                interp_method(moving.astype(np.float32), samples_moving_grid)
+            intensities_moving, inside = interp_method(
+                moving.astype(np.float32), samples_moving_grid
+            )
             intensities_moving = np.array(intensities_moving, dtype=np.float64)
-            parzen_hist.update_pdfs_sparse(
-                intensities_static, intensities_moving)
+            parzen_hist.update_pdfs_sparse(intensities_static, intensities_moving)
             J1 = np.copy(parzen_hist.joint)
             expected[..., i] = (J1 - J0) / h
 
         # Dot product and norms of gradients of each joint histogram cell
         # i.e. the derivatives of each cell w.r.t. all parameters
         P = (expected * actual).sum(2)
-        enorms = np.sqrt((expected ** 2).sum(2))
-        anorms = np.sqrt((actual ** 2).sum(2))
+        enorms = np.sqrt((expected**2).sum(2))
+        anorms = np.sqrt((actual**2).sum(2))
         prodnorms = enorms * anorms
         # Cosine of angle between the expected and actual gradients.
         # Exclude very small gradients
-        P[prodnorms > 1e-6] /= (prodnorms[prodnorms > 1e-6])
+        P[prodnorms > 1e-6] /= prodnorms[prodnorms > 1e-6]
         P[prodnorms <= 1e-6] = 0
         # Verify that a large proportion of the gradients point almost in
         # the same direction. Disregard very small gradients
         mean_cosine = P[P != 0].mean()
         std_cosine = P[P != 0].std()
-        assert(mean_cosine > 0.98)
-        assert(std_cosine < 0.16)
+        assert mean_cosine > 0.98
+        assert std_cosine < 0.16
 
 
 def test_sample_domain_regular():
@@ -538,11 +557,12 @@ def test_sample_domain_regular():
     n = shape[0] * shape[1]
     k = 2
     # Verify exception is raised with invalid affine
-    assert_raises(ValueError, sample_domain_regular, k, shape,
-                  invalid_affine, sigma)
-    samples = sample_domain_regular(k, shape, affine, sigma)
+    assert_raises(
+        ValueError, sample_domain_regular, k, shape, invalid_affine, sigma=sigma
+    )
+    samples = sample_domain_regular(k, shape, affine, sigma=sigma)
     isamples = np.array(samples, dtype=np.int32)
-    indices = (isamples[:, 0] * shape[1] + isamples[:, 1])
+    indices = isamples[:, 0] * shape[1] + isamples[:, 1]
     # Verify correct number of points sampled
     assert_array_equal(samples.shape, [n // k, dim])
     # Verify all sampled points are different
@@ -559,13 +579,16 @@ def test_sample_domain_regular():
     n = shape[0] * shape[1] * shape[2]
     k = 10
     # Verify exception is raised with invalid affine
-    assert_raises(ValueError, sample_domain_regular, k, shape,
-                  invalid_affine, sigma)
-    samples = sample_domain_regular(k, shape, affine, sigma)
+    assert_raises(
+        ValueError, sample_domain_regular, k, shape, invalid_affine, sigma=sigma
+    )
+    samples = sample_domain_regular(k, shape, affine, sigma=sigma)
     isamples = np.array(samples, dtype=np.int32)
-    indices = (isamples[:, 0] * shape[1] * shape[2] +
-               isamples[:, 1] * shape[2] +
-               isamples[:, 2])
+    indices = (
+        isamples[:, 0] * shape[1] * shape[2]
+        + isamples[:, 1] * shape[2]
+        + isamples[:, 2]
+    )
     # Verify correct number of points sampled
     assert_array_equal(samples.shape, [n // k, dim])
     # Verify all sampled points are different
@@ -588,7 +611,7 @@ def test_exceptions():
     for shape in [(5, 5), (5, 5, 5)]:
         dim = len(shape)
         grid2world = np.eye(dim + 1)
-        transform = regtransforms[('ROTATION', dim)]
+        transform = regtransforms[("ROTATION", dim)]
         theta = transform.get_identity_parameters()
         valid_img = np.empty(shape, dtype=np.float64)
         valid_grad = np.empty(shape + (dim,), dtype=np.float64)
@@ -597,18 +620,28 @@ def test_exceptions():
         invalid_grad_type = np.empty_like(valid_grad, dtype=np.int32)
         invalid_grad_dim = np.empty(shape + (dim + 1,), dtype=np.float64)
 
-        for s, m, g in [(valid_img, valid_img, invalid_grad_type),
-                        (valid_img, valid_img, invalid_grad_dim),
-                        (invalid_img, valid_img, valid_grad),
-                        (invalid_img, invalid_img, invalid_grad_type),
-                        (invalid_img, invalid_img, invalid_grad_dim)]:
-            assert_raises(ValueError, H.update_gradient_dense,
-                          theta, transform, s, m, grid2world, g)
+        for s, m, g in [
+            (valid_img, valid_img, invalid_grad_type),
+            (valid_img, valid_img, invalid_grad_dim),
+            (invalid_img, valid_img, valid_grad),
+            (invalid_img, invalid_img, invalid_grad_type),
+            (invalid_img, invalid_img, invalid_grad_dim),
+        ]:
+            assert_raises(
+                ValueError,
+                H.update_gradient_dense,
+                theta,
+                transform,
+                s,
+                m,
+                grid2world,
+                g,
+            )
 
     # Test exception from `ParzenJointHistogram.update_gradient_dense`
     nsamples = 2
     for dim in [2, 3]:
-        transform = regtransforms[('ROTATION', dim)]
+        transform = regtransforms[("ROTATION", dim)]
         theta = transform.get_identity_parameters()
         valid_vals = np.empty((nsamples,), dtype=np.float64)
         valid_grad = np.empty((nsamples, dim), dtype=np.float64)
@@ -621,15 +654,18 @@ def test_exceptions():
         invalid_points_dim = np.empty((nsamples, dim + 2), dtype=np.float64)
         invalid_points_len = np.empty((nsamples + 1, dim), dtype=np.float64)
 
-        C = [(invalid_vals, valid_vals, valid_points, valid_grad),
-             (valid_vals, invalid_vals, valid_points, valid_grad),
-             (valid_vals, valid_vals, invalid_points_dim, valid_grad),
-             (valid_vals, valid_vals, invalid_points_dim, invalid_grad_dim),
-             (valid_vals, valid_vals, invalid_points_len, valid_grad),
-             (valid_vals, valid_vals, valid_points, invalid_grad_type),
-             (valid_vals, valid_vals, valid_points, invalid_grad_dim),
-             (valid_vals, valid_vals, valid_points, invalid_grad_len)]
+        C = [
+            (invalid_vals, valid_vals, valid_points, valid_grad),
+            (valid_vals, invalid_vals, valid_points, valid_grad),
+            (valid_vals, valid_vals, invalid_points_dim, valid_grad),
+            (valid_vals, valid_vals, invalid_points_dim, invalid_grad_dim),
+            (valid_vals, valid_vals, invalid_points_len, valid_grad),
+            (valid_vals, valid_vals, valid_points, invalid_grad_type),
+            (valid_vals, valid_vals, valid_points, invalid_grad_dim),
+            (valid_vals, valid_vals, valid_points, invalid_grad_len),
+        ]
 
         for s, m, p, g in C:
-            assert_raises(ValueError, H.update_gradient_sparse,
-                          theta, transform, s, m, p, g)
+            assert_raises(
+                ValueError, H.update_gradient_sparse, theta, transform, s, m, p, g
+            )
