@@ -1,11 +1,10 @@
 import numpy as np
+from numpy.testing import assert_array_almost_equal, assert_array_equal, assert_raises
 import scipy as sp
-from numpy.testing import (assert_array_equal,
-                           assert_array_almost_equal,
-                           assert_raises)
+
 from dipy.align import floating
 from dipy.align.imwarp import get_direction_and_spacings
-from dipy.align.scalespace import ScaleSpace, IsotropicScaleSpace
+from dipy.align.scalespace import IsotropicScaleSpace, ScaleSpace
 from dipy.align.tests.test_imwarp import get_synthetic_warped_circle
 from dipy.testing.decorators import set_random_number_generator
 
@@ -27,8 +26,9 @@ def test_scale_space():
                 ss = test_class(
                     original,
                     num_levels,
-                    grid2world,
-                    input_spacing)
+                    image_grid2world=grid2world,
+                    input_spacing=input_spacing,
+                )
             elif test_class is IsotropicScaleSpace:
                 factors = [4, 2, 1]
                 sigmas = [3.0, 1.0, 0.0]
@@ -36,14 +36,16 @@ def test_scale_space():
                     original,
                     factors,
                     sigmas,
-                    grid2world,
-                    input_spacing)
+                    image_grid2world=grid2world,
+                    input_spacing=input_spacing,
+                )
             for level in range(num_levels):
                 # Verify sigmas and images are consistent
                 sigmas = ss.get_sigmas(level)
                 expected = sp.ndimage.gaussian_filter(original, sigmas)
-                expected = ((expected - expected.min()) /
-                            (expected.max() - expected.min()))
+                expected = (expected - expected.min()) / (
+                    expected.max() - expected.min()
+                )
                 actual = ss.get_image(level)
                 assert_array_almost_equal(actual, expected)
 
