@@ -1,15 +1,18 @@
 import numpy as np
-from dipy.align import floating
-from dipy.align import sumsqdiff as ssd
-from numpy.testing import (assert_equal,
-                           assert_almost_equal,
-                           assert_array_almost_equal,
-                           assert_allclose)
+from numpy.testing import (
+    assert_allclose,
+    assert_almost_equal,
+    assert_array_almost_equal,
+    assert_equal,
+)
+
+from dipy.align import floating, sumsqdiff as ssd
 from dipy.testing.decorators import set_random_number_generator
 
 
-def iterate_residual_field_ssd_2d(delta_field, sigmasq_field, grad, target,
-                                  lambda_param, dfield):
+def iterate_residual_field_ssd_2d(
+    delta_field, sigmasq_field, grad, target, lambda_param, dfield
+):
     r"""
     This implementation is for testing purposes only. The problem
     with Gauss-Seidel iterations is that it depends on the order
@@ -32,7 +35,7 @@ def iterate_residual_field_ssd_2d(delta_field, sigmasq_field, grad, target,
             # some d[...] may have been previously modified
             nn = 0
             y[:] = 0
-            for (dRow, dCol) in [(-1, 0), (0, 1), (1, 0), (0, -1)]:
+            for dRow, dCol in [(-1, 0), (0, 1), (1, 0), (0, -1)]:
                 dr = r + dRow
                 if dr < 0 or dr >= nrows:
                     continue
@@ -49,7 +52,7 @@ def iterate_residual_field_ssd_2d(delta_field, sigmasq_field, grad, target,
                 A = np.outer(grad[r, c], grad[r, c]) + tau * np.eye(2)
                 det = np.linalg.det(A)
                 if det < 1e-9:
-                    nrm2 = np.sum(grad[r, c]**2)
+                    nrm2 = np.sum(grad[r, c] ** 2)
                     if nrm2 < 1e-9:
                         dfield[r, c, :] = 0
                     else:
@@ -59,8 +62,9 @@ def iterate_residual_field_ssd_2d(delta_field, sigmasq_field, grad, target,
                     dfield[r, c] = np.linalg.solve(A, y)
 
 
-def iterate_residual_field_ssd_3d(delta_field, sigmasq_field, grad, target,
-                                  lambda_param, dfield):
+def iterate_residual_field_ssd_3d(
+    delta_field, sigmasq_field, grad, target, lambda_param, dfield
+):
     r"""
     This implementation is for testing purposes only. The problem
     with Gauss-Seidel iterations is that it depends on the order
@@ -81,12 +85,17 @@ def iterate_residual_field_ssd_3d(delta_field, sigmasq_field, grad, target,
             for c in range(ncols):
                 g = grad[s, r, c]
                 # delta = delta_field[s, r, c]
-                sigmasq = sigmasq_field[
-                    s, r, c] if sigmasq_field is not None else 1
+                sigmasq = sigmasq_field[s, r, c] if sigmasq_field is not None else 1
                 nn = 0
                 y[:] = 0
-                for dSlice, dRow, dCol in [(-1, 0, 0), (0, -1, 0), (0, 0, 1),
-                                           (0, 1, 0), (0, 0, -1), (1, 0, 0)]:
+                for dSlice, dRow, dCol in [
+                    (-1, 0, 0),
+                    (0, -1, 0),
+                    (0, 0, 1),
+                    (0, 1, 0),
+                    (0, 0, -1),
+                    (1, 0, 0),
+                ]:
                     ds = s + dSlice
                     if ds < 0 or ds >= nslices:
                         continue
@@ -133,23 +142,19 @@ def test_compute_residual_displacement_field_ssd_2d(rng):
     x_0 = np.asarray(range(sh[0]))
     x_1 = np.asarray(range(sh[1]))
     X = np.ndarray(sh + (2,), dtype=np.float64)
-    O = np.ones(sh)
-    X[..., 0] = x_0[:, None] * O
-    X[..., 1] = x_1[None, :] * O
+    _O = np.ones(sh)
+    X[..., 0] = x_0[:, None] * _O
+    X[..., 1] = x_1[None, :] * _O
 
     # Compute the gradient fields of F and G
     grad_F = X - c_f
     grad_G = X - c_g
 
-    Fnoise = rng.random(
-        np.size(grad_F)).reshape(
-        grad_F.shape) * grad_F.max() * 0.1
+    Fnoise = rng.random(np.size(grad_F)).reshape(grad_F.shape) * grad_F.max() * 0.1
     Fnoise = Fnoise.astype(floating)
     grad_F += Fnoise
 
-    Gnoise = rng.random(
-        np.size(grad_G)).reshape(
-        grad_G.shape) * grad_G.max() * 0.1
+    Gnoise = rng.random(np.size(grad_G)).reshape(grad_G.shape) * grad_G.max() * 0.1
     Gnoise = Gnoise.astype(floating)
     grad_G += Gnoise
 
@@ -170,8 +175,7 @@ def test_compute_residual_displacement_field_ssd_2d(rng):
 
     delta_field = np.array(F - G, dtype=floating)
 
-    sigma_field = \
-        rng.standard_normal(delta_field.size).reshape(delta_field.shape)
+    sigma_field = rng.standard_normal(delta_field.size).reshape(delta_field.shape)
     sigma_field = sigma_field.astype(floating)
 
     # Select some pixels to force sigma_field = infinite
@@ -191,7 +195,7 @@ def test_compute_residual_displacement_field_ssd_2d(rng):
     target = None
     rtol = 1e-9
     atol = 1e-4
-    for it in range(2):
+    for _ in range(2):
         # Sum of differences with the neighbors
         s = np.zeros_like(d, dtype=np.float64)
         s[:, :-1] += d[:, :-1] - d[:, 1:]  # right
@@ -201,8 +205,7 @@ def test_compute_residual_displacement_field_ssd_2d(rng):
         s *= lambda_param
 
         # Dot product of displacement and gradient
-        dp = d[..., 0] * grad_G[..., 0] + \
-            d[..., 1] * grad_G[..., 1]
+        dp = d[..., 0] * grad_G[..., 0] + d[..., 1] * grad_G[..., 1]
         dp = dp.astype(np.float64)
 
         # Compute expected residual
@@ -214,23 +217,41 @@ def test_compute_residual_displacement_field_ssd_2d(rng):
             expected = target.copy().astype(np.float64)
 
         # Expected residuals when sigma != infinity
-        expected[inf_sigma == 0, 0] -= grad_G[inf_sigma == 0, 0] * \
-            dp[inf_sigma == 0] + sigma_field[inf_sigma == 0] * s[inf_sigma == 0, 0]
-        expected[inf_sigma == 0, 1] -= grad_G[inf_sigma == 0, 1] * \
-            dp[inf_sigma == 0] + sigma_field[inf_sigma == 0] * s[inf_sigma == 0, 1]
+        expected[inf_sigma == 0, 0] -= (
+            grad_G[inf_sigma == 0, 0] * dp[inf_sigma == 0]
+            + sigma_field[inf_sigma == 0] * s[inf_sigma == 0, 0]
+        )
+        expected[inf_sigma == 0, 1] -= (
+            grad_G[inf_sigma == 0, 1] * dp[inf_sigma == 0]
+            + sigma_field[inf_sigma == 0] * s[inf_sigma == 0, 1]
+        )
         # Expected residuals when sigma == infinity
         expected[inf_sigma == 1] = -1.0 * s[inf_sigma == 1]
 
         # Test residual field computation starting with residual = None
-        actual = iut(delta_field, sigma_field, grad_G.astype(floating),
-                     target, lambda_param, d, None)
+        actual = iut(
+            delta_field,
+            sigma_field,
+            grad_G.astype(floating),
+            target,
+            lambda_param,
+            d,
+            None,
+        )
         assert_allclose(actual, expected, rtol=rtol, atol=atol)
         # destroy previous result
         actual = np.ndarray(actual.shape, dtype=floating)
 
         # Test residual field computation starting with residual is not None
-        iut(delta_field, sigma_field, grad_G.astype(floating),
-            target, lambda_param, d, actual)
+        iut(
+            delta_field,
+            sigma_field,
+            grad_G.astype(floating),
+            target,
+            lambda_param,
+            d,
+            actual,
+        )
         assert_allclose(actual, expected, rtol=rtol, atol=atol)
 
         # Set target for next iteration
@@ -245,7 +266,8 @@ def test_compute_residual_displacement_field_ssd_2d(rng):
                 grad_G.astype(floating),
                 residual,
                 lambda_param,
-                expected)
+                expected,
+            )
 
             actual = d.copy()
             ssd.iterate_residual_displacement_field_ssd_2d(
@@ -254,7 +276,8 @@ def test_compute_residual_displacement_field_ssd_2d(rng):
                 grad_G.astype(floating),
                 residual,
                 lambda_param,
-                actual)
+                actual,
+            )
 
             assert_allclose(actual, expected, rtol=rtol, atol=atol)
 
@@ -273,24 +296,20 @@ def test_compute_residual_displacement_field_ssd_3d(rng):
     x_1 = np.asarray(range(sh[1]))
     x_2 = np.asarray(range(sh[2]))
     X = np.ndarray(sh + (3,), dtype=np.float64)
-    O = np.ones(sh)
-    X[..., 0] = x_0[:, None, None] * O
-    X[..., 1] = x_1[None, :, None] * O
-    X[..., 2] = x_2[None, None, :] * O
+    _O = np.ones(sh)
+    X[..., 0] = x_0[:, None, None] * _O
+    X[..., 1] = x_1[None, :, None] * _O
+    X[..., 2] = x_2[None, None, :] * _O
 
     # Compute the gradient fields of F and G
     grad_F = X - c_f
     grad_G = X - c_g
 
-    Fnoise = rng.random(
-        np.size(grad_F)).reshape(
-        grad_F.shape) * grad_F.max() * 0.1
+    Fnoise = rng.random(np.size(grad_F)).reshape(grad_F.shape) * grad_F.max() * 0.1
     Fnoise = Fnoise.astype(floating)
     grad_F += Fnoise
 
-    Gnoise = rng.random(
-        np.size(grad_G)).reshape(
-        grad_G.shape) * grad_G.max() * 0.1
+    Gnoise = rng.random(np.size(grad_G)).reshape(grad_G.shape) * grad_G.max() * 0.1
     Gnoise = Gnoise.astype(floating)
     grad_G += Gnoise
 
@@ -331,7 +350,7 @@ def test_compute_residual_displacement_field_ssd_3d(rng):
     target = None
     rtol = 1e-9
     atol = 1e-4
-    for it in range(2):
+    for _ in range(2):
         # Sum of differences with the neighbors
         s = np.zeros_like(d, dtype=np.float64)
         s[:, :, :-1] += d[:, :, :-1] - d[:, :, 1:]  # right
@@ -343,9 +362,11 @@ def test_compute_residual_displacement_field_ssd_3d(rng):
         s *= lambda_param
 
         # Dot product of displacement and gradient
-        dp = d[..., 0] * grad_G[..., 0] + \
-            d[..., 1] * grad_G[..., 1] + \
-            d[..., 2] * grad_G[..., 2]
+        dp = (
+            d[..., 0] * grad_G[..., 0]
+            + d[..., 1] * grad_G[..., 1]
+            + d[..., 2] * grad_G[..., 2]
+        )
 
         # Compute expected residual
         if target is None:
@@ -357,21 +378,37 @@ def test_compute_residual_displacement_field_ssd_3d(rng):
 
         # Expected residuals when sigma != infinity
         for i in range(3):
-            expected[inf_sigma == 0, i] -= grad_G[inf_sigma == 0, i] * \
-                dp[inf_sigma == 0] + sigma_field[inf_sigma == 0] * s[inf_sigma == 0, i]
+            expected[inf_sigma == 0, i] -= (
+                grad_G[inf_sigma == 0, i] * dp[inf_sigma == 0]
+                + sigma_field[inf_sigma == 0] * s[inf_sigma == 0, i]
+            )
         # Expected residuals when sigma == infinity
         expected[inf_sigma == 1] = -1.0 * s[inf_sigma == 1]
 
         # Test residual field computation starting with residual = None
-        actual = iut(delta_field, sigma_field, grad_G.astype(floating),
-                     target, lambda_param, d, None)
+        actual = iut(
+            delta_field,
+            sigma_field,
+            grad_G.astype(floating),
+            target,
+            lambda_param,
+            d,
+            None,
+        )
         assert_allclose(actual, expected, rtol=rtol, atol=atol)
         # destroy previous result
         actual = np.ndarray(actual.shape, dtype=floating)
 
         # Test residual field computation starting with residual is not None
-        iut(delta_field, sigma_field, grad_G.astype(floating),
-            target, lambda_param, d, actual)
+        iut(
+            delta_field,
+            sigma_field,
+            grad_G.astype(floating),
+            target,
+            lambda_param,
+            d,
+            actual,
+        )
         assert_allclose(actual, expected, rtol=rtol, atol=atol)
 
         # Set target for next iteration
@@ -386,7 +423,8 @@ def test_compute_residual_displacement_field_ssd_3d(rng):
                 grad_G.astype(floating),
                 residual,
                 lambda_param,
-                expected)
+                expected,
+            )
 
             actual = d.copy()
             ssd.iterate_residual_displacement_field_ssd_3d(
@@ -395,7 +433,8 @@ def test_compute_residual_displacement_field_ssd_3d(rng):
                 grad_G.astype(floating),
                 residual,
                 lambda_param,
-                actual)
+                actual,
+            )
 
             # the numpy linear solver may differ from our custom implementation
             # we need to increase the tolerance a bit
@@ -404,10 +443,12 @@ def test_compute_residual_displacement_field_ssd_3d(rng):
 
 def test_solve_2d_symmetric_positive_definite():
     # Select some arbitrary right-hand sides
-    bs = [np.array([1.1, 2.2]),
-          np.array([1e-2, 3e-3]),
-          np.array([1e2, 1e3]),
-          np.array([1e-5, 1e5])]
+    bs = [
+        np.array([1.1, 2.2]),
+        np.array([1e-2, 3e-3]),
+        np.array([1e2, 1e3]),
+        np.array([1e-5, 1e5]),
+    ]
 
     # Select arbitrary symmetric positive-definite matrices
     As = []
@@ -435,10 +476,12 @@ def test_solve_2d_symmetric_positive_definite():
 
 def test_solve_3d_symmetric_positive_definite():
     # Select some arbitrary right-hand sides
-    bs = [np.array([1.1, 2.2, 3.3]),
-          np.array([1e-2, 3e-3, 2e-2]),
-          np.array([1e2, 1e3, 5e-2]),
-          np.array([1e-5, 1e5, 1.0])]
+    bs = [
+        np.array([1.1, 2.2, 3.3]),
+        np.array([1e-2, 3e-3, 2e-2]),
+        np.array([1e2, 1e3, 5e-2]),
+        np.array([1e-5, 1e5, 1.0]),
+    ]
 
     # Select arbitrary taus
     taus = [0.0, 1.0, 1e-4, 1e5]
@@ -466,7 +509,8 @@ def test_solve_3d_symmetric_positive_definite():
             AA = A + tau * np.eye(3)
             for b in bs:
                 actual, is_singular = ssd.solve_3d_symmetric_positive_definite(
-                    g, b, tau)
+                    g, b, tau
+                )
                 if tau == 0.0:
                     assert_equal(is_singular, 1)
                 else:
@@ -485,9 +529,9 @@ def test_compute_energy_ssd_2d():
     x_0 = np.asarray(range(sh[0]))
     x_1 = np.asarray(range(sh[1]))
     X = np.ndarray(sh + (2,), dtype=np.float64)
-    O = np.ones(sh)
-    X[..., 0] = x_0[:, None] * O
-    X[..., 1] = x_1[None, :] * O
+    _O = np.ones(sh)
+    X[..., 0] = x_0[:, None] * _O
+    X[..., 1] = x_1[None, :] * _O
 
     # Compute the gradient fields of F and G
     grad_F = X - c_f
@@ -502,7 +546,7 @@ def test_compute_energy_ssd_2d():
     # consider the data term, which is not the objective function
     # being optimized). This test case should be updated after
     # further investigation
-    expected = ((F - G)**2).sum()
+    expected = ((F - G) ** 2).sum()
     actual = ssd.compute_energy_ssd_2d(np.array(F - G, dtype=floating))
     assert_almost_equal(expected, actual)
 
@@ -519,10 +563,10 @@ def test_compute_energy_ssd_3d():
     x_1 = np.asarray(range(sh[1]))
     x_2 = np.asarray(range(sh[2]))
     X = np.ndarray(sh + (3,), dtype=np.float64)
-    O = np.ones(sh)
-    X[..., 0] = x_0[:, None, None] * O
-    X[..., 1] = x_1[None, :, None] * O
-    X[..., 2] = x_2[None, None, :] * O
+    _O = np.ones(sh)
+    X[..., 0] = x_0[:, None, None] * _O
+    X[..., 1] = x_1[None, :, None] * _O
+    X[..., 2] = x_2[None, None, :] * _O
 
     # Compute the gradient fields of F and G
     grad_F = X - c_f
@@ -537,7 +581,7 @@ def test_compute_energy_ssd_3d():
     # consider the data term, which is not the objective function
     # being optimized). This test case should be updated after
     # further investigating
-    expected = ((F - G)**2).sum()
+    expected = ((F - G) ** 2).sum()
     actual = ssd.compute_energy_ssd_3d(np.array(F - G, dtype=floating))
     assert_almost_equal(expected, actual)
 
@@ -568,23 +612,19 @@ def test_compute_ssd_demons_step_2d(rng):
     x_0 = np.asarray(range(sh[0]))
     x_1 = np.asarray(range(sh[1]))
     X = np.ndarray(sh + (2,), dtype=np.float64)
-    O = np.ones(sh)
-    X[..., 0] = x_0[:, None] * O
-    X[..., 1] = x_1[None, :] * O
+    _O = np.ones(sh)
+    X[..., 0] = x_0[:, None] * _O
+    X[..., 1] = x_1[None, :] * _O
 
     # Compute the gradient fields of F and G
     grad_F = X - c_f
     grad_G = X - c_g
 
-    Fnoise = rng.random(
-        np.size(grad_F)).reshape(
-        grad_F.shape) * grad_F.max() * 0.1
+    Fnoise = rng.random(np.size(grad_F)).reshape(grad_F.shape) * grad_F.max() * 0.1
     Fnoise = Fnoise.astype(floating)
     grad_F += Fnoise
 
-    Gnoise = rng.random(
-        np.size(grad_G)).reshape(
-        grad_G.shape) * grad_G.max() * 0.1
+    Gnoise = rng.random(np.size(grad_G)).reshape(grad_G.shape) * grad_G.max() * 0.1
     Gnoise = Gnoise.astype(floating)
     grad_G += Gnoise
 
@@ -617,7 +657,7 @@ def test_compute_ssd_demons_step_2d(rng):
     # Set arbitrary values for $\sigma_i$ (eq. 4 in [Vercauteren09])
     # The original Demons algorithm used simply |F(x) - G(x)| as an
     # estimator, so let's use it as well
-    sigma_i_sq = (F - G)**2
+    sigma_i_sq = (F - G) ** 2
 
     # Now select arbitrary parameters for $\sigma_x$ (eq 4 in [Vercauteren09])
     for sigma_x_sq in [0.01, 1.5, 4.2]:
@@ -626,7 +666,7 @@ def test_compute_ssd_demons_step_2d(rng):
         num = (sigma_x_sq * (F - G))[random_labels == 1]
         den = (sigma_x_sq * sq_norm_grad_G + sigma_i_sq)[random_labels == 1]
         # This is $J^{P}$ in eq. 4 [Vercauteren09]
-        expected = (-1 * np.array(grad_G))
+        expected = -1 * np.array(grad_G)
         expected[random_labels == 1, 0] *= num / den
         expected[random_labels == 1, 1] *= num / den
         expected[random_labels == 0, ...] = 0
@@ -634,10 +674,9 @@ def test_compute_ssd_demons_step_2d(rng):
         # Now compute it using the implementation under test
         actual = np.empty_like(expected, dtype=floating)
 
-        ssd.compute_ssd_demons_step_2d(delta_field,
-                                       np.array(grad_G, dtype=floating),
-                                       sigma_x_sq,
-                                       actual)
+        ssd.compute_ssd_demons_step_2d(
+            delta_field, np.array(grad_G, dtype=floating), sigma_x_sq, actual
+        )
 
         assert_array_almost_equal(actual, expected)
 
@@ -670,24 +709,20 @@ def test_compute_ssd_demons_step_3d(rng):
     x_1 = np.asarray(range(sh[1]))
     x_2 = np.asarray(range(sh[2]))
     X = np.ndarray(sh + (3,), dtype=np.float64)
-    O = np.ones(sh)
-    X[..., 0] = x_0[:, None, None] * O
-    X[..., 1] = x_1[None, :, None] * O
-    X[..., 2] = x_2[None, None, :] * O
+    _O = np.ones(sh)
+    X[..., 0] = x_0[:, None, None] * _O
+    X[..., 1] = x_1[None, :, None] * _O
+    X[..., 2] = x_2[None, None, :] * _O
 
     # Compute the gradient fields of F and G
     grad_F = X - c_f
     grad_G = X - c_g
 
-    Fnoise = rng.random(
-        np.size(grad_F)).reshape(
-        grad_F.shape) * grad_F.max() * 0.1
+    Fnoise = rng.random(np.size(grad_F)).reshape(grad_F.shape) * grad_F.max() * 0.1
     Fnoise = Fnoise.astype(floating)
     grad_F += Fnoise
 
-    Gnoise = rng.random(
-        np.size(grad_G)).reshape(
-        grad_G.shape) * grad_G.max() * 0.1
+    Gnoise = rng.random(np.size(grad_G)).reshape(grad_G.shape) * grad_G.max() * 0.1
     Gnoise = Gnoise.astype(floating)
     grad_G += Gnoise
 
@@ -720,7 +755,7 @@ def test_compute_ssd_demons_step_3d(rng):
     # Set arbitrary values for $\sigma_i$ (eq. 4 in [Vercauteren09])
     # The original Demons algorithm used simply |F(x) - G(x)| as an
     # estimator, so let's use it as well
-    sigma_i_sq = (F - G)**2
+    sigma_i_sq = (F - G) ** 2
 
     # Now select arbitrary parameters for $\sigma_x$ (eq 4 in [Vercauteren09])
     for sigma_x_sq in [0.01, 1.5, 4.2]:
@@ -729,7 +764,7 @@ def test_compute_ssd_demons_step_3d(rng):
         num = (sigma_x_sq * (F - G))[random_labels == 1]
         den = (sigma_x_sq * sq_norm_grad_G + sigma_i_sq)[random_labels == 1]
         # This is $J^{P}$ in eq. 4 [Vercauteren09]
-        expected = (-1 * np.array(grad_G))
+        expected = -1 * np.array(grad_G)
         expected[random_labels == 1, 0] *= num / den
         expected[random_labels == 1, 1] *= num / den
         expected[random_labels == 1, 2] *= num / den
@@ -738,9 +773,8 @@ def test_compute_ssd_demons_step_3d(rng):
         # Now compute it using the implementation under test
         actual = np.empty_like(expected, dtype=floating)
 
-        ssd.compute_ssd_demons_step_3d(delta_field,
-                                       np.array(grad_G, dtype=floating),
-                                       sigma_x_sq,
-                                       actual)
+        ssd.compute_ssd_demons_step_3d(
+            delta_field, np.array(grad_G, dtype=floating), sigma_x_sq, actual
+        )
 
         assert_array_almost_equal(actual, expected)
