@@ -1,39 +1,41 @@
 import numpy as np
-from numpy.testing import (assert_array_equal,
-                           assert_array_almost_equal,
-                           assert_equal,
-                           assert_raises)
+from numpy.testing import (
+    assert_array_almost_equal,
+    assert_array_equal,
+    assert_equal,
+    assert_raises,
+)
 
-from dipy.align.transforms import regtransforms, Transform
+from dipy.align.transforms import Transform, regtransforms
 from dipy.testing.decorators import set_random_number_generator
 
 
 def test_number_of_parameters():
-    expected_params = {('TRANSLATION', 2): 2,
-                       ('TRANSLATION', 3): 3,
-                       ('ROTATION', 2): 1,
-                       ('ROTATION', 3): 3,
-                       ('RIGID', 2): 3,
-                       ('RIGID', 3): 6,
-                       ('SCALING', 2): 1,
-                       ('SCALING', 3): 1,
-                       ('AFFINE', 2): 6,
-                       ('AFFINE', 3): 12,
-                       ('RIGIDSCALING', 2): 5,
-                       ('RIGIDSCALING', 3): 9,
-                       ('RIGIDISOSCALING', 2): 4,
-                       ('RIGIDISOSCALING', 3): 7}
+    expected_params = {
+        ("TRANSLATION", 2): 2,
+        ("TRANSLATION", 3): 3,
+        ("ROTATION", 2): 1,
+        ("ROTATION", 3): 3,
+        ("RIGID", 2): 3,
+        ("RIGID", 3): 6,
+        ("SCALING", 2): 1,
+        ("SCALING", 3): 1,
+        ("AFFINE", 2): 6,
+        ("AFFINE", 3): 12,
+        ("RIGIDSCALING", 2): 5,
+        ("RIGIDSCALING", 3): 9,
+        ("RIGIDISOSCALING", 2): 4,
+        ("RIGIDISOSCALING", 3): 7,
+    }
 
     for ttype, transform in regtransforms.items():
-        assert_equal(
-            transform.get_number_of_parameters(),
-            expected_params[ttype])
+        assert_equal(transform.get_number_of_parameters(), expected_params[ttype])
 
 
 @set_random_number_generator()
 def test_param_to_matrix_2d(rng):
     # Test translation matrix 2D
-    transform = regtransforms[('TRANSLATION', 2)]
+    transform = regtransforms[("TRANSLATION", 2)]
     dx, dy = rng.uniform(size=(2,))
     theta = np.array([dx, dy])
     expected = np.array([[1, 0, dx], [0, 1, dy], [0, 0, 1]])
@@ -41,7 +43,7 @@ def test_param_to_matrix_2d(rng):
     assert_array_equal(actual, expected)
 
     # Test rotation matrix 2D
-    transform = regtransforms[('ROTATION', 2)]
+    transform = regtransforms[("ROTATION", 2)]
     angle = rng.uniform()
     theta = np.array([angle])
     ct = np.cos(angle)
@@ -51,7 +53,7 @@ def test_param_to_matrix_2d(rng):
     assert_array_almost_equal(actual, expected)
 
     # Test rigid matrix 2D
-    transform = regtransforms[('RIGID', 2)]
+    transform = regtransforms[("RIGID", 2)]
     angle, dx, dy = rng.uniform(size=(3,))
     theta = np.array([angle, dx, dy])
     ct = np.cos(angle)
@@ -61,7 +63,7 @@ def test_param_to_matrix_2d(rng):
     assert_array_almost_equal(actual, expected)
 
     # Test scaling matrix 2D
-    transform = regtransforms[('SCALING', 2)]
+    transform = regtransforms[("SCALING", 2)]
     factor = rng.uniform()
     theta = np.array([factor])
     expected = np.array([[factor, 0, 0], [0, factor, 0], [0, 0, 1]])
@@ -69,31 +71,29 @@ def test_param_to_matrix_2d(rng):
     assert_array_almost_equal(actual, expected)
 
     # Test rigid isoscaling matrix 2D
-    transform = regtransforms[('RIGIDISOSCALING', 2)]
+    transform = regtransforms[("RIGIDISOSCALING", 2)]
     angle, dx, dy, factor = rng.uniform(size=(4,))
     theta = np.array([angle, dx, dy, factor])
     ct = np.cos(angle)
     st = np.sin(angle)
-    expected = np.array([[ct*factor, -st*factor, dx],
-                         [st*factor, ct*factor, dy],
-                         [0, 0, 1]])
+    expected = np.array(
+        [[ct * factor, -st * factor, dx], [st * factor, ct * factor, dy], [0, 0, 1]]
+    )
     actual = transform.param_to_matrix(theta)
     assert_array_almost_equal(actual, expected)
 
     # Test rigid scaling matrix 2D
-    transform = regtransforms[('RIGIDSCALING', 2)]
+    transform = regtransforms[("RIGIDSCALING", 2)]
     angle, dx, dy, sx, sy = rng.uniform(size=(5,))
     theta = np.array([angle, dx, dy, sx, sy])
     ct = np.cos(angle)
     st = np.sin(angle)
-    expected = np.array([[ct*sx, -st*sx, dx],
-                         [st*sy, ct*sy, dy],
-                         [0, 0, 1]])
+    expected = np.array([[ct * sx, -st * sx, dx], [st * sy, ct * sy, dy], [0, 0, 1]])
     actual = transform.param_to_matrix(theta)
     assert_array_almost_equal(actual, expected)
 
     # Test affine 2D
-    transform = regtransforms[('AFFINE', 2)]
+    transform = regtransforms[("AFFINE", 2)]
     theta = rng.uniform(size=(6,))
     expected = np.eye(3)
     expected[0, :] = theta[:3]
@@ -112,13 +112,10 @@ def test_param_to_matrix_2d(rng):
 @set_random_number_generator()
 def test_param_to_matrix_3d(rng):
     # Test translation matrix 3D
-    transform = regtransforms[('TRANSLATION', 3)]
+    transform = regtransforms[("TRANSLATION", 3)]
     dx, dy, dz = rng.uniform(size=(3,))
     theta = np.array([dx, dy, dz])
-    expected = np.array([[1, 0, 0, dx],
-                         [0, 1, 0, dy],
-                         [0, 0, 1, dz],
-                         [0, 0, 0, 1]])
+    expected = np.array([[1, 0, 0, dx], [0, 1, 0, dy], [0, 0, 1, dz], [0, 0, 0, 1]])
     actual = transform.param_to_matrix(theta)
     assert_array_equal(actual, expected)
 
@@ -131,20 +128,14 @@ def test_param_to_matrix_3d(rng):
         cc = np.cos(gamma)
         sc = np.sin(gamma)
 
-        X = np.array([[1, 0, 0],
-                      [0, ca, -sa],
-                      [0, sa, ca]])
-        Y = np.array([[cb, 0, sb],
-                      [0, 1, 0],
-                      [-sb, 0, cb]])
-        Z = np.array([[cc, -sc, 0],
-                      [sc, cc, 0],
-                      [0, 0, 1]])
+        X = np.array([[1, 0, 0], [0, ca, -sa], [0, sa, ca]])
+        Y = np.array([[cb, 0, sb], [0, 1, 0], [-sb, 0, cb]])
+        Z = np.array([[cc, -sc, 0], [sc, cc, 0], [0, 0, 1]])
 
         return Z.dot(X.dot(Y))  # Apply in order: Y, X, Z (Y goes to the right)
 
     # Test rotation matrix 3D
-    transform = regtransforms[('ROTATION', 3)]
+    transform = regtransforms[("ROTATION", 3)]
     theta = rng.uniform(size=(3,))
     R = get_rotation_matrix(theta[0], theta[1], theta[2])
     expected = np.eye(4)
@@ -153,7 +144,7 @@ def test_param_to_matrix_3d(rng):
     assert_array_almost_equal(actual, expected)
 
     # Test rigid matrix 3D
-    transform = regtransforms[('RIGID', 3)]
+    transform = regtransforms[("RIGID", 3)]
     theta = rng.uniform(size=(6,))
     R = get_rotation_matrix(theta[0], theta[1], theta[2])
     expected = np.eye(4)
@@ -163,7 +154,7 @@ def test_param_to_matrix_3d(rng):
     assert_array_almost_equal(actual, expected)
 
     # Test rigid isoscaling matrix 3D
-    transform = regtransforms[('RIGIDISOSCALING', 3)]
+    transform = regtransforms[("RIGIDISOSCALING", 3)]
     theta = rng.uniform(size=(7,))
     R = get_rotation_matrix(theta[0], theta[1], theta[2])
     expected = np.eye(4)
@@ -173,7 +164,7 @@ def test_param_to_matrix_3d(rng):
     assert_array_almost_equal(actual, expected)
 
     # Test rigid scaling matrix 3D
-    transform = regtransforms[('RIGIDSCALING', 3)]
+    transform = regtransforms[("RIGIDSCALING", 3)]
     theta = rng.uniform(size=(9,))
     R = get_rotation_matrix(theta[0], theta[1], theta[2])
     expected = np.eye(4)
@@ -186,18 +177,17 @@ def test_param_to_matrix_3d(rng):
     assert_array_almost_equal(actual, expected)
 
     # Test scaling matrix 3D
-    transform = regtransforms[('SCALING', 3)]
+    transform = regtransforms[("SCALING", 3)]
     factor = rng.uniform()
     theta = np.array([factor])
-    expected = np.array([[factor, 0, 0, 0],
-                         [0, factor, 0, 0],
-                         [0, 0, factor, 0],
-                         [0, 0, 0, 1]])
+    expected = np.array(
+        [[factor, 0, 0, 0], [0, factor, 0, 0], [0, 0, factor, 0], [0, 0, 0, 1]]
+    )
     actual = transform.param_to_matrix(theta)
     assert_array_almost_equal(actual, expected)
 
     # Test affine 3D
-    transform = regtransforms[('AFFINE', 3)]
+    transform = regtransforms[("AFFINE", 3)]
     theta = rng.uniform(size=(12,))
     expected = np.eye(4)
     expected[0, :] = theta[:4]
@@ -238,7 +228,7 @@ def test_jacobian_functions(rng):
         theta = rng.uniform(size=(n,))
         T = transform.param_to_matrix(theta)
 
-        for j in range(nsamples):
+        for _ in range(nsamples):
             x = 255 * (rng.uniform(size=(dim,)) - 0.5)
             actual = transform.jacobian(theta, x)
 
