@@ -1,10 +1,13 @@
-""" Utility functions for algebra etc """
+"""Utility functions for algebra etc"""
 
 import itertools
 import math
+
 import numpy as np
 import numpy.linalg as npl
 
+from dipy.testing.decorators import warning_for_keywords
+
 # epsilon for testing whether a number is close to zero
 _EPS = np.finfo(float).eps * 4.0
 
@@ -13,20 +16,37 @@ _NEXT_AXIS = [1, 2, 0, 1]
 
 # map axes strings to/from tuples of inner axis, parity, repetition, frame
 _AXES2TUPLE = {
-    'sxyz': (0, 0, 0, 0), 'sxyx': (0, 0, 1, 0), 'sxzy': (0, 1, 0, 0),
-    'sxzx': (0, 1, 1, 0), 'syzx': (1, 0, 0, 0), 'syzy': (1, 0, 1, 0),
-    'syxz': (1, 1, 0, 0), 'syxy': (1, 1, 1, 0), 'szxy': (2, 0, 0, 0),
-    'szxz': (2, 0, 1, 0), 'szyx': (2, 1, 0, 0), 'szyz': (2, 1, 1, 0),
-    'rzyx': (0, 0, 0, 1), 'rxyx': (0, 0, 1, 1), 'ryzx': (0, 1, 0, 1),
-    'rxzx': (0, 1, 1, 1), 'rxzy': (1, 0, 0, 1), 'ryzy': (1, 0, 1, 1),
-    'rzxy': (1, 1, 0, 1), 'ryxy': (1, 1, 1, 1), 'ryxz': (2, 0, 0, 1),
-    'rzxz': (2, 0, 1, 1), 'rxyz': (2, 1, 0, 1), 'rzyz': (2, 1, 1, 1)}
+    "sxyz": (0, 0, 0, 0),
+    "sxyx": (0, 0, 1, 0),
+    "sxzy": (0, 1, 0, 0),
+    "sxzx": (0, 1, 1, 0),
+    "syzx": (1, 0, 0, 0),
+    "syzy": (1, 0, 1, 0),
+    "syxz": (1, 1, 0, 0),
+    "syxy": (1, 1, 1, 0),
+    "szxy": (2, 0, 0, 0),
+    "szxz": (2, 0, 1, 0),
+    "szyx": (2, 1, 0, 0),
+    "szyz": (2, 1, 1, 0),
+    "rzyx": (0, 0, 0, 1),
+    "rxyx": (0, 0, 1, 1),
+    "ryzx": (0, 1, 0, 1),
+    "rxzx": (0, 1, 1, 1),
+    "rxzy": (1, 0, 0, 1),
+    "ryzy": (1, 0, 1, 1),
+    "rzxy": (1, 1, 0, 1),
+    "ryxy": (1, 1, 1, 1),
+    "ryxz": (2, 0, 0, 1),
+    "rzxz": (2, 0, 1, 1),
+    "rxyz": (2, 1, 0, 1),
+    "rzyz": (2, 1, 1, 1),
+}
 
-_TUPLE2AXES = dict((v, k) for k, v in _AXES2TUPLE.items())
+_TUPLE2AXES = dict({(v, k) for k, v in _AXES2TUPLE.items()})
 
 
 def sphere2cart(r, theta, phi):
-    """ Spherical to Cartesian coordinates
+    """Spherical to Cartesian coordinates
 
     This is the standard physics convention where `theta` is the
     inclination (polar) angle, and `phi` is the azimuth angle.
@@ -100,7 +120,7 @@ def sphere2cart(r, theta, phi):
 
 
 def cart2sphere(x, y, z):
-    r""" Return angles for Cartesian 3D coordinates `x`, `y`, and `z`
+    r"""Return angles for Cartesian 3D coordinates `x`, `y`, and `z`
 
     See doc for ``sphere2cart`` for angle conventions and derivation
     of the formulae.
@@ -127,8 +147,9 @@ def cart2sphere(x, y, z):
 
     """
     r = np.sqrt(x * x + y * y + z * z)
-    theta = np.arccos(np.divide(z, r, where=r > 0))
-    theta = np.where(r > 0, theta, 0.)
+    cos = np.divide(z, r, where=r > 0)
+    theta = np.arccos(cos, where=(cos >= -1) & (cos <= 1))
+    theta = np.where(r > 0, theta, 0.0)
     phi = np.arctan2(y, x)
     r, theta, phi = np.broadcast_arrays(r, theta, phi)
     return r, theta, phi
@@ -146,8 +167,9 @@ def sph2latlon(theta, phi):
     return np.rad2deg(theta - np.pi / 2), np.rad2deg(phi - np.pi)
 
 
-def normalized_vector(vec, axis=-1):
-    """ Return vector divided by its Euclidean (L2) norm
+@warning_for_keywords()
+def normalized_vector(vec, *, axis=-1):
+    """Return vector divided by its Euclidean (L2) norm
 
     See :term:`unit vector` and :term:`Euclidean norm`
 
@@ -174,11 +196,12 @@ def normalized_vector(vec, axis=-1):
     True
 
     """
-    return vec / vector_norm(vec, axis, keepdims=True)
+    return vec / vector_norm(vec, axis=axis, keepdims=True)
 
 
-def vector_norm(vec, axis=-1, keepdims=False):
-    """ Return vector Euclidean (L2) norm
+@warning_for_keywords()
+def vector_norm(vec, *, axis=-1, keepdims=False):
+    """Return vector Euclidean (L2) norm
 
     See :term:`unit vector` and :term:`Euclidean norm`
 
@@ -224,40 +247,60 @@ def vector_norm(vec, axis=-1, keepdims=False):
 
 
 def rodrigues_axis_rotation(r, theta):
-    """ Rodrigues formula
+    r"""Rodrigues formula
 
-    Rotation matrix for rotation around axis r for angle theta.
+    Rotation matrix for rotation around axis `r` for angle `theta`.
 
     The rotation matrix is given by the Rodrigues formula:
 
-    R = Id + sin(theta)*Sn + (1-cos(theta))*Sn^2
+    .. math::
+        :nowrap:
 
-    with::
+        \mathbf{R} = \mathbf{I} + \sin(\theta)*\mathbf{S}_n +
+        (1-\cos(\theta))*\mathbf{S}_n^2
 
-             0  -nz  ny
-      Sn =   nz   0 -nx
-            -ny  nx   0
+    with:
 
-    where n = r / ||r||
+    .. math::
 
-    In case the angle ||r|| is very small, the above formula may lead
+        Sn =
+        \begin{pmatrix}
+            0 & -n{z} & n{y} \\
+            n{z} & 0 & -n{x} \\
+            -n{y} & n{x} & 0
+        \end{pmatrix}
+
+    where :math:`n = r / ||r||`
+
+    In case the angle :math:`||r||` is very small, the above formula may lead
     to numerical instabilities. We instead use a Taylor expansion
-    around theta=0:
+    around :math:`theta=0`:
 
-    R = I + sin(theta)/tetha Sr + (1-cos(theta))/teta2 Sr^2
+    .. math::
+        :nowrap:
+
+        R = I + \sin(\theta)/\theta \mathbf{S}_r +
+        (1-\cos(\theta))/\theta^2 \mathbf{S}_r^2
 
     leading to:
 
-    R = I + (1-theta2/6)*Sr + (1/2-theta2/24)*Sr^2
+    .. math::
+        :nowrap:
+
+        R = \mathbf{I} + (1-\theta^2/6)*\mathbf{S}_r +
+        (\frac{1}{2}-\theta^2/24)*\mathbf{S}_r^2
 
     Parameters
     ----------
-    r :  array_like shape (3,), axis
-    theta : float, angle in degrees
+    r :  array_like shape (3,)
+        Axis.
+    theta : float
+        Angle in degrees.
 
     Returns
     -------
-    R : array, shape (3,3), rotation matrix
+    R : array, shape (3,3)
+        Rotation matrix.
 
     Examples
     --------
@@ -275,18 +318,18 @@ def rodrigues_axis_rotation(r, theta):
     if theta > 1e-30:
         n = r / np.linalg.norm(r)
         Sn = np.array([[0, -n[2], n[1]], [n[2], 0, -n[0]], [-n[1], n[0], 0]])
-        R = np.eye(3) + np.sin(theta) * Sn + \
-            (1 - np.cos(theta)) * np.dot(Sn, Sn)
+        R = np.eye(3) + np.sin(theta) * Sn + (1 - np.cos(theta)) * np.dot(Sn, Sn)
     else:
         Sr = np.array([[0, -r[2], r[1]], [r[2], 0, -r[0]], [-r[1], r[0], 0]])
         theta2 = theta * theta
-        R = np.eye(3) + (1 - theta2 / 6.) * \
-            Sr + (.5 - theta2 / 24.) * np.dot(Sr, Sr)
+        R = np.eye(3) + (1 - theta2 / 6.0) * Sr + (0.5 - theta2 / 24.0) * np.dot(Sr, Sr)
     return R
 
 
 def nearest_pos_semi_def(B):
-    """ Least squares positive semi-definite tensor estimation
+    """Least squares positive semi-definite tensor estimation.
+
+    See :footcite:p:`Niethammer2006` for further details about the method.
 
     Parameters
     ----------
@@ -308,10 +351,7 @@ def nearest_pos_semi_def(B):
 
     References
     ----------
-    .. [1] Niethammer M, San Jose Estepar R, Bouix S, Shenton M, Westin CF.
-           On diffusion tensor estimation. Conf Proc IEEE Eng Med Biol Soc.
-           2006;1:2622-5. PubMed PMID: 17946125; PubMed Central PMCID:
-           PMC2791793.
+    .. footbibliography::
 
     """
     B = np.asarray(B)
@@ -327,7 +367,7 @@ def nearest_pos_semi_def(B):
     lam1a, lam2a, lam3a = vals
     scalers = np.zeros((3,))
     if cardneg == 2:
-        b112 = np.max([0, lam1a + (lam2a + lam3a) / 3.])
+        b112 = np.max([0, lam1a + (lam2a + lam3a) / 3.0])
         scalers[0] = b112
     elif cardneg == 1:
         lam1b = lam1a + 0.25 * lam3a
@@ -336,18 +376,19 @@ def nearest_pos_semi_def(B):
             scalers[:2] = lam1b, lam2b
         else:  # one of the lam1b, lam2b is < 0
             if lam2b < 0:
-                b111 = np.max([0, lam1a + (lam2a + lam3a) / 3.])
+                b111 = np.max([0, lam1a + (lam2a + lam3a) / 3.0])
                 scalers[0] = b111
             if lam1b < 0:
-                b221 = np.max([0, lam2a + (lam1a + lam3a) / 3.])
+                b221 = np.max([0, lam2a + (lam1a + lam3a) / 3.0])
                 scalers[1] = b221
     # resort the scalers to match the original vecs
     scalers = scalers[np.argsort(inds)]
     return np.dot(vecs, np.dot(np.diag(scalers), vecs.T))
 
 
-def sphere_distance(pts1, pts2, radius=None, check_radius=True):
-    """ Distance across sphere surface between `pts1` and `pts2`
+@warning_for_keywords()
+def sphere_distance(pts1, pts2, *, radius=None, check_radius=True):
+    """Distance across sphere surface between `pts1` and `pts2`
 
     Parameters
     ----------
@@ -386,14 +427,13 @@ def sphere_distance(pts1, pts2, radius=None, check_radius=True):
     """
     pts1 = np.asarray(pts1)
     pts2 = np.asarray(pts2)
-    lens1 = np.sqrt(np.sum(pts1 ** 2, axis=-1))
-    lens2 = np.sqrt(np.sum(pts2 ** 2, axis=-1))
+    lens1 = np.sqrt(np.sum(pts1**2, axis=-1))
+    lens2 = np.sqrt(np.sum(pts2**2, axis=-1))
     if radius is None:
         radius = (np.mean(lens1) + np.mean(lens2)) / 2.0
     if check_radius:
-        if not (np.allclose(radius, lens1) and
-                np.allclose(radius, lens2)):
-            raise ValueError('Radii do not match sphere surface')
+        if not (np.allclose(radius, lens1) and np.allclose(radius, lens2)):
+            raise ValueError("Radii do not match sphere surface")
     # Get angle with vector cosine
     dots = np.inner(pts1, pts2)
     lens = lens1 * lens2
@@ -402,7 +442,7 @@ def sphere_distance(pts1, pts2, radius=None, check_radius=True):
 
 
 def cart_distance(pts1, pts2):
-    """ Cartesian distance between `pts1` and `pts2`
+    """Cartesian distance between `pts1` and `pts2`
 
     If either of `pts1` or `pts2` is 2D, then we take the first
     dimension to index points, and the second indexes coordinate.  More
@@ -439,7 +479,7 @@ def cart_distance(pts1, pts2):
 
 
 def vector_cosine(vecs1, vecs2):
-    """ Cosine of angle between two (sets of) vectors
+    """Cosine of angle between two (sets of) vectors
 
     The cosine of the angle between two vectors ``v1`` and ``v2`` is
     given by the inner product of ``v1`` and ``v2`` divided by the
@@ -469,15 +509,15 @@ def vector_cosine(vecs1, vecs2):
     """
     vecs1 = np.asarray(vecs1)
     vecs2 = np.asarray(vecs2)
-    lens1 = np.sqrt(np.sum(vecs1 ** 2, axis=-1))
-    lens2 = np.sqrt(np.sum(vecs2 ** 2, axis=-1))
+    lens1 = np.sqrt(np.sum(vecs1**2, axis=-1))
+    lens2 = np.sqrt(np.sum(vecs2**2, axis=-1))
     dots = np.inner(vecs1, vecs2)
     lens = lens1 * lens2
     return dots / lens
 
 
 def lambert_equal_area_projection_polar(theta, phi):
-    r""" Lambert Equal Area Projection from polar sphere to plane
+    r"""Lambert Equal Area Projection from polar sphere to plane
 
     Return positions in (y1,y2) plane corresponding to the points
     with polar coordinates (theta, phi) on the unit sphere, under the
@@ -506,12 +546,15 @@ def lambert_equal_area_projection_polar(theta, phi):
        planar coordinates of points following mapping by Lambert's EAP.
     """
 
-    return 2 * np.repeat(np.sin(theta / 2), 2).reshape((theta.shape[0], 2)) * \
-        np.column_stack((np.cos(phi), np.sin(phi)))
+    return (
+        2
+        * np.repeat(np.sin(theta / 2), 2).reshape((theta.shape[0], 2))
+        * np.column_stack((np.cos(phi), np.sin(phi)))
+    )
 
 
 def lambert_equal_area_projection_cart(x, y, z):
-    r""" Lambert Equal Area Projection from cartesian vector to plane
+    r"""Lambert Equal Area Projection from cartesian vector to plane
 
     Return positions in $(y_1,y_2)$ plane corresponding to the
     directions of the vectors with cartesian coordinates xyz under the
@@ -545,7 +588,8 @@ def lambert_equal_area_projection_cart(x, y, z):
     return lambert_equal_area_projection_polar(theta, phi)
 
 
-def euler_matrix(ai, aj, ak, axes='sxyz'):
+@warning_for_keywords()
+def euler_matrix(ai, aj, ak, *, axes="sxyz"):
     """Return homogeneous rotation matrix from Euler angles and axis sequence.
 
     Code modified from the work of Christoph Gohlke, link provided here
@@ -566,17 +610,17 @@ def euler_matrix(ai, aj, ak, axes='sxyz'):
     Examples
     --------
     >>> import numpy
-    >>> R = euler_matrix(1, 2, 3, 'syxz')
+    >>> R = euler_matrix(1, 2, 3, axes='syxz')
     >>> numpy.allclose(numpy.sum(R[0]), -1.34786452)
     True
-    >>> R = euler_matrix(1, 2, 3, (0, 1, 0, 1))
+    >>> R = euler_matrix(1, 2, 3, axes=(0, 1, 0, 1))
     >>> numpy.allclose(numpy.sum(R[0]), -0.383436184)
     True
     >>> ai, aj, ak = (4.0*math.pi) * (numpy.random.random(3) - 0.5)
     >>> for axes in _AXES2TUPLE.keys():
-    ...    _ = euler_matrix(ai, aj, ak, axes)
+    ...    _ = euler_matrix(ai, aj, ak, axes=axes)
     >>> for axes in _TUPLE2AXES.keys():
-    ...    _ = euler_matrix(ai, aj, ak, axes)
+    ...    _ = euler_matrix(ai, aj, ak, axes=axes)
 
     """
     try:
@@ -622,8 +666,10 @@ def euler_matrix(ai, aj, ak, axes='sxyz'):
     return M
 
 
-def compose_matrix(scale=None, shear=None, angles=None, translate=None,
-                   perspective=None):
+@warning_for_keywords()
+def compose_matrix(
+    *, scale=None, shear=None, angles=None, translate=None, perspective=None
+):
     """Return 4x4 transformation matrix from sequence of
     transformations.
 
@@ -660,7 +706,9 @@ def compose_matrix(scale=None, shear=None, angles=None, translate=None,
     >>> angles = (np.random.random(3) - 0.5) * (2*math.pi)
     >>> trans = np.random.random(3) - 0.5
     >>> persp = np.random.random(4) - 0.5
-    >>> M0 = gm.compose_matrix(scale, shear, angles, trans, persp)
+    >>> M0 = gm.compose_matrix(
+    ...     scale=scale, shear=shear, angles=angles, translate=trans, perspective=persp
+    ... )
 
     """
     M = np.identity(4)
@@ -673,7 +721,7 @@ def compose_matrix(scale=None, shear=None, angles=None, translate=None,
         T[:3, 3] = translate[:3]
         M = np.dot(M, T)
     if angles is not None:
-        R = euler_matrix(angles[0], angles[1], angles[2], 'sxyz')
+        R = euler_matrix(angles[0], angles[1], angles[2], axes="sxyz")
         M = np.dot(M, R)
     if shear is not None:
         Z = np.identity(4)
@@ -737,7 +785,7 @@ def decompose_matrix(matrix):
     if not np.linalg.det(P):
         raise ValueError("matrix is singular")
 
-    scale = np.zeros((3, ), dtype=np.float64)
+    scale = np.zeros((3,), dtype=np.float64)
     shear = [0, 0, 0]
     angles = [0, 0, 0]
 
@@ -783,7 +831,7 @@ def decompose_matrix(matrix):
 
 
 def circumradius(a, b, c):
-    """ a, b and c are 3-dimensional vectors which are the vertices of a
+    """a, b and c are 3-dimensional vectors which are the vertices of a
     triangle. The function returns the circumradius of the triangle, i.e
     the radius of the smallest circle that can contain the triangle. In
     the degenerate case when the 3 points are collinear it returns
@@ -806,16 +854,15 @@ def circumradius(a, b, c):
     z = np.cross(x, y)
     # test for collinearity
     if np.linalg.norm(z) == 0:
-        return np.sqrt(np.max(np.dot(x, x), np.dot(y, y),
-                              np.dot(a - b, a - b))) / 2.
+        return np.sqrt(np.max(np.dot(x, x), np.dot(y, y), np.dot(a - b, a - b))) / 2.0
     else:
         m = np.vstack((x, y, z))
-        w = np.dot(np.linalg.inv(m.T), np.array([xx / 2., yy / 2., 0]))
-        return np.linalg.norm(w) / 2.
+        w = np.dot(np.linalg.inv(m.T), np.array([xx / 2.0, yy / 2.0, 0]))
+        return np.linalg.norm(w) / 2.0
 
 
 def vec2vec_rotmat(u, v):
-    r""" rotation matrix from 2 unit vectors
+    r"""rotation matrix from 2 unit vectors
 
     u, v being unit 3d vectors return a 3x3 rotation matrix R than aligns u to
     v.
@@ -869,14 +916,14 @@ def vec2vec_rotmat(u, v):
     w = w / wn
 
     # vp is in plane of u,v,  perpendicular to u
-    vp = (v - (np.dot(u, v) * u))
+    vp = v - (np.dot(u, v) * u)
     vp = vp / np.linalg.norm(vp)
 
     # (u vp w) is an orthonormal basis
     P = np.array([u, vp, w])
     Pt = P.T
     cosa = np.clip(np.dot(u, v), -1, 1)
-    sina = np.sqrt(1 - cosa ** 2)
+    sina = np.sqrt(1 - cosa**2)
     R = np.array([[cosa, -sina, 0], [sina, cosa, 0], [0, 0, 1]])
     Rp = np.dot(Pt, np.dot(R, P))
 
@@ -889,7 +936,7 @@ def vec2vec_rotmat(u, v):
 
 
 def compose_transformations(*mats):
-    """ Compose multiple 4x4 affine transformations in one 4x4 matrix
+    """Compose multiple 4x4 affine transformations in one 4x4 matrix
 
     Parameters
     ----------
@@ -906,17 +953,17 @@ def compose_transformations(*mats):
     """
     prev = mats[0]
     if len(mats) < 2:
-        raise ValueError('At least two or more matrices are needed')
+        raise ValueError("At least two or more matrices are needed")
 
     for mat in mats[1:]:
-
         prev = np.dot(mat, prev)
 
     return prev
 
 
-def perpendicular_directions(v, num=30, half=False):
-    r""" Computes n evenly spaced perpendicular directions relative to a given
+@warning_for_keywords()
+def perpendicular_directions(v, *, num=30, half=False):
+    r"""Computes n evenly spaced perpendicular directions relative to a given
     vector v
 
     Parameters
@@ -941,18 +988,19 @@ def perpendicular_directions(v, num=30, half=False):
     Perpendicular directions are estimated using the following two step
     procedure:
 
-        1) the perpendicular directions are first sampled in a unit
-        circumference parallel to the plane normal to the x-axis.
+    1) the perpendicular directions are first sampled in a unit
+       circumference parallel to the plane normal to the x-axis.
 
-        2) Samples are then rotated and aligned to the plane normal to vector
-        v. The rotational matrix for this rotation is constructed as reference
-        frame basis which axis are the following:
-            - The first axis is vector v
-            - The second axis is defined as the normalized vector given by the
-            cross product between vector v and the unit vector aligned to the
-            x-axis
-            - The third axis is defined as the cross product between the
-            previous computed vector and vector v.
+    2) Samples are then rotated and aligned to the plane normal to vector
+       v. The rotational matrix for this rotation is constructed as reference
+       frame basis which axis are the following:
+
+       - The first axis is vector v
+       - The second axis is defined as the normalized vector given by the
+         cross product between vector v and the unit vector aligned to the
+         x-axis
+       - The third axis is defined as the cross product between the
+         previous computed vector and vector v.
 
     Following this two steps, coordinates of the final perpendicular directions
     are given as:
@@ -994,22 +1042,32 @@ def perpendicular_directions(v, num=30, half=False):
 
     # Define circumference or semi-circumference
     if half is True:
-        a = np.linspace(0., math.pi, num=num, endpoint=False)
+        a = np.linspace(0.0, math.pi, num=num, endpoint=False)
     else:
-        a = np.linspace(0., 2 * math.pi, num=num, endpoint=False)
+        a = np.linspace(0.0, 2 * math.pi, num=num, endpoint=False)
 
     cosa = np.cos(a)
     sina = np.sin(a)
 
     # Check if vector is not aligned to the x axis
-    if abs(v[0] - 1.) > er:
-        sq = np.sqrt(v[1]**2 + v[2]**2)
-        psamples = np.array([- sq*sina, (v[0]*v[1]*sina - v[2]*cosa) / sq,
-                             (v[0]*v[2]*sina + v[1]*cosa) / sq])
+    if abs(v[0] - 1.0) > er:
+        sq = np.sqrt(v[1] ** 2 + v[2] ** 2)
+        psamples = np.array(
+            [
+                -sq * sina,
+                (v[0] * v[1] * sina - v[2] * cosa) / sq,
+                (v[0] * v[2] * sina + v[1] * cosa) / sq,
+            ]
+        )
     else:
-        sq = np.sqrt(v[0]**2 + v[2]**2)
-        psamples = np.array([- (v[2]*cosa + v[0]*v[1]*sina) / sq, sina*sq,
-                             (v[0]*cosa - v[2]*v[1]*sina) / sq])
+        sq = np.sqrt(v[0] ** 2 + v[2] ** 2)
+        psamples = np.array(
+            [
+                -(v[2] * cosa + v[0] * v[1] * sina) / sq,
+                sina * sq,
+                (v[0] * cosa - v[2] * v[1] * sina) / sq,
+            ]
+        )
 
     return psamples.T
 
@@ -1056,16 +1114,16 @@ def is_hemispherical(vecs):
 
     References
     ----------
-    https://rstudio-pubs-static.s3.amazonaws.com/27121_a22e51b47c544980bad594d5e0bb2d04.html  # noqa
+    https://rstudio-pubs-static.s3.amazonaws.com/27121_a22e51b47c544980bad594d5e0bb2d04.html
 
-    """
+    """  # noqa: E501
     if vecs.shape[1] != 3:
         raise ValueError("Input vectors must be 3D vectors")
     if not np.allclose(1, np.linalg.norm(vecs, axis=1)):
         raise ValueError("Input vectors must be unit vectors")
 
     # Generate all pairwise cross products
-    v0, v1 = zip(*[p for p in itertools.permutations(vecs, 2)])
+    v0, v1 = zip(*itertools.permutations(vecs, 2))
     cross_prods = np.cross(v0, v1)
 
     # Normalize them
@@ -1084,9 +1142,7 @@ def is_hemispherical(vecs):
     is_hemi = len(vecs) in np.sum(dot_prod_test.astype(int), axis=1)
 
     if is_hemi:
-        vertices = cross_prods[
-            np.sum(dot_prod_test.astype(int), axis=1) == len(vecs)
-        ]
+        vertices = cross_prods[np.sum(dot_prod_test.astype(int), axis=1) == len(vecs)]
 
         pole = np.mean(vertices, axis=0)
         pole /= np.linalg.norm(pole)
