@@ -1,8 +1,11 @@
 import numpy as np
 
+from dipy.testing.decorators import warning_for_keywords
 
-def histeq(arr, num_bins=256):
-    """ Performs an histogram equalization on ``arr``.
+
+@warning_for_keywords()
+def histeq(arr, *, num_bins=256):
+    """Performs an histogram equalization on ``arr``.
     This was taken from:
     http://www.janeriksolem.net/2009/06/histogram-equalization-with-python-and.html
 
