@@ -1,20 +1,22 @@
-""" Class for profiling cython code
-"""
+"""Class for profiling cython code"""
 
 import os
 import subprocess
 
+from dipy.testing.decorators import warning_for_keywords
 from dipy.utils.optpkg import optional_package
 
-cProfile, _, _ = optional_package('cProfile')
-pstats, _, _ = optional_package('pstats',
-                                trip_msg='pstats is not installed.  It is '
-                                'part of the python-profiler package in '
-                                'Debian/Ubuntu')
+cProfile, _, _ = optional_package("cProfile")
+pstats, _, _ = optional_package(
+    "pstats",
+    trip_msg="pstats is not installed.  It is "
+    "part of the python-profiler package in "
+    "Debian/Ubuntu",
+)
 
 
 class Profiler:
-    """ Profile python/cython files or functions
+    """Profile python/cython files or functions
 
     If you are profiling cython code you need to add
     # cython: profile=True on the top of your .pyx file
@@ -51,41 +53,43 @@ class Profiler:
 
     """
 
-    def __init__(self, call=None, *args):
+    def __init__(self, *args, call=None):
         # Delay import until use of class instance.  We were getting some very
         # odd build-as-we-go errors running tests and documentation otherwise
         import pyximport
+
         pyximport.install()
 
         try:
-
             ext = os.path.splitext(call)[1].lower()
-            print('ext', ext)
-            if ext in ('.py', '.pyx'):  # python/cython file
-                print('profiling python/cython file ...')
-                subprocess.call(['python', '-m', 'cProfile',
-                                 '-o', 'profile.prof', call])
-                s = pstats.Stats('profile.prof')
-                stats = s.strip_dirs().sort_stats('time')
+            print("ext", ext)
+            if ext in (".py", ".pyx"):  # python/cython file
+                print("profiling python/cython file ...")
+                subprocess.call(
+                    ["python3", "-m", "cProfile", "-o", "profile.prof", call]
+                )
+                s = pstats.Stats("profile.prof")
+                stats = s.strip_dirs().sort_stats("time")
                 self.stats = stats
 
         except Exception:
-
-            print('profiling function call ...')
+            print("profiling function call ...")
             self.args = args
             self.call = call
 
-            cProfile.runctx('self._profile_function()', globals(), locals(),
-                            'profile.prof')
-            s = pstats.Stats('profile.prof')
-            stats = s.strip_dirs().sort_stats('time')
+            cProfile.runctx(
+                "self._profile_function()", globals(), locals(), "profile.prof"
+            )
+            s = pstats.Stats("profile.prof")
+            stats = s.strip_dirs().sort_stats("time")
             self.stats = stats
 
     def _profile_function(self):
         self.call(*self.args)
 
-    def print_stats(self, N=10):
-        """ Print stats for profiling
+    @warning_for_keywords()
+    def print_stats(self, *, N=10):
+        """Print stats for profiling
 
         You can use it in all different ways developed in pstats
         for example
