@@ -2,19 +2,18 @@
 
 from math import floor
 from platform import architecture
+
 import numpy as np
 
+from dipy.testing.decorators import warning_for_keywords
 
-def WichmannHill2006(ix=100001, iy=200002, iz=300003, it=400004):
-    """Wichmann Hill (2006) random number generator.
 
-    B.A. Wichmann, I.D. Hill, Generating good pseudo-random numbers,
-    Computational Statistics & Data Analysis, Volume 51, Issue 3, 1
-    December 2006, Pages 1614-1622, ISSN 0167-9473, DOI:
-    10.1016/j.csda.2006.05.019.
-    (https://www.sciencedirect.com/science/article/abs/pii/S0167947306001836)
-    for advice on generating many sequences for use together, and on
-    alternative algorithms and codes
+@warning_for_keywords()
+def WichmannHill2006(*, ix=100001, iy=200002, iz=300003, it=400004):
+    """Wichmann Hill random number generator.
+
+    See :footcite:p:`Wichmann2006` for advice on generating many sequences for
+    use together, and on alternative algorithms and codes
 
     Parameters
     ----------
@@ -32,6 +31,10 @@ def WichmannHill2006(ix=100001, iy=200002, iz=300003, it=400004):
     r_number : float
         pseudo-random number uniformly distributed between [0-1]
 
+    References
+    ----------
+    .. footbibliography::
+
     Examples
     --------
     >>> from dipy.core import rng
@@ -40,10 +43,9 @@ def WichmannHill2006(ix=100001, iy=200002, iz=300003, it=400004):
 
     """
     if not ix or not iy or not iz or not it:
-        raise ValueError('A seed value can not be null.')
-
-    if architecture()[0] == '64':
+        raise ValueError("A seed value can not be null.")
 
+    if architecture()[0] == "64":
         # If 64 bits are available then the following lines of code will be
         # faster.
         ix = (11600 * ix) % 2147483579
@@ -52,7 +54,6 @@ def WichmannHill2006(ix=100001, iy=200002, iz=300003, it=400004):
         it = (33000 * it) % 2147483123
 
     else:
-
         # If only 32 bits are available
 
         ix = 11600 * (ix % 185127) - 10379 * (ix / 185127)
@@ -69,12 +70,13 @@ def WichmannHill2006(ix=100001, iy=200002, iz=300003, it=400004):
         if it < 0:
             it = it + 2147483123
 
-    W = ix/2147483579.0 + iy/2147483543.0 + iz/2147483423.0 + it/2147483123.0
+    W = ix / 2147483579.0 + iy / 2147483543.0 + iz / 2147483423.0 + it / 2147483123.0
 
     return W - floor(W)
 
 
-def WichmannHill1982(ix=100001, iy=200002, iz=300003):
+@warning_for_keywords()
+def WichmannHill1982(*, ix=100001, iy=200002, iz=300003):
     """Algorithm AS 183 Appl. Statist. (1982) vol.31, no.2.
 
     Returns a pseudo-random number rectangularly distributed
@@ -109,7 +111,7 @@ def WichmannHill1982(ix=100001, iy=200002, iz=300003):
 
     """
     if not ix or not iy or not iz:
-        raise ValueError('A seed value can not be null.')
+        raise ValueError("A seed value can not be null.")
     ix = (171 * ix) % 30269
     iy = (172 * iy) % 30307
     iz = (170 * iz) % 30323
@@ -129,11 +131,13 @@ def WichmannHill1982(ix=100001, iy=200002, iz=300003):
     if iz < 0:
         iz = iz + 30323
     """
-    return np.remainder(float(ix) / 30269. + float(iy) / 30307. +
-                        float(iz) / 30323., 1.0)
+    return np.remainder(
+        float(ix) / 30269.0 + float(iy) / 30307.0 + float(iz) / 30323.0, 1.0
+    )
 
 
-def LEcuyer(s1=100001, s2=200002):
+@warning_for_keywords()
+def LEcuyer(*, s1=100001, s2=200002):
     """Return a LEcuyer random number generator.
 
     Generate uniformly distributed random numbers using the 32-bit
@@ -164,7 +168,7 @@ def LEcuyer(s1=100001, s2=200002):
 
     """
     if not s1 or not s2:
-        raise ValueError('A seed value can not be null.')
+        raise ValueError("A seed value can not be null.")
     k = s1 / 53668
     s1 = 40014 * (s1 - k * 53668) - k * 12211
     if s1 < 0:
@@ -177,4 +181,4 @@ def LEcuyer(s1=100001, s2=200002):
     if z < 0:
         z = z + 2147483562
 
-    return z / 2147483563.
+    return z / 2147483563.0
