@@ -1,12 +1,15 @@
-""" Statistics on spheres
-"""
+"""Statistics on spheres"""
 
-import numpy as np
-import dipy.core.geometry as geometry
 from itertools import permutations
 
+import numpy as np
 
-def random_uniform_on_sphere(n=1, coords='xyz'):
+import dipy.core.geometry as geometry
+from dipy.testing.decorators import warning_for_keywords
+
+
+@warning_for_keywords()
+def random_uniform_on_sphere(*, n=1, coords="xyz"):
     r"""Random unit vectors from a uniform distribution on the sphere.
 
     Parameters
@@ -36,28 +39,29 @@ def random_uniform_on_sphere(n=1, coords='xyz'):
     Examples
     --------
     >>> from dipy.core.sphere_stats import random_uniform_on_sphere
-    >>> X = random_uniform_on_sphere(4, 'radians')
+    >>> X = random_uniform_on_sphere(n=4, coords='radians')
     >>> X.shape == (4, 2)
     True
-    >>> X = random_uniform_on_sphere(4, 'xyz')
+    >>> X = random_uniform_on_sphere(n=4, coords='xyz')
     >>> X.shape == (4, 3)
     True
     """
     rng = np.random.default_rng()
     z = rng.uniform(-1, 1, n)
     theta = np.arccos(z)
-    phi = rng.uniform(0, 2*np.pi, n)
-    if coords == 'xyz':
+    phi = rng.uniform(0, 2 * np.pi, n)
+    if coords == "xyz":
         r = np.ones(n)
         return np.vstack(geometry.sphere2cart(r, theta, phi)).T
     angles = np.vstack((theta, phi)).T
-    if coords == 'radians':
+    if coords == "radians":
         return angles
-    if coords == 'degrees':
+    if coords == "degrees":
         return np.rad2deg(angles)
 
 
-def eigenstats(points, alpha=0.05):
+@warning_for_keywords()
+def eigenstats(points, *, alpha=0.05):
     r"""Principal direction and confidence ellipse
 
     Implements equations in section 6.3.1(ii) of Fisher, Lewis and
@@ -81,7 +85,7 @@ def eigenstats(points, alpha=0.05):
     n = points.shape[0]
     # the number of points
 
-    rad2deg = 180/np.pi
+    rad2deg = 180 / np.pi
     # scale angles from radians to degrees
 
     # there is a problem with averaging and axis data.
@@ -93,7 +97,7 @@ def eigenstats(points, alpha=0.05):
     polar_centroid = np.array(geometry.cart2sphere(x,y,z))*rad2deg
     """
 
-    cross = np.dot(points.T, points)/n
+    cross = np.dot(points.T, points) / n
     # cross-covariance of points
 
     evals, evecs = np.linalg.eigh(cross)
@@ -108,10 +112,10 @@ def eigenstats(points, alpha=0.05):
     h = evecs[:, order]
     # the eigenvectors in corresponding order
 
-    h[:, 2] = h[:, 2]*np.sign(h[2, 2])
+    h[:, 2] = h[:, 2] * np.sign(h[2, 2])
     # map the first principal direction into upper hemisphere
 
-    centre = np.array(geometry.cart2sphere(*h[:, 2]))[1:]*rad2deg
+    centre = np.array(geometry.cart2sphere(*h[:, 2]))[1:] * rad2deg
     # the spherical coordinates of the first principal direction
 
     e = np.zeros((2, 2))
@@ -121,22 +125,21 @@ def eigenstats(points, alpha=0.05):
     p2 = np.dot(points, h[:, 2])
     # the principal coordinates of the points
 
-    e[0, 0] = np.sum((p0**2)*(p2**2))/(n*(tau[0]-tau[2])**2)
-    e[1, 1] = np.sum((p1**2)*(p2**2))/(n*(tau[1]-tau[2])**2)
-    e[0, 1] = np.sum((p0*p1*(p2**2))/(n*(tau[0]-tau[2])*(tau[1]-tau[2])))
+    e[0, 0] = np.sum((p0**2) * (p2**2)) / (n * (tau[0] - tau[2]) ** 2)
+    e[1, 1] = np.sum((p1**2) * (p2**2)) / (n * (tau[1] - tau[2]) ** 2)
+    e[0, 1] = np.sum((p0 * p1 * (p2**2)) / (n * (tau[0] - tau[2]) * (tau[1] - tau[2])))
     e[1, 0] = e[0, 1]
     # e is a 2x2 helper matrix
 
-    d = -2*np.log(alpha)/n
+    d = -2 * np.log(alpha) / n
     s, w = np.linalg.eig(e)
-    g = np.sqrt(d*s)
-    b1 = np.arcsin(g)*rad2deg
+    g = np.sqrt(d * s)
+    b1 = np.arcsin(g) * rad2deg
     # b1 are the estimated 100*(1-alpha)% confidence ellipsoid semi-axes
     # in degrees
 
     return centre, b1
 
-
     # # b2 is equivalent to b1 above
     #
     # # try to invert e and calculate vector b the standard errors of
@@ -156,7 +159,6 @@ def eigenstats(points, alpha=0.05):
     #         b2= np.arcsin(g)*rad2deg
 
 
-
 def compare_orientation_sets(S, T):
     r"""Computes the mean cosine distance of the best match between
     points of two sets of vectors S and T (angular similarity)
@@ -201,9 +203,11 @@ def compare_orientation_sets(S, T):
         T = A
         n = a
 
-    v = [np.sum([np.abs(np.dot(p[i], T[i])) for i in range(n)])
-         for p in permutations(S, n)]
-    return np.max(v)/float(n)
+    v = [
+        np.sum([np.abs(np.dot(p[i], T[i])) for i in range(n)])
+        for p in permutations(S, n)
+    ]
+    return np.max(v) / float(n)
     # return np.max(v)*float(n)/float(m)
 
 
@@ -287,7 +291,9 @@ def angular_similarity(S, T):
         v.append(np.sum(angles))
     print(v)
     """
-    v = [np.sum([np.abs(np.dot(p[i], T[i])) for i in range(n)])
-         for p in permutations(S, n)]
+    v = [
+        np.sum([np.abs(np.dot(p[i], T[i])) for i in range(n)])
+        for p in permutations(S, n)
+    ]
 
     return float(np.max(v))  # *float(n)/float(m)
