@@ -1,17 +1,18 @@
 from functools import partial
-from multiprocessing import Pool
+import multiprocessing as mp
 
 import numpy as np
-import scipy
+import scipy.fft
 
+from dipy.testing.decorators import warning_for_keywords
 from dipy.utils.multiproc import determine_num_processes
 
-import scipy.fft
 _fft = scipy.fft
 
 
-def _image_tv(x, axis=0, n_points=3):
-    """ Computes total variation (TV) of matrix x across a given axis and
+@warning_for_keywords()
+def _image_tv(x, *, axis=0, n_points=3):
+    """Computes total variation (TV) of matrix x across a given axis and
     along two directions.
 
     Parameters
@@ -34,18 +35,25 @@ def _image_tv(x, axis=0, n_points=3):
     xs = x.copy() if axis else x.T.copy()
 
     # Add copies of the data so that data extreme points are also analysed
-    xs = np.concatenate((xs[:, (-n_points-1):], xs, xs[:, 0:(n_points+1)]),
-                        axis=1)
+    xs = np.concatenate(
+        (xs[:, (-n_points - 1) :], xs, xs[:, 0 : (n_points + 1)]), axis=1
+    )
 
-    ptv = np.absolute(xs[:, (n_points+1):(-n_points-1)] -
-                      xs[:, (n_points+2):(-n_points)])
-    ntv = np.absolute(xs[:, (n_points+1):(-n_points-1)] -
-                      xs[:, n_points:(-n_points-2)])
+    ptv = np.absolute(
+        xs[:, (n_points + 1) : (-n_points - 1)] - xs[:, (n_points + 2) : (-n_points)]
+    )
+    ntv = np.absolute(
+        xs[:, (n_points + 1) : (-n_points - 1)] - xs[:, n_points : (-n_points - 2)]
+    )
     for n in range(1, n_points):
-        ptv = ptv + np.absolute(xs[:, (n_points+1+n):(-n_points-1+n)] -
-                                xs[:, (n_points+2+n):(-n_points+n)])
-        ntv = ntv + np.absolute(xs[:, (n_points+1-n):(-n_points-1-n)] -
-                                xs[:, (n_points-n):(-n_points-2-n)])
+        ptv = ptv + np.absolute(
+            xs[:, (n_points + 1 + n) : (-n_points - 1 + n)]
+            - xs[:, (n_points + 2 + n) : (-n_points + n)]
+        )
+        ntv = ntv + np.absolute(
+            xs[:, (n_points + 1 - n) : (-n_points - 1 - n)]
+            - xs[:, (n_points - n) : (-n_points - 2 - n)]
+        )
 
     if axis:
         return ptv, ntv
@@ -53,7 +61,8 @@ def _image_tv(x, axis=0, n_points=3):
         return ptv.T, ntv.T
 
 
-def _gibbs_removal_1d(x, axis=0, n_points=3):
+@warning_for_keywords()
+def _gibbs_removal_1d(x, *, axis=0, n_points=3):
     """Suppresses Gibbs ringing along a given axis using fourier sub-shifts.
 
     Parameters
@@ -129,14 +138,16 @@ def _gibbs_removal_1d(x, axis=0, n_points=3):
 
     # use positive and negative optimal sub-voxel shifts to interpolate to
     # original grid points
-    xs[idx] = (isp[idx] - isn[idx])/(sp[idx] + sn[idx])*sn[idx] + isn[idx]
+    xs[idx] = (isp[idx] - isn[idx]) / (sp[idx] + sn[idx]) * sn[idx] + isn[idx]
 
     return xs if axis else xs.T
 
 
 def _weights(shape):
-    """ Computes the weights necessary to combine two images processed by
-    the 1D Gibbs removal procedure along two different axes [1]_.
+    """Computes the weights necessary to combine two images processed by
+    the 1D Gibbs removal procedure along two different axes.
+
+    See :footcite:p:`Kellner2016` for further details about the method.
 
     Parameters
     ----------
@@ -152,9 +163,7 @@ def _weights(shape):
 
     References
     ----------
-    .. [1] Kellner E, Dhital B, Kiselev VG, Reisert M. Gibbs-ringing artifact
-           removal based on local subvoxel-shifts. Magn Reson Med. 2016
-           doi: 10.1002/mrm.26054.
+    .. footbibliography::
 
     """
     G0 = np.zeros(shape)
@@ -171,15 +180,17 @@ def _weights(shape):
 
     # Boundaries
     G1[1:-1, 0] = G1[1:-1, -1] = 1
-    G1[0, 0] = G1[-1, -1] = G1[0, -1] = G1[-1, 0] = 1/2
+    G1[0, 0] = G1[-1, -1] = G1[0, -1] = G1[-1, 0] = 1 / 2
     G0[0, 1:-1] = G0[-1, 1:-1] = 1
-    G0[0, 0] = G0[-1, -1] = G0[0, -1] = G0[-1, 0] = 1/2
+    G0[0, 0] = G0[-1, -1] = G0[0, -1] = G0[-1, 0] = 1 / 2
 
     return G0, G1
 
 
-def _gibbs_removal_2d(image, n_points=3, G0=None, G1=None):
-    """ Suppress Gibbs ringing of a 2D image.
+@warning_for_keywords()
+def _gibbs_removal_2d(image, *, n_points=3, G0=None, G1=None):
+    """Suppress Gibbs ringing of a 2D image :footcite:p:`Kellner2016`,
+    :footcite:p:`NetoHenriques2018`.
 
     Parameters
     ----------
@@ -188,10 +199,10 @@ def _gibbs_removal_2d(image, n_points=3, G0=None, G1=None):
     n_points : int, optional
         Number of neighbours to access local TV (see note). Default is
         set to 3.
-    G0 : 2D ndarray, optional.
+    G0 : 2D ndarray, optional
         Weights for the image corrected along axis 0. If not given, the
         function estimates them using the function :func:`_weights`.
-    G1 : 2D ndarray
+    G1 : 2D ndarray, optional
         Weights for the image corrected along axis 1. If not given, the
         function estimates them using the function :func:`_weights`.
 
@@ -210,16 +221,10 @@ def _gibbs_removal_2d(image, n_points=3, G0=None, G1=None):
 
     References
     ----------
-    Please cite the following articles
-    .. [1] Neto Henriques, R., 2018. Advanced Methods for Diffusion MRI Data
-           Analysis and their Application to the Healthy Ageing Brain
-           (Doctoral thesis). https://doi.org/10.17863/CAM.29356
-    .. [2] Kellner E, Dhital B, Kiselev VG, Reisert M. Gibbs-ringing artifact
-           removal based on local subvoxel-shifts. Magn Reson Med. 2016
-           doi: 10.1002/mrm.26054.
+    .. footbibliography::
 
     """
-    if np.any(G0) is None or np.any(G1) is None:
+    if G0 is None or G1 is None:
         G0, G1 = _weights(image.shape)
 
     img_c1 = _gibbs_removal_1d(image, axis=1, n_points=n_points)
@@ -227,29 +232,29 @@ def _gibbs_removal_2d(image, n_points=3, G0=None, G1=None):
 
     C1 = _fft.fft2(img_c1)
     C0 = _fft.fft2(img_c0)
-    imagec = abs(_fft.ifft2(_fft.fftshift(C1)*G1 + _fft.fftshift(C0)*G0))
+    imagec = abs(_fft.ifft2(_fft.fftshift(C1) * G1 + _fft.fftshift(C0) * G0))
 
     return imagec
 
 
-def gibbs_removal(vol, slice_axis=2, n_points=3, inplace=True,
-                  num_processes=1):
+@warning_for_keywords()
+def gibbs_removal(vol, *, slice_axis=2, n_points=3, inplace=True, num_processes=1):
     """Suppresses Gibbs ringing artefacts of images volumes.
 
+    See :footcite:p:`Kellner2016` and :footcite:p:`NetoHenriques2018` for
+    further details about the method.
+
     Parameters
     ----------
     vol : ndarray ([X, Y]), ([X, Y, Z]) or ([X, Y, Z, g])
         Matrix containing one volume (3D) or multiple (4D) volumes of images.
     slice_axis : int (0, 1, or 2)
         Data axis corresponding to the number of acquired slices.
-        Default is set to the third axis.
     n_points : int, optional
         Number of neighbour points to access local TV (see note).
-        Default is set to 3.
     inplace : bool, optional
         If True, the input data is replaced with results. Otherwise, returns
         a new array.
-        Default is set to True.
     num_processes : int or None, optional
         Split the calculation to a pool of children processes. This only
         applies to 3D or 4D `data` arrays. Default is 1. If < 0 the maximal
@@ -269,13 +274,7 @@ def gibbs_removal(vol, slice_axis=2, n_points=3, inplace=True,
 
     References
     ----------
-    Please cite the following articles
-    .. [1] Neto Henriques, R., 2018. Advanced Methods for Diffusion MRI Data
-           Analysis and their Application to the Healthy Ageing Brain
-           (Doctoral thesis). https://doi.org/10.17863/CAM.29356
-    .. [2] Kellner E, Dhital B, Kiselev VG, Reisert M. Gibbs-ringing artifact
-           removal based on local subvoxel-shifts. Magn Reson Med. 2016
-           doi: 10.1002/mrm.26054.
+    .. footbibliography::
 
     """
     nd = vol.ndim
@@ -294,8 +293,10 @@ def gibbs_removal(vol, slice_axis=2, n_points=3, inplace=True,
     # check the axis corresponding to different slices
     # 1) This axis cannot be larger than 2
     if slice_axis > 2:
-        raise ValueError("Different slices have to be organized along" +
-                         "one of the 3 first matrix dimensions")
+        raise ValueError(
+            "Different slices have to be organized along"
+            + "one of the 3 first matrix dimensions"
+        )
 
     # 2) Reorder axis to allow iteration over the first axis
     elif nd == 3:
@@ -319,14 +320,19 @@ def gibbs_removal(vol, slice_axis=2, n_points=3, inplace=True,
     if nd == 2:
         vol[:, :] = _gibbs_removal_2d(vol, n_points=n_points, G0=G0, G1=G1)
     else:
-        pool = Pool(num_processes)
+        if num_processes == 1:
+            for i in range(shap[0]):
+                vol[i, :, :] = _gibbs_removal_2d(
+                    vol[i, :, :], n_points=n_points, G0=G0, G1=G1
+                )
+        else:
+            mp.set_start_method("spawn", force=True)
+            pool = mp.Pool(num_processes)
 
-        partial_func = partial(
-            _gibbs_removal_2d, n_points=n_points, G0=G0, G1=G1
-        )
-        vol[:, :, :] = pool.map(partial_func, vol)
-        pool.close()
-        pool.join()
+            partial_func = partial(_gibbs_removal_2d, n_points=n_points, G0=G0, G1=G1)
+            vol[:, :, :] = pool.map(partial_func, vol)
+            pool.close()
+            pool.join()
 
     # Reshape data to original format
     if nd == 3:
