@@ -2,10 +2,11 @@ import copy
 from warnings import warn
 
 import numpy as np
-from scipy.linalg.lapack import dgesvd as svd
 from scipy.linalg import eigh
+from scipy.linalg.lapack import dgesvd as svd
 
 from dipy.denoise.pca_noise_estimate import pca_noise_estimate
+from dipy.testing.decorators import warning_for_keywords
 
 
 def dimensionality_problem_message(arr, num_samples, spr):
@@ -20,7 +21,7 @@ def dimensionality_problem_message(arr, num_samples, spr):
         Number of samples.
     spr : int
         Suggested patch radius.
-.
+
     Returns
     -------
     str
@@ -35,7 +36,7 @@ def dimensionality_problem_message(arr, num_samples, spr):
 
 
 def _pca_classifier(L, nvoxels):
-    """ Classifies which PCA eigenvalues are related to noise and estimates the
+    """Classifies which PCA eigenvalues are related to noise and estimates the
     noise variance
 
     Parameters
@@ -54,24 +55,22 @@ def _pca_classifier(L, nvoxels):
 
     Notes
     -----
-    This is based on the algorithm described in [1]_.
+    This is based on the algorithm described in :footcite:p:`Veraart2016c`.
 
     References
     ----------
-    .. [1] Veraart J, Novikov DS, Christiaens D, Ades-aron B, Sijbers,
-           Fieremans E, 2016. Denoising of Diffusion MRI using random matrix
-           theory. Neuroimage 142:394-406.
-           doi: 10.1016/j.neuroimage.2016.08.016
+    .. footbibliography::
     """
 
     # if num_samples - 1 (to correct for mean subtraction) is less than number
     # of features, discard the zero eigenvalues
     if L.size > nvoxels - 1:
-        L = L[-(nvoxels - 1):]
+        L = L[-(nvoxels - 1) :]
 
     # Note that the condition expressed in the while-loop is expressed in terms
-    # of the variance of equation (12), not equation (11) as in [1]_. Also,
-    # this code implements ascending eigenvalues, unlike [1]_.
+    # of the variance of equation (12), not equation (11) as in
+    # :footcite:p:`Veraart2016c`. Also, this code implements ascending
+    # eigenvalues, unlike :footcite:p:`Veraart2016c`.
     var = np.mean(L)
     c = L.size - 1
     r = L[c] - L[0] - 4 * np.sqrt((c + 1.0) / nvoxels) * var
@@ -168,9 +167,9 @@ def compute_suggested_patch_radius(arr, patch_size):
 
     tmp = np.sum(patch_size == 1)  # count spatial dimensions with size 1
     if tmp == 0:
-        root = np.ceil(arr.shape[-1] ** (1. / 3))  # 3D
+        root = np.ceil(arr.shape[-1] ** (1.0 / 3))  # 3D
     if tmp == 1:
-        root = np.ceil(arr.shape[-1] ** (1. / 2))  # 2D
+        root = np.ceil(arr.shape[-1] ** (1.0 / 2))  # 2D
     if tmp == 2:
         root = arr.shape[-1]  # 1D
     root = root + 1 if (root % 2) == 0 else root  # make odd
@@ -178,9 +177,19 @@ def compute_suggested_patch_radius(arr, patch_size):
     return int((root - 1) / 2)
 
 
-def genpca(arr, sigma=None, mask=None, patch_radius=2, pca_method='eig',
-           tau_factor=None, return_sigma=False, out_dtype=None,
-           suppress_warning=False):
+@warning_for_keywords()
+def genpca(
+    arr,
+    *,
+    sigma=None,
+    mask=None,
+    patch_radius=2,
+    pca_method="eig",
+    tau_factor=None,
+    return_sigma=False,
+    out_dtype=None,
+    suppress_warning=False,
+):
     r"""General function to perform PCA-based denoising of diffusion datasets.
 
     Parameters
@@ -189,39 +198,39 @@ def genpca(arr, sigma=None, mask=None, patch_radius=2, pca_method='eig',
         Array of data to be denoised. The dimensions are (X, Y, Z, N), where N
         are the diffusion gradient directions. The first 3 dimension must have
         size >= 2 * patch_radius + 1 or size = 1.
-    sigma : float or 3D array (optional)
+    sigma : float or 3D array, optional
         Standard deviation of the noise estimated from the data. If no sigma
         is given, this will be estimated based on random matrix theory
-        [1]_,[2]_
-    mask : 3D boolean array (optional)
+        :footcite:p:`Veraart2016b`, :footcite:p:`Veraart2016c`.
+    mask : 3D boolean array, optional
         A mask with voxels that are true inside the brain and false outside of
         it. The function denoises within the true part and returns zeros
         outside of those voxels.
-    patch_radius : int or 1D array (optional)
+    patch_radius : int or 1D array, optional
         The radius of the local patch to be taken around each voxel (in
         voxels). E.g. patch_radius=2 gives 5x5x5 patches.
-    pca_method : 'eig' or 'svd' (optional)
+    pca_method : 'eig' or 'svd', optional
         Use either eigenvalue decomposition (eig) or singular value
         decomposition (svd) for principal component analysis. The default
         method is 'eig' which is faster. However, occasionally 'svd' might be
         more accurate.
-    tau_factor : float (optional)
+    tau_factor : float, optional
         Thresholding of PCA eigenvalues is done by nulling out eigenvalues that
         are smaller than:
 
-        .. math ::
+        .. math::
 
                 \tau = (\tau_{factor} \sigma)^2
 
-        \tau_{factor} can be set to a predefined values (e.g. \tau_{factor} =
-        2.3 [3]_), or automatically calculated using random matrix theory
-        (in case that \tau_{factor} is set to None).
-    return_sigma : bool (optional)
+        $\tau_{factor}$ can be set to a predefined values (e.g. $\tau_{factor} =
+        2.3$ :footcite:p:`Manjon2013`), or automatically calculated using random
+        matrix theory (in case that $\tau_{factor}$ is set to None).
+    return_sigma : bool, optional
         If true, the Standard deviation of the noise will be returned.
-    out_dtype : str or dtype (optional)
+    out_dtype : str or dtype, optional
         The dtype for the output array. Default: output has the same dtype as
         the input.
-    suppress_warning : bool (optional)
+    suppress_warning : bool, optional
         If true, suppress warning caused by patch_size < arr.shape[-1].
 
     Returns
@@ -232,17 +241,7 @@ def genpca(arr, sigma=None, mask=None, patch_radius=2, pca_method='eig',
 
     References
     ----------
-    .. [1] Veraart J, Novikov DS, Christiaens D, Ades-aron B, Sijbers,
-           Fieremans E, 2016. Denoising of Diffusion MRI using random matrix
-           theory. Neuroimage 142:394-406.
-           doi: 10.1016/j.neuroimage.2016.08.016
-    .. [2] Veraart J, Fieremans E, Novikov DS. 2016. Diffusion MRI noise
-           mapping using random matrix theory. Magnetic Resonance in Medicine.
-           doi: 10.1002/mrm.26059.
-    .. [3] Manjon JV, Coupe P, Concha L, Buades A, Collins DL (2013)
-           Diffusion Weighted Image Denoising Using Overcomplete Local
-           PCA. PLoS ONE 8(9): e73021.
-           https://doi.org/10.1371/journal.pone.0073021
+    .. footbibliography::
     """
     if mask is None:
         # If mask is not specified, use the whole volume
@@ -259,12 +258,11 @@ def genpca(arr, sigma=None, mask=None, patch_radius=2, pca_method='eig',
         calc_dtype = np.float32
 
     if not arr.ndim == 4:
-        raise ValueError("PCA denoising can only be performed on 4D arrays.",
-                         arr.shape)
+        raise ValueError("PCA denoising can only be performed on 4D arrays.", arr.shape)
 
-    if pca_method.lower() == 'svd':
+    if pca_method.lower() == "svd":
         is_svd = True
-    elif pca_method.lower() == 'eig':
+    elif pca_method.lower() == "eig":
         is_svd = False
     else:
         raise ValueError("pca_method should be either 'eig' or 'svd'")
@@ -278,24 +276,29 @@ def genpca(arr, sigma=None, mask=None, patch_radius=2, pca_method='eig',
 
     num_samples = compute_num_samples(patch_size)
     if num_samples == 1:
-        raise ValueError("Cannot have only 1 sample,\
-                          please increase patch_radius.")
+        raise ValueError(
+            "Cannot have only 1 sample,\
+                          please increase patch_radius."
+        )
     # account for mean subtraction by testing #samples - 1
     if (num_samples - 1) < arr.shape[-1] and not suppress_warning:
         spr = compute_suggested_patch_radius(arr, patch_size)
-        warn(dimensionality_problem_message(arr, num_samples, spr),
-             UserWarning)
+        warn(
+            dimensionality_problem_message(arr, num_samples, spr),
+            UserWarning,
+            stacklevel=2,
+        )
 
     if isinstance(sigma, np.ndarray):
-        var = sigma ** 2
+        var = sigma**2
         if not sigma.shape == arr.shape[:-1]:
             e_s = "You provided a sigma array with a shape"
-            e_s += "{0} for data with".format(sigma.shape)
-            e_s += "shape {0}. Please provide a sigma array".format(arr.shape)
+            e_s += f"{sigma.shape} for data with"
+            e_s += f"shape {arr.shape}. Please provide a sigma array"
             e_s += " that matches the spatial dimensions of the data."
             raise ValueError(e_s)
     elif isinstance(sigma, (int, float)):
-        var = sigma ** 2 * np.ones(arr.shape[:-1])
+        var = sigma**2 * np.ones(arr.shape[:-1])
 
     dim = arr.shape[-1]
     if tau_factor is None:
@@ -310,10 +313,8 @@ def genpca(arr, sigma=None, mask=None, patch_radius=2, pca_method='eig',
 
     # loop around and find the 3D patch for each direction at each pixel
     for k in range(patch_radius_arr[2], arr.shape[2] - patch_radius_arr[2]):
-        for j in range(patch_radius_arr[1],
-                       arr.shape[1] - patch_radius_arr[1]):
-            for i in range(
-                    patch_radius_arr[0], arr.shape[0] - patch_radius_arr[0]):
+        for j in range(patch_radius_arr[1], arr.shape[1] - patch_radius_arr[1]):
+            for i in range(patch_radius_arr[0], arr.shape[0] - patch_radius_arr[0]):
                 # Shorthand for indexing variables:
                 if not mask[i, j, k]:
                     continue
@@ -324,8 +325,7 @@ def genpca(arr, sigma=None, mask=None, patch_radius=2, pca_method='eig',
                 kx1 = k - patch_radius_arr[2]
                 kx2 = k + patch_radius_arr[2] + 1
 
-                X = arr[ix1:ix2, jx1:jx2, kx1:kx2].reshape(
-                                num_samples, dim)
+                X = arr[ix1:ix2, jx1:jx2, kx1:kx2].reshape(num_samples, dim)
                 # compute the mean
                 M = np.mean(X, axis=0)
                 # Upcast the dtype for precision in the SVD
@@ -357,7 +357,7 @@ def genpca(arr, sigma=None, mask=None, patch_radius=2, pca_method='eig',
                     this_var = var[i, j, k]
 
                 # Threshold by tau:
-                tau = tau_factor ** 2 * this_var
+                tau = tau_factor**2 * this_var
 
                 # Update ncomps according to tau_factor
                 ncomps = np.sum(d < tau)
@@ -365,9 +365,7 @@ def genpca(arr, sigma=None, mask=None, patch_radius=2, pca_method='eig',
 
                 # This is equations 1 and 2 in Manjon 2013:
                 Xest = X.dot(W).dot(W.T) + M
-                Xest = Xest.reshape(patch_size[0],
-                                    patch_size[1],
-                                    patch_size[2], dim)
+                Xest = Xest.reshape(patch_size[0], patch_size[1], patch_size[2], dim)
                 # This is equation 3 in Manjon 2013:
                 this_theta = 1.0 / (1.0 + dim - ncomps)
                 theta[ix1:ix2, jx1:jx2, kx1:kx2] += this_theta
@@ -390,62 +388,77 @@ def genpca(arr, sigma=None, mask=None, patch_radius=2, pca_method='eig',
         return denoised_arr.astype(out_dtype)
 
 
-def localpca(arr, sigma=None, mask=None, patch_radius=2, gtab=None,
-             patch_radius_sigma=1, pca_method='eig', tau_factor=2.3,
-             return_sigma=False, correct_bias=True, out_dtype=None,
-             suppress_warning=False):
-    r""" Performs local PCA denoising according to Manjon et al. [1]_.
+@warning_for_keywords()
+def localpca(
+    arr,
+    *,
+    sigma=None,
+    mask=None,
+    patch_radius=2,
+    gtab=None,
+    patch_radius_sigma=1,
+    pca_method="eig",
+    tau_factor=2.3,
+    return_sigma=False,
+    correct_bias=True,
+    out_dtype=None,
+    suppress_warning=False,
+):
+    r"""Performs local PCA denoising.
+
+    The method follows the algorithm in :footcite:t:`Manjon2013`.
 
     Parameters
     ----------
     arr : 4D array
         Array of data to be denoised. The dimensions are (X, Y, Z, N), where N
         are the diffusion gradient directions.
-    sigma : float or 3D array (optional)
+    sigma : float or 3D array, optional
         Standard deviation of the noise estimated from the data. If not given,
-        calculate using method in [1]_.
-    mask : 3D boolean array (optional)
+        calculate using method in :footcite:t:`Manjon2013`.
+    mask : 3D boolean array, optional
         A mask with voxels that are true inside the brain and false outside of
         it. The function denoises within the true part and returns zeros
         outside of those voxels.
-    patch_radius : int or 1D array (optional)
+    patch_radius : int or 1D array, optional
         The radius of the local patch to be taken around each voxel (in
         voxels). E.g. patch_radius=2 gives 5x5x5 patches.
     gtab: gradient table object (optional if sigma is provided)
         gradient information for the data gives us the bvals and bvecs of
         diffusion data, which is needed to calculate noise level if sigma is
         not provided.
-    patch_radius_sigma : int (optional)
+    patch_radius_sigma : int, optional
         The radius of the local patch to be taken around each voxel (in
         voxels) for estimating sigma. E.g. patch_radius_sigma=2 gives
         5x5x5 patches.
-    pca_method : 'eig' or 'svd' (optional)
+    pca_method : 'eig' or 'svd', optional
         Use either eigenvalue decomposition (eig) or singular value
         decomposition (svd) for principal component analysis. The default
         method is 'eig' which is faster. However, occasionally 'svd' might be
         more accurate.
-    tau_factor : float (optional)
+    tau_factor : float, optional
         Thresholding of PCA eigenvalues is done by nulling out eigenvalues that
         are smaller than:
 
-        .. math ::
+        .. math::
 
                 \tau = (\tau_{factor} \sigma)^2
 
         \tau_{factor} can be change to adjust the relationship between the
         noise standard deviation and the threshold \tau. If \tau_{factor} is
         set to None, it will be automatically calculated using the
-        Marcenko-Pastur distribution [2]_. Default: 2.3 according to [1]_.
-    return_sigma : bool (optional)
+        Marcenko-Pastur distribution :footcite:p:`Veraart2016c`. Default: 2.3
+        according to :footcite:t:`Manjon2013`.
+    return_sigma : bool, optional
         If true, a noise standard deviation estimate based on the
-        Marcenko-Pastur distribution is returned [2]_.
-    correct_bias : bool (optional)
+        Marcenko-Pastur distribution is returned :footcite:p:`Veraart2016c`.
+    correct_bias : bool, optional
         Whether to correct for bias due to Rician noise. This is an
-        implementation of equation 8 in [1]_.
-    out_dtype : str or dtype (optional)
+        implementation of equation 8 in :footcite:p:`Manjon2013`.
+    out_dtype : str or dtype, optional
         The dtype for the output array. Default: output has the same dtype as
         the input.
-    suppress_warning : bool (optional)
+    suppress_warning : bool, optional
         If true, suppress warning caused by patch_size < arr.shape[-1].
 
     Returns
@@ -456,14 +469,7 @@ def localpca(arr, sigma=None, mask=None, patch_radius=2, gtab=None,
 
     References
     ----------
-    .. [1] Manjon JV, Coupe P, Concha L, Buades A, Collins DL (2013)
-           Diffusion Weighted Image Denoising Using Overcomplete Local
-           PCA. PLoS ONE 8(9): e73021.
-           https://doi.org/10.1371/journal.pone.0073021
-    .. [2] Veraart J, Novikov DS, Christiaens D, Ades-aron B, Sijbers,
-           Fieremans E, 2016. Denoising of Diffusion MRI using random matrix
-           theory. Neuroimage 142:394-406.
-           doi: 10.1016/j.neuroimage.2016.08.016
+    .. footbibliography::
     """
     # check gtab is given, if sigma is not given
     if sigma is None and gtab is None:
@@ -471,46 +477,67 @@ def localpca(arr, sigma=None, mask=None, patch_radius=2, gtab=None,
 
     # calculate sigma
     if sigma is None:
-        sigma = pca_noise_estimate(arr, gtab,
-                                   correct_bias=correct_bias,
-                                   patch_radius=patch_radius_sigma,
-                                   images_as_samples=True)
+        sigma = pca_noise_estimate(
+            arr,
+            gtab,
+            correct_bias=correct_bias,
+            patch_radius=patch_radius_sigma,
+            images_as_samples=True,
+        )
 
-    return genpca(arr, sigma=sigma, mask=mask, patch_radius=patch_radius,
-                  pca_method=pca_method, tau_factor=tau_factor,
-                  return_sigma=return_sigma, out_dtype=out_dtype,
-                  suppress_warning=suppress_warning)
+    return genpca(
+        arr,
+        sigma=sigma,
+        mask=mask,
+        patch_radius=patch_radius,
+        pca_method=pca_method,
+        tau_factor=tau_factor,
+        return_sigma=return_sigma,
+        out_dtype=out_dtype,
+        suppress_warning=suppress_warning,
+    )
 
 
-def mppca(arr, mask=None, patch_radius=2, pca_method='eig',
-          return_sigma=False, out_dtype=None, suppress_warning=False):
+@warning_for_keywords()
+def mppca(
+    arr,
+    *,
+    mask=None,
+    patch_radius=2,
+    pca_method="eig",
+    return_sigma=False,
+    out_dtype=None,
+    suppress_warning=False,
+):
     r"""Performs PCA-based denoising using the Marcenko-Pastur
-    distribution [1]_.
+    distribution.
+
+    See :footcite:p:`Veraart2016c` for further details about the method.
 
     Parameters
     ----------
     arr : 4D array
         Array of data to be denoised. The dimensions are (X, Y, Z, N), where N
         are the diffusion gradient directions.
-    mask : 3D boolean array (optional)
+    mask : 3D boolean array, optional
         A mask with voxels that are true inside the brain and false outside of
         it. The function denoises within the true part and returns zeros
         outside of those voxels.
-    patch_radius : int or 1D array (optional)
+    patch_radius : int or 1D array, optional
         The radius of the local patch to be taken around each voxel (in
         voxels). E.g. patch_radius=2 gives 5x5x5 patches.
-    pca_method : 'eig' or 'svd' (optional)
+    pca_method : 'eig' or 'svd', optional
         Use either eigenvalue decomposition (eig) or singular value
         decomposition (svd) for principal component analysis. The default
         method is 'eig' which is faster. However, occasionally 'svd' might be
         more accurate.
-    return_sigma : bool (optional)
+    return_sigma : bool, optional
         If true, a noise standard deviation estimate based on the
-        Marcenko-Pastur distribution is returned [2]_.
-    out_dtype : str or dtype (optional)
+        Marcenko-Pastur distribution is returned :footcite:p:`Veraart2016b`.
+    out_dtype : str or dtype, optional
         The dtype for the output array. Default: output has the same dtype as
         the input.
-    suppress_warning : bool (optional)
+    suppress_warning : bool, optional
         If true, suppress warning caused by patch_size < arr.shape[-1].
 
     Returns
@@ -523,15 +550,16 @@ def mppca(arr, mask=None, patch_radius=2, pca_method='eig',
 
     References
     ----------
-    .. [1] Veraart J, Novikov DS, Christiaens D, Ades-aron B, Sijbers,
-           Fieremans E, 2016. Denoising of Diffusion MRI using random matrix
-           theory. Neuroimage 142:394-406.
-           doi: 10.1016/j.neuroimage.2016.08.016
-    .. [2] Veraart J, Fieremans E, Novikov DS. 2016. Diffusion MRI noise
-           mapping using random matrix theory. Magnetic Resonance in Medicine.
-           doi: 10.1002/mrm.26059.
+    .. footbibliography::
     """
-    return genpca(arr, sigma=None, mask=mask, patch_radius=patch_radius,
-                  pca_method=pca_method, tau_factor=None,
-                  return_sigma=return_sigma, out_dtype=out_dtype,
-                  suppress_warning=suppress_warning)
+    return genpca(
+        arr,
+        sigma=None,
+        mask=mask,
+        patch_radius=patch_radius,
+        pca_method=pca_method,
+        tau_factor=None,
+        return_sigma=return_sigma,
+        out_dtype=out_dtype,
+        suppress_warning=suppress_warning,
+    )
