@@ -1,5 +1,8 @@
 import numpy as np
+
 from dipy.denoise.denspeed import nlmeans_3d
+from dipy.testing.decorators import warning_for_keywords
+
 # from warnings import warn
 # import warnings
 
@@ -8,9 +11,20 @@ from dipy.denoise.denspeed import nlmeans_3d
 #                         " use module 'dipy.denoise.non_local_means' instead"))
 
 
-def nlmeans(arr, sigma, mask=None, patch_radius=1, block_radius=5,
-            rician=True, num_threads=None):
-    r""" Non-local means for denoising 3D and 4D images
+@warning_for_keywords()
+def nlmeans(
+    arr,
+    sigma,
+    *,
+    mask=None,
+    patch_radius=1,
+    block_radius=5,
+    rician=True,
+    num_threads=None,
+):
+    r"""Non-local means for denoising 3D and 4D images.
+
+    See :footcite:p:Descoteaux2008a` for further details about the method.
 
     Parameters
     ----------
@@ -30,7 +44,7 @@ def nlmeans(arr, sigma, mask=None, patch_radius=1, block_radius=5,
         Number of threads to be used for OpenMP parallelization. If None
         (default) the value of OMP_NUM_THREADS environment variable is used
         if it is set, otherwise all available threads are used. If < 0 the
-        maximal number of threads minus |num_threads + 1| is used (enter -1 to
+        maximal number of threads minus $|num_threads + 1|$ is used (enter -1 to
         use as many threads as possible). 0 raises an error.
 
     Returns
@@ -40,10 +54,7 @@ def nlmeans(arr, sigma, mask=None, patch_radius=1, block_radius=5,
 
     References
     ----------
-    .. [Descoteaux08] Descoteaux, Maxime and Wiest-Daesslé, Nicolas and Prima,
-                      Sylvain and Barillot, Christian and Deriche, Rachid
-                      Impact of Rician Adapted Non-Local Means Filtering on
-                      HARDI, MICCAI 2008
+    .. footbibliography::
 
     """
 
@@ -54,27 +65,34 @@ def nlmeans(arr, sigma, mask=None, patch_radius=1, block_radius=5,
 
     if arr.ndim == 3:
         sigma = np.ones(arr.shape, dtype=np.float64) * sigma
-        return nlmeans_3d(arr, mask, sigma,
-                          patch_radius, block_radius,
-                          rician, num_threads).astype(arr.dtype)
+        return nlmeans_3d(
+            arr,
+            mask=mask,
+            sigma=sigma,
+            patch_radius=patch_radius,
+            block_radius=block_radius,
+            rician=rician,
+            num_threads=num_threads,
+        ).astype(arr.dtype)
 
     elif arr.ndim == 4:
         denoised_arr = np.zeros_like(arr)
 
         if isinstance(sigma, np.ndarray) and sigma.ndim == 3:
-            sigma = (np.ones(arr.shape, dtype=np.float64) *
-                     sigma[..., np.newaxis])
+            sigma = np.ones(arr.shape, dtype=np.float64) * sigma[..., np.newaxis]
         else:
             sigma = np.ones(arr.shape, dtype=np.float64) * sigma
 
         for i in range(arr.shape[-1]):
-            denoised_arr[..., i] = nlmeans_3d(arr[..., i],
-                                              mask,
-                                              sigma[..., i],
-                                              patch_radius,
-                                              block_radius,
-                                              rician,
-                                              num_threads).astype(arr.dtype)
+            denoised_arr[..., i] = nlmeans_3d(
+                arr[..., i],
+                mask=mask,
+                sigma=sigma[..., i],
+                patch_radius=patch_radius,
+                block_radius=block_radius,
+                rician=rician,
+                num_threads=num_threads,
+            ).astype(arr.dtype)
 
         return denoised_arr
 
