@@ -1,32 +1,46 @@
 import numpy as np
-
-from scipy.special import gammainccinv
 from scipy.ndimage import convolve
+from scipy.special import gammainccinv
+
+from dipy.testing.decorators import warning_for_keywords
+from dipy.utils.deprecator import deprecated_params
 
 
 def _inv_nchi_cdf(N, K, alpha):
-    """Inverse CDF for the noncentral chi distribution
-    See [1]_ p.3 section 2.3"""
+    """Inverse CDF for the noncentral chi distribution.
+
+    See :footcite:t:`Koay2009b`, p.3 section 2.3.
+
+    References
+    ----------
+    .. footbibliography::
+    """
     return gammainccinv(N * K, 1 - alpha) / K
 
 
 # List of optimal quantile for PIESNO.
 # Get optimal quantile for N if available, else use the median.
-opt_quantile = {1: 0.79681213002002,
-                2: 0.7306303027491917,
-                4: 0.6721952960782169,
-                8: 0.6254030432343569,
-               16: 0.5900487123737876,
-               32: 0.5641772300866416,
-               64: 0.5455611840489607,
-              128: 0.5322811923303339}
+opt_quantile = {
+    1: 0.79681213002002,
+    2: 0.7306303027491917,
+    4: 0.6721952960782169,
+    8: 0.6254030432343569,
+    16: 0.5900487123737876,
+    32: 0.5641772300866416,
+    64: 0.5455611840489607,
+    128: 0.5322811923303339,
+}
 
 
-def piesno(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
-           return_mask=False):
+@deprecated_params("l", new_name="step", since="1.10.0", until="1.12.0")
+@warning_for_keywords()
+def piesno(data, N, *, alpha=0.01, step=100, itermax=100, eps=1e-5, return_mask=False):
     """
     Probabilistic Identification and Estimation of Noise (PIESNO).
 
+    See :footcite:p:`Koay2009a` and :footcite:p:`Koay2009b` for further details
+    about the method.
+
     Parameters
     ----------
     data : ndarray
@@ -43,7 +57,7 @@ def piesno(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
     alpha : float
         Probabilistic estimation threshold for the gamma function.
 
-    l : int
+    step : int
         number of initial estimates for sigma to try.
 
     itermax : int
@@ -63,7 +77,7 @@ def piesno(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
     sigma : float
         The estimated standard deviation of the gaussian noise.
 
-    mask : ndarray (optional)
+    mask : ndarray, optional
         A boolean mask indicating the voxels identified as pure noise.
 
     Notes
@@ -79,16 +93,7 @@ def piesno(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
 
     References
     ----------
-
-    .. [1] Koay CG, Ozarslan E and Pierpaoli C.
-    "Probabilistic Identification and Estimation of Noise (PIESNO):
-    A self-consistent approach and its applications in MRI."
-    Journal of Magnetic Resonance 2009; 199: 94-103.
-
-    .. [2] Koay CG, Ozarslan E and Basser PJ.
-    "A signal transformational framework for breaking the noise floor
-    and its applications in MRI."
-    Journal of Magnetic Resonance 2009; 197: 108-119.
+    .. footbibliography::
     """
 
     # This method works on a 2D array with repetitions as the third dimension,
@@ -103,33 +108,37 @@ def piesno(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
         q = 0.5
 
     # Initial estimation of sigma
-    initial_estimation = (np.percentile(data, q * 100) /
-                          np.sqrt(2 * _inv_nchi_cdf(N, 1, q)))
+    initial_estimation = np.percentile(data, q * 100) / np.sqrt(
+        2 * _inv_nchi_cdf(N, 1, q)
+    )
 
     if data.ndim == 4:
-
         sigma = np.zeros(data.shape[-2], dtype=np.float32)
         mask_noise = np.zeros(data.shape[:-1], dtype=bool)
 
         for idx in range(data.shape[-2]):
-            sigma[idx], mask_noise[..., idx] = _piesno_3D(data[..., idx, :],
-                                                          N,
-                                                          alpha=alpha,
-                                                          l=l,
-                                                          itermax=itermax,
-                                                          eps=eps,
-                                                          return_mask=True,
-                                                          initial_estimation=initial_estimation)
+            sigma[idx], mask_noise[..., idx] = _piesno_3D(
+                data[..., idx, :],
+                N,
+                alpha=alpha,
+                step=step,
+                itermax=itermax,
+                eps=eps,
+                return_mask=True,
+                initial_estimation=initial_estimation,
+            )
 
     else:
-        sigma, mask_noise = _piesno_3D(data,
-                                       N,
-                                       alpha=alpha,
-                                       l=l,
-                                       itermax=itermax,
-                                       eps=eps,
-                                       return_mask=True,
-                                       initial_estimation=initial_estimation)
+        sigma, mask_noise = _piesno_3D(
+            data,
+            N,
+            alpha=alpha,
+            step=step,
+            itermax=itermax,
+            eps=eps,
+            return_mask=True,
+            initial_estimation=initial_estimation,
+        )
 
     if return_mask:
         return sigma, mask_noise
@@ -137,10 +146,25 @@ def piesno(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
     return sigma
 
 
-def _piesno_3D(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
-               return_mask=False, initial_estimation=None):
+@deprecated_params("l", new_name="step", since="1.10.0", until="1.12.0")
+@warning_for_keywords()
+def _piesno_3D(
+    data,
+    N,
+    *,
+    alpha=0.01,
+    step=100,
+    itermax=100,
+    eps=1e-5,
+    return_mask=False,
+    initial_estimation=None,
+):
     """
     Probabilistic Identification and Estimation of Noise (PIESNO).
+
+    See :footcite:p:`Koay2009a` and :footcite:p:`Koay2009b` for further details
+    about the method.
+
     This is the slice by slice version for working on a 4D array.
 
     Parameters
@@ -152,27 +176,25 @@ def _piesno_3D(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
     N : int
         The number of phase array coils of the MRI scanner.
 
-    alpha : float (optional)
+    alpha : float, optional
         Probabilistic estimation threshold for the gamma function.
-        Default: 0.01.
 
-    l : int (optional)
-        number of initial estimates for sigma to try. Default: 100.
+    step : int, optional
+        number of initial estimates for sigma to try.
 
-    itermax : int (optional)
+    itermax : int, optional
         Maximum number of iterations to execute if convergence
-        is not reached. Default: 100.
+        is not reached.
 
-    eps : float (optional)
+    eps : float, optional
         Tolerance for the convergence criterion. Convergence is
         reached if two subsequent estimates are smaller than eps.
-        Default: 1e-5.
 
-    return_mask : bool (optional)
+    return_mask : bool, optional
         If True, return a mask identifying all the pure noise voxel
-        that were found. Default: False.
+        that were found.
 
-    initial_estimation : float (optional)
+    initial_estimation : float, optional
         Upper bound for the initial estimation of sigma. default : None,
         which computes the optimal quantile for N.
 
@@ -193,16 +215,7 @@ def _piesno_3D(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
 
     References
     ----------
-
-    .. [1] Koay CG, Ozarslan E and Pierpaoli C.
-    "Probabilistic Identification and Estimation of Noise (PIESNO):
-    A self-consistent approach and its applications in MRI."
-    Journal of Magnetic Resonance 2009; 199: 94-103.
-
-    .. [2] Koay CG, Ozarslan E and Basser PJ.
-    "A signal transformational framework for breaking the noise floor
-    and its applications in MRI."
-    Journal of Magnetic Resonance 2009; 197: 108-119.
+    .. footbibliography::
     """
 
     if np.all(data == 0):
@@ -223,29 +236,29 @@ def _piesno_3D(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
     else:
         m = initial_estimation
 
-    phi = np.arange(1, l + 1) * m / l
+    phi = np.arange(1, step + 1) * m / step
     K = data.shape[-1]
-    sum_m2 = np.sum(data.astype(np.float32)**2, axis=2)
+    sum_m2 = np.sum(data.astype(np.float32) ** 2, axis=2)
 
     sigma_prev = 0
     sigma = m
     prev_idx = 0
     mask = np.zeros(data.shape[:-1], dtype=bool)
 
-    lambda_minus = _inv_nchi_cdf(N, K, alpha/2)
-    lambda_plus = _inv_nchi_cdf(N, K, 1 - alpha/2)
+    lambda_minus = _inv_nchi_cdf(N, K, alpha / 2)
+    lambda_plus = _inv_nchi_cdf(N, K, 1 - alpha / 2)
 
     for sigma_init in phi:
-
         s = sum_m2 / (2 * K * sigma_init**2)
-        found_idx = np.sum(np.logical_and(lambda_minus <= s, s <= lambda_plus),
-                           dtype=np.int16)
+        found_idx = np.sum(
+            np.logical_and(lambda_minus <= s, s <= lambda_plus), dtype=np.int16
+        )
 
         if found_idx > prev_idx:
             sigma = sigma_init
             prev_idx = found_idx
 
-    for n in range(itermax):
+    for _ in range(itermax):
         if np.abs(sigma - sigma_prev) < eps:
             break
 
@@ -268,7 +281,8 @@ def _piesno_3D(data, N, alpha=0.01, l=100, itermax=100, eps=1e-5,
     return sigma
 
 
-def estimate_sigma(arr, disable_background_masking=False, N=0):
+@warning_for_keywords()
+def estimate_sigma(arr, *, disable_background_masking=False, N=0):
     """Standard deviation estimation from local patches
 
     Parameters
@@ -276,16 +290,16 @@ def estimate_sigma(arr, disable_background_masking=False, N=0):
     arr : 3D or 4D ndarray
         The array to be estimated
 
-    disable_background_masking : bool, default False
+    disable_background_masking : bool, optional
         If True, uses all voxels for the estimation, otherwise, only non-zeros
         voxels are used. Useful if the background is masked by the scanner.
 
-    N : int, default 0
+    N : int, optional
         Number of coils of the receiver array. Use N = 1 in case of a SENSE
         reconstruction (Philips scanners) or the number of coils for a GRAPPA
         reconstruction (Siemens and GE). Use 0 to disable the correction factor,
-        as for example if the noise is Gaussian distributed. See [1] for more
-        information.
+        as for example if the noise is Gaussian distributed. See
+        :footcite:p:`Koay2006a` for more information.
 
     Returns
     -------
@@ -296,23 +310,17 @@ def estimate_sigma(arr, disable_background_masking=False, N=0):
     -----
     This function is the same as manually taking the standard deviation of the
     background and gives one value for the whole 3D array.
-    It also includes the coil-dependent correction factor of Koay 2006
-    (see [1]_, equation 18) with theta = 0.
-    Since this function was introduced in [2]_ for T1 imaging,
-    it is expected to perform ok on diffusion MRI data, but might oversmooth
-    some regions and leave others un-denoised for spatially varying noise
-    profiles. Consider using :func:`piesno` to estimate sigma instead if visual
-    inaccuracies are apparent in the denoised result.
+    It also includes the coil-dependent correction factor from
+    :footcite:t:`Koay2006a` (see equation 18 in :footcite:p:`Koay2006a`) with
+    theta = 0. Since this function was introduced in :footcite:p:`Coupe2008` for
+    T1 imaging, it is expected to perform ok on diffusion MRI data, but might
+    oversmooth some regions and leave others un-denoised for spatially varying
+    noise profiles. Consider using :func:`piesno` to estimate sigma instead if
+    visual inaccuracies are apparent in the denoised result.
 
     References
     ----------
-    .. [1] Koay, C. G., & Basser, P. J. (2006). Analytically exact correction
-    scheme for signal extraction from noisy magnitude MR signals.
-    Journal of Magnetic Resonance), 179(2), 317-22.
-
-    .. [2] Coupe, P., Yger, P., Prima, S., Hellier, P., Kervrann, C., Barillot,
-    C., 2008. An optimized blockwise nonlocal means denoising filter for 3-D
-    magnetic resonance images, IEEE Trans. Med. Imaging 27, 425-41.
+    .. footbibliography::
 
     """
     k = np.zeros((3, 3, 3), dtype=np.int8)
@@ -326,23 +334,27 @@ def estimate_sigma(arr, disable_background_masking=False, N=0):
 
     # Precomputed factor from Koay 2006, this corrects the bias of magnitude
     # image
-    correction_factor = {0: 1,  # No correction
-                         1: 0.42920367320510366,
-                         4: 0.4834941393603609,
-                         6: 0.4891759468548269,
-                         8: 0.49195420135894175,
-                        12: 0.4946862482541263,
-                        16: 0.4960339908122364,
-                        20: 0.4968365823718557,
-                        24: 0.49736907650825657,
-                        32: 0.49803177052530145,
-                        64: 0.49901964176235936}
+    correction_factor = {
+        0: 1,  # No correction
+        1: 0.42920367320510366,
+        4: 0.4834941393603609,
+        6: 0.4891759468548269,
+        8: 0.49195420135894175,
+        12: 0.4946862482541263,
+        16: 0.4960339908122364,
+        20: 0.4968365823718557,
+        24: 0.49736907650825657,
+        32: 0.49803177052530145,
+        64: 0.49901964176235936,
+    }
 
     if N in correction_factor:
         factor = correction_factor[N]
     else:
-        raise ValueError("N = {0} is not supported! Please choose amongst \
-{1}".format(N, sorted(list(correction_factor.keys()))))
+        raise ValueError(
+            f"N = {N} is not supported! Please choose amongst "
+            f"{sorted(correction_factor.keys())}"
+        )
 
     if arr.ndim == 3:
         sigma = np.zeros(1, dtype=np.float32)
@@ -361,7 +373,7 @@ def estimate_sigma(arr, disable_background_masking=False, N=0):
 
     for i in range(sigma.size):
         convolve(arr[..., i], k, output=conv_out)
-        mean_block = np.sqrt(6/7) * (arr[..., i] - 1/6 * conv_out)
-        sigma[i] = np.sqrt(np.mean(mean_block[mask]**2) / factor)
+        mean_block = np.sqrt(6 / 7) * (arr[..., i] - 1 / 6 * conv_out)
+        sigma[i] = np.sqrt(np.mean(mean_block[mask] ** 2) / factor)
 
     return sigma
