@@ -1,17 +1,30 @@
 import numpy as np
-from numpy.testing import (assert_,
-                           assert_equal,
-                           assert_array_almost_equal,
-                           assert_raises)
+from numpy.testing import (
+    assert_,
+    assert_array_almost_equal,
+    assert_equal,
+    assert_raises,
+)
+
 from dipy.denoise.non_local_means import non_local_means
 from dipy.testing.decorators import set_random_number_generator
 
 
 def test_nlmeans_static():
-    S0 = 100 * np.ones((20, 20, 20), dtype='f8')
+    S0 = 100 * np.ones((20, 20, 20), dtype="f8")
     S0nb = non_local_means(S0, sigma=1.0, rician=False)
     assert_array_almost_equal(S0, S0nb)
 
+    S0 = 100 * np.ones((20, 20, 20, 3), dtype="f8")
+    S0nb = non_local_means(S0, sigma=1.0, rician=False)
+    assert_array_almost_equal(S0, S0nb)
+
+    S0nb = non_local_means(S0, sigma=np.array(1.0), rician=False)
+    assert_array_almost_equal(S0, S0nb)
+
+    S0nb = non_local_means(S0, sigma=np.array([1.0]), rician=False)
+    assert_array_almost_equal(S0, S0nb)
+
 
 @set_random_number_generator()
 def test_nlmeans_random_noise(rng):
@@ -40,8 +53,10 @@ def test_scalar_sigma(rng):
     S0 += noise
     S0[:10, :10, :10] = 300 + noise[:10, :10, :10]
 
-    assert_raises(
-        ValueError, non_local_means, S0, sigma=noise, rician=False)
+    assert_raises(ValueError, non_local_means, S0, sigma=noise, rician=False)
+
+    noise = "a"
+    assert_raises(ValueError, non_local_means, S0, sigma=noise, rician=False)
 
 
 @set_random_number_generator()
@@ -61,11 +76,11 @@ def test_nlmeans_wrong():
     assert_raises(ValueError, non_local_means, S0, 1.0)
     S0 = 100 + np.zeros((20, 20, 20))
     mask = np.ones((10, 10))
-    assert_raises(ValueError, non_local_means, S0, 1.0, mask)
+    assert_raises(ValueError, non_local_means, S0, 1.0, mask=mask)
 
 
 def test_nlmeans_4D_and_mask():
-    S0 = 200 * np.ones((20, 20, 20, 3), dtype='f8')
+    S0 = 200 * np.ones((20, 20, 20, 3), dtype="f8")
     mask = np.zeros((20, 20, 20))
     mask[10, 10, 10] = 1
     S0n = non_local_means(S0, sigma=1, mask=mask, rician=True)
@@ -75,8 +90,7 @@ def test_nlmeans_4D_and_mask():
 
 
 def test_nlmeans_dtype():
-
-    S0 = 200 * np.ones((20, 20, 20, 3), dtype='f4')
+    S0 = 200 * np.ones((20, 20, 20, 3), dtype="f4")
     mask = np.zeros((20, 20, 20))
     mask[10:14, 10:14, 10:14] = 1
     S0n = non_local_means(S0, sigma=1, mask=mask, rician=True)
@@ -86,3 +100,18 @@ def test_nlmeans_dtype():
     mask[10:14, 10:14, 10:14] = 1
     S0n = non_local_means(S0, sigma=1, mask=mask, rician=True)
     assert_equal(S0.dtype, S0n.dtype)
+
+
+def test_nlmeans_2D_sigma():
+    S0 = np.ones((20, 20, 20, 3))
+    noise = np.ones((3, 2))
+    assert_raises(ValueError, non_local_means, S0, sigma=noise, rician=True)
+
+    S0 = np.ones((20, 20, 20))
+    assert_raises(ValueError, non_local_means, S0, sigma=noise, rician=True)
+
+
+def test_nlmeans_sigma_arr():
+    S0 = np.ones((20, 20, 20, 3))
+    noise = np.ones(4)
+    assert_raises(ValueError, non_local_means, S0, sigma=noise, rician=True)
