@@ -1,8 +1,8 @@
+import io
 from os.path import splitext
 import re
-import io
-import tempfile
 import warnings
+
 import numpy as np
 
 
@@ -38,20 +38,27 @@ def read_bvals_bvecs(fbvals, fbvecs):
             continue
 
         if not isinstance(this_fname, str):
-            raise ValueError('String with full path to file is required')
+            raise ValueError("String with full path to file is required")
 
         base, ext = splitext(this_fname)
-        if ext in ['.bvals', '.bval', '.bvecs', '.bvec', '.txt',
-                   '.eddy_rotated_bvecs', '']:
-            with open(this_fname, 'r') as f:
+        if ext in [
+            ".bvals",
+            ".bval",
+            ".bvecs",
+            ".bvec",
+            ".txt",
+            ".eddy_rotated_bvecs",
+            "",
+        ]:
+            with open(this_fname, "r") as f:
                 content = f.read()
 
-            munged_content = io.StringIO(re.sub(r'(\t|,)', ' ', content))
+            munged_content = io.StringIO(re.sub(r"(\t|,)", " ", content))
             vals.append(np.squeeze(np.loadtxt(munged_content)))
-        elif ext == '.npy':
+        elif ext == ".npy":
             vals.append(np.squeeze(np.load(this_fname)))
         else:
-            e_s = "File type %s is not recognized" % ext
+            e_s = f"File type {ext} is not recognized"
             raise ValueError(e_s)
 
     # Once out of the loop, unpack them:
@@ -62,14 +69,14 @@ def read_bvals_bvecs(fbvals, fbvecs):
         return bvals, bvecs
 
     if 3 not in bvecs.shape:
-        raise OSError('bvec file should have three rows')
+        raise OSError("bvec file should have three rows")
     if bvecs.ndim != 2:
         bvecs = bvecs[None, ...]
         bvals = bvals[None, ...]
         msg = "Detected only 1 direction on your bvec file. For diffusion "
         msg += "dataset, it is recommended to have at least 3 directions."
         msg += "You may have problems during the reconstruction step."
-        warnings.warn(msg)
+        warnings.warn(msg, stacklevel=2)
     if bvecs.shape[1] != 3:
         bvecs = bvecs.T
 
@@ -78,9 +85,9 @@ def read_bvals_bvecs(fbvals, fbvecs):
         return bvals, bvecs
 
     if len(bvals.shape) > 1:
-        raise OSError('bval file should have one row')
+        raise OSError("bval file should have one row")
 
     if bvals.shape[0] != bvecs.shape[0]:
-        raise OSError('b-values and b-vectors shapes do not correspond')
+        raise OSError("b-values and b-vectors shapes do not correspond")
 
     return bvals, bvecs
