@@ -1,8 +1,12 @@
 from warnings import warn
+
 import nibabel as nib
 
+from dipy.testing.decorators import warning_for_keywords
 
-def load_pial(fname, return_meta=False):
+
+@warning_for_keywords()
+def load_pial(fname, *, return_meta=False):
     """Load pial file.
 
     Parameters
@@ -21,7 +25,7 @@ def load_pial(fname, return_meta=False):
     try:
         return nib.freesurfer.read_geometry(fname, read_metadata=return_meta)
     except ValueError:
-        warn(f'The file {fname} provided does not have geometry data.')
+        warn(f"The file {fname} provided does not have geometry data.", stacklevel=2)
 
 
 def load_gifti(fname):
@@ -38,4 +42,4 @@ def load_gifti(fname):
         (vertices, faces)
     """
     surf_img = nib.load(fname)
-    return surf_img.agg_data(('pointset', 'triangle'))
+    return surf_img.agg_data(("pointset", "triangle"))
