@@ -5,4 +5,4 @@ from dipy import io
 
 def test_imports():
     # Make sure io has not pulled in setup_module from dpy
-    assert not hasattr(io, 'setup_module')
+    assert not hasattr(io, "setup_module")
