@@ -1,11 +1,14 @@
 import numpy as np
+
+from dipy.testing.decorators import warning_for_keywords
 from dipy.tracking.streamline import transform_streamlines
 from dipy.utils.optpkg import optional_package
-fury, have_fury, setup_module = optional_package('fury', min_version="0.10.0")
+
+fury, have_fury, setup_module = optional_package("fury", min_version="0.10.0")
 
 if have_fury:
-    import fury.utils
     import fury.io
+    import fury.utils
 
 
 def load_polydata(file_name):
@@ -25,7 +28,8 @@ def load_polydata(file_name):
     return fury.io.load_polydata(file_name)
 
 
-def save_polydata(polydata, file_name, binary=False, color_array_name=None):
+@warning_for_keywords()
+def save_polydata(polydata, file_name, *, binary=False, color_array_name=None):
     """Save a vtk polydata to a supported format file.
 
     Save formats can be VTK, VTP, FIB, PLY, STL and XML.
@@ -36,12 +40,16 @@ def save_polydata(polydata, file_name, binary=False, color_array_name=None):
     file_name : string
 
     """
-    fury.io.save_polydata(polydata=polydata, file_name=file_name,
-                          binary=binary, color_array_name=color_array_name)
+    fury.io.save_polydata(
+        polydata=polydata,
+        file_name=file_name,
+        binary=binary,
+        color_array_name=color_array_name,
+    )
 
 
-def save_vtk_streamlines(streamlines, filename,
-                         to_lps=True, binary=False):
+@warning_for_keywords()
+def save_vtk_streamlines(streamlines, filename, *, to_lps=True, binary=False):
     """Save streamlines as vtk polydata to a supported format file.
 
     File formats can be OBJ, VTK, VTP, FIB, PLY, STL and XML
@@ -70,7 +78,8 @@ def save_vtk_streamlines(streamlines, filename,
     save_polydata(polydata, file_name=filename, binary=binary)
 
 
-def load_vtk_streamlines(filename, to_lps=True):
+@warning_for_keywords()
+def load_vtk_streamlines(filename, *, to_lps=True):
     """Load streamlines from vtk polydata.
 
     Load formats can be VTK, FIB
