@@ -1,7 +1,8 @@
 import warnings
 
 import numpy as np
-from dipy.nn.utils import normalize, unnormalize, transform_img, recover_img
+
+from dipy.nn.utils import normalize, recover_img, transform_img, unnormalize
 from dipy.testing.decorators import set_random_number_generator
 
 
@@ -16,9 +17,9 @@ def test_norm(rng=None):
 @set_random_number_generator()
 def test_transform(rng=None):
     temp = rng.random((30, 31, 32))
-    temp2, new_affine, ori_shape = transform_img(temp, np.eye(4),
-                                                 init_shape=(32, 32, 32),
-                                                 voxsize=np.ones(3)*2)
+    temp2, affine, mid_shape, offset_array, scale, crop_vs, pad_vs = transform_img(
+        temp, np.eye(4), init_shape=(32, 32, 32), voxsize=np.ones(3) * 2
+    )
     with warnings.catch_warnings():
         scipy_affine_txfm_msg = (
             "The behavior of affine_transform with a 1-D "
@@ -26,8 +27,17 @@ def test_transform(rng=None):
             "SciPy 0.18.0."
         )
         warnings.filterwarnings(
-            "ignore", message=scipy_affine_txfm_msg,
-            category=UserWarning)
-        temp2 = recover_img(temp2, new_affine, ori_shape, temp.shape,
-                            init_shape=(32, 32, 32), voxsize=np.ones(3)*2)
+            "ignore", message=scipy_affine_txfm_msg, category=UserWarning
+        )
+        temp2 = recover_img(
+            temp2,
+            affine,
+            mid_shape,
+            temp.shape,
+            offset_array,
+            np.ones(3) * 2,
+            scale,
+            crop_vs,
+            pad_vs,
+        )
     np.testing.assert_almost_equal(np.array(temp.shape), np.array(temp2.shape))
