@@ -10,10 +10,11 @@ particular set of data (different voxels, for example).
 
 """
 
+from dipy.testing.decorators import warning_for_keywords
+
 
 class ReconstModel:
-    """ Abstract class for signal reconstruction models
-    """
+    """Abstract class for signal reconstruction models"""
 
     def __init__(self, gtab):
         """Initialization of the abstract class for signal reconstruction models
@@ -21,16 +22,18 @@ class ReconstModel:
         Parameters
         ----------
         gtab : GradientTable class instance
+            Gradient table.
 
         """
         self.gtab = gtab
 
-    def fit(self, data, mask=None, **kwargs):
+    @warning_for_keywords()
+    def fit(self, data, *, mask=None, **kwargs):
         return ReconstFit(self, data)
 
 
 class ReconstFit:
-    """ Abstract class which holds the fit result of ReconstModel
+    """Abstract class which holds the fit result of ReconstModel
 
     For example that could be holding FA or GFA etc.
     """
