@@ -1,11 +1,16 @@
-"""Cross-validation analysis of diffusion models."""
+"""
+Cross-validation analysis of diffusion models.
+"""
 
 import numpy as np
+
 import dipy.core.gradients as gt
+from dipy.testing.decorators import warning_for_keywords
 
 
-def coeff_of_determination(data, model, axis=-1):
-    """Calculate the coefficient of determination for a model prediction,
+@warning_for_keywords()
+def coeff_of_determination(data, model, *, axis=-1):
+    r"""Calculate the coefficient of determination for a model prediction,
     relative to data.
 
     Parameters
@@ -15,7 +20,7 @@ def coeff_of_determination(data, model, axis=-1):
     model : ndarray
         The predictions of a model for this data. Same shape as the data.
     axis: int, optional
-        The axis along which different samples are laid out (default: -1).
+        The axis along which different samples are laid out.
 
     Returns
     -------
@@ -38,22 +43,24 @@ def coeff_of_determination(data, model, axis=-1):
 
     """
     residuals = data - model
-    ss_err = np.sum(residuals ** 2, axis=axis)
+    ss_err = np.sum(residuals**2, axis=axis)
 
     demeaned_data = data - np.mean(data, axis=axis)[..., np.newaxis]
-    ss_tot = np.sum(demeaned_data ** 2, axis=axis)
+    ss_tot = np.sum(demeaned_data**2, axis=axis)
 
     # Don't divide by 0:
     if np.all(ss_tot == 0.0):
         return np.nan
 
-    return 100 * (1 - (ss_err/ss_tot))
+    return 100 * (1 - (ss_err / ss_tot))
 
 
 def kfold_xval(model, data, folds, *model_args, **model_kwargs):
     """Perform k-fold cross-validation.
 
-    It generate out-of-sample predictions for each measurement.
+    It generates out-of-sample predictions for each measurement.
+
+    See :footcite:p:`Rokem2014` for further details about the method.
 
     Parameters
     ----------
@@ -89,12 +96,10 @@ def kfold_xval(model, data, folds, *model_args, **model_kwargs):
 
     References
     ----------
-    .. [1] Rokem, A., Chan, K.L. Yeatman, J.D., Pestilli, F., Mezer, A.,
-       Wandell, B.A., 2014. Evaluating the accuracy of diffusion models at
-       multiple b-values with cross-validation. ISMRM 2014.
+    .. footbibliography::
 
     """
-    rng = model_kwargs.pop('rng', np.random.default_rng())
+    _ = model_kwargs.pop("rng", np.random.default_rng())
 
     # This should always be there, if the model inherits from
     # dipy.reconst.base.ReconstModel:
@@ -105,7 +110,7 @@ def kfold_xval(model, data, folds, *model_args, **model_kwargs):
     if div_by_folds != 0:
         msg = "The number of folds must divide the diffusion-weighted "
         msg += "data equally, but "
-        msg = "np.mod(%s, %s) is %s" % (data_b.shape[-1], folds, div_by_folds)
+        msg = f"np.mod({data_b.shape[-1]}, {folds}) is {div_by_folds}"
         raise ValueError(msg)
 
     data_0 = data[..., gtab.b0s_mask]
@@ -119,34 +124,33 @@ def kfold_xval(model, data, folds, *model_args, **model_kwargs):
     nz_bvec = gtab.bvecs[~gtab.b0s_mask]
 
     # Pop the mask, if there is one, out here for use in every fold:
-    mask = model_kwargs.pop('mask', None)
+    mask = model_kwargs.pop("mask", None)
     gtgt = gt.gradient_table  # Shorthand
     for k in range(folds):
         fold_mask = np.ones(data_b.shape[-1], dtype=bool)
-        fold_idx = order[int(k * n_in_fold): int((k + 1) * n_in_fold)]
+        fold_idx = order[int(k * n_in_fold) : int((k + 1) * n_in_fold)]
         fold_mask[fold_idx] = False
         this_data = np.concatenate([data_0, data_b[..., fold_mask]], -1)
 
-        this_gtab = gtgt(np.hstack([gtab.bvals[gtab.b0s_mask],
-                                    nz_bval[fold_mask]]),
-                         np.concatenate([gtab.bvecs[gtab.b0s_mask],
-                                         nz_bvec[fold_mask]]))
-        left_out_gtab = gtgt(np.hstack([gtab.bvals[gtab.b0s_mask],
-                                        nz_bval[~fold_mask]]),
-                             np.concatenate([gtab.bvecs[gtab.b0s_mask],
-                                             nz_bvec[~fold_mask]]))
+        this_gtab = gtgt(
+            np.hstack([gtab.bvals[gtab.b0s_mask], nz_bval[fold_mask]]),
+            bvecs=np.concatenate([gtab.bvecs[gtab.b0s_mask], nz_bvec[fold_mask]]),
+        )
+        left_out_gtab = gtgt(
+            np.hstack([gtab.bvals[gtab.b0s_mask], nz_bval[~fold_mask]]),
+            bvecs=np.concatenate([gtab.bvecs[gtab.b0s_mask], nz_bvec[~fold_mask]]),
+        )
         this_model = model.__class__(this_gtab, *model_args, **model_kwargs)
         this_fit = this_model.fit(this_data, mask=mask)
-        if not hasattr(this_fit, 'predict'):
-            err_str = "Models of type: %s " % this_model.__class__
+        if not hasattr(this_fit, "predict"):
+            err_str = f"Models of type: {this_model.__class__} "
             err_str += "do not have an implementation of model prediction"
             err_str += " and do not support cross-validation"
             raise ValueError(err_str)
-        this_predict = S0[..., None] * this_fit.predict(left_out_gtab, S0=1)
+        this_predict = S0[..., None] * this_fit.predict(gtab=left_out_gtab, S0=1)
 
         idx_to_assign = np.where(~gtab.b0s_mask)[0][~fold_mask]
-        prediction[..., idx_to_assign] =\
-            this_predict[..., np.sum(gtab.b0s_mask):]
+        prediction[..., idx_to_assign] = this_predict[..., np.sum(gtab.b0s_mask) :]
 
     # For the b0 measurements
     prediction[..., gtab.b0s_mask] = S0[..., None]
