@@ -1,19 +1,22 @@
 #!/usr/bin/python
-""" Classes and functions for fitting the correlation tensor model """
+"""Classes and functions for fitting the correlation tensor model"""
 
 import numpy as np
-from dipy.reconst.multi_voxel import multi_voxel_fit
+
+from dipy.core.onetime import auto_attr
 from dipy.reconst.base import ReconstModel
-from dipy.reconst.utils import cti_design_matrix as design_matrix
 from dipy.reconst.dki import (
     DiffusionKurtosisFit,
 )
 from dipy.reconst.dti import (
+    MIN_POSITIVE_SIGNAL,
     decompose_tensor,
     from_lower_triangular,
     lower_triangular,
-    MIN_POSITIVE_SIGNAL)
-from dipy.core.onetime import auto_attr
+)
+from dipy.reconst.multi_voxel import multi_voxel_fit
+from dipy.reconst.utils import cti_design_matrix as design_matrix
+from dipy.testing.decorators import warning_for_keywords
 
 
 def from_qte_to_cti(C):
@@ -66,7 +69,8 @@ def multi_gaussian_k_from_c(ccti, MD):
     ----------
     ccti: array(..., 21)
         Covariance Tensor Elements with no hidden factors.
-    MD: Mean Diffusivity (MD) of a diffusion tensor.
+    MD : ndarray
+        Mean Diffusivity (MD) of a diffusion tensor.
 
     Returns
     -------
@@ -74,15 +78,15 @@ def multi_gaussian_k_from_c(ccti, MD):
         Fifteen elements of the kurtosis tensor
     """
     K = np.zeros((15, 1))
-    K[0] = 3 * ccti[0] / (MD ** 2)
-    K[1] = 3 * ccti[1] / (MD ** 2)
-    K[2] = 3 * ccti[2] / (MD ** 2)
-    K[3] = 3 * ccti[8] / (MD ** 2)
-    K[4] = 3 * ccti[7] / (MD ** 2)
-    K[5] = 3 * ccti[11] / (MD ** 2)
-    K[6] = 3 * ccti[9] / (MD ** 2)
-    K[7] = 3 * ccti[13] / (MD ** 2)
-    K[8] = 3 * ccti[12] / (MD ** 2)
+    K[0] = 3 * ccti[0] / (MD**2)
+    K[1] = 3 * ccti[1] / (MD**2)
+    K[2] = 3 * ccti[2] / (MD**2)
+    K[3] = 3 * ccti[8] / (MD**2)
+    K[4] = 3 * ccti[7] / (MD**2)
+    K[5] = 3 * ccti[11] / (MD**2)
+    K[6] = 3 * ccti[9] / (MD**2)
+    K[7] = 3 * ccti[13] / (MD**2)
+    K[8] = 3 * ccti[12] / (MD**2)
     K[9] = (ccti[5] + 2 * ccti[17]) / (MD**2)
     K[10] = (ccti[4] + 2 * ccti[16]) / (MD**2)
     K[11] = (ccti[3] + 2 * ccti[15]) / (MD**2)
@@ -102,13 +106,13 @@ def split_cti_params(cti_params):
 
     Parameters
     ----------
-        params: numpy.ndarray (..., 48)
+    cti_params: numpy.ndarray (..., 48)
         All parameters estimated from the correlation tensor model.
         Parameters are ordered as follows:
 
             1. Three diffusion tensor's eigenvalues
             2. Three lines of the eigenvector matrix each containing the
-            first, second and third coordinates of the eigenvector
+               first, second and third coordinates of the eigenvector
             3. Fifteen elements of the kurtosis tensor
             4. Twenty-One elements of the covariance tensor
 
@@ -124,7 +128,7 @@ def split_cti_params(cti_params):
         Fifteen elements of the kurtosis tensor
     ct: array(..., 21)
         Twenty-one elements of the covariance tensor
-       """
+    """
     evals = cti_params[..., :3]
     evecs = cti_params[..., 3:12].reshape(cti_params.shape[:-1] + (3, 3))
     kt = cti_params[..., 12:27]
@@ -132,33 +136,36 @@ def split_cti_params(cti_params):
     return evals, evecs, kt, ct
 
 
-def cti_prediction(cti_params, gtab1, gtab2, S0=1):
+@warning_for_keywords()
+def cti_prediction(cti_params, gtab1, gtab2, *, S0=1):
     """Predict a signal given correlation tensor imaging parameters.
 
-        Parameters
-        ----------
-        cti_params: numpy.ndarray (..., 48)
+    Parameters
+    ----------
+    cti_params: numpy.ndarray (..., 48)
         All parameters estimated from the correlation tensor model.
         Parameters are ordered as follows:
+
             1. Three diffusion tensor's eigenvalues
             2. Three lines of the eigenvector matrix each containing the
-            first, second and third coordinates of the eigenvector
+               first, second and third coordinates of the eigenvector
             3. Fifteen elements of the kurtosis tensor
             4. Twenty-One elements of the covariance tensor
-        gtab1: dipy.core.gradients.GradientTable
-            A GradientTable class instance for first DDE diffusion epoch
 
-        gtab2: dipy.core.gradients.GradientTable
-            A GradientTable class instance for second DDE diffusion epoch
+    gtab1: dipy.core.gradients.GradientTable
+        A GradientTable class instance for first DDE diffusion epoch
 
-        S0 : float or ndarray (optional)
-            The non diffusion-weighted signal in every voxel, or across all
-            voxels. Default: 1
+    gtab2: dipy.core.gradients.GradientTable
+        A GradientTable class instance for second DDE diffusion epoch
 
-        Returns
-        -------
-        S : ndarray
-            Simulated signal based on the CTI model
+    S0 : float or ndarray, optional
+        The non diffusion-weighted signal in every voxel, or across all
+        voxels. Default: 1
+
+    Returns
+    -------
+    S : ndarray
+        Simulated signal based on the CTI model
 
     """
     evals, evecs, kt, ct = split_cti_params(cti_params)
@@ -181,9 +188,9 @@ def cti_prediction(cti_params, gtab1, gtab2, S0=1):
             this_S0 = S0_vol[v]
         else:
             this_S0 = S0_vol
-        X = np.concatenate((dt, fkt[v] * MD * MD, fct[v],
-                            np.array([-np.log(this_S0)])),
-                           axis=0)
+        X = np.concatenate(
+            (dt, fkt[v] * MD * MD, fct[v], np.array([-np.log(this_S0)])), axis=0
+        )
         pred_sig[v] = np.exp(np.dot(A, X))
     pred_sig = pred_sig.reshape(cti_params.shape[:-1] + (pred_sig.shape[-1],))
 
@@ -191,11 +198,12 @@ def cti_prediction(cti_params, gtab1, gtab2, S0=1):
 
 
 class CorrelationTensorModel(ReconstModel):
-    """ Class for the Correlation Tensor Model
-    """
+    """Class for the Correlation Tensor Model"""
 
-    def __init__(self, gtab1, gtab2, fit_method="WLS", *args, **kwargs):
-        """ Correlation Tensor Imaging Model [1]
+    def __init__(self, gtab1, gtab2, *args, fit_method="WLS", **kwargs):
+        """Correlation Tensor Imaging Model.
+
+        See :footcite:p:`NetoHenriques2020` for further details about the model.
 
         Parameters
         ----------
@@ -204,9 +212,15 @@ class CorrelationTensorModel(ReconstModel):
         gtab2: dipy.core.gradients.GradientTable
             A GradientTable class instance for second DDE diffusion epoch
         fit_method : str or callable, optional
-        args, kwargs :
-            arguments and key-word arguments passed to the fit_method.
+            Fitting method.
+        *args
+            Variable length argument list passed to the :func:`fit` method.
+        **kwargs
+            Arbitrary keyword arguments passed to the :func:`fit` method.
 
+        References
+        ----------
+        .. footbibliography::
         """
         self.gtab1 = gtab1
         self.gtab2 = gtab2
@@ -217,17 +231,16 @@ class CorrelationTensorModel(ReconstModel):
         if self.common_fit_method:
             try:
                 self.fit_method = common_fit_methods[fit_method]
-            except KeyError:
-                msg = '"' + str(fit_method) + \
-                    '" is not a known fit method. The'
-                msg += ' fit method should either be a function or one of the'
-                msg += ' common fit methods.'
-                raise ValueError(msg)
+            except KeyError as e:
+                msg = '"' + str(fit_method) + '" is not a known fit method. The'
+                msg += " fit method should either be a function or one of the"
+                msg += " common fit methods."
+                raise ValueError(msg) from e
 
         self.args = args
         self.kwargs = kwargs
 
-        self.min_signal = self.kwargs.pop('min_signal', None)
+        self.min_signal = self.kwargs.pop("min_signal", None)
         if self.min_signal is None:
             self.min_signal = MIN_POSITIVE_SIGNAL
         elif self.min_signal <= 0:
@@ -240,11 +253,12 @@ class CorrelationTensorModel(ReconstModel):
 
         tol = 1e-6
         self.min_diffusivity = tol / -self.design_matrix.min()
-        self.weights = fit_method in {'WLS', 'WLLS', 'UWLLS'}
+        self.weights = fit_method in {"WLS", "WLLS", "UWLLS"}
 
     @multi_voxel_fit
-    def fit(self, data, mask=None):
-        """ Fit method of the CTI model class.
+    @warning_for_keywords()
+    def fit(self, data, *, mask=None):
+        """Fit method of the CTI model class.
 
         Parameters
         ----------
@@ -256,34 +270,40 @@ class CorrelationTensorModel(ReconstModel):
             designates which coordinates in the data should be analyzed.
         """
         data_thres = np.maximum(data, self.min_signal)
-        params = self.fit_method(self.design_matrix, data_thres,
-                                 self.inverse_design_matrix,
-                                 weights=self.weights,
-                                 *self.args, **self.kwargs)
+        params = self.fit_method(
+            self.design_matrix,
+            data_thres,
+            self.inverse_design_matrix,
+            weights=self.weights,
+            *self.args,
+            **self.kwargs,
+        )
 
         return CorrelationTensorFit(self, params)
 
-    def predict(self, cti_params, S0=1):
+    @warning_for_keywords()
+    def predict(self, cti_params, *, S0=1):
         """Predict a signal for the CTI model class instance given parameters
 
         Parameters
         ----------
         cti_params: numpy.ndarray (..., 48)
-        All parameters estimated from the correlation tensor model.
-        Parameters are ordered as follows:
+            All parameters estimated from the correlation tensor model.
+            Parameters are ordered as follows:
+
+                1. Three diffusion tensor's eigenvalues
+                2. Three lines of the eigenvector matrix each containing the
+                   first, second and third coordinates of the eigenvector
+                3. Fifteen elements of the kurtosis tensor
+                4. Twenty-One elements of the covariance tensor
 
-            1. Three diffusion tensor's eigenvalues
-            2. Three lines of the eigenvector matrix each containing the
-            first, second and third coordinates of the eigenvector
-            3. Fifteen elements of the kurtosis tensor
-            4. Twenty-One elements of the covariance tensor
         gtab1: dipy.core.gradients.GradientTable
             A GradientTable class instance for first DDE diffusion epoch
         gtab2: dipy.core.gradients.GradientTable
             A GradientTable class instance for second DDE diffusion epoch
-        S0 : float or ndarray (optional)
+        S0 : float or ndarray, optional
             The non diffusion-weighted signal in every voxel, or across all
-            voxels. Default: 1
+            voxels.
 
         Returns
         -------
@@ -291,15 +311,14 @@ class CorrelationTensorModel(ReconstModel):
             Predicted signal based on the CTI model
         """
 
-        return cti_prediction(cti_params, self.gtab1, self.gtab2, S0)
+        return cti_prediction(cti_params, self.gtab1, self.gtab2, S0=S0)
 
 
 class CorrelationTensorFit(DiffusionKurtosisFit):
-
-    """ Class for fitting the Correlation Tensor Model """
+    """Class for fitting the Correlation Tensor Model"""
 
     def __init__(self, model, model_params):
-        """ Initialize a CorrelationTensorFit class instance.
+        """Initialize a CorrelationTensorFit class instance.
 
         Parameters
         ----------
@@ -308,6 +327,7 @@ class CorrelationTensorFit(DiffusionKurtosisFit):
         model_params : ndarray (x, y, z, 48) or (n, 48)
             All parameters estimated from the diffusion kurtosis model.
             Parameters are ordered as follows:
+
                 1) Three diffusion tensor's eigenvalues
                 2) Three lines of the eigenvector matrix each containing the
                    first, second and third coordinates of the eigenvector
@@ -325,26 +345,18 @@ class CorrelationTensorFit(DiffusionKurtosisFit):
         """
         return self.model_params[..., 27:48]
 
-    def predict(self, gtab1, gtab2, S0=1):
+    @warning_for_keywords()
+    def predict(self, gtab1, gtab2, *, S0=1):
         """Given a CTI model fit, predict the signal on the vertices of a
         gradient table
 
-        Parameters:
-        -----------
-        params: numpy.ndarray (...,43)
-                All parameters estimated from the correlation tensor model.
-                Parameters are ordered as follows:
-
-                1. Three diffusion tensor's eigenvalues
-                2. Three lines of the eigenvector matrix each containing the
-                first, second and third coordinates of the eigenvector
-                3. Fifteen elements of the kurtosis tensor
-                4. Twenty-One elements of the covariance tensor
+        Parameters
+        ----------
         gtab1: dipy.core.gradients.GradientTable
             A GradientTable class instance for first DDE diffusion epoch
         gtab2: dipy.core.gradients.GradientTable
             A GradientTable class instance for second DDE diffusion epoch
-        S0 : float or ndarray (optional)
+        S0 : float or ndarray, optional
             The non diffusion-weighted signal in every voxel, or across all
             voxels. Default: 1
 
@@ -353,77 +365,103 @@ class CorrelationTensorFit(DiffusionKurtosisFit):
         S : numpy.ndarray
             Predicted signal based on the CTI model
         """
-        return cti_prediction(self.model_params, gtab1, gtab2, S0)
+        return cti_prediction(self.model_params, gtab1, gtab2, S0=S0)
 
     @property
     def K_aniso(self):
-        r""" Returns the anisotropic Source of Kurtosis (K_aniso)
+        r"""Returns the anisotropic Source of Kurtosis ($K_{aniso}$)
 
-            Notes
-            -----
-            The K_aniso is defined as[1]_:
+        Notes
+        -----
+        The $K_{aniso}$ is defined as :footcite:p:`NetoHenriques2020`:
 
-            :math::
+        .. math::
 
             \[K_{aniso} = \frac{6}{5} \cdot \frac{\langle V_{\lambda}(D_c)
-                                                  \rangle}{\overline{D}^2}\]
+                                              \rangle}{\overline{D}^2}\]
 
-        where: $K_{aniso}$ is the anisotropic kurtosis,
-            $\langle V_{\lambda}(D_c) \rangle$ represents the mean of the
-            variance of eigenvalues of the diffusion tensor,
-            $\overline{D}$ is the mean of the diffusion tensor.
+        where $K_{aniso}$ is the anisotropic kurtosis,
+        $\langle V_{\lambda}(D_c) \rangle$ represents the mean of the variance
+        of eigenvalues of the diffusion tensor, $\overline{D}$ is the mean of
+        the diffusion tensor.
 
         References
         ----------
-        .. [1]  [NetoHe2020] Henriques, R.N., Jespersen, S.N., Shemesh, N., 2020.
-                Correlation tensor magnetic resonance imaging. Neuroimage 211.
-                doi: 10.1016/j.neuroimage.2020.116605
+        .. footbibliography::
         """
         C = self.ct
         D = self.quadratic_form
 
-        Variance = 2/9 * (C[..., 0] + D[..., 0, 0] ** 2 + C[..., 1]
-                          + D[..., 1, 1] ** 2 + C[..., 2]
-                          + D[..., 2, 2]**2 - C[..., 5]
-                          - D[..., 0, 0] * D[..., 1, 1] -
-                          C[..., 4] - D[..., 0, 0] * D[..., 2, 2]
-                          - C[..., 3] - D[..., 1, 1] * D[..., 2, 2]
-                          + 3 * (C[..., 17] + D[..., 0, 1] ** 2 + C[..., 16]
-                                 + D[..., 0, 2] ** 2
-                                 + C[..., 15] + D[..., 1, 2] ** 2))
+        Variance = (
+            2
+            / 9
+            * (
+                C[..., 0]
+                + D[..., 0, 0] ** 2
+                + C[..., 1]
+                + D[..., 1, 1] ** 2
+                + C[..., 2]
+                + D[..., 2, 2] ** 2
+                - C[..., 5]
+                - D[..., 0, 0] * D[..., 1, 1]
+                - C[..., 4]
+                - D[..., 0, 0] * D[..., 2, 2]
+                - C[..., 3]
+                - D[..., 1, 1] * D[..., 2, 2]
+                + 3
+                * (
+                    C[..., 17]
+                    + D[..., 0, 1] ** 2
+                    + C[..., 16]
+                    + D[..., 0, 2] ** 2
+                    + C[..., 15]
+                    + D[..., 1, 2] ** 2
+                )
+            )
+        )
         mean_D = np.trace(D) / 3
         if mean_D == 0:
             K_aniso = 0
         else:
-            K_aniso = (6/5) * (Variance / (mean_D ** 2))
+            K_aniso = (6 / 5) * (Variance / (mean_D**2))
 
         return K_aniso
 
     @property
     def K_iso(self):
-        r""" Returns the isotropic Source of Kurtosis (K_iso)
+        r"""Returns the isotropic Source of Kurtosis ($K_{iso}$)
 
         Notes
         -----
-        The K_iso is defined as :
+        The $K_{iso}$ is defined as :
 
-        :math::
-            $$ K_{\text{iso}} = 3 \cdot \frac{V(\overline{D}^c)}{\overline{D}^2} $$
+        .. math::
 
-        where: $ K_{\text{iso}} $ is the isotropic kurtosis,
-            \(V({\overline{D}^c})\) represents the variance of the diffusion
-            tensor raised to the power c,
-            \(\overline{D}\) is the mean of the diffusion tensor.
+            K_{\text{iso}} = 3 \cdot \frac{V(\overline{D}^c)}{\overline{D}^2}
+
+        where: $K_{\text{iso}}$ is the isotropic kurtosis, $V({\overline{D}^c})$
+        represents the variance of the diffusion tensor raised to the power $c$,
+        $\overline{D}$ is the mean of the diffusion tensor.
 
         """
         C = self.ct
         mean_D = self.md
-        Variance = 1/9 * (C[..., 0] + C[..., 1] + C[..., 2] + 2 * C[..., 5]
-                          + 2 * C[..., 4] + 2 * C[..., 3])
+        Variance = (
+            1
+            / 9
+            * (
+                C[..., 0]
+                + C[..., 1]
+                + C[..., 2]
+                + 2 * C[..., 5]
+                + 2 * C[..., 4]
+                + 2 * C[..., 3]
+            )
+        )
         if mean_D == 0:
             K_iso = 0
         else:
-            K_iso = 3 * (Variance / (mean_D ** 2))
+            K_iso = 3 * (Variance / (mean_D**2))
         return K_iso
 
     @auto_attr
@@ -432,9 +470,9 @@ class CorrelationTensorFit(DiffusionKurtosisFit):
 
             Notes
             -----
-            $K_total$ is defined as :
+            $K_{total}$ is defined as:
 
-            :math::
+            .. math::
                 \[\Psi = \frac{2}{5} \cdot \frac{D_{11}^2 + D_{22}^2 + D_{33}^2
                                                  + 2D_{12}^2 + 2D_{13}^2 +
                                                  2D_{23}^2{\overline{D}^2} -
@@ -444,12 +482,11 @@ class CorrelationTensorFit(DiffusionKurtosisFit):
                                                       + 2W_{1133} + 2W_{2233})\
                   ]
 
-            where \(\Psi\) is a variable representing a part of the total
-            excess kurtosis,
-            \(D_{ij}\) are elements of the diffusion tensor,
-            \(\overline{D}\) is the mean of the diffusion tensor.
-            \{\overline{W}} is the mean kurtosis,
-            \(W_{ijkl}\) are elements of the kurtosis tensor.
+            where $\Psi$ is a variable representing a part of the total
+            excess kurtosis, $D_{ij}$ are elements of the diffusion tensor,
+            $\overline{D}$ is the mean of the diffusion tensor. $\overline{W}$
+            is the mean kurtosis, $W_{ijkl}$ are elements of the kurtosis
+            tensor.
         """
 
         mean_K = self.mkt()
@@ -458,16 +495,23 @@ class CorrelationTensorFit(DiffusionKurtosisFit):
         if mean_D == 0:
             psi = 0
         else:
-            psi = 2 / 5 * ((D[..., 0, 0]**2 + D[..., 1, 1]**2
-                            + D[..., 2, 2]**2
-                            + 2 * D[..., 0, 1]**2 + 2 * D[..., 0, 2]**2
-                            + D[..., 1, 2]**2) / (mean_D ** 2)) - (6/5)
+            psi = 2 / 5 * (
+                (
+                    D[..., 0, 0] ** 2
+                    + D[..., 1, 1] ** 2
+                    + D[..., 2, 2] ** 2
+                    + 2 * D[..., 0, 1] ** 2
+                    + 2 * D[..., 0, 2] ** 2
+                    + D[..., 1, 2] ** 2
+                )
+                / (mean_D**2)
+            ) - (6 / 5)
 
         return mean_K + psi
 
     @property
     def K_micro(self):
-        r""" Returns Microscopic Source of Kurtosis.  """
+        r"""Returns Microscopic Source of Kurtosis."""
 
         K_total = self.K_total
         K_aniso = self.K_aniso
@@ -476,28 +520,33 @@ class CorrelationTensorFit(DiffusionKurtosisFit):
         return micro_K
 
 
-def params_to_cti_params(result, min_diffusivity=0):
+@warning_for_keywords()
+def params_to_cti_params(result, *, min_diffusivity=0):
     # Extracting the diffusion tensor parameters from solution
     DT_elements = result[:6]
-    evals, evecs = decompose_tensor(from_lower_triangular(DT_elements),
-                                    min_diffusivity=min_diffusivity)
+    evals, evecs = decompose_tensor(
+        from_lower_triangular(DT_elements), min_diffusivity=min_diffusivity
+    )
     # Extracting kurtosis tensor parameters from solution
-    MD_square = evals.mean(0)**2
-    KT_elements = result[6:21] / MD_square if MD_square else 0.*result[6:21]
+    MD_square = evals.mean(0) ** 2
+    KT_elements = result[6:21] / MD_square if MD_square else 0.0 * result[6:21]
 
     # Extracting correlation tensor parameters from solution
     CT_elements = result[21:42]
 
     # Write output
-    cti_params = np.concatenate((evals, evecs[0], evecs[1], evecs[2],
-                                KT_elements, CT_elements), axis=0)
+    cti_params = np.concatenate(
+        (evals, evecs[0], evecs[1], evecs[2], KT_elements, CT_elements), axis=0
+    )
 
     return cti_params
 
 
-def ls_fit_cti(design_matrix, data, inverse_design_matrix, weights=True,
-               min_diffusivity=0):
-    r""" Compute the diffusion kurtosis and covariance tensors using an
+@warning_for_keywords()
+def ls_fit_cti(
+    design_matrix, data, inverse_design_matrix, *, weights=True, min_diffusivity=0
+):
+    r"""Compute the diffusion kurtosis and covariance tensors using an
     ordinary or weighted linear least squares approach
 
     Parameters
@@ -510,7 +559,7 @@ def ls_fit_cti(design_matrix, data, inverse_design_matrix, weights=True,
     inverse_design_matrix : array (43, g)
         Inverse of the design matrix.
     weights : bool, optional
-        Parameter indicating whether weights are used. Default: True.
+        Parameter indicating whether weights are used.
     min_diffusivity : float, optional
         Because negative eigenvalues are not physical and small eigenvalues,
         much smaller than the diffusion weighting, cause quite a lot of noise
@@ -520,13 +569,14 @@ def ls_fit_cti(design_matrix, data, inverse_design_matrix, weights=True,
     Returns
     -------
     cti_params : array (48)
-    All parameters estimated from the diffusion kurtosis model for all N
-    voxels. Parameters are ordered as follows:
-        1) Three diffusion tensor eigenvalues.
-        2) Three blocks of three elements, containing the first second and
-            third coordinates of the diffusion tensor eigenvectors.
-        3) Fifteen elements of the kurtosis tensor.
-        4) Twenty One elements of the covariance tensor.
+        All parameters estimated from the diffusion kurtosis model for all N
+        voxels. Parameters are ordered as follows:
+
+            1) Three diffusion tensor eigenvalues.
+            2) Three blocks of three elements, containing the first second and
+                third coordinates of the diffusion tensor eigenvectors.
+            3) Fifteen elements of the kurtosis tensor.
+            4) Twenty One elements of the covariance tensor.
 
     """
     A = design_matrix
@@ -543,10 +593,11 @@ def ls_fit_cti(design_matrix, data, inverse_design_matrix, weights=True,
     return cti_params
 
 
-common_fit_methods = {'WLS': ls_fit_cti,
-                      'OLS': ls_fit_cti,
-                      'UWLLS': ls_fit_cti,
-                      'ULLS': ls_fit_cti,
-                      'WLLS': ls_fit_cti,
-                      'OLLS': ls_fit_cti
-                      }
+common_fit_methods = {
+    "WLS": ls_fit_cti,
+    "OLS": ls_fit_cti,
+    "UWLLS": ls_fit_cti,
+    "ULLS": ls_fit_cti,
+    "WLLS": ls_fit_cti,
+    "OLLS": ls_fit_cti,
+}
