@@ -1,27 +1,32 @@
-""" Classes and functions for fitting tensors without free water
-contamination """
+"""Classes and functions for fitting tensors without free water
+contamination"""
 
+from functools import partial
 import warnings
 
 import numpy as np
-
 import scipy.optimize as opt
 
-from dipy.reconst.base import ReconstModel
-
-from dipy.reconst.dti import (TensorFit, design_matrix, decompose_tensor,
-                              _decompose_tensor_nan, from_lower_triangular,
-                              lower_triangular)
-from dipy.reconst.dki import _positive_evals
-
-from dipy.reconst.vec_val_sum import vec_val_vect
-from dipy.core.ndindex import ndindex
 from dipy.core.gradients import check_multi_b
+from dipy.core.ndindex import ndindex
+from dipy.reconst.base import ReconstModel
+from dipy.reconst.dki import _positive_evals
+from dipy.reconst.dti import (
+    TensorFit,
+    _decompose_tensor_nan,
+    decompose_tensor,
+    design_matrix,
+    from_lower_triangular,
+    lower_triangular,
+)
 from dipy.reconst.multi_voxel import multi_voxel_fit
+from dipy.reconst.vec_val_sum import vec_val_vect
+from dipy.testing.decorators import warning_for_keywords
 
 
-def fwdti_prediction(params, gtab, S0=1, Diso=3.0e-3):
-    r""" Signal prediction given the free water DTI model parameters.
+@warning_for_keywords()
+def fwdti_prediction(params, gtab, *, S0=1, Diso=3.0e-3):
+    r"""Signal prediction given the free water DTI model parameters.
 
     Parameters
     ----------
@@ -53,20 +58,17 @@ def fwdti_prediction(params, gtab, S0=1, Diso=3.0e-3):
     value provided in the GradientTable input for that direction, $Q$ is the
     quadratic form of the tensor determined by the input parameters, $f$ is the
     free water diffusion compartment, $D_{iso}$ is the free water diffusivity
-    which is equal to $3 * 10^{-3} mm^{2}s^{-1} [1]_.
+    which is equal to $3 * 10^{-3} mm^{2}s^{-1} :footcite:p:`NetoHenriques2017`.
 
     References
     ----------
-    .. [1] Henriques, R.N., Rokem, A., Garyfallidis, E., St-Jean, S.,
-           Peterson E.T., Correia, M.M., 2017. [Re] Optimization of a free
-           water elimination two-compartment model for diffusion tensor
-           imaging. ReScience volume 3, issue 1, article number 2
+    .. footbibliography::
     """
     evals = params[..., :3]
     evecs = params[..., 3:-1].reshape(params.shape[:-1] + (3, 3))
     f = params[..., 12]
     qform = vec_val_vect(evecs, evals)
-    lower_dt = lower_triangular(qform, S0)
+    lower_dt = lower_triangular(qform, b0=S0)
     lower_diso = lower_dt.copy()
     lower_diso[..., 0] = lower_diso[..., 2] = lower_diso[..., 5] = Diso
     lower_diso[..., 1] = lower_diso[..., 3] = lower_diso[..., 4] = 0
@@ -77,40 +79,42 @@ def fwdti_prediction(params, gtab, S0=1, Diso=3.0e-3):
     index = ndindex(f.shape)
     for v in index:
         if mask[v]:
-            pred_sig[v] = (1 - f[v]) * np.exp(np.dot(lower_dt[v], D.T)) + \
-                          f[v] * np.exp(np.dot(lower_diso[v], D.T))
+            pred_sig[v] = (1 - f[v]) * np.exp(np.dot(lower_dt[v], D.T)) + f[v] * np.exp(
+                np.dot(lower_diso[v], D.T)
+            )
 
     return pred_sig
 
 
 class FreeWaterTensorModel(ReconstModel):
-    """ Class for the Free Water Elimination Diffusion Tensor Model """
-    def __init__(self, gtab, fit_method="NLS", *args, **kwargs):
-        """ Free Water Diffusion Tensor Model [1]_.
+    """Class for the Free Water Elimination Diffusion Tensor Model"""
+
+    def __init__(self, gtab, *args, fit_method="NLS", **kwargs):
+        """Free Water Diffusion Tensor Model.
+
+        See :footcite:p:`NetoHenriques2017` for further details about the model.
 
         Parameters
         ----------
         gtab : GradientTable class instance
+            Gradient table.
         fit_method : str or callable
             str can be one of the following:
 
-            'WLS' for weighted linear least square fit according to [1]_
-                :func:`fwdti.wls_iter`
-            'NLS' for non-linear least square fit according to [1]_
-                :func:`fwdti.nls_iter`
+            - 'WLS' for weighted linear least square fit according to
+              :footcite:p:`NetoHenriques2017` :func:`fwdti.wls_iter`
+            - 'NLS' for non-linear least square fit according to
+              :footcite:p:`NetoHenriques2017` :func:`fwdti.nls_iter`
 
             callable has to have the signature:
-              fit_method(design_matrix, data, *args, **kwargs)
+              ``fit_method(design_matrix, data, *args, **kwargs)``
         args, kwargs : arguments and key-word arguments passed to the
            fit_method. See fwdti.wls_iter, fwdti.nls_iter for
            details
 
         References
         ----------
-        .. [1] Henriques, R.N., Rokem, A., Garyfallidis, E., St-Jean, S.,
-               Peterson E.T., Correia, M.M., 2017. [Re] Optimization of a free
-               water elimination two-compartment model for diffusion tensor
-               imaging. ReScience volume 3, issue 1, article number 2
+        .. footbibliography::
 
         """
         ReconstModel.__init__(self, gtab)
@@ -118,11 +122,11 @@ class FreeWaterTensorModel(ReconstModel):
         if not callable(fit_method):
             try:
                 fit_method = common_fit_methods[fit_method]
-            except KeyError:
+            except KeyError as e:
                 e_s = '"' + str(fit_method) + '" is not a known fit '
-                e_s += 'method, the fit method should either be a '
-                e_s += 'function or one of the common fit methods'
-                raise ValueError(e_s)
+                e_s += "method, the fit method should either be a "
+                e_s += "function or one of the common fit methods"
+                raise ValueError(e_s) from e
         self.fit_method = fit_method
         self.design_matrix = design_matrix(self.gtab)
         self.args = args
@@ -135,8 +139,9 @@ class FreeWaterTensorModel(ReconstModel):
             raise ValueError(mes)
 
     @multi_voxel_fit
-    def fit(self, data, mask=None):
-        """ Fit method of the free water elimination DTI model class
+    @warning_for_keywords()
+    def fit(self, data, *, mask=None, **kwargs):
+        """Fit method of the free water elimination DTI model class
 
         Parameters
         ----------
@@ -147,13 +152,15 @@ class FreeWaterTensorModel(ReconstModel):
             should be analyzed that has the shape data.shape[:-1]
         """
         S0 = np.mean(data[self.gtab.b0s_mask])
-        fwdti_params = self.fit_method(self.design_matrix, data, S0,
-                                       *self.args, **self.kwargs)
+        fwdti_params = self.fit_method(
+            self.design_matrix, data, S0, *self.args, **self.kwargs
+        )
 
         return FreeWaterTensorFit(self, fwdti_params)
 
-    def predict(self, fwdti_params, S0=1):
-        """ Predict a signal for this TensorModel class instance given
+    @warning_for_keywords()
+    def predict(self, fwdti_params, *, S0=1):
+        """Predict a signal for this TensorModel class instance given
         parameters.
 
         Parameters
@@ -175,12 +182,17 @@ class FreeWaterTensorModel(ReconstModel):
 
 
 class FreeWaterTensorFit(TensorFit):
-    """ Class for fitting the Free Water Tensor Model """
+    """Class for fitting the Free Water Tensor Model"""
+
     def __init__(self, model, model_params):
-        """ Initialize a FreeWaterTensorFit class instance.
+        """Initialize a FreeWaterTensorFit class instance.
+
         Since the free water tensor model is an extension of DTI, class
         instance is defined as subclass of the TensorFit from dti.py
 
+        See :footcite:p:`NetoHenriques2017` for further details about the
+        method.
+
         Parameters
         ----------
         model : FreeWaterTensorModel Class instance
@@ -188,6 +200,7 @@ class FreeWaterTensorFit(TensorFit):
         model_params : ndarray (x, y, z, 13) or (n, 13)
             All parameters estimated from the free water tensor model.
             Parameters are ordered as follows:
+
                 1) Three diffusion tensor's eigenvalues
                 2) Three lines of the eigenvector matrix each containing the
                    first, second and third coordinates of the eigenvector
@@ -195,20 +208,18 @@ class FreeWaterTensorFit(TensorFit):
 
         References
         ----------
-        .. [1] Henriques, R.N., Rokem, A., Garyfallidis, E., St-Jean, S.,
-               Peterson E.T., Correia, M.M., 2017. [Re] Optimization of a free
-               water elimination two-compartment model for diffusion tensor
-               imaging. ReScience volume 3, issue 1, article number 2
+        .. footbibliography::
         """
         TensorFit.__init__(self, model, model_params)
 
     @property
     def f(self):
-        """ Returns the free water diffusion volume fraction f """
+        """Returns the free water diffusion volume fraction f"""
         return self.model_params[..., 12]
 
-    def predict(self, gtab, S0=1):
-        r""" Given a free water tensor model fit, predict the signal on the
+    @warning_for_keywords()
+    def predict(self, gtab, *, S0=1):
+        r"""Given a free water tensor model fit, predict the signal on the
         vertices of a gradient table
 
         Parameters
@@ -228,9 +239,11 @@ class FreeWaterTensorFit(TensorFit):
         return fwdti_prediction(self.model_params, gtab, S0=S0)
 
 
-def wls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
-             min_signal=1.0e-6, piterations=3):
-    """ Applies weighted linear least squares fit of the water free elimination
+@warning_for_keywords()
+def wls_iter(
+    design_matrix, sig, S0, *, Diso=3e-3, mdreg=2.7e-3, min_signal=1.0e-6, piterations=3
+):
+    """Applies weighted linear least squares fit of the water free elimination
     model to single voxel signals.
 
     Parameters
@@ -246,7 +259,7 @@ def wls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
         Value of the free water isotropic diffusion. Default is set to 3e-3
         $mm^{2}.s^{-1}$. Please adjust this value if you are assuming different
         units of diffusion.
-     mdreg : float, optimal
+    mdreg : float, optimal
         DTI's mean diffusivity regularization threshold. If standard DTI
         diffusion tensor's mean diffusivity is almost near the free water
         diffusion value, the diffusion signal is assumed to be only free water
@@ -262,12 +275,15 @@ def wls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
 
     Returns
     -------
-    All parameters estimated from the free water tensor model.
-    Parameters are ordered as follows:
-        1) Three diffusion tensor's eigenvalues
-        2) Three lines of the eigenvector matrix each containing the
-           first, second and third coordinates of the eigenvector
-        3) The volume fraction of the free water compartment
+    fw_params : ndarray
+        All parameters estimated from the free water tensor model. Parameters
+        are ordered as follows:
+
+            1) Three diffusion tensor's eigenvalues
+            2) Three lines of the eigenvector matrix each containing the
+               first, second and third coordinates of the eigenvector
+            3) The volume fraction of the free water compartment
+
     """
     W = design_matrix
 
@@ -284,32 +300,37 @@ def wls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
     params = np.dot(invWTS2W_WTS2, log_s)
 
     md = (params[0] + params[2] + params[5]) / 3
+
     # Process voxel if it has significant signal from tissue
     if md < mdreg and np.mean(sig) > min_signal and S0 > min_signal:
         # General free-water signal contribution
-        fwsig = np.exp(np.dot(design_matrix,
-                              np.array([Diso, 0, Diso, 0, 0, Diso, 0])))
+        fwsig = np.exp(np.dot(design_matrix, np.array([Diso, 0, Diso, 0, 0, Diso, 0])))
 
         df = 1  # initialize precision
         flow = 0  # lower f evaluated
         fhig = 1  # higher f evaluated
         ns = 9  # initial number of samples per iteration
-        for p in range(piterations):
+        for _ in range(piterations):
             df = df * 0.1
-            fs = np.linspace(flow+df, fhig-df, num=ns)  # sampling f
-            SFW = np.array([fwsig, ]*ns)  # repeat contributions for all values
+            fs = np.linspace(flow + df, fhig - df, num=ns)  # sampling f
+            SFW = np.array(
+                [
+                    fwsig,
+                ]
+                * ns
+            )  # repeat contributions for all values
             FS, SI = np.meshgrid(fs, sig)
-            SA = SI - FS*S0*SFW.T
+            SA = SI - FS * S0 * SFW.T
             # SA < 0 means that the signal components from the free water
-            # component is larger than the total fiber. This cases are present
+            # component is larger than the total fiber. These cases are present
             # for inappropriate large volume fractions (given the current S0
             # value estimated). To overcome this issue negative SA are replaced
             # by data's min positive signal.
             SA[SA <= 0] = min_signal
-            y = np.log(SA / (1-FS))
+            y = np.log(SA / (1 - FS))
             all_new_params = np.dot(invWTS2W_WTS2, y)
             # Select params for lower F2
-            SIpred = (1-FS)*np.exp(np.dot(W, all_new_params)) + FS*S0*SFW.T
+            SIpred = (1 - FS) * np.exp(np.dot(W, all_new_params)) + FS * S0 * SFW.T
             F2 = np.sum(np.square(SI - SIpred), axis=0)
             Mind = np.argmin(F2)
             params = all_new_params[:, Mind]
@@ -319,8 +340,9 @@ def wls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
             ns = 19
 
         evals, evecs = decompose_tensor(from_lower_triangular(params))
-        fw_params = np.concatenate((evals, evecs[0], evecs[1], evecs[2],
-                                    np.array([f])), axis=0)
+        fw_params = np.concatenate(
+            (evals, evecs[0], evecs[1], evecs[2], np.array([f])), axis=0
+        )
     else:
         fw_params = np.zeros(13)
         if md > mdreg:
@@ -329,10 +351,14 @@ def wls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
     return fw_params
 
 
-def wls_fit_tensor(gtab, data, Diso=3e-3, mask=None, min_signal=1.0e-6,
-                   piterations=3, mdreg=2.7e-3):
-    r""" Computes weighted least squares (WLS) fit to calculate self-diffusion
-    tensor using a linear regression model [1]_.
+@warning_for_keywords()
+def wls_fit_tensor(
+    gtab, data, *, Diso=3e-3, mask=None, min_signal=1.0e-6, piterations=3, mdreg=2.7e-3
+):
+    r"""Computes weighted least squares (WLS) fit to calculate self-diffusion
+    tensor using a linear regression model.
+
+    See :footcite:p:`NetoHenriques2017` for further details about the method.
 
     Parameters
     ----------
@@ -350,7 +376,7 @@ def wls_fit_tensor(gtab, data, Diso=3e-3, mask=None, min_signal=1.0e-6,
         be analyzed that has the shape data.shape[:-1]
     min_signal : float
         The minimum signal value. Needs to be a strictly positive
-        number. Default: 1.0e-6.
+        number.
     piterations : inter, optional
         Number of iterations used to refine the precision of f. Default is set
         to 3 corresponding to a precision of 0.01.
@@ -367,6 +393,7 @@ def wls_fit_tensor(gtab, data, Diso=3e-3, mask=None, min_signal=1.0e-6,
     fw_params : ndarray (x, y, z, 13)
         Matrix containing in the last dimension the free water model parameters
         in the following order:
+
             1) Three diffusion tensor's eigenvalues
             2) Three lines of the eigenvector matrix each containing the
                first, second and third coordinates of the eigenvector
@@ -374,10 +401,7 @@ def wls_fit_tensor(gtab, data, Diso=3e-3, mask=None, min_signal=1.0e-6,
 
     References
     ----------
-    .. [1] Henriques, R.N., Rokem, A., Garyfallidis, E., St-Jean, S.,
-           Peterson E.T., Correia, M.M., 2017. [Re] Optimization of a free
-           water elimination two-compartment model for diffusion tensor
-           imaging. ReScience volume 3, issue 1, article number 2
+    .. footbibliography::
     """
     fw_params = np.zeros(data.shape[:-1] + (13,))
     W = design_matrix(gtab)
@@ -388,7 +412,7 @@ def wls_fit_tensor(gtab, data, Diso=3e-3, mask=None, min_signal=1.0e-6,
     else:
         if mask.shape != data.shape[:-1]:
             raise ValueError("Mask is not the same shape as data.")
-        mask = np.array(mask, dtype=bool, copy=False)
+        mask = np.asarray(mask, dtype=bool)
 
     # Prepare S0
     S0 = np.mean(data[:, :, :, gtab.b0s_mask], axis=-1)
@@ -396,17 +420,33 @@ def wls_fit_tensor(gtab, data, Diso=3e-3, mask=None, min_signal=1.0e-6,
     index = ndindex(mask.shape)
     for v in index:
         if mask[v]:
-            params = wls_iter(W, data[v], S0[v], min_signal=min_signal,
-                              Diso=3e-3, piterations=piterations, mdreg=mdreg)
+            params = wls_iter(
+                W,
+                data[v],
+                S0[v],
+                min_signal=min_signal,
+                Diso=Diso,
+                piterations=piterations,
+                mdreg=mdreg,
+            )
             fw_params[v] = params
 
     return fw_params
 
 
-def _nls_err_func(tensor_elements, design_matrix, data, Diso=3e-3,
-                  weighting=None, sigma=None, cholesky=False,
-                  f_transform=False):
-    """ Error function for the non-linear least-squares fit of the tensor water
+@warning_for_keywords()
+def _nls_err_func(
+    tensor_elements,
+    design_matrix,
+    data,
+    *,
+    Diso=3e-3,
+    weighting=None,
+    sigma=None,
+    cholesky=False,
+    f_transform=False,
+):
+    """Error function for the non-linear least-squares fit of the tensor water
     elimination model.
 
     Parameters
@@ -426,10 +466,10 @@ def _nls_err_func(tensor_elements, design_matrix, data, Diso=3e-3,
         Value of the free water isotropic diffusion. Default is set to 3e-3
         $mm^{2}.s^{-1}$. Please adjust this value if you are assuming different
         units of diffusion.
-    weighting : str (optional).
-         Whether to use the Geman-McClure weighting criterion (see [1]_
-         for details)
-    sigma : float or float array (optional)
+    weighting : str, optional
+         Whether to use the Geman-McClure weighting criterion (see
+        :footcite:p:`NetoHenriques2017` for details)
+    sigma : float or float array, optional
         If 'sigma' weighting is used, we will weight the error function
         according to the background noise estimated either in aggregate over
         all directions (when a float is provided), or to an estimate of the
@@ -439,26 +479,28 @@ def _nls_err_func(tensor_elements, design_matrix, data, Diso=3e-3,
     cholesky : bool, optional
         If true, the diffusion tensor elements were decomposed using Cholesky
         decomposition. See fwdti.nls_fit_tensor
-        Default: False
     f_transform : bool, optional
         If true, the water volume fraction was converted to
         ft = arcsin(2*f - 1) + pi/2, insuring f estimates between 0 and 1.
         See fwdti.nls_fit_tensor
-        Default: True
+
+    References
+    ----------
+    .. footbibliography::
     """
     tensor = np.copy(tensor_elements)
     if cholesky:
         tensor[:6] = cholesky_to_lower_triangular(tensor[:6])
 
     if f_transform:
-        f = 0.5 * (1 + np.sin(tensor[7] - np.pi/2))
+        f = 0.5 * (1 + np.sin(tensor[7] - np.pi / 2))
     else:
         f = tensor[7]
 
     # This is the predicted signal given the params:
-    y = (1-f) * np.exp(np.dot(design_matrix, tensor[:7])) + \
-        f * np.exp(np.dot(design_matrix,
-                          np.array([Diso, 0, Diso, 0, 0, Diso, tensor[6]])))
+    y = (1 - f) * np.exp(np.dot(design_matrix, tensor[:7])) + f * np.exp(
+        np.dot(design_matrix, np.array([Diso, 0, Diso, 0, 0, Diso, tensor[6]]))
+    )
 
     # Compute the residuals
     residuals = data - y
@@ -467,25 +509,25 @@ def _nls_err_func(tensor_elements, design_matrix, data, Diso=3e-3,
     if weighting is None:
         # And we return the SSE:
         return residuals
-    se = residuals ** 2
+    se = residuals**2
     # If the user provided a sigma (e.g 1.5267 * std(background_noise), as
     # suggested by Chang et al.) we will use it:
-    if weighting == 'sigma':
+    if weighting == "sigma":
         if sigma is None:
             e_s = "Must provide sigma value as input to use this weighting"
             e_s += " method"
             raise ValueError(e_s)
-        w = 1/(sigma**2)
+        w = 1 / (sigma**2)
 
-    elif weighting == 'gmm':
+    elif weighting == "gmm":
         # We use the Geman-McClure M-estimator to compute the weights on the
         # residuals:
         C = 1.4826 * np.median(np.abs(residuals - np.median(residuals)))
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
-            w = 1/(se + C**2)
+            w = 1 / (se + C**2)
             # The weights are normalized to the mean weight (see p. 1089):
-            w = w/np.mean(w)
+            w = w / np.mean(w)
 
     # Return the weighted residuals:
     with warnings.catch_warnings():
@@ -493,9 +535,18 @@ def _nls_err_func(tensor_elements, design_matrix, data, Diso=3e-3,
         return np.sqrt(w * se)
 
 
-def _nls_jacobian_func(tensor_elements, design_matrix, data, Diso=3e-3,
-                       weighting=None, sigma=None, cholesky=False,
-                       f_transform=False):
+@warning_for_keywords()
+def _nls_jacobian_func(
+    tensor_elements,
+    design_matrix,
+    data,
+    *,
+    Diso=3e-3,
+    weighting=None,
+    sigma=None,
+    cholesky=False,
+    f_transform=False,
+):
     """The Jacobian is the first derivative of the least squares error
     function.
 
@@ -515,33 +566,44 @@ def _nls_jacobian_func(tensor_elements, design_matrix, data, Diso=3e-3,
     f_transform : bool, optional
         If true, the water volume fraction was converted to
         ft = arcsin(2*f - 1) + pi/2, insuring f estimates between 0 and 1.
-        See fwdti.nls_fit_tensor
-        Default: True
+        See fwdti.nls_fit_tensor.
     """
     tensor = np.copy(tensor_elements)
     if f_transform:
-        f = 0.5 * (1 + np.sin(tensor[7] - np.pi/2))
+        f = 0.5 * (1 + np.sin(tensor[7] - np.pi / 2))
     else:
         f = tensor[7]
 
     t = np.exp(np.dot(design_matrix, tensor[:7]))
-    s = np.exp(np.dot(design_matrix,
-                      np.array([Diso, 0, Diso, 0, 0, Diso, tensor[6]])))
-    T = (f-1.0) * t[:, None] * design_matrix
+    s = np.exp(np.dot(design_matrix, np.array([Diso, 0, Diso, 0, 0, Diso, tensor[6]])))
+
+    T = (f - 1.0) * t[:, None] * design_matrix
     S = np.zeros(design_matrix.shape)
     S[:, 6] = f * s
 
     if f_transform:
-        df = (t-s) * (0.5*np.cos(tensor[7]-np.pi/2))
+        df = (t - s) * (0.5 * np.cos(tensor[7] - np.pi / 2))
     else:
-        df = (t-s)
+        df = t - s
     return np.concatenate((T - S, df[:, None]), axis=1)
 
 
-def nls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
-             min_signal=1.0e-6, cholesky=False, f_transform=True, jac=False,
-             weighting=None, sigma=None):
-    """ Applies non linear least squares fit of the water free elimination
+@warning_for_keywords()
+def nls_iter(
+    design_matrix,
+    sig,
+    S0,
+    *,
+    Diso=3e-3,
+    mdreg=2.7e-3,
+    min_signal=1.0e-6,
+    cholesky=False,
+    f_transform=True,
+    jac=False,
+    weighting=None,
+    sigma=None,
+):
+    """Applies non linear least squares fit of the water free elimination
     model to single voxel signals.
 
     Parameters
@@ -564,28 +626,26 @@ def nls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
         diffusion (i.e. volume fraction will be set to 1 and tissue's diffusion
         parameters are set to zero). Default md_reg is 2.7e-3 $mm^{2}.s^{-1}$
         (corresponding to 90% of the free water diffusion value).
-    min_signal : float
+    min_signal : float, optional
         The minimum signal value. Needs to be a strictly positive
         number.
     cholesky : bool, optional
-        If true it uses Cholesky decomposition to insure that diffusion tensor
+        If true it uses Cholesky decomposition to ensure that diffusion tensor
         is positive define.
-        Default: False
     f_transform : bool, optional
         If true, the water volume fractions is converted during the convergence
         procedure to ft = arcsin(2*f - 1) + pi/2, insuring f estimates between
         0 and 1.
-        Default: True
-    jac : bool
-        Use the Jacobian? Default: False
+    jac : bool, optional
+        True to use the Jacobian.
     weighting: str, optional
         the weighting scheme to use in considering the
         squared-error. Default behavior is to use uniform weighting. Other
         options: 'sigma' 'gmm'
     sigma: float, optional
         If the 'sigma' weighting scheme is used, a value of sigma needs to be
-        provided here. According to [Chang2005]_, a good value to use is
-        1.5267 * std(background_noise), where background_noise is estimated
+        provided here. According to :footcite:t:`Chang2005`, a good value to use
+        is 1.5267 * std(background_noise), where background_noise is estimated
         from some part of the image known to contain no signal (only noise).
 
     Returns
@@ -598,8 +658,18 @@ def nls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
         3) The volume fraction of the free water compartment.
     """
     # Initial guess
-    params = wls_iter(design_matrix, sig, S0,
-                      min_signal=min_signal, Diso=Diso, mdreg=mdreg)
+    params = wls_iter(
+        design_matrix, sig, S0, min_signal=min_signal, Diso=Diso, mdreg=mdreg
+    )
+
+    partial_err_func = partial(
+        _nls_err_func,
+        Diso=Diso,
+        weighting=weighting,
+        sigma=sigma,
+        cholesky=cholesky,
+        f_transform=f_transform,
+    )
 
     # Process voxel if it has significant signal from tissue
     if params[12] < 0.99 and np.mean(sig) > min_signal and S0 > min_signal:
@@ -614,23 +684,23 @@ def nls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
 
         # f transformation if requested
         if f_transform:
-            f = np.arcsin(2*params[12] - 1) + np.pi/2
+            f = np.arcsin(2 * params[12] - 1) + np.pi / 2
         else:
             f = params[12]
 
         # Use the Levenberg-Marquardt algorithm wrapped in opt.leastsq
         start_params = np.concatenate((dt, [-np.log(S0), f]), axis=0)
         if jac:
-            this_tensor, status = opt.leastsq(_nls_err_func, start_params[:8],
-                                              args=(design_matrix, sig, Diso,
-                                                    weighting, sigma, cholesky,
-                                                    f_transform),
-                                              Dfun=_nls_jacobian_func)
+            this_tensor, status = opt.leastsq(
+                partial_err_func,
+                start_params[:8],
+                args=(design_matrix, sig),
+                Dfun=_nls_jacobian_func,
+            )
         else:
-            this_tensor, status = opt.leastsq(_nls_err_func, start_params[:8],
-                                              args=(design_matrix, sig, Diso,
-                                                    weighting, sigma, cholesky,
-                                                    f_transform))
+            this_tensor, status = opt.leastsq(
+                partial_err_func, start_params[:8], args=(design_matrix, sig)
+            )
 
         # Process tissue diffusion tensor
         if cholesky:
@@ -638,21 +708,35 @@ def nls_iter(design_matrix, sig, S0, Diso=3e-3, mdreg=2.7e-3,
 
         evals, evecs = _decompose_tensor_nan(
             from_lower_triangular(this_tensor[:6]),
-            from_lower_triangular(start_params[:6]))
+            from_lower_triangular(start_params[:6]),
+        )
 
         # Process water volume fraction f
         f = this_tensor[7]
         if f_transform:
-            f = 0.5 * (1 + np.sin(f - np.pi/2))
+            f = 0.5 * (1 + np.sin(f - np.pi / 2))
 
-        params = np.concatenate((evals, evecs[0], evecs[1], evecs[2],
-                                 np.array([f])), axis=0)
+        params = np.concatenate(
+            (evals, evecs[0], evecs[1], evecs[2], np.array([f])), axis=0
+        )
     return params
 
 
-def nls_fit_tensor(gtab, data, mask=None, Diso=3e-3, mdreg=2.7e-3,
-                   min_signal=1.0e-6, f_transform=True, cholesky=False,
-                   jac=False, weighting=None, sigma=None):
+@warning_for_keywords()
+def nls_fit_tensor(
+    gtab,
+    data,
+    *,
+    mask=None,
+    Diso=3e-3,
+    mdreg=2.7e-3,
+    min_signal=1.0e-6,
+    f_transform=True,
+    cholesky=False,
+    jac=False,
+    weighting=None,
+    sigma=None,
+):
     """
     Fit the water elimination tensor model using the non-linear least-squares.
 
@@ -677,28 +761,26 @@ def nls_fit_tensor(gtab, data, mask=None, Diso=3e-3, mdreg=2.7e-3,
         diffusion (i.e. volume fraction will be set to 1 and tissue's diffusion
         parameters are set to zero). Default md_reg is 2.7e-3 $mm^{2}.s^{-1}$
         (corresponding to 90% of the free water diffusion value).
-    min_signal : float
+    min_signal : float, optional
         The minimum signal value. Needs to be a strictly positive
-        number. Default: 1.0e-6.
+        number.
     f_transform : bool, optional
         If true, the water volume fractions is converted during the convergence
         procedure to ft = arcsin(2*f - 1) + pi/2, insuring f estimates between
         0 and 1.
-        Default: True
     cholesky : bool, optional
-        If true it uses Cholesky decomposition to insure that diffusion tensor
+        If true it uses Cholesky decomposition to ensure that diffusion tensor
         is positive define.
-        Default: False
-    jac : bool
-        Use the Jacobian? Default: False
+    jac : bool, optional
+        True to use the Jacobian.
     weighting: str, optional
         the weighting scheme to use in considering the
         squared-error. Default behavior is to use uniform weighting. Other
         options: 'sigma' 'gmm'
     sigma: float, optional
         If the 'sigma' weighting scheme is used, a value of sigma needs to be
-        provided here. According to [Chang2005]_, a good value to use is
-        1.5267 * std(background_noise), where background_noise is estimated
+        provided here. According to :footcite:t:`Chang2005`, a good value to use
+        is 1.5267 * std(background_noise), where background_noise is estimated
         from some part of the image known to contain no signal (only noise).
 
     Returns
@@ -706,10 +788,15 @@ def nls_fit_tensor(gtab, data, mask=None, Diso=3e-3, mdreg=2.7e-3,
     fw_params : ndarray (x, y, z, 13)
         Matrix containing in the dimension the free water model parameters in
         the following order:
+
             1) Three diffusion tensor's eigenvalues
             2) Three lines of the eigenvector matrix each containing the
                first, second and third coordinates of the eigenvector
             3) The volume fraction of the free water compartment
+
+    References
+    ----------
+    .. footbibliography::
     """
     fw_params = np.zeros(data.shape[:-1] + (13,))
     W = design_matrix(gtab)
@@ -720,7 +807,7 @@ def nls_fit_tensor(gtab, data, mask=None, Diso=3e-3, mdreg=2.7e-3,
     else:
         if mask.shape != data.shape[:-1]:
             raise ValueError("Mask is not the same shape as data.")
-        mask = np.array(mask, dtype=bool, copy=False)
+        mask = np.asarray(mask, dtype=bool)
 
     # Prepare S0
     S0 = np.mean(data[:, :, :, gtab.b0s_mask], axis=-1)
@@ -728,17 +815,26 @@ def nls_fit_tensor(gtab, data, mask=None, Diso=3e-3, mdreg=2.7e-3,
     index = ndindex(mask.shape)
     for v in index:
         if mask[v]:
-            params = nls_iter(W, data[v], S0[v], Diso=Diso, mdreg=mdreg,
-                              min_signal=min_signal, f_transform=f_transform,
-                              cholesky=cholesky, jac=jac, weighting=weighting,
-                              sigma=sigma)
+            params = nls_iter(
+                W,
+                data[v],
+                S0[v],
+                Diso=Diso,
+                mdreg=mdreg,
+                min_signal=min_signal,
+                f_transform=f_transform,
+                cholesky=cholesky,
+                jac=jac,
+                weighting=weighting,
+                sigma=sigma,
+            )
             fw_params[v] = params
 
     return fw_params
 
 
 def lower_triangular_to_cholesky(tensor_elements):
-    """ Performs Cholesky decomposition of the diffusion tensor
+    """Performs Cholesky decomposition of the diffusion tensor
 
     Parameters
     ----------
@@ -750,33 +846,30 @@ def lower_triangular_to_cholesky(tensor_elements):
     -------
     cholesky_elements : array (6,)
         Array containing the six Cholesky's decomposition elements
-        (R0, R1, R2, R3, R4, R5) [1]_.
+        (R0, R1, R2, R3, R4, R5) :footcite:p:`Koay2006b`.
 
     References
     ----------
-    .. [1] Koay, C.G., Carew, J.D., Alexander, A.L., Basser, P.J.,
-           Meyerand, M.E., 2006. Investigation of anomalous estimates of
-           tensor-derived quantities in diffusion tensor imaging. Magnetic
-           Resonance in Medicine, 55(4), 930-936. doi:10.1002/mrm.20832
+    .. footbibliography::
     """
     R0 = np.sqrt(tensor_elements[0])
     R3 = tensor_elements[1] / R0
     R1 = np.sqrt(tensor_elements[2] - R3**2)
     R5 = tensor_elements[3] / R0
-    R4 = (tensor_elements[4] - R3*R5) / R1
+    R4 = (tensor_elements[4] - R3 * R5) / R1
     R2 = np.sqrt(tensor_elements[5] - R4**2 - R5**2)
 
     return np.array([R0, R1, R2, R3, R4, R5])
 
 
 def cholesky_to_lower_triangular(R):
-    """ Convert Cholesky decomposition elements to the diffusion tensor elements
+    """Convert Cholesky decomposition elements to the diffusion tensor elements
 
     Parameters
     ----------
     R : array (6,)
         Array containing the six Cholesky's decomposition elements
-        (R0, R1, R2, R3, R4, R5) [1]_.
+        (R0, R1, R2, R3, R4, R5) :footcite:p:`Koay2006b`.
 
     Returns
     -------
@@ -786,22 +879,20 @@ def cholesky_to_lower_triangular(R):
 
     References
     ----------
-    .. [1] Koay, C.G., Carew, J.D., Alexander, A.L., Basser, P.J.,
-           Meyerand, M.E., 2006. Investigation of anomalous estimates of
-           tensor-derived quantities in diffusion tensor imaging. Magnetic
-           Resonance in Medicine, 55(4), 930-936. doi:10.1002/mrm.20832
+    .. footbibliography::
     """
-    Dxx = R[0]**2
-    Dxy = R[0]*R[3]
-    Dyy = R[1]**2 + R[3]**2
-    Dxz = R[0]*R[5]
-    Dyz = R[1]*R[4] + R[3]*R[5]
-    Dzz = R[2]**2 + R[4]**2 + R[5]**2
+    Dxx = R[0] ** 2
+    Dxy = R[0] * R[3]
+    Dyy = R[1] ** 2 + R[3] ** 2
+    Dxz = R[0] * R[5]
+    Dyz = R[1] * R[4] + R[3] * R[5]
+    Dzz = R[2] ** 2 + R[4] ** 2 + R[5] ** 2
     return np.array([Dxx, Dxy, Dyy, Dxz, Dyz, Dzz])
 
 
-common_fit_methods = {'WLLS': wls_iter,
-                      'WLS': wls_iter,
-                      'NLLS': nls_iter,
-                      'NLS': nls_iter,
-                      }
+common_fit_methods = {
+    "WLLS": wls_iter,
+    "WLS": wls_iter,
+    "NLLS": nls_iter,
+    "NLS": nls_iter,
+}
