@@ -1,17 +1,19 @@
-""" Classes and functions for fitting ivim model """
+"""Classes and functions for fitting ivim model"""
+
 import warnings
 
 import numpy as np
-from scipy.optimize import least_squares, differential_evolution
+from scipy.optimize import differential_evolution, least_squares
 
 from dipy.reconst.base import ReconstModel
 from dipy.reconst.multi_voxel import multi_voxel_fit
+from dipy.testing.decorators import warning_for_keywords
 from dipy.utils.optpkg import optional_package
 
 cvxpy, have_cvxpy, _ = optional_package("cvxpy", min_version="1.4.1")
 
 # global variable for bounding least_squares in both models
-BOUNDS = ([0., 0., 0., 0.], [np.inf, .2, 1., 1.])
+BOUNDS = ([0.0, 0.0, 0.0, 0.0], [np.inf, 0.2, 1.0, 1.0])
 
 
 def ivim_prediction(params, gtab):
@@ -128,7 +130,8 @@ def f_D_star_error(params, gtab, signal, S0, D):
     return signal - f_D_star_prediction([f, D_star], gtab, S0, D)
 
 
-def ivim_model_selector(gtab, fit_method='trr', **kwargs):
+@warning_for_keywords()
+def ivim_model_selector(gtab, *, fit_method="trr", **kwargs):
     """
     Selector function to switch between the 2-stage Trust-Region Reflective
     based NLLS fitting method (also containing the linear fit): `trr` and the
@@ -141,26 +144,26 @@ def ivim_model_selector(gtab, fit_method='trr', **kwargs):
         default : trr
 
     """
-    bounds_warning = 'Bounds for this fit have been set from experiments '
-    bounds_warning += 'and literature survey. To change the bounds, please '
-    bounds_warning += 'input your bounds in model definition...'
+    bounds_warning = "Bounds for this fit have been set from experiments "
+    bounds_warning += "and literature survey. To change the bounds, please "
+    bounds_warning += "input your bounds in model definition..."
 
-    if fit_method.lower() == 'trr':
+    if fit_method.lower() == "trr":
         ivimmodel_trr = IvimModelTRR(gtab, **kwargs)
-        if 'bounds' not in kwargs:
-            warnings.warn(bounds_warning, UserWarning)
+        if "bounds" not in kwargs:
+            warnings.warn(bounds_warning, UserWarning, stacklevel=2)
         return ivimmodel_trr
 
-    elif fit_method.lower() == 'varpro':
+    elif fit_method.lower() == "varpro":
         ivimmodel_vp = IvimModelVP(gtab, **kwargs)
-        if 'bounds' not in kwargs:
-            warnings.warn(bounds_warning, UserWarning)
+        if "bounds" not in kwargs:
+            warnings.warn(bounds_warning, UserWarning, stacklevel=2)
         return ivimmodel_vp
 
     else:
-        opt_msg = 'The fit_method option chosen was not correct. '
-        opt_msg += 'Using fit_method: TRR instead...'
-        warnings.warn(opt_msg, UserWarning)
+        opt_msg = "The fit_method option chosen was not correct. "
+        opt_msg += "Using fit_method: TRR instead..."
+        warnings.warn(opt_msg, UserWarning, stacklevel=2)
         return IvimModelTRR(gtab, **kwargs)
 
 
@@ -168,30 +171,39 @@ IvimModel = ivim_model_selector
 
 
 class IvimModelTRR(ReconstModel):
-    """Ivim model
-    """
-    def __init__(self, gtab, split_b_D=400.0, split_b_S0=200., bounds=None,
-                 two_stage=True, tol=1e-15,
-                 x_scale=(1000., 0.1, 0.001, 0.0001),
-                 gtol=1e-15, ftol=1e-15, eps=1e-15, maxiter=1000):
+    """Ivim model"""
 
+    @warning_for_keywords()
+    def __init__(
+        self,
+        gtab,
+        *,
+        split_b_D=400.0,
+        split_b_S0=200.0,
+        bounds=None,
+        two_stage=True,
+        tol=1e-15,
+        x_scale=(1000.0, 0.1, 0.001, 0.0001),
+        gtol=1e-15,
+        ftol=1e-15,
+        eps=1e-15,
+        maxiter=1000,
+    ):
         r"""
         Initialize an IVIM model.
 
-        The IVIM model assumes that biological tissue includes a volume
-        fraction 'f' of water flowing with a pseudo-diffusion coefficient
-        D* and a fraction (1-f) of static (diffusion only), intra and
-        extracellular water, with a diffusion coefficient D. In this model
-        the echo attenuation of a signal in a single voxel can be written as
+        The IVIM model footcite:p:`LeBihan1988`, :footcite:p:`Federau2012`
+        assumes that biological tissue includes a volume fraction 'f' of water
+        flowing with a pseudo-diffusion coefficient D* and a fraction (1-f) of
+        static (diffusion only), intra and extracellular water, with a diffusion
+        coefficient D. In this model the echo attenuation of a signal in a
+        single voxel can be written as
 
-            .. math::
+        .. math::
 
             S(b) = S_0[f*e^{(-b*D\*)} + (1-f)e^{(-b*D)}]
 
-            Where:
-            .. math::
-
-            S_0, f, D\* and D are the IVIM parameters.
+        where $S_0$, $f$, $D\*$ and $D$ are the IVIM parameters.
 
         Parameters
         ----------
@@ -203,13 +215,11 @@ class IvimModelTRR(ReconstModel):
             used while estimating the value of D. The assumption is that at
             higher b values the effects of perfusion is less and hence the
             signal can be approximated as a mono-exponential decay.
-            default : 400.
 
         split_b_S0 : float, optional
             The b-value to split the data on for two-stage fit for estimation
             of S0 and initial guess for D_star. The assumption here is that
             at low bvalues the effects of perfusion are more.
-            default : 200.
 
         bounds : tuple of arrays with 4 elements, optional
             Bounds to constrain the fitted model parameters. This is only
@@ -224,41 +234,30 @@ class IvimModelTRR(ReconstModel):
             parameters after the linear fitting by splitting the data based on
             bvalues. This gives more accurate parameters but takes more time.
             The linear fit can be used to get a quick estimation of the
-            parameters. default : False
+            parameters.
 
         tol : float, optional
             Tolerance for convergence of minimization.
-            default : 1e-15
 
         x_scale : array-like, optional
             Scaling for the parameters. This is passed to `least_squares` which
             is only available for Scipy version > 0.17.
-            default: [1000, 0.01, 0.001, 0.0001]
 
         gtol : float, optional
             Tolerance for termination by the norm of the gradient.
-            default : 1e-15
 
         ftol : float, optional
             Tolerance for termination by the change of the cost function.
-            default : 1e-15
 
         eps : float, optional
             Step size used for numerical approximation of the jacobian.
-            default : 1e-15
 
         maxiter : int, optional
             Maximum number of iterations to perform.
-            default : 1000
 
         References
         ----------
-        .. [1] Le Bihan, Denis, et al. "Separation of diffusion and perfusion
-               in intravoxel incoherent motion MR imaging." Radiology 168.2
-               (1988): 497-505.
-        .. [2] Federau, Christian, et al. "Quantitative measurement of brain
-               perfusion with intravoxel incoherent motion MR imaging."
-               Radiology 265.3 (2012): 874-881.
+        .. footbibliography::
         """
         if not np.any(gtab.b0s_mask):
             e_s = "No measured signal at bvalue == 0."
@@ -281,15 +280,14 @@ class IvimModelTRR(ReconstModel):
         self.bounds = bounds
         self.two_stage = two_stage
         self.tol = tol
-        self.options = {'gtol': gtol, 'ftol': ftol,
-                        'eps': eps, 'maxiter': maxiter}
+        self.options = {"gtol": gtol, "ftol": ftol, "eps": eps, "maxiter": maxiter}
         self.x_scale = x_scale
 
         self.bounds = bounds or BOUNDS
 
     @multi_voxel_fit
-    def fit(self, data):
-        """ Fit method of the IvimModelTRR class.
+    def fit(self, data, **kwargs):
+        """Fit method of the IvimModelTRR class.
 
         The fitting takes place in the following steps: Linear fitting for D
         (bvals > `split_b_D` (default: 400)) and store S0_prime. Another linear
@@ -318,14 +316,14 @@ class IvimModelTRR(ReconstModel):
         """
         # Get S0_prime and D - parameters assuming a single exponential decay
         # for signals for bvals greater than `split_b_D`
-        S0_prime, D = self.estimate_linear_fit(
-            data, self.split_b_D, less_than=False)
+        S0_prime, D = self.estimate_linear_fit(data, self.split_b_D, less_than=False)
 
         # Get S0 and D_star_prime - parameters assuming a single exponential
         # decay for for signals for bvals greater than `split_b_S0`.
 
-        S0, D_star_prime = self.estimate_linear_fit(data, self.split_b_S0,
-                                                    less_than=True)
+        S0, D_star_prime = self.estimate_linear_fit(
+            data, self.split_b_S0, less_than=True
+        )
         # Estimate f
         f_guess = 1 - S0_prime / S0
 
@@ -336,19 +334,22 @@ class IvimModelTRR(ReconstModel):
         # Fit parameters again if two_stage flag is set.
         if self.two_stage:
             params_two_stage = self._leastsq(data, params_linear)
-            bounds_violated = ~(np.all(params_two_stage >= self.bounds[0]) and
-                                (np.all(params_two_stage <= self.bounds[1])))
+            bounds_violated = ~(
+                np.all(params_two_stage >= self.bounds[0])
+                and (np.all(params_two_stage <= self.bounds[1]))
+            )
             if bounds_violated:
                 warningMsg = "Bounds are violated for leastsq fitting. "
                 warningMsg += "Returning parameters from linear fit"
-                warnings.warn(warningMsg, UserWarning)
+                warnings.warn(warningMsg, UserWarning, stacklevel=2)
                 return IvimFit(self, params_linear)
             else:
                 return IvimFit(self, params_two_stage)
         else:
             return IvimFit(self, params_linear)
 
-    def estimate_linear_fit(self, data, split_b, less_than=True):
+    @warning_for_keywords()
+    def estimate_linear_fit(self, data, split_b, *, less_than=True):
         """Estimate a linear fit by taking log of data.
 
         Parameters
@@ -372,14 +373,14 @@ class IvimModelTRR(ReconstModel):
         """
         if less_than:
             bvals_split = self.gtab.bvals[self.gtab.bvals <= split_b]
-            D, neg_log_S0 = np.polyfit(bvals_split,
-                                       -np.log(data[self.gtab.bvals <=
-                                                    split_b]), 1)
+            D, neg_log_S0 = np.polyfit(
+                bvals_split, -np.log(data[self.gtab.bvals <= split_b]), 1
+            )
         else:
             bvals_split = self.gtab.bvals[self.gtab.bvals >= split_b]
-            D, neg_log_S0 = np.polyfit(bvals_split,
-                                       -np.log(data[self.gtab.bvals >=
-                                                    split_b]), 1)
+            D, neg_log_S0 = np.polyfit(
+                bvals_split, -np.log(data[self.gtab.bvals >= split_b]), 1
+            )
 
         S0 = np.exp(-neg_log_S0)
         return S0, D
@@ -415,15 +416,16 @@ class IvimModelTRR(ReconstModel):
         maxfev = self.options["maxiter"]
 
         try:
-            res = least_squares(f_D_star_error,
-                                params_f_D_star,
-                                bounds=((0., 0.), (self.bounds[1][1],
-                                                   self.bounds[1][2])),
-                                args=(self.gtab, data, S0, D),
-                                ftol=ftol,
-                                xtol=xtol,
-                                gtol=gtol,
-                                max_nfev=maxfev)
+            res = least_squares(
+                f_D_star_error,
+                params_f_D_star,
+                bounds=((0.0, 0.0), (self.bounds[1][1], self.bounds[1][2])),
+                args=(self.gtab, data, S0, D),
+                ftol=ftol,
+                xtol=xtol,
+                gtol=gtol,
+                max_nfev=maxfev,
+            )
             f, D_star = res.x
             return f, D_star
         except ValueError:
@@ -431,11 +433,12 @@ class IvimModelTRR(ReconstModel):
             warningMsg += " as initial guess for leastsq while estimating "
             warningMsg += "f and D_star. Using parameters from the "
             warningMsg += "linear fit."
-            warnings.warn(warningMsg, UserWarning)
+            warnings.warn(warningMsg, UserWarning, stacklevel=2)
             f, D_star = params_f_D_star
             return f, D_star
 
-    def predict(self, ivim_params, gtab, S0=1.):
+    @warning_for_keywords()
+    def predict(self, ivim_params, gtab, *, S0=1.0):
         """
         Predict a signal for this IvimModel class instance given parameters.
 
@@ -488,15 +491,17 @@ class IvimModelTRR(ReconstModel):
         bounds = self.bounds
 
         try:
-            res = least_squares(_ivim_error,
-                                x0,
-                                bounds=bounds,
-                                ftol=ftol,
-                                xtol=xtol,
-                                gtol=gtol,
-                                max_nfev=maxfev,
-                                args=(self.gtab, data),
-                                x_scale=self.x_scale)
+            res = least_squares(
+                _ivim_error,
+                x0,
+                bounds=bounds,
+                ftol=ftol,
+                xtol=xtol,
+                gtol=gtol,
+                max_nfev=maxfev,
+                args=(self.gtab, data),
+                x_scale=self.x_scale,
+            )
             ivim_params = res.x
             if np.all(np.isnan(ivim_params)):
                 return np.array([-1, -1, -1, -1])
@@ -504,14 +509,17 @@ class IvimModelTRR(ReconstModel):
         except ValueError:
             warningMsg = "x0 is unfeasible for leastsq fitting."
             warningMsg += " Returning x0 values from the linear fit."
-            warnings.warn(warningMsg, UserWarning)
+            warnings.warn(warningMsg, UserWarning, stacklevel=2)
             return x0
 
 
 class IvimModelVP(ReconstModel):
+    @warning_for_keywords()
+    def __init__(self, gtab, *, bounds=None, maxiter=10, xtol=1e-8):
+        r"""Initialize an IvimModelVP class.
 
-    def __init__(self, gtab, bounds=None, maxiter=10, xtol=1e-8):
-        r""" Initialize an IvimModelVP class.
+        See :footcite:p:`LeBihan1988`, :footcite:p:`Federau2012` and
+        :footcite:p:`Fadnavis2019` for further details about the model.
 
         The IVIM model assumes that biological tissue includes a volume
         fraction 'f' of water flowing with a pseudo-diffusion coefficient
@@ -520,37 +528,22 @@ class IvimModelVP(ReconstModel):
         extracellular water, with a diffusion coefficient D. In this model
         the echo attenuation of a signal in a single voxel can be written as
 
-            .. math::
+        .. math::
 
             S(b) = S_0*[f*e^{(-b*D\*)} + (1-f)e^{(-b*D)}]
 
-            Where:
-            .. math::
-
-            S_0, f, D\* and D are the IVIM parameters.
-
+        where $S_0$, $f$, $D\*$ and $D$ are the IVIM parameters.
 
         maxiter: int, optional
             Maximum number of iterations for the Differential Evolution in
             SciPy.
-            default : 10
 
         xtol : float, optional
             Tolerance for convergence of minimization.
-            default : 1e-8
 
         References
         ----------
-        .. [1] Le Bihan, Denis, et al. "Separation of diffusion and perfusion
-               in intravoxel incoherent motion MR imaging." Radiology 168.2
-               (1988): 497-505.
-        .. [2] Federau, Christian, et al. "Quantitative measurement of brain
-               perfusion with intravoxel incoherent motion MR imaging."
-               Radiology 265.3 (2012): 874-881.
-        .. [3] Fadnavis, Shreyas et.al. "MicroLearn: Framework for machine
-               learning, reconstruction, optimization and microstructure
-               modeling, Proceedings of: International Society of Magnetic
-               Resonance in Medicine (ISMRM), Montreal, Canada, 2019.
+        .. footbibliography::
         """
 
         self.maxiter = maxiter
@@ -562,10 +555,10 @@ class IvimModelVP(ReconstModel):
         self.bounds = bounds or (BOUNDS[0][1:], BOUNDS[1][1:])
 
     @multi_voxel_fit
-    def fit(self, data, bounds_de=None):
-        r""" Fit method of the IvimModelVP model class
+    def fit(self, data, bounds_de=None, **kwargs):
+        r"""Fit method of the IvimModelVP model class
 
-        MicroLearn framework (VarPro)[1]_.
+        MicroLearn framework (VarPro) :footcite:p:`Fadnavis2019`.
 
         The VarPro computes the IVIM parameters using the MIX approach.
         This algorithm uses three different optimizers. It starts with a
@@ -575,18 +568,12 @@ class IvimModelVP(ReconstModel):
         the volume fractions are determined. Then the last step is non linear
         least square fitting on all the parameters. The results of the first
         and second step are utilized as the initial values for the last step
-        of the algorithm. (see [1]_ and [2]_ for a comparison and a through
-        discussion).
+        of the algorithm. (see :footcite:p:`Fadnavis2019` and
+        :footcite:p:`Farooq2016` for a comparison and a thorough discussion).
 
         References
         ----------
-        .. [1] Fadnavis, Shreyas et.al. "MicroLearn: Framework for machine
-               learning, reconstruction, optimization and microstructure
-               modeling, Proceedings of: International Society of Magnetic
-               Resonance in Medicine (ISMRM), Montreal, Canada, 2019.
-        .. [2] Farooq, Hamza, et al. "Microstructure Imaging of Crossing (MIX)
-               White Matter Fibers from diffusion MRI." Scientific reports 6
-               (2016).
+        .. footbibliography::
 
         """
         data_max = data.max()
@@ -597,9 +584,15 @@ class IvimModelVP(ReconstModel):
         bounds_de = np.array([(0.005, 0.01), (10**-4, 0.001)])
 
         # Optimizer #1: Differential Evolution
-        res_one = differential_evolution(self.stoc_search_cost, bounds_de,
-                                         maxiter=self.maxiter, args=(data,),
-                                         disp=False, polish=True, popsize=28)
+        res_one = differential_evolution(
+            self.stoc_search_cost,
+            bounds_de,
+            maxiter=self.maxiter,
+            args=(data,),
+            disp=False,
+            polish=True,
+            popsize=28,
+        )
         x = res_one.x
         phi = self.phi(x)
 
@@ -611,15 +604,15 @@ class IvimModelVP(ReconstModel):
         bounds = self.bounds
 
         # Optimizer #3: Nonlinear-Least Squares
-        res = least_squares(self.nlls_cost, x_f, bounds=bounds,
-                            xtol=self.xtol, args=(data,))
+        res = least_squares(
+            self.nlls_cost, x_f, bounds=bounds, xtol=self.xtol, args=(data,)
+        )
         result = res.x
         f_est = result[0]
         D_star_est = result[1]
         D_est = result[2]
 
-        S0 = data / (f_est * np.exp(-b * D_star_est) + (1 - f_est) *
-                     np.exp(-b * D_est))
+        S0 = data / (f_est * np.exp(-b * D_star_est) + (1 - f_est) * np.exp(-b * D_est))
         S0_est = S0 * data_max
 
         # final result containing the four fit parameters: S0, f, D* and D
@@ -656,8 +649,9 @@ class IvimModelVP(ReconstModel):
         First calculates the Moore-Penrose inverse of the input `phi` and takes
         a dot product with the measured signal. The result obtained is again
         multiplied with `phi` to complete the projection of the variable into
-        a transformed space. (see [1]_ and [2]_ for thorough discussion on
-        Variable Projections and relevant cost functions).
+        a transformed space. (see :footcite:p:`Fadnavis2019` and
+        :footcite:p:`Farooq2016` for thorough discussion on Variable Projections
+        and relevant cost functions).
 
         Parameters
         ----------
@@ -680,13 +674,7 @@ class IvimModelVP(ReconstModel):
 
         References
         ----------
-        .. [1] Fadnavis, Shreyas et.al. "MicroLearn: Framework for machine
-               learning, reconstruction, optimization and microstructure
-               modeling, Proceedings of: International Society of Magnetic
-               Resonance in Medicine (ISMRM), Montreal, Canada, 2019.
-        .. [2] Farooq, Hamza, et al. "Microstructure Imaging of Crossing (MIX)
-               White Matter Fibers from diffusion MRI." Scientific reports 6
-               (2016).
+        .. footbibliography::
 
         """
         # Moore-Penrose
@@ -729,11 +717,13 @@ class IvimModelVP(ReconstModel):
         f = cvxpy.Variable(2)
         # Constraints have been set similar to the MIX paper's
         # Supplementary Note 2: Synthetic Data Experiments, experiment 2
-        constraints = [cvxpy.sum(f) == 1,
-                       f[0] >= 0.011,
-                       f[1] >= 0.011,
-                       f[0] <= self.bounds[1][0],
-                       f[1] <= 0.89]
+        constraints = [
+            cvxpy.sum(f) == 1,
+            f[0] >= 0.011,
+            f[1] >= 0.011,
+            f[0] <= self.bounds[1][0],
+            f[1] <= 0.89,
+        ]
 
         # Form objective.
         obj = cvxpy.Minimize(cvxpy.sum(cvxpy.square(phi @ f - signal)))
@@ -748,7 +738,7 @@ class IvimModelVP(ReconstModel):
         Cost function for the least square problem. The cost function is used
         in the Least Squares function of SciPy in :func: `fit`. It guarantees
         that stopping point of the algorithm is at least a stationary point
-        with reduction in the the number of iterations required by the
+        with reduction in the number of iterations required by the
         differential evolution optimizer.
 
         Parameters
@@ -846,9 +836,8 @@ class IvimModelVP(ReconstModel):
 
 
 class IvimFit:
-
     def __init__(self, model, model_params):
-        """ Initialize a IvimFit class instance.
+        """Initialize a IvimFit class instance.
 
         Parameters
         ----------
@@ -896,7 +885,8 @@ class IvimFit:
     def shape(self):
         return self.model_params.shape[:-1]
 
-    def predict(self, gtab, S0=1.):
+    @warning_for_keywords()
+    def predict(self, gtab, *, S0=1.0):
         """Given a model fit, predict the signal.
 
         Parameters
