@@ -4,24 +4,29 @@ import warnings
 import numpy as np
 
 from dipy.core import geometry as geo
-from dipy.core.gradients import (GradientTable, gradient_table,
-                                 unique_bvals_tolerance, get_bval_indices)
+from dipy.core.gradients import (
+    GradientTable,
+    get_bval_indices,
+    gradient_table,
+    unique_bvals_tolerance,
+)
 from dipy.data import default_sphere
 from dipy.reconst import shm
 from dipy.reconst.csdeconv import response_from_mask_ssst
-from dipy.reconst.dti import (TensorModel, fractional_anisotropy,
-                              mean_diffusivity)
+from dipy.reconst.dti import TensorModel, fractional_anisotropy, mean_diffusivity
 from dipy.reconst.multi_voxel import multi_voxel_fit
-from dipy.reconst.utils import _roi_in_volume, _mask_from_roi
+from dipy.reconst.utils import _mask_from_roi, _roi_in_volume
 from dipy.sims.voxel import single_tensor
+from dipy.testing.decorators import warning_for_keywords
 from dipy.utils.deprecator import deprecated_params
-
 from dipy.utils.optpkg import optional_package
+
 cvxpy, have_cvxpy, _ = optional_package("cvxpy", min_version="1.4.1")
 
-SH_CONST = .5 / np.sqrt(np.pi)
+SH_CONST = 0.5 / np.sqrt(np.pi)
 
-@deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
+
+@deprecated_params("sh_order", new_name="sh_order_max", since="1.9", until="2.0")
 def multi_tissue_basis(gtab, sh_order_max, iso_comp):
     """
     Builds a basis for multi-shell multi-tissue CSD model.
@@ -29,6 +34,7 @@ def multi_tissue_basis(gtab, sh_order_max, iso_comp):
     Parameters
     ----------
     gtab : GradientTable
+        Gradient table.
     sh_order_max : int
         Maximal spherical harmonics order (l).
     iso_comp: int
@@ -40,18 +46,19 @@ def multi_tissue_basis(gtab, sh_order_max, iso_comp):
     B : ndarray
         Matrix of the spherical harmonics model used to fit the data
     m_values : int ``|m_value| <= l_value``
-        The phase factor (m) of the harmonic.
+        The phase factor ($m$) of the harmonic.
     l_values : int ``l_value >= 0``
-        The order (l) of the harmonic.
+        The order ($l$) of the harmonic.
     """
     if iso_comp < 2:
         msg = "Multi-tissue CSD requires at least 2 tissue compartments"
         raise ValueError(msg)
     r, theta, phi = geo.cart2sphere(*gtab.gradients.T)
     m_values, l_values = shm.sph_harm_ind_list(sh_order_max)
-    B = shm.real_sh_descoteaux_from_index(m_values, l_values,
-                                          theta[:, None], phi[:, None])
-    B[np.ix_(gtab.b0s_mask, l_values > 0)] = 0.
+    B = shm.real_sh_descoteaux_from_index(
+        m_values, l_values, theta[:, None], phi[:, None]
+    )
+    B[np.ix_(gtab.b0s_mask, l_values > 0)] = 0.0
 
     iso = np.empty([B.shape[0], iso_comp])
     iso[:] = SH_CONST
@@ -61,9 +68,10 @@ def multi_tissue_basis(gtab, sh_order_max, iso_comp):
 
 
 class MultiShellResponse:
-    @deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
-    def __init__(self, response, sh_order_max, shells, S0=None):
-        """ Estimate Multi Shell response function for multiple tissues and
+    @deprecated_params("sh_order", new_name="sh_order_max", since="1.9", until="2.0")
+    @warning_for_keywords()
+    def __init__(self, response, sh_order_max, shells, *, S0=None):
+        """Estimate Multi Shell response function for multiple tissues and
         multiple shells.
 
         The method `multi_shell_fiber_response` allows to create a multi-shell
@@ -97,20 +105,26 @@ class MultiShellResponse:
     def iso(self):
         return self.response.shape[1] - (self.sh_order_max // 2) - 1
 
-@deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
+
+@deprecated_params("sh_order", new_name="sh_order_max", since="1.9", until="2.0")
 def _inflate_response(response, gtab, sh_order_max, delta):
     """Used to inflate the response for the `multiplier_matrix` in the
     `MultiShellDeconvModel`.
+
     Parameters
     ----------
     response : MultiShellResponse object
+        Response function.
     gtab : GradientTable
+        Gradient table.
     sh_order_max : int ``>= 0``
-        The maximal order (l) of the harmonic.
+        The maximal order ($l$) of the harmonic.
     delta : Delta generated from `_basic_delta`
     """
-    if any((sh_order_max % 2) != 0) or \
-        (sh_order_max.max() // 2) >= response.sh_order_max:
+    if (
+        any((sh_order_max % 2) != 0)
+        or (sh_order_max.max() // 2) >= response.sh_order_max
+    ):
         raise ValueError("Response and n do not match")
 
     iso = response.iso
@@ -133,9 +147,9 @@ def _basic_delta(iso, m_value, l_value, theta, phi):
         number of compartments required is 2.
         Default: 2
     m_value : int ``|m| <= l``
-        The phase factor (m) of the harmonic.
+        The phase factor ($m$) of the harmonic.
     l_value : int ``>= 0``
-        The order (l) of the harmonic.
+        The order ($l$) of the harmonic.
     theta : array_like
        inclination or polar angle
     phi : array_like
@@ -147,27 +161,39 @@ def _basic_delta(iso, m_value, l_value, theta, phi):
 
 
 class MultiShellDeconvModel(shm.SphHarmModel):
-    @deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
-    def __init__(self, gtab, response, reg_sphere=default_sphere,
-                 sh_order_max=8, iso=2, tol=20):
+    @deprecated_params("sh_order", new_name="sh_order_max", since="1.9", until="2.0")
+    @warning_for_keywords()
+    def __init__(
+        self,
+        gtab,
+        response,
+        reg_sphere=default_sphere,
+        *,
+        sh_order_max=8,
+        iso=2,
+        tol=20,
+    ):
         r"""
         Multi-Shell Multi-Tissue Constrained Spherical Deconvolution
-        (MSMT-CSD) [1]_. This method extends the CSD model proposed in [2]_ by
-        the estimation of multiple response functions as a function of multiple
-        b-values and multiple tissue types.
+        (MSMT-CSD) :footcite:p:`Jeurissen2014`. This method extends the CSD
+        model proposed in :footcite:p:`Tournier2007`. by the estimation of
+        multiple response functions as a function of multiple b-values and
+        multiple tissue types.
 
         Spherical deconvolution computes a fiber orientation distribution
-        (FOD), also called fiber ODF (fODF) [2]_. The fODF is derived from
-        different tissue types and thus overcomes the overestimation of WM in
-        GM and CSF areas.
+        (FOD), also called fiber ODF (fODF) :footcite:p:`Tournier2007`. The fODF
+        is derived from different tissue types and thus overcomes the
+        overestimation of WM in GM and CSF areas.
 
         The response function is based on the different tissue types
         and is provided as input to the MultiShellDeconvModel.
-        It will be used as deconvolution kernel, as described in [2]_.
+        It will be used as deconvolution kernel, as described in
+        :footcite:p:`Tournier2007`.
 
         Parameters
         ----------
         gtab : GradientTable
+            Gradient table.
         response : ndarray or MultiShellResponse object
             Pre-computed multi-shell fiber response function in the form of a
             MultiShellResponse object, or simple response function as a ndarray.
@@ -180,29 +206,19 @@ class MultiShellDeconvModel(shm.SphHarmModel):
             for the response function without diffusion weighting (S0). Note
             that in order to use more than three compartments, one must create
             a MultiShellResponse object on the side.
-        reg_sphere : Sphere (optional)
+        reg_sphere : Sphere, optional
             sphere used to build the regularization B matrix.
-            Default: 'symmetric362'.
-        sh_order_max : int (optional)
-            Maximal spherical harmonics order (l). Default: 8
-        iso: int (optional)
+        sh_order_max : int, optional
+            Maximal spherical harmonics order (l).
+        iso: int, optional
             Number of tissue compartments for running the MSMT-CSD. Minimum
             number of compartments required is 2.
-            Default: 2
         tol : int, optional
             Tolerance gap for b-values clustering.
 
         References
         ----------
-        .. [1] Jeurissen, B., et al. NeuroImage 2014. Multi-tissue constrained
-               spherical deconvolution for improved analysis of multi-shell
-               diffusion MRI data
-        .. [2] Tournier, J.D., et al. NeuroImage 2007. Robust determination of
-               the fibre orientation distribution in diffusion MRI:
-               Non-negativity constrained super-resolved spherical
-               deconvolution
-        .. [3] Tournier, J.D, et al. Imaging Systems and Technology
-               2012. MRtrix: Diffusion Tractography in Crossing Fiber Regions
+        .. footbibliography::
         """
         if not iso >= 2:
             msg = "Multi-tissue CSD requires at least 2 tissue compartments"
@@ -216,20 +232,23 @@ class MultiShellDeconvModel(shm.SphHarmModel):
                 msg = """Too many compartments for this kind of response
                 input. It must be two tissue compartments."""
                 raise ValueError(msg)
-            if response.shape != (3, len(bvals)-1, 4):
+            if response.shape != (3, len(bvals) - 1, 4):
                 msg = """Response must be of shape (3, len(bvals)-1, 4) or be a
                 MultiShellResponse object."""
                 raise ValueError(msg)
-            response = multi_shell_fiber_response(sh_order_max,
-                                                  bvals=bvals,
-                                                  wm_rf=response[0],
-                                                  gm_rf=response[1],
-                                                  csf_rf=response[2])
+            response = multi_shell_fiber_response(
+                sh_order_max,
+                bvals=bvals,
+                wm_rf=response[0],
+                gm_rf=response[1],
+                csf_rf=response[2],
+            )
 
         B, m_values, l_values = multi_tissue_basis(gtab, sh_order_max, iso)
 
-        delta = _basic_delta(response.iso, response.m_values,
-                             response.l_values, 0., 0.)
+        delta = _basic_delta(
+            response.iso, response.m_values, response.l_values, 0.0, 0.0
+        )
         self.delta = delta
         multiplier_matrix = _inflate_response(response, gtab, l_values, delta)
 
@@ -251,7 +270,8 @@ class MultiShellDeconvModel(shm.SphHarmModel):
         self.l_values = l_values
         self.response = response
 
-    def predict(self, params, gtab=None, S0=None):
+    @warning_for_keywords()
+    def predict(self, params, *, gtab=None, S0=None):
         """Compute a signal prediction given spherical harmonic coefficients
         for the provided GradientTable class instance.
 
@@ -270,17 +290,14 @@ class MultiShellDeconvModel(shm.SphHarmModel):
             X = self._X
         else:
             iso = self.response.iso
-            B, m_values, l_values = multi_tissue_basis(gtab,
-                                                       self.sh_order_max,
-                                                       iso)
-            multiplier_matrix = _inflate_response(self.response,
-                                                  gtab,
-                                                  l_values,
-                                                  self.delta)
+            B, m_values, l_values = multi_tissue_basis(gtab, self.sh_order_max, iso)
+            multiplier_matrix = _inflate_response(
+                self.response, gtab, l_values, self.delta
+            )
             X = B * multiplier_matrix
 
-        scaling = 1.
-        if S0 and S0 != 1.:     # The S0=1. case comes from fit.predict().
+        scaling = 1.0
+        if S0 and S0 != 1.0:  # The S0=1. case comes from fit.predict().
             raise NotImplementedError
             # This case is not implemented yet because it would require to have
             # access to volume fractions (vf) from the fit. The following code
@@ -298,7 +315,7 @@ class MultiShellDeconvModel(shm.SphHarmModel):
         return pred_sig
 
     @multi_voxel_fit
-    def fit(self, data, verbose=True):
+    def fit(self, data, verbose=True, **kwargs):
         """Fits the model to diffusion data and returns the model fit.
 
         Sometimes the solving process of some voxels can end in a SolverError
@@ -313,9 +330,8 @@ class MultiShellDeconvModel(shm.SphHarmModel):
         ----------
         data : ndarray
             The diffusion data to fit the model on.
-        verbose : bool (optional)
+        verbose : bool, optional
             Whether to show warnings when a SolverError appears or not.
-            Default: True
         """
         coeff = self.fitter(data)
         if verbose:
@@ -323,13 +339,12 @@ class MultiShellDeconvModel(shm.SphHarmModel):
                 msg = """Voxel could not be solved properly and ended up with a
                 SolverError. Proceeding to fill it with NaN values.
                 """
-                warnings.warn(msg, UserWarning)
+                warnings.warn(msg, UserWarning, stacklevel=2)
 
         return MSDeconvFit(self, coeff, None)
 
 
 class MSDeconvFit(shm.SphHarmFit):
-
     def __init__(self, model, coeff, mask):
         """
         Abstract class which holds the fit result of MultiShellDeconvModel.
@@ -351,7 +366,7 @@ class MSDeconvFit(shm.SphHarmFit):
 
     @property
     def shm_coeff(self):
-        return self._shm_coef[..., self.model.response.iso:]
+        return self._shm_coef[..., self.model.response.iso :]
 
     @property
     def all_shm_coeff(self):
@@ -400,13 +415,12 @@ def solve_qp(P, Q, G, H):
         opt = np.array(x.value).reshape((Q.shape[0],))
     except cvxpy.error.SolverError:
         opt = np.empty((Q.shape[0],))
-        opt[:] = np.NaN
+        opt[:] = np.nan
 
     return opt
 
 
 class QpFitter:
-
     def __init__(self, X, reg):
         r"""
         Makes use of the quadratic programming solver `solve_qp` to fit the
@@ -435,9 +449,12 @@ class QpFitter:
         fodf_sh = solve_qp(self._P_mat, Q_mat, self._reg_mat, self._h_mat)
         return fodf_sh
 
-@deprecated_params('sh_order', 'sh_order_max', since='1.9', until='2.0')
-def multi_shell_fiber_response(sh_order_max, bvals, wm_rf, gm_rf, csf_rf,
-                               sphere=None, tol=20, btens=None):
+
+@deprecated_params("sh_order", new_name="sh_order_max", since="1.9", until="2.0")
+@warning_for_keywords()
+def multi_shell_fiber_response(
+    sh_order_max, bvals, wm_rf, gm_rf, csf_rf, *, sphere=None, tol=20, btens=None
+):
     """Fiber response function estimation for multi-shell data.
 
     Parameters
@@ -483,7 +500,7 @@ def multi_shell_fiber_response(sh_order_max, bvals, wm_rf, gm_rf, csf_rf,
         msg = """bvals and btens parameters must have the same dimension."""
         raise ValueError(msg)
     evecs = np.zeros((3, 3))
-    z = np.array([0, 0, 1.])
+    z = np.array([0, 0, 1.0])
     evecs[:, 0] = z
     evecs[:2, 1:] = np.eye(2)
 
@@ -496,43 +513,45 @@ def multi_shell_fiber_response(sh_order_max, bvals, wm_rf, gm_rf, csf_rf,
     big_sphere = sphere.subdivide()
     theta, phi = big_sphere.theta, big_sphere.phi
 
-    B = shm.real_sh_descoteaux_from_index(m_values, l_values,
-                                          theta[:, None], phi[:, None])
+    B = shm.real_sh_descoteaux_from_index(
+        m_values, l_values, theta[:, None], phi[:, None]
+    )
     A = shm.real_sh_descoteaux_from_index(0, 0, 0, 0)
 
     response = np.empty([len(bvals), len(l_values) + 2])
 
     if bvals[0] < tol:
         gtab = GradientTable(big_sphere.vertices * 0, btens=btens[0])
-        wm_response = single_tensor(gtab, wm_rf[0, 3], wm_rf[0, :3], evecs,
-                                    snr=None)
+        wm_response = single_tensor(
+            gtab, wm_rf[0, 3], evals=wm_rf[0, :3], evecs=evecs, snr=None
+        )
         response[0, 2:] = np.linalg.lstsq(B, wm_response, rcond=None)[0]
 
         response[0, 1] = gm_rf[0, 3] / A
         response[0, 0] = csf_rf[0, 3] / A
 
         for i, bvalue in enumerate(bvals[1:]):
-            gtab = GradientTable(big_sphere.vertices * bvalue,
-                                 btens=btens[i + 1])
-            wm_response = single_tensor(gtab, wm_rf[i, 3], wm_rf[i, :3], evecs,
-                                        snr=None)
-            response[i+1, 2:] = np.linalg.lstsq(B, wm_response,
-                                                rcond=None)[0]
+            gtab = GradientTable(big_sphere.vertices * bvalue, btens=btens[i + 1])
+            wm_response = single_tensor(
+                gtab, wm_rf[i, 3], evals=wm_rf[i, :3], evecs=evecs, snr=None
+            )
+            response[i + 1, 2:] = np.linalg.lstsq(B, wm_response, rcond=None)[0]
 
-            response[i+1, 1] = gm_rf[i, 3] * np.exp(-bvalue * gm_rf[i, 0]) / A
-            response[i+1, 0] = csf_rf[i, 3] * np.exp(-bvalue * csf_rf[i, 0]) / A
+            response[i + 1, 1] = gm_rf[i, 3] * np.exp(-bvalue * gm_rf[i, 0]) / A
+            response[i + 1, 0] = csf_rf[i, 3] * np.exp(-bvalue * csf_rf[i, 0]) / A
 
         S0 = [csf_rf[0, 3], gm_rf[0, 3], wm_rf[0, 3]]
 
     else:
-        warnings.warn("""No b0 given. Proceeding either way.""", UserWarning)
+        warnings.warn(
+            """No b0 given. Proceeding either way.""", UserWarning, stacklevel=2
+        )
         for i, bvalue in enumerate(bvals):
-            gtab = GradientTable(big_sphere.vertices * bvalue,
-                                 btens=btens[i])
-            wm_response = single_tensor(gtab, wm_rf[i, 3], wm_rf[i, :3], evecs,
-                                        snr=None)
-            response[i, 2:] = np.linalg.lstsq(B, wm_response,
-                                              rcond=None)[0]
+            gtab = GradientTable(big_sphere.vertices * bvalue, btens=btens[i])
+            wm_response = single_tensor(
+                gtab, wm_rf[i, 3], evals=wm_rf[i, :3], evecs=evecs, snr=None
+            )
+            response[i, 2:] = np.linalg.lstsq(B, wm_response, rcond=None)[0]
 
             response[i, 1] = gm_rf[i, 3] * np.exp(-bvalue * gm_rf[i, 0]) / A
             response[i, 0] = csf_rf[i, 3] * np.exp(-bvalue * csf_rf[i, 0]) / A
@@ -542,15 +561,26 @@ def multi_shell_fiber_response(sh_order_max, bvals, wm_rf, gm_rf, csf_rf,
     return MultiShellResponse(response, sh_order_max, bvals, S0=S0)
 
 
-def mask_for_response_msmt(gtab, data, roi_center=None, roi_radii=10,
-                           wm_fa_thr=0.7, gm_fa_thr=0.2, csf_fa_thr=0.1,
-                           gm_md_thr=0.0007, csf_md_thr=0.002):
-    """ Computation of masks for multi-shell multi-tissue (msmt) response
+@warning_for_keywords()
+def mask_for_response_msmt(
+    gtab,
+    data,
+    *,
+    roi_center=None,
+    roi_radii=10,
+    wm_fa_thr=0.7,
+    gm_fa_thr=0.2,
+    csf_fa_thr=0.1,
+    gm_md_thr=0.0007,
+    csf_md_thr=0.002,
+):
+    """Computation of masks for multi-shell multi-tissue (msmt) response
         function using FA and MD.
 
     Parameters
     ----------
     gtab : GradientTable
+        Gradient table.
     data : ndarray
         diffusion data (4D)
     roi_center : array-like, (3,)
@@ -604,8 +634,9 @@ def mask_for_response_msmt(gtab, data, roi_center=None, roi_radii=10,
     if roi_center is None:
         roi_center = np.array(data.shape[:3]) // 2
 
-    roi_radii = _roi_in_volume(data.shape, np.asarray(roi_center),
-                               np.asarray(roi_radii))
+    roi_radii = _roi_in_volume(
+        data.shape, np.asarray(roi_center), np.asarray(roi_radii)
+    )
 
     roi_mask = _mask_from_roi(data.shape[:3], roi_center, roi_radii)
 
@@ -613,7 +644,7 @@ def mask_for_response_msmt(gtab, data, roi_center=None, roi_radii=10,
     if not np.all(list_bvals <= 1200):
         msg_bvals = """Some b-values are higher than 1200.
         The DTI fit might be affected."""
-        warnings.warn(msg_bvals, UserWarning)
+        warnings.warn(msg_bvals, UserWarning, stacklevel=2)
 
     ten = TensorModel(gtab)
     tenfit = ten.fit(data, mask=roi_mask)
@@ -648,31 +679,33 @@ def mask_for_response_msmt(gtab, data, roi_center=None, roi_radii=10,
     Try a larger roi or a {2} threshold for {3}."""
 
     if np.sum(mask_wm) == 0:
-        msg_fa = msg.format('FA higher', str(wm_fa_thr), 'lower FA', 'WM')
-        warnings.warn(msg_fa, UserWarning)
+        msg_fa = msg.format("FA higher", str(wm_fa_thr), "lower FA", "WM")
+        warnings.warn(msg_fa, UserWarning, stacklevel=2)
 
     if np.sum(mask_gm) == 0:
-        msg_fa = msg.format('FA lower', str(gm_fa_thr), 'higher FA', 'GM')
-        msg_md = msg.format('MD lower', str(gm_md_thr), 'higher MD', 'GM')
-        warnings.warn(msg_fa, UserWarning)
-        warnings.warn(msg_md, UserWarning)
+        msg_fa = msg.format("FA lower", str(gm_fa_thr), "higher FA", "GM")
+        msg_md = msg.format("MD lower", str(gm_md_thr), "higher MD", "GM")
+        warnings.warn(msg_fa, UserWarning, stacklevel=2)
+        warnings.warn(msg_md, UserWarning, stacklevel=2)
 
     if np.sum(mask_csf) == 0:
-        msg_fa = msg.format('FA lower', str(csf_fa_thr), 'higher FA', 'CSF')
-        msg_md = msg.format('MD lower', str(csf_md_thr), 'higher MD', 'CSF')
-        warnings.warn(msg_fa, UserWarning)
-        warnings.warn(msg_md, UserWarning)
+        msg_fa = msg.format("FA lower", str(csf_fa_thr), "higher FA", "CSF")
+        msg_md = msg.format("MD lower", str(csf_md_thr), "higher MD", "CSF")
+        warnings.warn(msg_fa, UserWarning, stacklevel=2)
+        warnings.warn(msg_md, UserWarning, stacklevel=2)
 
     return mask_wm, mask_gm, mask_csf
 
 
-def response_from_mask_msmt(gtab, data, mask_wm, mask_gm, mask_csf, tol=20):
-    """ Computation of multi-shell multi-tissue (msmt) response
+@warning_for_keywords()
+def response_from_mask_msmt(gtab, data, mask_wm, mask_gm, mask_csf, *, tol=20):
+    """Computation of multi-shell multi-tissue (msmt) response
         functions from given tissues masks.
 
     Parameters
     ----------
     gtab : GradientTable
+        Gradient table.
     data : ndarray
         diffusion data
     mask_wm : ndarray
@@ -714,9 +747,9 @@ def response_from_mask_msmt(gtab, data, mask_wm, mask_gm, mask_csf, tol=20):
     bvecs = gtab.bvecs
     btens = gtab.btens
 
-    list_bvals = unique_bvals_tolerance(bvals, tol)
+    list_bvals = unique_bvals_tolerance(bvals, tol=tol)
 
-    b0_indices = get_bval_indices(bvals, list_bvals[0], tol)
+    b0_indices = get_bval_indices(bvals, list_bvals[0], tol=tol)
     b0_map = np.mean(data[..., b0_indices], axis=-1)[..., np.newaxis]
 
     masks = [mask_wm, mask_gm, mask_csf]
@@ -724,10 +757,9 @@ def response_from_mask_msmt(gtab, data, mask_wm, mask_gm, mask_csf, tol=20):
     for mask in masks:
         responses = []
         for bval in list_bvals[1:]:
-            indices = get_bval_indices(bvals, bval, tol)
+            indices = get_bval_indices(bvals, bval, tol=tol)
 
-            bvecs_sub = np.concatenate([[bvecs[b0_indices[0]]],
-                                       bvecs[indices]])
+            bvecs_sub = np.concatenate([[bvecs[b0_indices[0]]], bvecs[indices]])
             bvals_sub = np.concatenate([[0], bvals[indices]])
             if btens is not None:
                 btens_b0 = btens[b0_indices[0]].reshape((1, 3, 3))
@@ -737,7 +769,7 @@ def response_from_mask_msmt(gtab, data, mask_wm, mask_gm, mask_csf, tol=20):
 
             data_conc = np.concatenate([b0_map, data[..., indices]], axis=3)
 
-            gtab = gradient_table(bvals_sub, bvecs_sub, btens=btens_sub)
+            gtab = gradient_table(bvals_sub, bvecs=bvecs_sub, btens=btens_sub)
             response, _ = response_from_mask_ssst(gtab, data_conc, mask)
 
             responses.append(list(np.concatenate([response[0], [response[1]]])))
@@ -750,15 +782,27 @@ def response_from_mask_msmt(gtab, data, mask_wm, mask_gm, mask_csf, tol=20):
     return wm_response, gm_response, csf_response
 
 
-def auto_response_msmt(gtab, data, tol=20, roi_center=None, roi_radii=10,
-                       wm_fa_thr=0.7, gm_fa_thr=0.3, csf_fa_thr=0.15,
-                       gm_md_thr=0.001, csf_md_thr=0.0032):
-    """ Automatic estimation of multi-shell multi-tissue (msmt) response
+@warning_for_keywords()
+def auto_response_msmt(
+    gtab,
+    data,
+    *,
+    tol=20,
+    roi_center=None,
+    roi_radii=10,
+    wm_fa_thr=0.7,
+    gm_fa_thr=0.3,
+    csf_fa_thr=0.15,
+    gm_md_thr=0.001,
+    csf_md_thr=0.0032,
+):
+    """Automatic estimation of multi-shell multi-tissue (msmt) response
         functions using FA and MD.
 
     Parameters
     ----------
     gtab : GradientTable
+        Gradient table.
     data : ndarray
         diffusion data
     tol : int, optional
@@ -807,18 +851,20 @@ def auto_response_msmt(gtab, data, tol=20, roi_center=None, roi_radii=10,
         The DTI fit might be affected. It is advised to use
         mask_for_response_msmt with bvalues lower than 1200, followed by
         response_from_mask_msmt with all bvalues to overcome this."""
-        warnings.warn(msg_bvals, UserWarning)
-    mask_wm, mask_gm, mask_csf = mask_for_response_msmt(gtab, data,
-                                                        roi_center,
-                                                        roi_radii,
-                                                        wm_fa_thr,
-                                                        gm_fa_thr,
-                                                        csf_fa_thr,
-                                                        gm_md_thr,
-                                                        csf_md_thr)
+        warnings.warn(msg_bvals, UserWarning, stacklevel=2)
+    mask_wm, mask_gm, mask_csf = mask_for_response_msmt(
+        gtab,
+        data,
+        roi_center=roi_center,
+        roi_radii=roi_radii,
+        wm_fa_thr=wm_fa_thr,
+        gm_fa_thr=gm_fa_thr,
+        csf_fa_thr=csf_fa_thr,
+        gm_md_thr=gm_md_thr,
+        csf_md_thr=csf_md_thr,
+    )
     response_wm, response_gm, response_csf = response_from_mask_msmt(
-                                                        gtab, data,
-                                                        mask_wm, mask_gm,
-                                                        mask_csf, tol)
+        gtab, data, mask_wm, mask_gm, mask_csf, tol=tol
+    )
 
     return response_wm, response_gm, response_csf
