@@ -1,19 +1,20 @@
 #!/usr/bin/python
-""" Classes and functions for fitting the mean signal diffusion kurtosis
-model """
+"""Classes and functions for fitting the mean signal diffusion kurtosis
+model"""
 
 import numpy as np
 import scipy.optimize as opt
 
-from dipy.core.gradients import (check_multi_b, unique_bvals_magnitude,
-                                 round_bvals)
-from dipy.reconst.base import ReconstModel
-from dipy.reconst.dti import MIN_POSITIVE_SIGNAL
+from dipy.core.gradients import check_multi_b, round_bvals, unique_bvals_magnitude
 from dipy.core.ndindex import ndindex
 from dipy.core.onetime import auto_attr
+from dipy.reconst.base import ReconstModel
+from dipy.reconst.dti import MIN_POSITIVE_SIGNAL
+from dipy.testing.decorators import warning_for_keywords
 
 
-def mean_signal_bvalue(data, gtab, bmag=None):
+@warning_for_keywords()
+def mean_signal_bvalue(data, gtab, *, bmag=None):
     """
     Computes the average signal across different diffusion directions
     for each unique b-value
@@ -75,24 +76,22 @@ def msk_from_awf(f):
 
     Notes
     -----
-    Computes mean signal kurtosis using equations 17 of [1]_
+    Computes mean signal kurtosis using equations 17 of
+    :footcite:p:`NetoHenriques2019`.
 
     References
     ----------
-    .. [1] Neto Henriques R, Jespersen SN, Shemesh N (2019). Microscopic
-           anisotropy misestimation in spherical‐mean single diffusion
-           encoding MRI. Magnetic Resonance in Medicine (In press).
-           doi: 10.1002/mrm.27606
+    .. footbibliography::
     """
-    msk_num = 216*f - 504 * f**2 + 504 * f**3 - 180 * f**4
-    msk_den = 135 - 360*f + 420 * f**2 - 240 * f**3 + 60 * f**4
+    msk_num = 216 * f - 504 * f**2 + 504 * f**3 - 180 * f**4
+    msk_den = 135 - 360 * f + 420 * f**2 - 240 * f**3 + 60 * f**4
     msk = msk_num / msk_den
 
     return msk
 
 
 def _msk_from_awf_error(f, msk):
-    """ Helper function that calculates the error of a predicted mean signal
+    """Helper function that calculates the error of a predicted mean signal
     kurtosis from the axonal water fraction of SMT2 model and a measured
     mean signal kurtosis
 
@@ -107,11 +106,16 @@ def _msk_from_awf_error(f, msk):
     -------
     error : float
        Error computed by subtracting msk with fun(f), where fun is the function
-       described in equation 17 of [1]_
+       described in equation 17 of :footcite:p:`NetoHenriques2019`.
 
     Notes
     -----
-    This function corresponds to the differential of equations 17 of [1]_
+    This function corresponds to the differential of equations 17 of
+    :footcite:p:`NetoHenriques2019`.
+
+    References
+    ----------
+    .. footbibliography::
     """
     return msk_from_awf(f) - msk
 
@@ -134,29 +138,32 @@ def _diff_msk_from_awf(f, msk):
 
     Notes
     -----
-    This function corresponds to the differential of equations 17 of [1]_.
+    This function corresponds to the differential of equations 17 of
+    :footcite:p:`NetoHenriques2019`.
+
     This function is applicable to both _msk_from_awf and _msk_from_awf_error.
 
     References
     ----------
-    .. [1] Neto Henriques R, Jespersen SN, Shemesh N (2019). Microscopic
-           anisotropy misestimation in spherical‐mean single diffusion
-           encoding MRI. Magnetic Resonance in Medicine (In press).
-           doi: 10.1002/mrm.27606
+    .. footbibliography::
     """
-    F = 216*f - 504 * f**2 + 504 * f**3 - 180 * f**4  # Numerator
-    G = 135 - 360*f + 420 * f**2 - 240 * f**3 + 60 * f**4  # Denominator
+    F = 216 * f - 504 * f**2 + 504 * f**3 - 180 * f**4  # Numerator
+    G = 135 - 360 * f + 420 * f**2 - 240 * f**3 + 60 * f**4  # Denominator
 
     dF = 216 - 1008 * f + 1512 * f**2 - 720 * f**3  # Num. differential
     dG = -360 + 840 * f - 720 * f**2 + 240 * f**3  # Den. differential
 
-    return (G * dF - F * dG) / (G ** 2)
+    return (G * dF - F * dG) / (G**2)
 
 
-def awf_from_msk(msk, mask=None):
+@warning_for_keywords()
+def awf_from_msk(msk, *, mask=None):
     """
     Computes the axonal water fraction from the mean signal kurtosis
-    assuming the 2-compartmental spherical mean technique model [1]_, [2]_
+    assuming the 2-compartmental spherical mean technique model.
+
+    See :footcite:p:`Kaden2016b` and :footcite:p:`NetoHenriques2019` for further
+    details about the method.
 
     Parameters
     ----------
@@ -174,16 +181,11 @@ def awf_from_msk(msk, mask=None):
     Notes
     -----
     Computes the axonal water fraction from the mean signal kurtosis
-    MSK using equation 17 of [1]_
+    MSK using equation 17 of :footcite:p:`NetoHenriques2019`.
 
     References
     ----------
-    .. [1] Neto Henriques R, Jespersen SN, Shemesh N (2019). Microscopic
-           anisotropy misestimation in spherical‐mean single diffusion
-           encoding MRI. Magnetic Resonance in Medicine (In press).
-           doi: 10.1002/mrm.27606
-    .. [2] Kaden E, Kelm ND, Carson RP, et al. (2016) Multi‐compartment
-           microscopic diffusion imaging. Neuroimage 139:346–359.
+    .. footbibliography::
     """
     awf = np.zeros(msk.shape)
 
@@ -193,7 +195,7 @@ def awf_from_msk(msk, mask=None):
     else:
         if mask.shape != msk.shape:
             raise ValueError("Mask is not the same shape as data.")
-        mask = np.array(mask, dtype=bool, copy=False)
+        mask = np.asarray(mask, dtype=bool)
 
     # looping voxels
     index = ndindex(mask.shape)
@@ -217,17 +219,20 @@ def awf_from_msk(msk, mask=None):
                     fini,
                     args=(mski,),
                     fprime=_diff_msk_from_awf,
-                    col_deriv=True
+                    col_deriv=True,
                 ).item()
 
     return awf
 
 
-def msdki_prediction(msdki_params, gtab, S0=1.0):
+@warning_for_keywords()
+def msdki_prediction(msdki_params, gtab, *, S0=1.0):
     """
     Predict the mean signal given the parameters of the mean signal DKI, an
     GradientTable object and S0 signal.
 
+    See :footcite:p:`NetoHenriques2018` for further details about the method.
+
     Parameters
     ----------
     msdki_params : ndarray ([X, Y, Z, ...], 2)
@@ -235,9 +240,9 @@ def msdki_prediction(msdki_params, gtab, S0=1.0):
         in its last axis
     gtab : a GradientTable class instance
         The gradient table for this prediction
-    S0 : float or ndarray (optional)
+    S0 : float or ndarray, optional
         The non diffusion-weighted signal in every voxel, or across all
-        voxels. Default: 1
+        voxels.
 
     Notes
     -----
@@ -247,10 +252,7 @@ def msdki_prediction(msdki_params, gtab, S0=1.0):
 
     References
     ----------
-    .. [1] Henriques, R.N., 2018. Advanced Methods for Diffusion MRI Data
-           Analysis and their Application to the Healthy Ageing Brain (Doctoral
-           thesis). Downing College, University of Cambridge.
-           https://doi.org/10.17863/CAM.29356
+    .. footbibliography::
     """
     A = design_matrix(round_bvals(gtab.bvals))
 
@@ -272,22 +274,24 @@ def msdki_prediction(msdki_params, gtab, S0=1.0):
 
 
 class MeanDiffusionKurtosisModel(ReconstModel):
-    """ Mean signal Diffusion Kurtosis Model
-    """
+    """Mean signal Diffusion Kurtosis Model"""
 
-    def __init__(self, gtab, bmag=None, return_S0_hat=False, *args, **kwargs):
-        """ Mean Signal Diffusion Kurtosis Model [1]_.
+    def __init__(self, gtab, *args, bmag=None, return_S0_hat=False, **kwargs):
+        """Mean Signal Diffusion Kurtosis Model.
+
+        See :footcite:p:`NetoHenriques2018` for further details about the model.
 
         Parameters
         ----------
         gtab : GradientTable class instance
+            Gradient table.
 
-        bmag : int
+        bmag : int, optional
             The order of magnitude that the bvalues have to differ to be
             considered an unique b-value. Default: derive this value from the
             maximal b-value provided: $bmag=log_{10}(max(bvals)) - 1$.
 
-        return_S0_hat : bool
+        return_S0_hat : bool, optional
             If True, also return S0 values for the fit.
 
         args, kwargs : arguments and keyword arguments passed to the
@@ -295,10 +299,7 @@ class MeanDiffusionKurtosisModel(ReconstModel):
 
         References
         ----------
-        .. [1] Henriques, R.N., 2018. Advanced Methods for Diffusion MRI Data
-               Analysis and their Application to the Healthy Ageing Brain
-               (Doctoral thesis). Downing College, University of Cambridge.
-               https://doi.org/10.17863/CAM.29356
+        .. footbibliography::
 
         """
         ReconstModel.__init__(self, gtab)
@@ -309,7 +310,7 @@ class MeanDiffusionKurtosisModel(ReconstModel):
         self.bmag = bmag
         self.args = args
         self.kwargs = kwargs
-        self.min_signal = self.kwargs.pop('min_signal', MIN_POSITIVE_SIGNAL)
+        self.min_signal = self.kwargs.pop("min_signal", MIN_POSITIVE_SIGNAL)
         if self.min_signal is not None and self.min_signal <= 0:
             e_s = "The `min_signal` key-word argument needs to be strictly"
             e_s += " positive."
@@ -321,8 +322,9 @@ class MeanDiffusionKurtosisModel(ReconstModel):
             mes = "MSDKI requires at least 3 b-values (which can include b=0)"
             raise ValueError(mes)
 
-    def fit(self, data, mask=None):
-        """ Fit method of the MSDKI model class
+    @warning_for_keywords()
+    def fit(self, data, *, mask=None):
+        """Fit method of the MSDKI model class
 
         Parameters
         ----------
@@ -341,26 +343,36 @@ class MeanDiffusionKurtosisModel(ReconstModel):
         # Remove mdata zeros
         mdata = np.maximum(mdata, self.min_signal)
 
-        params = wls_fit_msdki(self.design_matrix, mdata, ng, mask=mask,
-                               return_S0_hat=self.return_S0_hat, *self.args,
-                               **self.kwargs)
+        params = wls_fit_msdki(
+            self.design_matrix,
+            mdata,
+            ng,
+            mask=mask,
+            return_S0_hat=self.return_S0_hat,
+            *self.args,
+            **self.kwargs,
+        )
         if self.return_S0_hat:
             params, S0_params = params
 
         return MeanDiffusionKurtosisFit(self, params, model_S0=S0_params)
 
-    def predict(self, msdki_params, S0=1.):
+    @warning_for_keywords()
+    def predict(self, msdki_params, *, S0=1.0):
         """
         Predict a signal for this MeanDiffusionKurtosisModel class instance
         given parameters.
 
+        See :footcite:p:`NetoHenriques2018` for further details about the
+        method.
+
         Parameters
         ----------
         msdki_params : ndarray
             The parameters of the mean signal diffusion kurtosis model
-        S0 : float or ndarray
+        S0 : float or ndarray, optional
             The non diffusion-weighted signal in every voxel, or across all
-            voxels. Default: 1
+            voxels.
 
         Returns
         -------
@@ -376,19 +388,15 @@ class MeanDiffusionKurtosisModel(ReconstModel):
 
         References
         ----------
-        .. [1] Henriques, R.N., 2018. Advanced Methods for Diffusion MRI Data
-               Analysis and their Application to the Healthy Ageing Brain
-               (Doctoral thesis). Downing College, University of Cambridge.
-               https://doi.org/10.17863/CAM.29356
+        .. footbibliography::
         """
-        return msdki_prediction(msdki_params, self.gtab, S0)
+        return msdki_prediction(msdki_params, self.gtab, S0=S0)
 
 
 class MeanDiffusionKurtosisFit:
-
-    def __init__(self, model, model_params, model_S0=None):
-        """ Initialize a MeanDiffusionKurtosisFit class instance.
-        """
+    @warning_for_keywords()
+    def __init__(self, model, model_params, *, model_S0=None):
+        """Initialize a MeanDiffusionKurtosisFit class instance."""
         self.model = model
         self.model_params = model_params
         self.model_S0 = model_S0
@@ -404,8 +412,9 @@ class MeanDiffusionKurtosisFit:
         index = index + (slice(None),) * (N - len(index))
         if model_S0 is not None:
             model_S0 = model_S0[index[:-1]]
-        return MeanDiffusionKurtosisFit(self.model, model_params[index],
-                                        model_S0=model_S0)
+        return MeanDiffusionKurtosisFit(
+            self.model, model_params[index], model_S0=model_S0
+        )
 
     @property
     def S0_hat(self):
@@ -414,20 +423,20 @@ class MeanDiffusionKurtosisFit:
     @auto_attr
     def msd(self):
         r"""
-        Mean signal diffusitivity (MSD) calculated from the mean signal
+        Mean signal diffusivity (MSD) calculated from the mean signal
         Diffusion Kurtosis Model.
 
+        See :footcite:p:`NetoHenriques2018` for further details about the
+        method.
+
         Returns
         -------
         msd : ndarray
-            Calculated signal mean diffusitivity.
+            Calculated signal mean diffusivity.
 
         References
         ----------
-        .. [1] Henriques, R.N., 2018. Advanced Methods for Diffusion MRI Data
-               Analysis and their Application to the Healthy Ageing Brain
-               (Doctoral thesis). Downing College, University of Cambridge.
-               https://doi.org/10.17863/CAM.29356
+        .. footbibliography::
         """
         return self.model_params[..., 0]
 
@@ -437,6 +446,9 @@ class MeanDiffusionKurtosisFit:
         Mean signal kurtosis (MSK) calculated from the mean signal
         Diffusion Kurtosis Model.
 
+        See :footcite:p:`NetoHenriques2018` for further details about the
+        method.
+
         Returns
         -------
         msk : ndarray
@@ -444,10 +456,7 @@ class MeanDiffusionKurtosisFit:
 
         References
         ----------
-        .. [1] Henriques, R.N., 2018. Advanced Methods for Diffusion MRI Data
-               Analysis and their Application to the Healthy Ageing Brain
-               (Doctoral thesis). Downing College, University of Cambridge.
-               https://doi.org/10.17863/CAM.29356
+        .. footbibliography::
         """
         return self.model_params[..., 1]
 
@@ -455,7 +464,10 @@ class MeanDiffusionKurtosisFit:
     def smt2f(self):
         r"""
         Computes the axonal water fraction from the mean signal kurtosis
-        assuming the 2-compartmental spherical mean technique model [1]_, [2]_
+        assuming the 2-compartmental spherical mean technique model.
+
+        See :footcite:p:`Kaden2016b` and :footcite:p:`NetoHenriques2019` for
+        further details about the method.
 
         Returns
         -------
@@ -465,25 +477,23 @@ class MeanDiffusionKurtosisFit:
         Notes
         -----
         Computes the axonal water fraction from the mean signal kurtosis
-        MSK using equation 17 of [1]_
+        MSK using equation 17 of :footcite:p:`NetoHenriques2019`.
 
         References
         ----------
-        .. [1] Neto Henriques R, Jespersen SN, Shemesh N (2019). Microscopic
-               anisotropy misestimation in spherical‐mean single diffusion
-               encoding MRI. Magnetic Resonance in Medicine (In press).
-               doi: 10.1002/mrm.27606
-        .. [2] Kaden E, Kelm ND, Carson RP, et al. (2016) Multi‐compartment
-               microscopic diffusion imaging. Neuroimage 139:346–359.
+        .. footbibliography::
         """
         return awf_from_msk(self.msk)
 
     @auto_attr
     def smt2di(self):
         r"""
-        Computes the intrisic diffusivity from the mean signal diffusional
+        Computes the intrinsic diffusivity from the mean signal diffusional
         kurtosis parameters assuming the 2-compartmental spherical mean
-        technique model [1]_, [2]_
+        technique model.
+
+        See :footcite:p:`Kaden2016b` and :footcite:p:`NetoHenriques2019` for
+        further details about the method.
 
         Returns
         -------
@@ -492,25 +502,24 @@ class MeanDiffusionKurtosisFit:
 
         Notes
         -----
-        Computes the intrinsic diffusivity using equation 16 of [1]_
+        Computes the intrinsic diffusivity using equation 16 of
+        :footcite:p:`NetoHenriques2019`.
 
         References
         ----------
-        .. [1] Neto Henriques R, Jespersen SN, Shemesh N (2019). Microscopic
-               anisotropy misestimation in spherical‐mean single diffusion
-               encoding MRI. Magnetic Resonance in Medicine (In press).
-               doi: 10.1002/mrm.27606
-        .. [2] Kaden E, Kelm ND, Carson RP, et al. (2016) Multi‐compartment
-               microscopic diffusion imaging. Neuroimage 139:346–359.
+        .. footbibliography::
         """
-        return 3 * self.msd / (1 + 2 * (1 - self.smt2f)**2)
+        return 3 * self.msd / (1 + 2 * (1 - self.smt2f) ** 2)
 
     @auto_attr
     def smt2uFA(self):
         r"""
         Computes the microscopic fractional anisotropy from the mean signal
         diffusional kurtosis parameters assuming the 2-compartmental spherical
-        mean technique model [1]_, [2]_
+        mean technique model.
+
+        See :footcite:p:`Kaden2016b` and :footcite:p:`NetoHenriques2019` for
+        further details about the method.
 
         Returns
         -------
@@ -520,27 +529,27 @@ class MeanDiffusionKurtosisFit:
 
         Notes
         -----
-        Computes the intrinsic diffusivity using equation 10 of [1]_
+        Computes the intrinsic diffusivity using equation 10 of
+        :footcite:p:`NetoHenriques2019`.
 
         References
         ----------
-        .. [1] Neto Henriques R, Jespersen SN, Shemesh N (2019). Microscopic
-               anisotropy misestimation in spherical‐mean single diffusion
-               encoding MRI. Magnetic Resonance in Medicine (In press).
-               doi: 10.1002/mrm.27606
-        .. [2] Kaden E, Kelm ND, Carson RP, et al. (2016) Multi‐compartment
-               microscopic diffusion imaging. Neuroimage 139:346–359.
+        .. footbibliography::
         """
-        fe = (1 - self.smt2f)
-        num = 3 * (1 - 2 * fe ** 2 + fe ** 3)
-        den = 3 + 2 * fe ** 3 + 4 * fe ** 4
-        return np.sqrt(num/den)
+        fe = 1 - self.smt2f
+        num = 3 * (1 - 2 * fe**2 + fe**3)
+        den = 3 + 2 * fe**3 + 4 * fe**4
+        return np.sqrt(num / den)
 
-    def predict(self, gtab, S0=1.):
+    @warning_for_keywords()
+    def predict(self, gtab, *, S0=1.0):
         r"""
         Given a mean signal diffusion kurtosis model fit, predict the signal
         on the vertices of a sphere
 
+        See :footcite:p:`NetoHenriques2018` for further details about the
+        method.
+
         Parameters
         ----------
         gtab : a GradientTable class instance
@@ -564,19 +573,26 @@ class MeanDiffusionKurtosisFit:
 
         References
         ----------
-        .. [1] Henriques, R.N., 2018. Advanced Methods for Diffusion MRI Data
-               Analysis and their Application to the Healthy Ageing Brain
-               (Doctoral thesis). Downing College, University of Cambridge.
-               https://doi.org/10.17863/CAM.29356
+        .. footbibliography::
         """
         return msdki_prediction(self.model_params, gtab, S0=S0)
 
 
-def wls_fit_msdki(design_matrix, msignal, ng, mask=None,
-                  min_signal=MIN_POSITIVE_SIGNAL, return_S0_hat=False):
+@warning_for_keywords()
+def wls_fit_msdki(
+    design_matrix,
+    msignal,
+    ng,
+    *,
+    mask=None,
+    min_signal=MIN_POSITIVE_SIGNAL,
+    return_S0_hat=False,
+):
     r"""
     Fits the mean signal diffusion kurtosis imaging based on a weighted
-    least square solution [1]_.
+    least square solution.
+
+    See :footcite:p:`NetoHenriques2018` for further details about the method.
 
     Parameters
     ----------
@@ -607,10 +623,7 @@ def wls_fit_msdki(design_matrix, msignal, ng, mask=None,
 
     References
     ----------
-    .. [1] Henriques, R.N., 2018. Advanced Methods for Diffusion MRI Data
-           Analysis and their Application to the Healthy Ageing Brain
-           (Doctoral thesis). Downing College, University of Cambridge.
-           https://doi.org/10.17863/CAM.29356
+    .. footbibliography::
     """
     params = np.zeros(msignal.shape[:-1] + (3,))
 
@@ -620,7 +633,7 @@ def wls_fit_msdki(design_matrix, msignal, ng, mask=None,
     else:
         if mask.shape != msignal.shape[:-1]:
             raise ValueError("Mask is not the same shape as data.")
-        mask = np.array(mask, dtype=bool, copy=False)
+        mask = np.asarray(mask, dtype=bool)
 
     index = ndindex(mask.shape)
     for v in index:
@@ -631,7 +644,7 @@ def wls_fit_msdki(design_matrix, msignal, ng, mask=None,
         if np.mean(msignal[v]) <= min_signal:
             continue
         # Define weights as diag(ng * yn**2)
-        W = np.diag(ng * msignal[v]**2)
+        W = np.diag(ng * msignal[v] ** 2)
 
         # WLS fitting
         BTW = np.dot(design_matrix.T, W)
@@ -639,7 +652,7 @@ def wls_fit_msdki(design_matrix, msignal, ng, mask=None,
         p = np.linalg.multi_dot([inv_BT_W_B, BTW, np.log(msignal[v])])
 
         # Process parameters
-        p[1] = p[1] / (p[0]**2)
+        p[1] = p[1] / (p[0] ** 2)
         p[2] = np.exp(p[2])
         params[v] = p
 
@@ -650,7 +663,7 @@ def wls_fit_msdki(design_matrix, msignal, ng, mask=None,
 
 
 def design_matrix(ubvals):
-    """  Constructs design matrix for the mean signal diffusion kurtosis model
+    """Constructs design matrix for the mean signal diffusion kurtosis model
 
     Parameters
     ----------
@@ -667,6 +680,6 @@ def design_matrix(ubvals):
     nb = ubvals.shape
     B = np.zeros(nb + (3,))
     B[:, 0] = -ubvals
-    B[:, 1] = 1.0/6.0 * ubvals**2
+    B[:, 1] = 1.0 / 6.0 * ubvals**2
     B[:, 2] = np.ones(nb)
     return B
