@@ -1,17 +1,19 @@
-from dipy.reconst.base import ReconstModel, ReconstFit
 import numpy as np
 
+from dipy.reconst.base import ReconstFit, ReconstModel
+from dipy.testing.decorators import warning_for_keywords
+
 # Classes OdfModel and OdfFit are using API ReconstModel and ReconstFit from
 # .base
 
 
 class OdfModel(ReconstModel):
-
     """An abstract class to be sub-classed by specific odf models
 
     All odf models should provide a fit method which may take data as it's
     first and only argument.
     """
+
     def __init__(self, gtab):
         ReconstModel.__init__(self, gtab)
 
@@ -44,7 +46,9 @@ def gfa(samples):
 
     Notes
     -----
-    The GFA is defined as [1]_ ::
+    The GFA is defined as :footcite:p:`CohenAdad2011`:
+
+    .. math::
 
         \sqrt{\frac{n \sum_i{(\Psi_i - <\Psi>)^2}}{(n-1) \sum{\Psi_i ^ 2}}}
 
@@ -52,21 +56,22 @@ def gfa(samples):
     the unit sphere and angle brackets denote average over the samples on the
     sphere.
 
-    .. [1] Quality assessment of High Angular Resolution Diffusion Imaging
-           data using bootstrap on Q-ball reconstruction. J. Cohen Adad, M.
-           Descoteaux, L.L. Wald. JMRI 33: 1194-1208.
+    References
+    ----------
+    .. footbibliography::
     """
     diff = samples - samples.mean(-1)[..., None]
     n = samples.shape[-1]
-    numer = np.array([n * (diff ** 2).sum(-1)])
-    denom = np.array([(n - 1) * (samples ** 2).sum(-1)])
+    numer = np.array([n * (diff**2).sum(-1)])
+    denom = np.array([(n - 1) * (samples**2).sum(-1)])
     result = np.ones_like(denom) * np.nan
     idx = np.where(denom > 0)
     result[idx] = np.sqrt(numer[idx] / denom[idx])
     return result.squeeze()
 
 
-def minmax_normalize(samples, out=None):
+@warning_for_keywords()
+def minmax_normalize(samples, *, out=None):
     """Min-max normalization of a function evaluated on the unit sphere
 
     Normalizes samples to ``(samples - min(samples)) / (max(samples) -
@@ -87,7 +92,7 @@ def minmax_normalize(samples, out=None):
 
     """
     if out is None:
-        dtype = np.common_type(np.empty(0, 'float32'), samples)
+        dtype = np.common_type(np.empty(0, "float32"), samples)
         out = np.array(samples, dtype=dtype, copy=True)
     else:
         out[:] = samples
@@ -95,5 +100,5 @@ def minmax_normalize(samples, out=None):
     sample_mins = np.min(samples, -1)[..., None]
     sample_maxes = np.max(samples, -1)[..., None]
     out -= sample_mins
-    out /= (sample_maxes - sample_mins)
+    out /= sample_maxes - sample_mins
     return out
