@@ -1,20 +1,21 @@
 """Robust and Unbiased Model-BAsed Spherical Deconvolution (RUMBA-SD)"""
+
 import logging
 import warnings
 
 import numpy as np
 
 from dipy.core.geometry import vec2vec_rotmat
-from dipy.core.gradients import gradient_table, unique_bvals_tolerance, \
-    get_bval_indices
+from dipy.core.gradients import get_bval_indices, gradient_table, unique_bvals_tolerance
 from dipy.core.onetime import auto_attr
 from dipy.core.sphere import Sphere
 from dipy.data import get_sphere
-from dipy.reconst.shm import lazy_index, normalize_data
-from dipy.reconst.odf import OdfModel, OdfFit
 from dipy.reconst.csdeconv import AxSymShResponse
+from dipy.reconst.odf import OdfFit, OdfModel
+from dipy.reconst.shm import lazy_index, normalize_data
 from dipy.segment.mask import bounding_box, crop
-from dipy.sims.voxel import single_tensor, all_tensor_evecs
+from dipy.sims.voxel import all_tensor_evecs, single_tensor
+from dipy.testing.decorators import warning_for_keywords
 
 # Machine precision for numerical stability in division
 _EPS = np.finfo(float).eps
@@ -22,33 +23,47 @@ logger = logging.getLogger(__name__)
 
 
 class RumbaSDModel(OdfModel):
-
-    def __init__(self, gtab, wm_response=np.array([1.7e-3, 0.2e-3, 0.2e-3]),
-                 gm_response=0.8e-3, csf_response=3.0e-3, n_iter=600,
-                 recon_type='smf', n_coils=1, R=1, voxelwise=True,
-                 use_tv=False, sphere=None, verbose=False):
+    @warning_for_keywords()
+    def __init__(
+        self,
+        gtab,
+        *,
+        wm_response=(1.7e-3, 0.2e-3, 0.2e-3),
+        gm_response=0.8e-3,
+        csf_response=3.0e-3,
+        n_iter=600,
+        recon_type="smf",
+        n_coils=1,
+        R=1,
+        voxelwise=True,
+        use_tv=False,
+        sphere=None,
+        verbose=False,
+    ):
         """
-        Robust and Unbiased Model-BAsed Spherical Deconvolution (RUMBA-SD) [1]_
+        Robust and Unbiased Model-BAsed Spherical Deconvolution (RUMBA-SD).
 
-        Modification of the Richardson-Lucy algorithm accounting for Rician
-        and Noncentral Chi noise distributions, which more accurately
-        represent MRI noise. Computes a maximum likelihood estimation of the
-        fiber orientation density function (fODF) at each voxel. Includes
-        white matter compartments alongside optional GM and CSF compartments
-        to account for partial volume effects. This fit can be performed
-        voxelwise or globally. The global fit will proceed more quickly than
-        the voxelwise fit provided that the computer has adequate RAM (>= 16 GB
-        should be sufficient for most datasets).
+        RUMBA-SD :footcite:p:`CanalesRodriguez2015` is a modification of the
+        Richardson-Lucy algorithm accounting for Rician and Noncentral Chi noise
+        distributions, which more accurately represent MRI noise. Computes a
+        maximum likelihood estimation of the fiber orientation density function
+        (fODF) at each voxel. Includes white matter compartments alongside
+        optional GM and CSF compartments to account for partial volume effects.
+        This fit can be performed voxelwise or globally. The global fit will
+        proceed more quickly than the voxelwise fit provided that the computer
+        has adequate RAM (>= 16 GB should be sufficient for most datasets).
 
         Kernel for deconvolution constructed using a priori knowledge of white
         matter response function, as well as the mean diffusivity of GM and/or
         CSF. RUMBA-SD is robust against impulse response imprecision, and thus
-        the default diffusivity values are often adequate [2]_.
+        the default diffusivity values are often adequate
+        :footcite:p:`DellAcqua2007`.
 
 
         Parameters
         ----------
         gtab : GradientTable
+            Gradient table.
         wm_response : 1d ndarray or 2d ndarray or AxSymShResponse, optional
             Tensor eigenvalues as a (3,) ndarray, multishell eigenvalues as
             a (len(unique_bvals_tolerance(gtab.bvals))-1, 3) ndarray in
@@ -79,37 +94,21 @@ class RumbaSDModel(OdfModel):
         voxelwise : bool, optional
             If true, performs a voxelwise fit. If false, performs a global fit
             on the entire brain at once. The global fit requires a 4D brain
-            volume in `fit`. Default: True
+            volume in `fit`.
         use_tv : bool, optional
             If true, applies total variation regularization. This only takes
             effect in a global fit (`voxelwise` is set to `False`). TV can only
             be applied to 4D brain volumes with no singleton dimensions.
-            Default: False
         sphere : Sphere, optional
             Sphere on which to construct fODF. If None, uses `repulsion724`.
-            Default: None
         verbose : bool, optional
             If true, logs updates on estimated signal-to-noise ratio after each
             iteration. This only takes effect in a global fit (`voxelwise` is
-            set to `False`). Default: False
+            set to `False`).
 
         References
         ----------
-        .. [1] Canales-Rodríguez, E. J., Daducci, A., Sotiropoulos, S. N.,
-               Caruyer, E., Aja-Fernández, S., Radua, J., Mendizabal, J. M. Y.,
-               Iturria-Medina, Y., Melie-García, L., Alemán-Gómez, Y.,
-               Thiran, J.-P., Sarró, S., Pomarol-Clotet, E., & Salvador, R.
-               (2015). Spherical Deconvolution of Multichannel Diffusion MRI
-               Data with Non-Gaussian Noise Models and Spatial Regularization.
-               PLOS ONE, 10(10), e0138910.
-               https://doi.org/10.1371/journal.pone.0138910
-
-        .. [2] Dell’Acqua, F., Rizzo, G., Scifo, P., Clarke, R., Scotti, G., &
-               Fazio, F. (2007). A Model-Based Deconvolution Approach to Solve
-               Fiber Crossing in Diffusion-Weighted MR Imaging. IEEE
-               Transactions on Bio-Medical Engineering, 54, 462–472.
-               https://doi.org/10.1109/TBME.2006.888830
-
+        .. footbibliography::
 
         """
 
@@ -125,11 +124,14 @@ class RumbaSDModel(OdfModel):
         # Correct gradient table to contain b0 data at the beginning
         bvals_cor = np.concatenate(([0], gtab.bvals[self.where_dwi]))
         bvecs_cor = np.concatenate(([[0, 0, 0]], gtab.bvecs[self.where_dwi]))
-        gtab_cor = gradient_table(bvals_cor, bvecs_cor)
+        gtab_cor = gradient_table(bvals_cor, bvecs=bvecs_cor)
 
         # Initialize self.gtab
         OdfModel.__init__(self, gtab_cor)
 
+        if isinstance(wm_response, tuple):
+            wm_response = np.asarray(wm_response)
+
         # Store responses
         self.wm_response = wm_response
         self.gm_response = gm_response
@@ -137,8 +139,10 @@ class RumbaSDModel(OdfModel):
 
         # Initializing remaining parameters
         if R < 1 or n_iter < 1 or n_coils < 1:
-            raise ValueError(f"R, n_iter, and n_coils must be >= 1, but R={R},"
-                             + f"n_iter={n_iter}, and n_coils={n_coils} ")
+            raise ValueError(
+                f"R, n_iter, and n_coils must be >= 1, but R={R},"
+                + f"n_iter={n_iter}, and n_coils={n_coils} "
+            )
 
         self.R = R
         self.n_iter = n_iter
@@ -148,8 +152,9 @@ class RumbaSDModel(OdfModel):
         if voxelwise and use_tv:
             raise ValueError("Total variation has no effect in voxelwise fit")
         if voxelwise and verbose:
-            warnings.warn("Verbosity has no effect in voxelwise fit",
-                          UserWarning)
+            warnings.warn(
+                "Verbosity has no effect in voxelwise fit", UserWarning, stacklevel=2
+            )
 
         self.voxelwise = voxelwise
         self.use_tv = use_tv
@@ -157,7 +162,7 @@ class RumbaSDModel(OdfModel):
         self.verbose = verbose
 
         if sphere is None:
-            self.sphere = get_sphere('repulsion724')
+            self.sphere = get_sphere(name="repulsion724")
         else:
             self.sphere = sphere
 
@@ -169,7 +174,8 @@ class RumbaSDModel(OdfModel):
         # Fitting parameters
         self.kernel = None
 
-    def _global_fit(self, data, mask=None):
+    @warning_for_keywords()
+    def _global_fit(self, data, *, mask=None):
         """
         Fit fODF and GM/CSF volume fractions globally.
 
@@ -191,46 +197,58 @@ class RumbaSDModel(OdfModel):
 
         # Checking data and mask shapes
         if len(data.shape) != 4:
-            raise ValueError(
-                f"Data should be 4D, received shape f{data.shape}")
+            raise ValueError(f"Data should be 4D, received shape f{data.shape}")
 
         if mask is None:  # default mask includes all voxels
             mask = np.ones(data.shape[:3])
 
         if data.shape[:3] != mask.shape:
-            raise ValueError("Mask shape should match first 3 dimensions of "
-                             + f"data, but data dimensions are f{data.shape} "
-                             + f"while mask dimensions are f{mask.shape}")
+            raise ValueError(
+                "Mask shape should match first 3 dimensions of "
+                + f"data, but data dimensions are f{data.shape} "
+                + f"while mask dimensions are f{mask.shape}"
+            )
 
         # Signal repair, normalization
 
         # Normalize data to mean b0 image
-        data = normalize_data(data, self.where_b0s, _EPS)
+        data = normalize_data(data, self.where_b0s, min_signal=_EPS)
         # Rearrange data to match corrected gradient table
         data = np.concatenate(
-            (np.ones([*data.shape[:3], 1]), data[..., self.where_dwi]), axis=3)
+            (np.ones([*data.shape[:3], 1]), data[..., self.where_dwi]), axis=3
+        )
         data[data > 1] = 1  # clip values between 0 and 1
 
         # All arrays are converted to float32 to reduce memory load
         data = data.astype(np.float32)
 
         # Generate kernel
-        self.kernel = generate_kernel(self.gtab, self.sphere, self.wm_response,
-                                      self.gm_response, self.csf_response
-                                      ).astype(np.float32)
+        self.kernel = generate_kernel(
+            self.gtab,
+            self.sphere,
+            self.wm_response,
+            self.gm_response,
+            self.csf_response,
+        ).astype(np.float32)
 
         # Fit fODF
-        model_params = rumba_deconv_global(data, self.kernel, mask,
-                                           self.n_iter,
-                                           self.recon_type,
-                                           self.n_coils,
-                                           self.R, self.use_tv,
-                                           self.verbose)
+        model_params = rumba_deconv_global(
+            data,
+            self.kernel,
+            mask,
+            n_iter=self.n_iter,
+            recon_type=self.recon_type,
+            n_coils=self.n_coils,
+            R=self.R,
+            use_tv=self.use_tv,
+            verbose=self.verbose,
+        )
 
         model_fit = RumbaFit(self, model_params)
         return model_fit
 
-    def _voxelwise_fit(self, data, mask=None):
+    @warning_for_keywords()
+    def _voxelwise_fit(self, data, *, mask=None):
         """
         Fit fODF and GM/CSF volume fractions voxelwise.
 
@@ -254,36 +272,39 @@ class RumbaSDModel(OdfModel):
             mask = np.ones(data.shape[:-1])
 
         if data.shape[:-1] != mask.shape:
-            raise ValueError("Mask shape should match first dimensions of "
-                             + f"data, but data dimensions are f{data.shape} "
-                             + f"while mask dimensions are f{mask.shape}")
+            raise ValueError(
+                "Mask shape should match first dimensions of "
+                + f"data, but data dimensions are f{data.shape} "
+                + f"while mask dimensions are f{mask.shape}"
+            )
 
-        self.kernel = generate_kernel(self.gtab,
-                                      self.sphere,
-                                      self.wm_response,
-                                      self.gm_response,
-                                      self.csf_response)
+        self.kernel = generate_kernel(
+            self.gtab,
+            self.sphere,
+            self.wm_response,
+            self.gm_response,
+            self.csf_response,
+        )
 
-        model_params = np.zeros(
-            data.shape[:-1] + (len(self.sphere.vertices) + 2,))
+        model_params = np.zeros(data.shape[:-1] + (len(self.sphere.vertices) + 2,))
 
         for ijk in np.ndindex(data.shape[:-1]):
             if mask[ijk]:
-
                 vox_data = data[ijk]
                 # Normalize data to mean b0 image
-                vox_data = normalize_data(vox_data, self.where_b0s,
-                                          min_signal=_EPS)
+                vox_data = normalize_data(vox_data, self.where_b0s, min_signal=_EPS)
                 # Rearrange data to match corrected gradient table
                 vox_data = np.concatenate(([1], vox_data[self.where_dwi]))
                 vox_data[vox_data > 1] = 1  # clip values between 0 and 1
 
                 # Fitting
-                model_param = rumba_deconv(vox_data,
-                                           self.kernel,
-                                           self.n_iter,
-                                           self.recon_type,
-                                           self.n_coils)
+                model_param = rumba_deconv(
+                    vox_data,
+                    self.kernel,
+                    n_iter=self.n_iter,
+                    recon_type=self.recon_type,
+                    n_coils=self.n_coils,
+                )
 
                 model_params[ijk] = model_param
 
@@ -292,7 +313,6 @@ class RumbaSDModel(OdfModel):
 
 
 class RumbaFit(OdfFit):
-
     def __init__(self, model, model_params):
         """
         Constructs fODF, GM/CSF volume fractions, and other derived results.
@@ -312,7 +332,8 @@ class RumbaFit(OdfFit):
         self.model = model
         self.model_params = model_params
 
-    def odf(self, sphere=None):
+    @warning_for_keywords()
+    def odf(self, *, sphere=None):
         """
         Constructs fODF at discrete vertices on model sphere for each voxel.
 
@@ -329,8 +350,10 @@ class RumbaFit(OdfFit):
 
         """
         if sphere is not None and sphere != self.model.sphere:
-            raise ValueError("Reconstruction sphere must be the same as used"
-                             + " in the RUMBA-SD model.")
+            raise ValueError(
+                "Reconstruction sphere must be the same as used"
+                + " in the RUMBA-SD model."
+            )
 
         odf = self.model_params[..., :-2]
         return odf
@@ -414,7 +437,8 @@ class RumbaFit(OdfFit):
         combined = odf + self.f_iso[..., None] / odf.shape[-1]
         return combined
 
-    def predict(self, gtab=None, S0=None):
+    @warning_for_keywords()
+    def predict(self, *, gtab=None, S0=None):
         """
         Compute signal prediction on model gradient table given given fODF
         and GM/CSF volume fractions for each voxel.
@@ -440,11 +464,13 @@ class RumbaFit(OdfFit):
         if gtab is None:
             gtab = self.model.gtab_orig
 
-        pred_kernel = generate_kernel(gtab,
-                                      self.model.sphere,
-                                      self.model.wm_response,
-                                      self.model.gm_response,
-                                      self.model.csf_response)
+        pred_kernel = generate_kernel(
+            gtab,
+            self.model.sphere,
+            self.model.wm_response,
+            self.model.gm_response,
+            self.model.csf_response,
+        )
 
         if S0 is None:
             S0 = np.ones(model_params.shape[:-1] + (1,))
@@ -460,15 +486,16 @@ class RumbaFit(OdfFit):
         return pred_sig
 
 
-def rumba_deconv(data, kernel, n_iter=600, recon_type='smf', n_coils=1):
+@warning_for_keywords()
+def rumba_deconv(data, kernel, *, n_iter=600, recon_type="smf", n_coils=1):
     r"""
-    Fit fODF and GM/CSF volume fractions for a voxel using RUMBA-SD [1]_.
+    Fit fODF and GM/CSF volume fractions for a voxel using RUMBA-SD.
 
     Deconvolves the kernel from the diffusion-weighted signal by computing a
-    maximum likelihood estimation of the fODF. Minimizes the negative
-    log-likelihood of the data under Rician or Noncentral Chi noise
-    distributions by adapting the iterative technique developed in
-    Richardson-Lucy deconvolution.
+    maximum likelihood estimation of the fODF
+    :footcite:p:`CanalesRodriguez2015`. Minimizes the negative log-likelihood of
+    the data under Rician or Noncentral Chi noise distributions by adapting the
+    iterative technique developed in Richardson-Lucy deconvolution.
 
     Parameters
     ----------
@@ -522,9 +549,9 @@ def rumba_deconv(data, kernel, n_iter=600, recon_type='smf', n_coils=1):
     fractions for each compartment.
 
     Modern MRI scanners produce noise following a Rician or Noncentral Chi
-    distribution, depending on their signal reconstruction technique [2]_.
-    Using this linear model, it can be shown that the likelihood of a signal
-    under a Noncentral Chi noise model is:
+    distribution, depending on their signal reconstruction technique
+    `footcite:p:`Constantinides1997`. Using this linear model, it can be shown
+    that the likelihood of a signal under a Noncentral Chi noise model is:
 
     $P(\textbf{S}|\textbf{H}, \textbf{f}, \sigma^2, n) = \prod_{i=1}^{N}\left(
     \frac{S_i}{\bar{S_i}}\right)^n\exp\left\{-\frac{1}{2\sigma^2}\left[
@@ -560,23 +587,11 @@ def rumba_deconv(data, kernel, n_iter=600, recon_type='smf', n_coils=1):
     \circ\textbf{Hf})\circ\frac{I_n(\textbf{S}\circ\textbf{Hf}/\alpha^k)}
     {I_{n-1}(\textbf{S}\circ\textbf{Hf}/\alpha^k)} \right ]\right \}$
 
-    For more details, see [1]_.
+    For more details, see :footcite:p:`CanalesRodriguez2015`.
 
     References
     ----------
-    .. [1] Canales-Rodríguez, E. J., Daducci, A., Sotiropoulos, S. N., Caruyer,
-           E., Aja-Fernández, S., Radua, J., Mendizabal, J. M. Y.,
-           Iturria-Medina, Y., Melie-García, L., Alemán-Gómez, Y., Thiran,
-           J.-P.,Sarró, S., Pomarol-Clotet, E., & Salvador, R. (2015).
-           Spherical Deconvolution of Multichannel Diffusion MRI Data with
-           Non-Gaussian Noise Models and Spatial Regularization. PLOS ONE,
-           10(10), e0138910. https://doi.org/10.1371/journal.pone.0138910
-
-    .. [2] Constantinides, C. D., Atalar, E., & McVeigh, E. R. (1997).
-           Signal-to-Noise Measurements in Magnitude Images from NMR Phased
-           Arrays. Magnetic Resonance in Medicine: Official Journal of the
-           Society of Magnetic Resonance in Medicine / Society of Magnetic
-           Resonance in Medicine, 38(5), 852–857.
+    .. footbibliography::
     """
 
     n_comp = kernel.shape[1]  # number of compartments
@@ -590,8 +605,9 @@ def rumba_deconv(data, kernel, n_iter=600, recon_type='smf', n_coils=1):
     elif recon_type == "sos":
         n_order = n_coils  # Noncentral Chi noise (order = # of coils)
     else:
-        raise ValueError("Invalid recon_type. Should be 'smf' or 'sos', " +
-                         f"received {recon_type}")
+        raise ValueError(
+            f"Invalid recon_type. Should be 'smf' or 'sos', received {recon_type}"
+        )
 
     data = data.reshape(-1, 1)
     reblurred = np.matmul(kernel, fodf)
@@ -609,8 +625,9 @@ def rumba_deconv(data, kernel, n_iter=600, recon_type='smf', n_coils=1):
     for _ in range(n_iter):
         fodf_i = fodf
         ratio = mbessel_ratio(n_order, reblurred_s)
-        rl_factor = np.matmul(kernel_t, data * ratio) / \
-            (np.matmul(kernel_t, reblurred) + _EPS)
+        rl_factor = np.matmul(kernel_t, data * ratio) / (
+            np.matmul(kernel_t, reblurred) + _EPS
+        )
 
         fodf = fodf_i * rl_factor  # result of iteration
         fodf = np.maximum(f_zero, fodf)  # apply positivity constraint
@@ -620,11 +637,10 @@ def rumba_deconv(data, kernel, n_iter=600, recon_type='smf', n_coils=1):
         reblurred_s = data * reblurred / sigma2
 
         # Iterate variance
-        sigma2_i = (1 / (n_grad * n_order)) * \
-            np.sum((data**2 + reblurred**2) / 2 -
-                   (sigma2 * reblurred_s) * ratio,
-                   axis=0)
-        sigma2_i = np.minimum((1 / 8)**2, np.maximum(sigma2_i, (1 / 80)**2))
+        sigma2_i = (1 / (n_grad * n_order)) * np.sum(
+            (data**2 + reblurred**2) / 2 - (sigma2 * reblurred_s) * ratio, axis=0
+        )
+        sigma2_i = np.minimum((1 / 8) ** 2, np.maximum(sigma2_i, (1 / 80) ** 2))
         sigma2 = sigma2_i * np.ones(data.shape)  # Expand into vector
 
     # Normalize final result
@@ -642,7 +658,7 @@ def mbessel_ratio(n, x):
     $I_{n}(x) / I_{n-1}(x)$
 
     using Perron's continued fraction equation where $I_n$ is the modified
-    Bessel function of first kind, order $n$ [1]_.
+    Bessel function of first kind, order $n$ :footcite:p:`Gautschi1978`.
 
     Parameters
     ----------
@@ -659,14 +675,28 @@ def mbessel_ratio(n, x):
 
     References
     ----------
-    .. [1] W. Gautschi and J. Slavik, “On the computation of modified Bessel
-           function ratios,” Math. Comp., vol. 32, no. 143, pp. 865–875, 1978,
-           doi: 10.1090/S0025-5718-1978-0470267-9
+    .. footbibliography::
     """
 
-    y = x / ((2 * n + x) - (2 * x * (n + 1 / 2) / (2 * n + 1 + 2 * x - (
-        2 * x * (n + 3 / 2) / (2 * n + 2 + 2 * x - (2 * x * (n + 5 / 2) / (
-            2 * n + 3 + 2 * x)))))))
+    y = x / (
+        (2 * n + x)
+        - (
+            2
+            * x
+            * (n + 1 / 2)
+            / (
+                2 * n
+                + 1
+                + 2 * x
+                - (
+                    2
+                    * x
+                    * (n + 3 / 2)
+                    / (2 * n + 2 + 2 * x - (2 * x * (n + 5 / 2) / (2 * n + 3 + 2 * x)))
+                )
+            )
+        )
+    )
 
     return y
 
@@ -682,6 +712,7 @@ def generate_kernel(gtab, sphere, wm_response, gm_response, csf_response):
     Parameters
     ----------
     gtab : GradientTable
+        Gradient table.
     sphere : Sphere
         Sphere with which to sample discrete fiber orientations in order to
         construct kernel
@@ -743,13 +774,13 @@ def generate_kernel(gtab, sphere, wm_response, gm_response, csf_response):
             indices = get_bval_indices(bvals, bval)
             with warnings.catch_warnings():  # extract relevant b-value
                 warnings.simplefilter("ignore")
-                gtab_sub = gradient_table(bvals[indices], bvecs[indices])
+                gtab_sub = gradient_table(bvals[indices], bvecs=bvecs[indices])
 
             for i in range(n_wm_comp):
                 # Signal generated by WM-fiber for each gradient direction
-                S = single_tensor(gtab_sub,
-                                  evals=wm_response[n],
-                                  evecs=all_tensor_evecs(sticks[i]))
+                S = single_tensor(
+                    gtab_sub, evals=wm_response[n], evecs=all_tensor_evecs(sticks[i])
+                )
                 kernel[indices, i] = S
 
         # Set b0 components
@@ -760,8 +791,9 @@ def generate_kernel(gtab, sphere, wm_response, gm_response, csf_response):
         # Single-shell response
         for i in range(n_wm_comp):
             # Signal generated by WM-fiber for each gradient direction
-            S = single_tensor(gtab, evals=wm_response,
-                              evecs=all_tensor_evecs(sticks[i]))
+            S = single_tensor(
+                gtab, evals=wm_response, evecs=all_tensor_evecs(sticks[i])
+            )
             kernel[:, i] = S
 
         # Set b0 components
@@ -771,16 +803,16 @@ def generate_kernel(gtab, sphere, wm_response, gm_response, csf_response):
     if gm_response is None:
         S_gm = np.zeros(n_grad)
     else:
-        S_gm = \
-            single_tensor(gtab, evals=np.array(
-                [gm_response, gm_response, gm_response]))
+        S_gm = single_tensor(
+            gtab, evals=np.array([gm_response, gm_response, gm_response])
+        )
 
     if csf_response is None:
         S_csf = np.zeros(n_grad)
     else:
-        S_csf = \
-            single_tensor(gtab, evals=np.array(
-                [csf_response, csf_response, csf_response]))
+        S_csf = single_tensor(
+            gtab, evals=np.array([csf_response, csf_response, csf_response])
+        )
 
     kernel[:, n_comp - 2] = S_gm
     kernel[:, n_comp - 1] = S_csf
@@ -788,18 +820,30 @@ def generate_kernel(gtab, sphere, wm_response, gm_response, csf_response):
     return kernel
 
 
-def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
-                        n_coils=1, R=1, use_tv=True, verbose=False):
+@warning_for_keywords()
+def rumba_deconv_global(
+    data,
+    kernel,
+    mask,
+    *,
+    n_iter=600,
+    recon_type="smf",
+    n_coils=1,
+    R=1,
+    use_tv=True,
+    verbose=False,
+):
     r"""
     Fit fODF for all voxels simultaneously using RUMBA-SD.
 
     Deconvolves the kernel from the diffusion-weighted signal at each voxel by
-    computing a maximum likelihood estimation of the fODF [1]_. Global fitting
-    also permits the use of total variation regularization (RUMBA-SD + TV). The
-    spatial dependence introduced by TV promotes smoother solutions (i.e.
-    prevents oscillations), while still allowing for sharp discontinuities
-    [2]_. This promotes smoothness and continuity along individual tracts while
-    preventing smoothing of adjacent tracts.
+    computing a maximum likelihood estimation of the fODF
+    :footcite:p:`CanalesRodriguez2015`. Global fitting also permits the use of
+    total variation regularization (RUMBA-SD + TV). The spatial dependence
+    introduced by TV promotes smoother solutions (i.e. prevents oscillations),
+    while still allowing for sharp discontinuities :footcite:p:`Rudin1992`. This
+    promotes smoothness and continuity along individual tracts while preventing
+    smoothing of adjacent tracts.
 
     Generally, global_fit will proceed more quickly than the voxelwise fit
     provided that the computer has adequate RAM (>= 16 GB should be more than
@@ -818,20 +862,19 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
         fit at these voxels (0 elsewhere).
     n_iter : int, optional
         Number of iterations for fODF estimation. Must be a positive int.
-        Default: 600
     recon_type : {'smf', 'sos'}, optional
         MRI reconstruction method: spatial matched filter (SMF) or
         sum-of-squares (SoS). SMF reconstruction generates Rician noise while
-        SoS reconstruction generates Noncentral Chi noise. Default: 'smf'
+        SoS reconstruction generates Noncentral Chi noise.
     n_coils : int, optional
         Number of coils in MRI scanner -- only relevant in SoS reconstruction.
-        Must be a positive int. Default: 1
+        Must be a positive int.
     use_tv : bool, optional
         If true, applies total variation regularization. This requires a brain
-        volume with no singleton dimensions. Default: True
+        volume with no singleton dimensions.
     verbose : bool, optional
         If true, logs updates on estimated signal-to-noise ratio after each
-        iteration. Default: False
+        iteration.
 
     Returns
     -------
@@ -843,49 +886,40 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
     -----
     TV modifies our cost function as follows:
 
-    $J(\textbf{f}) = -\log{P(\textbf{S}|\textbf{H}, \textbf{f}, \sigma^2, n)})+
-    \alpha_{TV}TV(\textbf{f})$
+    .. math::
+
+    J(\textbf{f}) = -\log{P(\textbf{S}|\textbf{H}, \textbf{f}, \sigma^2, n)})+
+    \alpha_{TV}TV(\textbf{f})
 
     where the first term is the negative log likelihood described in the notes
     of `rumba_deconv`, and the second term is the TV energy, or the sum of
     gradient absolute values for the fODF across the entire brain. This results
     in a new multiplicative factor in the iterative scheme, now becoming:
 
-    $\textbf{f}^{k+1} = \textbf{f}^k \circ \frac{\textbf{H}^T\left[\textbf{S}
+    .. math::
+
+    \textbf{f}^{k+1} = \textbf{f}^k \circ \frac{\textbf{H}^T\left[\textbf{S}
     \circ\frac{I_n(\textbf{S}\circ\textbf{Hf}^k/\sigma^2)} {I_{n-1}(\textbf{S}
     \circ\textbf{Hf}^k/\sigma^2)} \right ]} {\textbf{H}^T\textbf{Hf}^k}\circ
-    \textbf{R}^k$
+    \textbf{R}^k
 
     where $\textbf{R}^k$ is computed voxelwise by:
 
-    $(\textbf{R}^k)_j = \frac{1}{1 - \alpha_{TV}div\left(\frac{\triangledown[
+    .. math::
+
+    (\textbf{R}^k)_j = \frac{1}{1 - \alpha_{TV}div\left(\frac{\triangledown[
     \textbf{f}^k_{3D}]_j}{\lvert\triangledown[\textbf{f}^k_{3D}]_j \rvert}
-    \right)\biggr\rvert_{x, y, z}}$
+    \right)\biggr\rvert_{x, y, z}}
 
     Here, $\triangledown$ is the symbol for the 3D gradient at any voxel.
 
     The regularization strength, $\alpha_{TV}$ is updated after each iteration
     by the discrepancy principle -- specifically, it is selected to match the
-    estimated variance after each iteration [3]_.
+    estimated variance after each iteration :footcite:p:`Chambolle2004`.
 
     References
     ----------
-    .. [1] Canales-Rodríguez, E. J., Daducci, A., Sotiropoulos, S. N., Caruyer,
-           E., Aja-Fernández, S., Radua, J., Mendizabal, J. M. Y.,
-           Iturria-Medina, Y., Melie-García, L., Alemán-Gómez, Y., Thiran,
-           J.-P., Sarró, S., Pomarol-Clotet, E., & Salvador, R. (2015).
-           Spherical Deconvolution of Multichannel Diffusion MRI Data with
-           Non-Gaussian Noise Models and Spatial Regularization. PLOS ONE,
-           10(10), e0138910. https://doi.org/10.1371/journal.pone.0138910
-
-    .. [2] Rudin, L. I., Osher, S., & Fatemi, E. (1992). Nonlinear total
-           variation based noise removal algorithms. Physica D: Nonlinear
-           Phenomena, 60(1), 259–268.
-           https://doi.org/10.1016/0167-2789(92)90242-F
-
-    .. [3] Chambolle A. An algorithm for total variation minimization and
-           applications. Journal of Mathematical Imaging and Vision. 2004;
-           20:89–97.
+    .. footbibliography::
     """
 
     # Crop data to reduce memory consumption
@@ -895,9 +929,11 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
     mask = crop(mask, ixmin, ixmax)
 
     if np.any(np.array(data.shape[:3]) == 1) and use_tv:
-        raise ValueError("Cannot use TV regularization if any spatial" +
-                         "dimensions are 1; " +
-                         f"provided dimensions were {data.shape[:3]}")
+        raise ValueError(
+            "Cannot use TV regularization if any spatial"
+            + "dimensions are 1; "
+            + f"provided dimensions were {data.shape[:3]}"
+        )
 
     epsilon = 1e-7
 
@@ -915,8 +951,9 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
     elif recon_type == "sos":
         n_order = n_coils  # Noncentral Chi noise (order = # of coils)
     else:
-        raise ValueError("Invalid recon_type. Should be 'smf' or 'sos', " +
-                         f"received f{recon_type}")
+        raise ValueError(
+            f"Invalid recon_type. Should be 'smf' or 'sos', received f{recon_type}"
+        )
 
     mask_vec = np.ravel(mask)
     # Indices of target voxels
@@ -926,7 +963,8 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
     data_2d = np.zeros((n_v_true, n_grad), dtype=np.float32)
     for i in range(n_grad):
         data_2d[:, i] = np.ravel(data[:, :, :, i])[
-            index_mask]  # only keep voxels of interest
+            index_mask
+        ]  # only keep voxels of interest
 
     data_2d = data_2d.T
     fodf = np.tile(fodf0, (1, n_v_true))
@@ -950,8 +988,9 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
     for i in range(n_iter):
         fodf_i = fodf
         ratio = mbessel_ratio(n_order, reblurred_s).astype(np.float32)
-        rl_factor = np.matmul(kernel_t, data_2d * ratio) / \
-            (np.matmul(kernel_t, reblurred) + _EPS)
+        rl_factor = np.matmul(kernel_t, data_2d * ratio) / (
+            np.matmul(kernel_t, reblurred) + _EPS
+        )
 
         if use_tv:  # apply TV regularization
             tv_factor = np.ones(fodf_i.shape, dtype=np.float32)
@@ -959,7 +998,7 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
             # Compute gradient, divergence
             gr = _grad(fodf_4d)
             d_inv = 1 / np.sqrt(epsilon**2 + np.sum(gr**2, axis=3))
-            gr_norm = (gr * d_inv[:, :, :, None, :])
+            gr_norm = gr * d_inv[:, :, :, None, :]
             div_f = _divergence(gr_norm)
             g0 = np.abs(1 - tv_lambda * div_f)
             tv_factor_4d = 1 / (g0 + _EPS)
@@ -979,10 +1018,10 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
         reblurred_s = data_2d * reblurred / sigma2
 
         # Iterate variance
-        sigma2_i = (1 / (n_grad * n_order)) * \
-            np.sum((data_2d**2 + reblurred**2) / 2 - (
-                sigma2 * reblurred_s) * ratio, axis=0)
-        sigma2_i = np.minimum((1 / 8)**2, np.maximum(sigma2_i, (1 / 80)**2))
+        sigma2_i = (1 / (n_grad * n_order)) * np.sum(
+            (data_2d**2 + reblurred**2) / 2 - (sigma2 * reblurred_s) * ratio, axis=0
+        )
+        sigma2_i = np.minimum((1 / 8) ** 2, np.maximum(sigma2_i, (1 / 80) ** 2))
 
         if verbose:
             logger.info("Iteration %d of %d", i + 1, n_iter)
@@ -990,8 +1029,8 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
             snr_mean = np.mean(1 / np.sqrt(sigma2_i))
             snr_std = np.std(1 / np.sqrt(sigma2_i))
             logger.info(
-                "Mean SNR (S0/sigma) estimated to be %.3f +/- %.3f",
-                snr_mean, snr_std)
+                "Mean SNR (S0/sigma) estimated to be %.3f +/- %.3f", snr_mean, snr_std
+            )
         # Expand into matrix
         sigma2 = np.tile(sigma2_i[None, :], (data_2d.shape[0], 1))
 
@@ -1000,8 +1039,8 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
             if R == 1:
                 tv_lambda = np.mean(sigma2_i)
 
-                if tv_lambda < (1 / 30)**2:
-                    tv_lambda = (1 / 30)**2
+                if tv_lambda < (1 / 30) ** 2:
+                    tv_lambda = (1 / 30) ** 2
             else:  # different factor for each voxel
                 tv_lambda_aux[index_mask] = sigma2_i
                 tv_lambda = np.reshape(tv_lambda_aux, (*dim[:3], 1))
@@ -1011,9 +1050,11 @@ def rumba_deconv_global(data, kernel, mask, n_iter=600, recon_type='smf',
 
     # Extract compartments
     fit_array = np.zeros((*dim_orig[:3], n_comp))
-    _reshape_2d_4d(fodf.T, mask, out=fit_array[ixmin[0]:ixmax[0],
-                                               ixmin[1]:ixmax[1],
-                                               ixmin[2]:ixmax[2]])
+    _reshape_2d_4d(
+        fodf.T,
+        mask,
+        out=fit_array[ixmin[0] : ixmax[0], ixmin[1] : ixmax[1], ixmin[2] : ixmax[2]],
+    )
 
     return fit_array
 
@@ -1062,7 +1103,8 @@ def _divergence(F):
     return fx + fy + fz
 
 
-def _reshape_2d_4d(M, mask, out=None):
+@warning_for_keywords()
+def _reshape_2d_4d(M, mask, *, out=None):
     """
     Faster reshape from 2D to 4D.
     """
