@@ -386,6 +386,9 @@ class SparseFascicleModel(ReconstModel, Cache):
             implement other fits to the aspects of the data that depend on
             b-value, but not on direction.
 
+        seed : int, optional
+            Seed for the random number generator.
+
         Notes
         -----
         This is an implementation of the SFM, described in
@@ -556,7 +559,7 @@ class SparseFascicleModel(ReconstModel, Cache):
             ) as parallel:
                 out = parallel(
                     joblib.delayed(self._fit_solver2voxels)(
-                        isopredict, vox_data, vox, True
+                        isopredict, vox_data, vox, parallel=True
                     )
                     for vox, vox_data in enumerate(flat_S)
                 )
