@@ -1,95 +1,78 @@
-from warnings import warn
 from math import factorial
+from warnings import warn
 
 import numpy as np
+from scipy.special import gamma, genlaguerre, hyp2f1
 
-from scipy.special import genlaguerre, gamma, hyp2f1
-
+from dipy.core.geometry import cart2sphere
 from dipy.reconst.cache import Cache
 from dipy.reconst.multi_voxel import multi_voxel_fit
 from dipy.reconst.shm import real_sh_descoteaux_from_index
-from dipy.core.geometry import cart2sphere
-
+from dipy.testing.decorators import warning_for_keywords
 from dipy.utils.optpkg import optional_package
 
 cvxpy, have_cvxpy, _ = optional_package("cvxpy", min_version="1.4.1")
 
 
 class ShoreModel(Cache):
-
     r"""Simple Harmonic Oscillator based Reconstruction and Estimation
-    (SHORE) [1]_ of the diffusion signal.
+    (SHORE) of the diffusion signal.
 
-    The main idea is to model the diffusion signal as a linear combination of
-    continuous functions $\phi_i$,
+    The main idea of SHORE :footcite:p:`Ozarslan2008` is to model the diffusion
+    signal as a linear combination of continuous functions $\phi_i$,
 
-    ..math::
-        :nowrap:
-            \begin{equation}
-                S(\mathbf{q})= \sum_{i=0}^I  c_{i} \phi_{i}(\mathbf{q}).
-            \end{equation}
+    .. math::
+
+       S(\mathbf{q})= \sum_{i=0}^I  c_{i} \phi_{i}(\mathbf{q})
 
     where $\mathbf{q}$ is the wave vector which corresponds to different
     gradient directions. Numerous continuous functions $\phi_i$ can be used to
-    model $S$. Some are presented in [2,3,4]_.
+    model $S$. Some are presented in :footcite:p:`Merlet2013`,
+    :footcite:p:`Rathi2011`, and :footcite:p:`Cheng2011`.
 
     From the $c_i$ coefficients, there exist analytical formulae to estimate
     the ODF, the return to the origin probability (RTOP), the mean square
-    displacement (MSD), amongst others [5]_.
+    displacement (MSD), amongst others :footcite:p:`Ozarslan2013`.
 
     References
     ----------
-    .. [1] Ozarslan E. et al., "Simple harmonic oscillator based reconstruction
-           and estimation for one-dimensional q-space magnetic resonance
-           1D-SHORE)", Proc Intl Soc Mag Reson Med, vol. 16, p. 35., 2008.
-
-    .. [2] Merlet S. et al., "Continuous diffusion signal, EAP and ODF
-           estimation via Compressive Sensing in diffusion MRI", Medical
-           Image Analysis, 2013.
-
-    .. [3] Rathi Y. et al., "Sparse multi-shell diffusion imaging", MICCAI,
-           2011.
-
-    .. [4] Cheng J. et al., "Theoretical Analysis and Practical Insights on
-           EAP Estimation via a Unified HARDI Framework", MICCAI workshop on
-           Computational Diffusion MRI, 2011.
-
-    .. [5] Ozarslan E. et al., "Mean apparent propagator (MAP) MRI: A novel
-           diffusion imaging method for mapping tissue microstructure",
-           NeuroImage, 2013.
+    .. footbibliography::
 
     Notes
     -----
     The implementation of SHORE depends on CVXPY (https://www.cvxpy.org/).
     """
 
-    def __init__(self,
-                 gtab,
-                 radial_order=6,
-                 zeta=700,
-                 lambdaN=1e-8,
-                 lambdaL=1e-8,
-                 tau=1. / (4 * np.pi ** 2),
-                 constrain_e0=False,
-                 positive_constraint=False,
-                 pos_grid=11,
-                 pos_radius=20e-03,
-                 cvxpy_solver=None
-                 ):
-        r""" Analytical and continuous modeling of the diffusion signal with
-        respect to the SHORE basis [1,2]_.
-        This implementation is a modification of SHORE presented in [1]_.
-        The modification was made to obtain the same ordering of the basis
-        presented in [2,3]_.
+    @warning_for_keywords()
+    def __init__(
+        self,
+        gtab,
+        *,
+        radial_order=6,
+        zeta=700,
+        lambdaN=1e-8,
+        lambdaL=1e-8,
+        tau=1.0 / (4 * np.pi**2),
+        constrain_e0=False,
+        positive_constraint=False,
+        pos_grid=11,
+        pos_radius=20e-03,
+        cvxpy_solver=None,
+    ):
+        r"""Analytical and continuous modeling of the diffusion signal with
+        respect to the SHORE basis.
+
+        This implementation is a modification of SHORE presented in
+        :footcite:p:`Merlet2013`. The modification was made to obtain the same
+        ordering of the basis presented in :footcite:p:`Cheng2011`,
+        :footcite:p:`Ozarslan2013`.
 
         The main idea is to model the diffusion signal as a linear
         combination of continuous functions $\phi_i$,
 
-        ..math::
-            :nowrap:
-                \begin{equation}
-                    S(\mathbf{q})= \sum_{i=0}^I  c_{i} \phi_{i}(\mathbf{q}).
-                \end{equation}
+        .. math::
+
+           S(\mathbf{q})= \sum_{i=0}^I  c_{i} \phi_{i}(\mathbf{q})
 
         where $\mathbf{q}$ is the wave vector which corresponds to different
         gradient directions.
@@ -97,32 +80,31 @@ class ShoreModel(Cache):
         From the $c_i$ coefficients, there exists an analytical formula to
         estimate the ODF.
 
-
         Parameters
         ----------
         gtab : GradientTable,
             gradient directions and bvalues container class
-        radial_order : unsigned int,
+        radial_order : unsigned int, optional
             an even integer that represent the order of the basis
-        zeta : unsigned int,
+        zeta : unsigned int, optional
             scale factor
-        lambdaN : float,
+        lambdaN : float, optional
             radial regularisation constant
-        lambdaL : float,
+        lambdaL : float, optional
             angular regularisation constant
-        tau : float,
+        tau : float, optional
             diffusion time. By default the value that makes q equal to the
             square root of the b-value.
-        constrain_e0 : bool,
+        constrain_e0 : bool, optional
             Constrain the optimization such that E(0) = 1.
-        positive_constraint : bool,
+        positive_constraint : bool, optional
             Constrain the propagator to be positive.
-        pos_grid : int,
+        pos_grid : int, optional
             Grid that define the points of the EAP in which we want to enforce
             positivity.
-        pos_radius : float,
+        pos_radius : float, optional
             Radius of the grid of the EAP in which enforce positivity in
-            millimeters. By default 20e-03 mm.
+            millimeters.
         cvxpy_solver : str, optional
             cvxpy solver name. Optionally optimize the positivity constraint
             with a particular cvxpy solver. See https://www.cvxpy.org/ for
@@ -131,17 +113,7 @@ class ShoreModel(Cache):
 
         References
         ----------
-        .. [1] Merlet S. et al., "Continuous diffusion signal, EAP and
-        ODF estimation via Compressive Sensing in diffusion MRI", Medical
-        Image Analysis, 2013.
-
-        .. [2] Cheng J. et al., "Theoretical Analysis and Practical Insights
-        on EAP Estimation via a Unified HARDI Framework", MICCAI workshop on
-        Computational Diffusion MRI, 2011.
-
-        .. [3] Ozarslan E. et al., "Mean apparent propagator (MAP) MRI: A novel
-           diffusion imaging method for mapping tissue microstructure",
-           NeuroImage, 2013.
+        .. footbibliography::
 
         Examples
         --------
@@ -176,7 +148,7 @@ class ShoreModel(Cache):
         self.bvecs = gtab.bvecs
         self.gtab = gtab
         self.constrain_e0 = constrain_e0
-        if radial_order > 0 and not(bool(radial_order % 2)):
+        if radial_order > 0 and not (bool(radial_order % 2)):
             self.radial_order = radial_order
         else:
             msg = "radial_order must be a non-zero even positive number."
@@ -200,8 +172,8 @@ class ShoreModel(Cache):
                 raise ImportError(msg)
             if cvxpy_solver is not None:
                 if cvxpy_solver not in cvxpy.installed_solvers():
-                    msg = "Input `cvxpy_solver` was set to %s." % cvxpy_solver
-                    msg += " One of %s" % ', '.join(cvxpy.installed_solvers())
+                    msg = f"Input `cvxpy_solver` was set to {cvxpy_solver}."
+                    msg += f" One of {', '.join(cvxpy.installed_solvers())}"
                     msg += " was expected."
                     raise ValueError(msg)
 
@@ -211,22 +183,24 @@ class ShoreModel(Cache):
         self.pos_radius = pos_radius
 
     @multi_voxel_fit
-    def fit(self, data):
+    def fit(self, data, **kwargs):
         Lshore = l_shore(self.radial_order)
         Nshore = n_shore(self.radial_order)
         # Generate the SHORE basis
-        M = self.cache_get('shore_matrix', key=self.gtab)
+        M = self.cache_get("shore_matrix", key=self.gtab)
         if M is None:
-            M = shore_matrix(
-                self.radial_order,  self.zeta, self.gtab, self.tau)
-            self.cache_set('shore_matrix', self.gtab, M)
+            M = shore_matrix(self.radial_order, self.zeta, self.gtab, tau=self.tau)
+            self.cache_set("shore_matrix", self.gtab, M)
 
-        MpseudoInv = self.cache_get('shore_matrix_reg_pinv', key=self.gtab)
+        MpseudoInv = self.cache_get("shore_matrix_reg_pinv", key=self.gtab)
         if MpseudoInv is None:
             MpseudoInv = np.dot(
-                np.linalg.inv(np.dot(M.T, M) + self.lambdaN * Nshore +
-                              self.lambdaL * Lshore), M.T)
-            self.cache_set('shore_matrix_reg_pinv', self.gtab, MpseudoInv)
+                np.linalg.inv(
+                    np.dot(M.T, M) + self.lambdaN * Nshore + self.lambdaL * Lshore
+                ),
+                M.T,
+            )
+            self.cache_set("shore_matrix_reg_pinv", self.gtab, MpseudoInv)
 
         # Compute the signal coefficients in SHORE basis
         if not self.constrain_e0:
@@ -235,11 +209,10 @@ class ShoreModel(Cache):
             signal_0 = 0
 
             for n in range(int(self.radial_order / 2) + 1):
-                signal_0 += (
-                    coef[n] * (genlaguerre(n, 0.5)(0) * (
-                        (factorial(n)) /
-                        (2 * np.pi * (self.zeta ** 1.5) * gamma(n + 1.5))
-                    ) ** 0.5)
+                signal_0 += coef[n] * (
+                    genlaguerre(n, 0.5)(0)
+                    * ((factorial(n)) / (2 * np.pi * (self.zeta**1.5) * gamma(n + 1.5)))
+                    ** 0.5
                 )
 
             coef = coef / signal_0
@@ -250,39 +223,41 @@ class ShoreModel(Cache):
             c = cvxpy.Variable(M.shape[1])
             design_matrix = cvxpy.Constant(M) @ c
             objective = cvxpy.Minimize(
-                cvxpy.sum_squares(design_matrix - data_norm) +
-                self.lambdaN * cvxpy.quad_form(c, Nshore) +
-                self.lambdaL * cvxpy.quad_form(c, Lshore)
+                cvxpy.sum_squares(design_matrix - data_norm)
+                + self.lambdaN * cvxpy.quad_form(c, Nshore)
+                + self.lambdaL * cvxpy.quad_form(c, Lshore)
             )
 
             if not self.positive_constraint:
                 constraints = [M0[0] @ c == 1]
             else:
-                lg = int(np.floor(self.pos_grid ** 3 / 2))
+                lg = int(np.floor(self.pos_grid**3 / 2))
                 v, t = create_rspace(self.pos_grid, self.pos_radius)
-                psi = self.cache_get('shore_matrix_positive_constraint',
-                                     key=(self.pos_grid, self.pos_radius))
+                psi = self.cache_get(
+                    "shore_matrix_positive_constraint",
+                    key=(self.pos_grid, self.pos_radius),
+                )
                 if psi is None:
-                    psi = shore_matrix_pdf(
-                        self.radial_order, self.zeta, t[:lg])
+                    psi = shore_matrix_pdf(self.radial_order, self.zeta, t[:lg])
                     self.cache_set(
-                        'shore_matrix_positive_constraint',
-                        (self.pos_grid, self.pos_radius), psi)
-                constraints = [(M0[0] @ c) == 1., (psi @ c) >= 1e-3]
+                        "shore_matrix_positive_constraint",
+                        (self.pos_grid, self.pos_radius),
+                        psi,
+                    )
+                constraints = [(M0[0] @ c) == 1.0, (psi @ c) >= 1e-3]
             prob = cvxpy.Problem(objective, constraints)
             try:
                 prob.solve(solver=self.cvxpy_solver)
                 coef = np.asarray(c.value).squeeze()
             except Exception:
-                warn('Optimization did not find a solution')
+                warn("Optimization did not find a solution", stacklevel=2)
                 coef = np.zeros(M.shape[1])
         return ShoreFit(self, coef)
 
 
 class ShoreFit:
-
     def __init__(self, model, shore_coef):
-        """ Calculates diffusion properties for a single voxel
+        """Calculates diffusion properties for a single voxel
 
         Parameters
         ----------
@@ -299,7 +274,7 @@ class ShoreFit:
         self.zeta = model.zeta
 
     def pdf_grid(self, gridsize, radius_max):
-        r""" Applies the analytical FFT on $S$ to generate the diffusion
+        r"""Applies the analytical FFT on $S$ to generate the diffusion
         propagator. This is calculated on a discrete 3D grid in order to
         obtain an EAP similar to that which is obtained with DSI.
 
@@ -317,20 +292,16 @@ class ShoreFit:
 
         """
         # Create the grid in which to compute the pdf
-        rgrid_rtab = self.model.cache_get(
-            'pdf_grid', key=(gridsize, radius_max))
+        rgrid_rtab = self.model.cache_get("pdf_grid", key=(gridsize, radius_max))
         if rgrid_rtab is None:
             rgrid_rtab = create_rspace(gridsize, radius_max)
-            self.model.cache_set(
-                'pdf_grid', (gridsize, radius_max), rgrid_rtab)
+            self.model.cache_set("pdf_grid", (gridsize, radius_max), rgrid_rtab)
         rgrid, rtab = rgrid_rtab
 
-        psi = self.model.cache_get(
-            'shore_matrix_pdf', key=(gridsize, radius_max))
+        psi = self.model.cache_get("shore_matrix_pdf", key=(gridsize, radius_max))
         if psi is None:
-            psi = shore_matrix_pdf(self.radial_order,  self.zeta, rtab)
-            self.model.cache_set(
-                'shore_matrix_pdf', (gridsize, radius_max), psi)
+            psi = shore_matrix_pdf(self.radial_order, self.zeta, rtab)
+            self.model.cache_set("shore_matrix_pdf", (gridsize, radius_max), psi)
 
         propagator = np.dot(psi, self._shore_coef)
         eap = np.empty((gridsize, gridsize, gridsize), dtype=float)
@@ -340,27 +311,25 @@ class ShoreFit:
         return eap
 
     def pdf(self, r_points):
-        """ Diffusion propagator on a given set of real points.
-            if the array r_points is non writeable, then intermediate
-            results are cached for faster recalculation
+        """Diffusion propagator on a given set of real points.
+        if the array r_points is non writeable, then intermediate
+        results are cached for faster recalculation
         """
         if not r_points.flags.writeable:
-            psi = self.model.cache_get(
-                'shore_matrix_pdf', key=hash(r_points.data))
+            psi = self.model.cache_get("shore_matrix_pdf", key=hash(r_points.data))
         else:
             psi = None
         if psi is None:
-            psi = shore_matrix_pdf(self.radial_order,  self.zeta, r_points)
+            psi = shore_matrix_pdf(self.radial_order, self.zeta, r_points)
             if not r_points.flags.writeable:
-                self.model.cache_set(
-                    'shore_matrix_pdf', hash(r_points.data), psi)
+                self.model.cache_set("shore_matrix_pdf", hash(r_points.data), psi)
 
         eap = np.dot(psi, self._shore_coef)
 
         return np.clip(eap, 0, eap.max())
 
     def odf_sh(self):
-        r""" Calculates the real analytical ODF in terms of Spherical
+        r"""Calculates the real analytical ODF in terms of Spherical
         Harmonics.
         """
         # Number of Spherical Harmonics involved in the estimation
@@ -370,23 +339,30 @@ class ShoreFit:
         c_sh = np.zeros(J)
         counter = 0
 
-        for l in range(0, self.radial_order + 1, 2):
-            for n in range(l, int((self.radial_order + l) / 2) + 1):
-                for m in range(-l, l + 1):
-
-                    j = int(l + m + (2 * np.array(range(0, l, 2)) + 1).sum())
+        for ell in range(0, self.radial_order + 1, 2):
+            for n in range(ell, int((self.radial_order + ell) / 2) + 1):
+                for m in range(-ell, ell + 1):
+                    j = int(ell + m + (2 * np.array(range(0, ell, 2)) + 1).sum())
 
                     Cnl = (
-                        ((-1) ** (n - l / 2)) /
-                        (2.0 * (4.0 * np.pi ** 2 * self.zeta) ** (3.0 / 2.0)) *
-                        ((2.0 * (4.0 * np.pi ** 2 * self.zeta) ** (3.0 / 2.0) *
-                          factorial(n - l)) /
-                         (gamma(n + 3.0 / 2.0))) ** (1.0 / 2.0)
+                        ((-1) ** (n - ell / 2))
+                        / (2.0 * (4.0 * np.pi**2 * self.zeta) ** (3.0 / 2.0))
+                        * (
+                            (
+                                2.0
+                                * (4.0 * np.pi**2 * self.zeta) ** (3.0 / 2.0)
+                                * factorial(n - ell)
+                            )
+                            / (gamma(n + 3.0 / 2.0))
+                        )
+                        ** (1.0 / 2.0)
                     )
-                    Gnl = (gamma(l / 2 + 3.0 / 2.0) * gamma(3.0 / 2.0 + n)) / \
-                        (gamma(l + 3.0 / 2.0) * factorial(n - l)) * \
-                        (1.0 / 2.0) ** (-l / 2 - 3.0 / 2.0)
-                    Fnl = hyp2f1(-n + l, l / 2 + 3.0 / 2.0, l + 3.0 / 2.0, 2.0)
+                    Gnl = (
+                        (gamma(ell / 2 + 3.0 / 2.0) * gamma(3.0 / 2.0 + n))
+                        / (gamma(ell + 3.0 / 2.0) * factorial(n - ell))
+                        * (1.0 / 2.0) ** (-ell / 2 - 3.0 / 2.0)
+                    )
+                    Fnl = hyp2f1(-n + ell, ell / 2 + 3.0 / 2.0, ell + 3.0 / 2.0, 2.0)
 
                     c_sh[j] += self._shore_coef[counter] * Cnl * Gnl * Fnl
                     counter += 1
@@ -394,123 +370,134 @@ class ShoreFit:
         return c_sh
 
     def odf(self, sphere):
-        r""" Calculates the ODF for a given discrete sphere.
-        """
-        upsilon = self.model.cache_get('shore_matrix_odf', key=sphere)
+        r"""Calculates the ODF for a given discrete sphere."""
+        upsilon = self.model.cache_get("shore_matrix_odf", key=sphere)
         if upsilon is None:
-            upsilon = shore_matrix_odf(
-                self.radial_order,  self.zeta, sphere.vertices)
-            self.model.cache_set('shore_matrix_odf', sphere, upsilon)
+            upsilon = shore_matrix_odf(self.radial_order, self.zeta, sphere.vertices)
+            self.model.cache_set("shore_matrix_odf", sphere, upsilon)
 
         odf = np.dot(upsilon, self._shore_coef)
         return odf
 
     def rtop_signal(self):
-        r""" Calculates the analytical return to origin probability (RTOP)
-        from the signal [1]_.
+        r"""Calculates the analytical return to origin probability (RTOP)
+        from the signal.
+
+        See :footcite:p:`Ozarslan2013` for further details about the method.
 
         References
         ----------
-        .. [1] Ozarslan E. et al., "Mean apparent propagator (MAP) MRI: A novel
-        diffusion imaging method for mapping tissue microstructure",
-        NeuroImage, 2013.
+        .. footbibliography::
         """
         rtop = 0
         c = self._shore_coef
 
         for n in range(int(self.radial_order / 2) + 1):
-            rtop += c[n] * (-1) ** n * \
-                ((16 * np.pi * self.zeta ** 1.5 * gamma(n + 1.5)) / (
-                 factorial(n))) ** 0.5
+            rtop += (
+                c[n]
+                * (-1) ** n
+                * ((16 * np.pi * self.zeta**1.5 * gamma(n + 1.5)) / (factorial(n)))
+                ** 0.5
+            )
 
         return np.clip(rtop, 0, rtop.max())
 
     def rtop_pdf(self):
-        r""" Calculates the analytical return to origin probability (RTOP)
-        from the pdf [1]_.
+        r"""Calculates the analytical return to origin probability (RTOP)
+        from the pdf.
+
+        See :footcite:p:`Ozarslan2013` for further details about the method.
 
         References
         ----------
-        .. [1] Ozarslan E. et al., "Mean apparent propagator (MAP) MRI: A novel
-        diffusion imaging method for mapping tissue microstructure",
-        NeuroImage, 2013.
+        .. footbibliography::
         """
         rtop = 0
         c = self._shore_coef
         for n in range(int(self.radial_order / 2) + 1):
-            rtop += c[n] * (-1) ** n * \
-                ((4 * np.pi ** 2 * self.zeta ** 1.5 * factorial(n)) /
-                 (gamma(n + 1.5))) ** 0.5 * \
-                genlaguerre(n, 0.5)(0)
+            rtop += (
+                c[n]
+                * (-1) ** n
+                * ((4 * np.pi**2 * self.zeta**1.5 * factorial(n)) / (gamma(n + 1.5)))
+                ** 0.5
+                * genlaguerre(n, 0.5)(0)
+            )
 
         return np.clip(rtop, 0, rtop.max())
 
     def msd(self):
-        r""" Calculates the analytical mean squared displacement (MSD) [1]_
+        r"""Calculates the analytical mean squared displacement (MSD).
 
-        ..math::
-            :nowrap:
-                \begin{equation}
-                    MSD:{DSI}=\int_{-\infty}^{\infty}\int_{-\infty}^{\infty}
-                    \int_{-\infty}^{\infty} P(\hat{\mathbf{r}}) \cdot
-                    \hat{\mathbf{r}}^{2} \ dr_x \ dr_y \ dr_z
-                \end{equation}
+        See :footcite:p:`Wu2007` for a definition of the method.
 
-        where $\hat{\mathbf{r}}$ is a point in the 3D propagator space (see Wu
-        et al. [1]_).
+        .. math::
+           :nowrap:
+
+            MSD:{DSI}=\int_{-\infty}^{\infty}\int_{-\infty}^{\infty}
+            \int_{-\infty}^{\infty} P(\hat{\mathbf{r}}) \cdot
+            \hat{\mathbf{r}}^{2} \ dr_x \ dr_y \ dr_z
+
+        where $\hat{\mathbf{r}}$ is a point in the 3D propagator space (see
+        :footcite:t:`Wu2007`).
 
         References
         ----------
-        .. [1] Wu Y. et al., "Hybrid diffusion imaging", NeuroImage, vol 36,
-        p. 617-629, 2007.
+        .. footbibliography::
         """
         msd = 0
         c = self._shore_coef
 
         for n in range(int(self.radial_order / 2) + 1):
-            msd += c[n] * (-1) ** n *\
-                (9 * (gamma(n + 1.5)) / (8 * np.pi ** 6 * self.zeta ** 3.5 *
-                                         factorial(n))) ** 0.5 *\
-                hyp2f1(-n, 2.5, 1.5, 2)
+            msd += (
+                c[n]
+                * (-1) ** n
+                * (
+                    9
+                    * (gamma(n + 1.5))
+                    / (8 * np.pi**6 * self.zeta**3.5 * factorial(n))
+                )
+                ** 0.5
+                * hyp2f1(-n, 2.5, 1.5, 2)
+            )
 
         return np.clip(msd, 0, msd.max())
 
     def fitted_signal(self):
-        """ The fitted signal.
-        """
-        phi = self.model.cache_get('shore_matrix', key=self.model.gtab)
+        """The fitted signal."""
+        phi = self.model.cache_get("shore_matrix", key=self.model.gtab)
         return np.dot(phi, self._shore_coef)
 
     @property
     def shore_coeff(self):
-        """The SHORE coefficients
-        """
+        """The SHORE coefficients"""
         return self._shore_coef
 
 
-def shore_matrix(radial_order, zeta, gtab, tau=1 / (4 * np.pi ** 2)):
-    r"""Compute the SHORE matrix for modified Merlet's 3D-SHORE [1]_
+@warning_for_keywords()
+def shore_matrix(radial_order, zeta, gtab, *, tau=1 / (4 * np.pi**2)):
+    r"""Compute the SHORE matrix for modified Merlet's 3D-SHORE.
 
-    ..math::
-            :nowrap:
-                \begin{equation}
-                    \textbf{E}(q\textbf{u})=\sum_{l=0, even}^{N_{max}}
-                                            \sum_{n=l}^{(N_{max}+l)/2}
-                                            \sum_{m=-l}^l c_{nlm}
-                                            \phi_{nlm}(q\textbf{u})
-                \end{equation}
+    See :footcite:p:`Merlet2013` for the definition.
+
+    .. math::
+        :nowrap:
+
+        \textbf{E}(q\textbf{u})=\sum_{l=0, even}^{N_{max}}
+                               \sum_{n=l}^{(N_{max}+l)/2}
+                               \sum_{m=-l}^l c_{nlm}
+                               \phi_{nlm}(q\textbf{u})
 
     where $\phi_{nlm}$ is
-    ..math::
-            :nowrap:
-                \begin{equation}
-                    \phi_{nlm}^{SHORE}(q\textbf{u})=\Biggl[\dfrac{2(n-l)!}
-                        {\zeta^{3/2} \Gamma(n+3/2)} \Biggr]^{1/2}
-                        \Biggl(\dfrac{q^2}{\zeta}\Biggr)^{l/2}
-                        exp\Biggl(\dfrac{-q^2}{2\zeta}\Biggr)
-                        L^{l+1/2}_{n-l} \Biggl(\dfrac{q^2}{\zeta}\Biggr)
-                        Y_l^m(\textbf{u}).
-                \end{equation}
+
+    .. math::
+        :nowrap:
+
+        \phi_{nlm}^{SHORE}(q\textbf{u})=\Biggl[\dfrac{2(n-l)!}
+            {\zeta^{3/2} \Gamma(n+3/2)} \Biggr]^{1/2}
+            \Biggl(\dfrac{q^2}{\zeta}\Biggr)^{l/2}
+            exp\Biggl(\dfrac{-q^2}{2\zeta}\Biggr)
+            L^{l+1/2}_{n-l} \Biggl(\dfrac{q^2}{\zeta}\Biggr)
+            Y_l^m(\textbf{u})
 
     Parameters
     ----------
@@ -520,50 +507,50 @@ def shore_matrix(radial_order, zeta, gtab, tau=1 / (4 * np.pi ** 2)):
         scale factor
     gtab : GradientTable,
         gradient directions and bvalues container class
-    tau : float,
+    tau : float, optional
         diffusion time. By default the value that makes q=sqrt(b).
 
     References
     ----------
-    .. [1] Merlet S. et al., "Continuous diffusion signal, EAP and
-    ODF estimation via Compressive Sensing in diffusion MRI", Medical
-    Image Analysis, 2013.
+    .. footbibliography::
 
     """
 
-    qvals = np.sqrt(gtab.bvals / (4 * np.pi ** 2 * tau))
+    qvals = np.sqrt(gtab.bvals / (4 * np.pi**2 * tau))
     qvals[gtab.b0s_mask] = 0
     bvecs = gtab.bvecs
 
     qgradients = qvals[:, None] * bvecs
 
-    r, theta, phi = cart2sphere(qgradients[:, 0], qgradients[:, 1],
-                                qgradients[:, 2])
+    r, theta, phi = cart2sphere(qgradients[:, 0], qgradients[:, 1], qgradients[:, 2])
     theta[np.isnan(theta)] = 0
     F = radial_order / 2
     n_c = int(np.round(1 / 6.0 * (F + 1) * (F + 2) * (4 * F + 3)))
     M = np.zeros((r.shape[0], n_c))
 
     counter = 0
-    for l in range(0, radial_order + 1, 2):
-        for n in range(l, int((radial_order + l) / 2) + 1):
-            for m in range(-l, l + 1):
-                M[:, counter] = real_sh_descoteaux_from_index(
-                    m, l, theta, phi) * \
-                    genlaguerre(n - l, l + 0.5)(r ** 2 / zeta) * \
-                    np.exp(- r ** 2 / (2.0 * zeta)) * \
-                    _kappa(zeta, n, l) * \
-                    (r ** 2 / zeta) ** (l / 2)
+    for ell in range(0, radial_order + 1, 2):
+        for n in range(ell, int((radial_order + ell) / 2) + 1):
+            for m in range(-ell, ell + 1):
+                M[:, counter] = (
+                    real_sh_descoteaux_from_index(m, ell, theta, phi)
+                    * genlaguerre(n - ell, ell + 0.5)(r**2 / zeta)
+                    * np.exp(-(r**2) / (2.0 * zeta))
+                    * _kappa(zeta, n, ell)
+                    * (r**2 / zeta) ** (ell / 2)
+                )
                 counter += 1
     return M
 
 
-def _kappa(zeta, n, l):
-    return np.sqrt((2 * factorial(n - l)) / (zeta ** 1.5 * gamma(n + 1.5)))
+def _kappa(zeta, n, ell):
+    return np.sqrt((2 * factorial(n - ell)) / (zeta**1.5 * gamma(n + 1.5)))
 
 
 def shore_matrix_pdf(radial_order, zeta, rtab):
-    r"""Compute the SHORE propagator matrix [1]_"
+    r"""Compute the SHORE propagator matrix.
+
+    See :footcite:p:`Merlet2013` for the definition.
 
     Parameters
     ----------
@@ -576,9 +563,7 @@ def shore_matrix_pdf(radial_order, zeta, rtab):
 
     References
     ----------
-    .. [1] Merlet S. et al., "Continuous diffusion signal, EAP and
-    ODF estimation via Compressive Sensing in diffusion MRI", Medical
-    Image Analysis, 2013.
+    .. footbibliography::
     """
 
     r, theta, phi = cart2sphere(rtab[:, 0], rtab[:, 1], rtab[:, 2])
@@ -587,28 +572,29 @@ def shore_matrix_pdf(radial_order, zeta, rtab):
     n_c = int(np.round(1 / 6.0 * (F + 1) * (F + 2) * (4 * F + 3)))
     psi = np.zeros((r.shape[0], n_c))
     counter = 0
-    for l in range(0, radial_order + 1, 2):
-        for n in range(l, int((radial_order + l) / 2) + 1):
-            for m in range(-l, l + 1):
-                psi[:, counter] = real_sh_descoteaux_from_index(
-                    m, l, theta, phi) * \
-                    genlaguerre(n - l, l + 0.5)(4 * np.pi ** 2 *
-                                                zeta * r ** 2) *\
-                    np.exp(-2 * np.pi ** 2 * zeta * r ** 2) *\
-                    _kappa_pdf(zeta, n, l) *\
-                    (4 * np.pi ** 2 * zeta * r ** 2) ** (l / 2) * \
-                    (-1) ** (n - l / 2)
+    for ell in range(0, radial_order + 1, 2):
+        for n in range(ell, int((radial_order + ell) / 2) + 1):
+            for m in range(-ell, ell + 1):
+                psi[:, counter] = (
+                    real_sh_descoteaux_from_index(m, ell, theta, phi)
+                    * genlaguerre(n - ell, ell + 0.5)(4 * np.pi**2 * zeta * r**2)
+                    * np.exp(-2 * np.pi**2 * zeta * r**2)
+                    * _kappa_pdf(zeta, n, ell)
+                    * (4 * np.pi**2 * zeta * r**2) ** (ell / 2)
+                    * (-1) ** (n - ell / 2)
+                )
                 counter += 1
     return psi
 
 
-def _kappa_pdf(zeta, n, l):
-    return np.sqrt((16 * np.pi ** 3 * zeta ** 1.5 * factorial(n - l)) /
-                   gamma(n + 1.5))
+def _kappa_pdf(zeta, n, ell):
+    return np.sqrt((16 * np.pi**3 * zeta**1.5 * factorial(n - ell)) / gamma(n + 1.5))
 
 
 def shore_matrix_odf(radial_order, zeta, sphere_vertices):
-    r"""Compute the SHORE ODF matrix [1]_"
+    r"""Compute the SHORE ODF matrix.
+
+    See :footcite:p:`Merlet2013` for the definition.
 
     Parameters
     ----------
@@ -621,35 +607,36 @@ def shore_matrix_odf(radial_order, zeta, sphere_vertices):
 
     References
     ----------
-    .. [1] Merlet S. et al., "Continuous diffusion signal, EAP and
-    ODF estimation via Compressive Sensing in diffusion MRI", Medical
-    Image Analysis, 2013.
+    .. footbibliography::
     """
 
-    r, theta, phi = cart2sphere(sphere_vertices[:, 0], sphere_vertices[:, 1],
-                                sphere_vertices[:, 2])
+    r, theta, phi = cart2sphere(
+        sphere_vertices[:, 0], sphere_vertices[:, 1], sphere_vertices[:, 2]
+    )
     theta[np.isnan(theta)] = 0
     F = radial_order / 2
     n_c = int(np.round(1 / 6.0 * (F + 1) * (F + 2) * (4 * F + 3)))
     upsilon = np.zeros((len(sphere_vertices), n_c))
     counter = 0
-    for l in range(0, radial_order + 1, 2):
-        for n in range(l, int((radial_order + l) / 2) + 1):
-            for m in range(-l, l + 1):
-                upsilon[:, counter] = (-1) ** (n - l / 2.0) * \
-                    _kappa_odf(zeta, n, l) * \
-                    hyp2f1(l - n, l / 2.0 + 1.5, l + 1.5, 2.0) * \
-                    real_sh_descoteaux_from_index(m, l, theta, phi)
+    for ell in range(0, radial_order + 1, 2):
+        for n in range(ell, int((radial_order + ell) / 2) + 1):
+            for m in range(-ell, ell + 1):
+                upsilon[:, counter] = (
+                    (-1) ** (n - ell / 2.0)
+                    * _kappa_odf(zeta, n, ell)
+                    * hyp2f1(ell - n, ell / 2.0 + 1.5, ell + 1.5, 2.0)
+                    * real_sh_descoteaux_from_index(m, ell, theta, phi)
+                )
                 counter += 1
 
     return upsilon
 
 
-def _kappa_odf(zeta, n, l):
-    return np.sqrt((gamma(l / 2.0 + 1.5) ** 2 *
-                    gamma(n + 1.5) * 2 ** (l + 3)) /
-                   (16 * np.pi ** 3 * zeta ** 1.5 * factorial(n - l) *
-                    gamma(l + 1.5) ** 2))
+def _kappa_odf(zeta, n, ell):
+    return np.sqrt(
+        (gamma(ell / 2.0 + 1.5) ** 2 * gamma(n + 1.5) * 2 ** (ell + 3))
+        / (16 * np.pi**3 * zeta**1.5 * factorial(n - ell) * gamma(ell + 1.5) ** 2)
+    )
 
 
 def l_shore(radial_order):
@@ -658,10 +645,10 @@ def l_shore(radial_order):
     n_c = int(np.round(1 / 6.0 * (F + 1) * (F + 2) * (4 * F + 3)))
     diagL = np.zeros(n_c)
     counter = 0
-    for l in range(0, radial_order + 1, 2):
-        for n in range(l, int((radial_order + l) / 2) + 1):
-            for m in range(-l, l + 1):
-                diagL[counter] = (l * (l + 1)) ** 2
+    for ell in range(0, radial_order + 1, 2):
+        for _ in range(ell, int((radial_order + ell) / 2) + 1):
+            for _ in range(-ell, ell + 1):
+                diagL[counter] = (ell * (ell + 1)) ** 2
                 counter += 1
 
     return np.diag(diagL)
@@ -673,9 +660,9 @@ def n_shore(radial_order):
     n_c = int(np.round(1 / 6.0 * (F + 1) * (F + 2) * (4 * F + 3)))
     diagN = np.zeros(n_c)
     counter = 0
-    for l in range(0, radial_order + 1, 2):
-        for n in range(l, int((radial_order + l) / 2) + 1):
-            for m in range(-l, l + 1):
+    for ell in range(0, radial_order + 1, 2):
+        for n in range(ell, int((radial_order + ell) / 2) + 1):
+            for _ in range(-ell, ell + 1):
                 diagN[counter] = (n * (n + 1)) ** 2
                 counter += 1
 
@@ -683,7 +670,7 @@ def n_shore(radial_order):
 
 
 def create_rspace(gridsize, radius_max):
-    """ Create the real space table, that contains the points in which
+    """Create the real space table, that contains the points in which
         to compute the pdf.
 
     Parameters
@@ -720,26 +707,30 @@ def create_rspace(gridsize, radius_max):
 def shore_indices(radial_order, index):
     r"""Given the basis order and the index, return the shore indices n, l, m
     for modified Merlet's 3D-SHORE
-    ..math::
-            :nowrap:
-                \begin{equation}
-                    \textbf{E}(q\textbf{u})=\sum_{l=0, even}^{N_{max}}
-                                            \sum_{n=l}^{(N_{max}+l)/2}
-                                            \sum_{m=-l}^l c_{nlm}
-                                            \phi_{nlm}(q\textbf{u})
-                \end{equation}
+
+    .. math::
+        :nowrap:
+
+        \begin{equation}
+            \textbf{E}(q\textbf{u})=\sum_{l=0, even}^{N_{max}}
+                                    \sum_{n=l}^{(N_{max}+l)/2}
+                                    \sum_{m=-l}^l c_{nlm}
+                                    \phi_{nlm}(q\textbf{u})
+        \end{equation}
 
     where $\phi_{nlm}$ is
-    ..math::
-            :nowrap:
-                \begin{equation}
-                    \phi_{nlm}^{SHORE}(q\textbf{u})=\Biggl[\dfrac{2(n-l)!}
-                        {\zeta^{3/2} \Gamma(n+3/2)} \Biggr]^{1/2}
-                        \Biggl(\dfrac{q^2}{\zeta}\Biggr)^{l/2}
-                        exp\Biggl(\dfrac{-q^2}{2\zeta}\Biggr)
-                        L^{l+1/2}_{n-l} \Biggl(\dfrac{q^2}{\zeta}\Biggr)
-                        Y_l^m(\textbf{u}).
-                \end{equation}
+
+    .. math::
+        :nowrap:
+
+        \begin{equation}
+            \phi_{nlm}^{SHORE}(q\textbf{u})=\Biggl[\dfrac{2(n-l)!}
+                {\zeta^{3/2} \Gamma(n+3/2)} \Biggr]^{1/2}
+                \Biggl(\dfrac{q^2}{\zeta}\Biggr)^{l/2}
+                exp\Biggl(\dfrac{-q^2}{2\zeta}\Biggr)
+                L^{l+1/2}_{n-l} \Biggl(\dfrac{q^2}{\zeta}\Biggr)
+                Y_l^m(\textbf{u}).
+        \end{equation}
 
     Parameters
     ----------
@@ -765,25 +756,25 @@ def shore_indices(radial_order, index):
     m_i = 0
 
     if n_c < (index + 1):
-        msg = "The index %s is higher than the number of" % index
+        msg = f"The index {index} is higher than the number of"
         msg += " coefficients of the truncated basis,"
-        msg += " which is %s starting from 0." % int(n_c - 1)
+        msg += f" which is {int(n_c - 1)} starting from 0."
         msg += " Select a lower index."
         raise ValueError(msg)
     else:
         counter = 0
-        for l in range(0, radial_order + 1, 2):
-            for n in range(l, int((radial_order + l) / 2) + 1):
-                for m in range(-l, l + 1):
+        for ell in range(0, radial_order + 1, 2):
+            for n in range(ell, int((radial_order + ell) / 2) + 1):
+                for m in range(-ell, ell + 1):
                     if counter == index:
                         n_i = n
-                        l_i = l
+                        l_i = ell
                         m_i = m
                     counter += 1
     return n_i, l_i, m_i
 
 
-def shore_order(n, l, m):
+def shore_order(n, ell, m):
     r"""Given the indices (n,l,m) of the basis, return the minimum order
     for those indices and their index for modified Merlet's 3D-SHORE.
 
@@ -791,7 +782,7 @@ def shore_order(n, l, m):
     ----------
     n :  unsigned int
         the index n of the modified shore basis
-    l :  unsigned int
+    ell :  unsigned int
         the index l of the modified shore basis
     m :  unsigned int
         the index m of the modified shore basis
@@ -804,10 +795,10 @@ def shore_order(n, l, m):
         index of the coefficient corresponding to (n,l,m), start from 0
 
     """
-    if l % 2 == 1 or l > n or l < 0 or n < 0 or np.abs(m) > l:
+    if ell % 2 == 1 or ell > n or ell < 0 or n < 0 or np.abs(m) > ell:
         msg = "The index l must be even and 0 <= l <= n, the index m must be "
-        msg += "-l <= m <= l. Given values were"
-        msg += " [n,l,m]=[%s]." % ','.join([str(n), str(l), str(m)])
+        msg += "-l <= m <= ell. Given values were"
+        msg += f" [n,l,m]=[{','.join([str(n), str(ell), str(m)])}]."
         raise ValueError(msg)
     else:
         if n % 2 == 1:
@@ -821,7 +812,7 @@ def shore_order(n, l, m):
         for l_i in range(0, radial_order + 1, 2):
             for n_i in range(l_i, int((radial_order + l_i) / 2) + 1):
                 for m_i in range(-l_i, l_i + 1):
-                    if n == n_i and l == l_i and m == m_i:
+                    if n == n_i and ell == l_i and m == m_i:
                         counter_i = counter
                     counter += 1
 
