@@ -4,20 +4,20 @@ import warnings
 
 import numpy as np
 import numpy.testing as npt
-import dipy.reconst.cross_validation as xval
-import dipy.data as dpd
-import dipy.reconst.dti as dti
+
 import dipy.core.gradients as gt
-import dipy.sims.voxel as sims
-import dipy.reconst.csdeconv as csd
-import dipy.reconst.base as base
+import dipy.data as dpd
 from dipy.io.image import load_nifti_data
+import dipy.reconst.base as base
+import dipy.reconst.cross_validation as xval
+import dipy.reconst.csdeconv as csd
+import dipy.reconst.dti as dti
 from dipy.reconst.shm import descoteaux07_legacy_msg
+import dipy.sims.voxel as sims
 from dipy.testing.decorators import set_random_number_generator
 
-
 # We'll set these globally:
-fdata, fbval, fbvec = dpd.get_fnames('small_64D')
+fdata, fbval, fbvec = dpd.get_fnames(name="small_64D")
 
 
 @set_random_number_generator()
@@ -31,23 +31,25 @@ def test_coeff_of_determination(rng):
 
 def test_dti_xval():
     data = load_nifti_data(fdata)
-    gtab = gt.gradient_table(fbval, fbvec)
-    dm = dti.TensorModel(gtab, 'LS')
+    gtab = gt.gradient_table(fbval, bvecs=fbvec)
+    dm = dti.TensorModel(gtab, fit_method="LS")
     # The data has 102 directions, so will not divide neatly into 10 bits
     npt.assert_raises(ValueError, xval.kfold_xval, dm, data, 10)
 
     # In simulation with no noise, COD should be perfect:
-    psphere = dpd.get_sphere('symmetric362')
+    psphere = dpd.get_sphere(name="symmetric362")
     bvecs = np.concatenate(([[0, 0, 0]], psphere.vertices))
     bvals = np.zeros(len(bvecs)) + 1000
     bvals[0] = 0
-    gtab = gt.gradient_table(bvals, bvecs)
+    gtab = gt.gradient_table(bvals, bvecs=bvecs)
     mevals = np.array(([0.0015, 0.0003, 0.0001], [0.0015, 0.0003, 0.0003]))
-    mevecs = [np.array([[1, 0, 0], [0, 1, 0], [0, 0, 1]]),
-              np.array([[0, 0, 1], [0, 1, 0], [1, 0, 0]])]
-    S = sims.single_tensor(gtab, 100, mevals[0], mevecs[0], snr=None)
+    mevecs = [
+        np.array([[1, 0, 0], [0, 1, 0], [0, 0, 1]]),
+        np.array([[0, 0, 1], [0, 1, 0], [1, 0, 0]]),
+    ]
+    S = sims.single_tensor(gtab, 100, evals=mevals[0], evecs=mevecs[0], snr=None)
 
-    dm = dti.TensorModel(gtab, 'LS')
+    dm = dti.TensorModel(gtab, fit_method="LS")
     kf_xval = xval.kfold_xval(dm, S, 2)
     cod = xval.coeff_of_determination(S, kf_xval)
     npt.assert_array_almost_equal(cod, np.ones(kf_xval.shape[:-1]) * 100)
@@ -65,31 +67,37 @@ def test_dti_xval():
 def test_csd_xval(rng):
     # First, let's see that it works with some data:
     data = load_nifti_data(fdata)[1:3, 1:3, 1:3]  # Make it *small*
-    gtab = gt.gradient_table(fbval, fbvec)
+    gtab = gt.gradient_table(fbval, bvecs=fbvec)
     S0 = np.mean(data[..., gtab.b0s_mask])
     response = ([0.0015, 0.0003, 0.0001], S0)
 
     # In simulation, it should work rather well (high COD):
-    psphere = dpd.get_sphere('symmetric362')
+    psphere = dpd.get_sphere(name="symmetric362")
     bvecs = np.concatenate(([[0, 0, 0]], psphere.vertices))
     bvals = np.zeros(len(bvecs)) + 1000
     bvals[0] = 0
-    gtab = gt.gradient_table(bvals, bvecs)
+    gtab = gt.gradient_table(bvals, bvecs=bvecs)
     mevals = np.array(([0.0015, 0.0003, 0.0001], [0.0015, 0.0003, 0.0003]))
-    mevecs = [np.array([[1, 0, 0], [0, 1, 0], [0, 0, 1]]),
-              np.array([[0, 0, 1], [0, 1, 0], [1, 0, 0]])]
+    mevecs = [
+        np.array([[1, 0, 0], [0, 1, 0], [0, 0, 1]]),
+        np.array([[0, 0, 1], [0, 1, 0], [1, 0, 0]]),
+    ]
     S0 = 100
-    S = sims.single_tensor(gtab, S0, mevals[0], mevecs[0], snr=None)
+    S = sims.single_tensor(gtab, S0, evals=mevals[0], evecs=mevecs[0], snr=None)
     with warnings.catch_warnings():
         warnings.filterwarnings(
-            "ignore", message=descoteaux07_legacy_msg,
-            category=PendingDeprecationWarning)
+            "ignore",
+            message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning,
+        )
         sm = csd.ConstrainedSphericalDeconvModel(gtab, response)
     response = ([0.0015, 0.0003, 0.0001], S0)
     with warnings.catch_warnings():
         warnings.filterwarnings(
-            "ignore", message=descoteaux07_legacy_msg,
-            category=PendingDeprecationWarning)
+            "ignore",
+            message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning,
+        )
         kf_xval = xval.kfold_xval(sm, S, 2, response, sh_order_max=2, rng=rng)
     # Because of the regularization, COD is not going to be perfect here:
     cod = xval.coeff_of_determination(S, kf_xval)
@@ -104,10 +112,13 @@ def test_csd_xval(rng):
     mask[1, 1] = 0
     with warnings.catch_warnings():
         warnings.filterwarnings(
-            "ignore", message=descoteaux07_legacy_msg,
-            category=PendingDeprecationWarning)
-        kf_xval = xval.kfold_xval(sm, S, 2, response, sh_order_max=2,
-                                  mask=mask, rng=rng)
+            "ignore",
+            message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning,
+        )
+        kf_xval = xval.kfold_xval(
+            sm, S, 2, response, sh_order_max=2, mask=mask, rng=rng
+        )
 
     cod = xval.coeff_of_determination(S, kf_xval)
     npt.assert_array_almost_equal(np.round(cod[0]), csd_cod)
@@ -127,8 +138,8 @@ def test_no_predict():
         def __init__(self, model, data, mask=None):
             base.ReconstFit.__init__(self, model, data)
 
-    gtab = gt.gradient_table(fbval, fbvec)
+    gtab = gt.gradient_table(fbval, bvecs=fbvec)
     my_model = NoPredictModel(gtab)
     data = load_nifti_data(fdata)[1:3, 1:3, 1:3]  # Whatever
 
-    npt.assert_raises(ValueError,  xval.kfold_xval, my_model, data, 2)
+    npt.assert_raises(ValueError, xval.kfold_xval, my_model, data, 2)
