@@ -1,14 +1,13 @@
 import numpy as np
-from numpy.testing import assert_equal, assert_almost_equal, assert_
-from dipy.reconst.odf import (OdfFit, OdfModel, minmax_normalize, gfa)
+from numpy.testing import assert_, assert_almost_equal, assert_equal
 
+from dipy.core.gradients import GradientTable, gradient_table
 from dipy.core.subdivide_octahedron import create_unit_hemisphere
-from dipy.sims.voxel import multi_tensor, multi_tensor_odf
 from dipy.data import get_sphere
-from dipy.core.gradients import gradient_table, GradientTable
+from dipy.reconst.odf import OdfFit, OdfModel, gfa, minmax_normalize
+from dipy.sims.voxel import multi_tensor, multi_tensor_odf
 
-
-_sphere = create_unit_hemisphere(4)
+_sphere = create_unit_hemisphere(recursion_level=4)
 _odf = (_sphere.vertices * [1, 2, 3]).sum(-1)
 _gtab = GradientTable(np.ones((64, 3)))
 
@@ -22,7 +21,6 @@ class SimpleOdfModel(OdfModel):
 
 
 class SimpleOdfFit(OdfFit):
-
     def odf(self, sphere=None):
         if sphere is None:
             sphere = self.model.sphere
@@ -39,30 +37,31 @@ def test_OdfFit():
 
 
 def test_minmax_normalize():
-
     bvalue = 3000
     S0 = 1
     SNR = 100
 
-    sphere = get_sphere('symmetric362')
+    sphere = get_sphere(name="symmetric362")
     bvecs = np.concatenate(([[0, 0, 0]], sphere.vertices))
     bvals = np.zeros(len(bvecs)) + bvalue
     bvals[0] = 0
-    gtab = gradient_table(bvals, bvecs)
+    gtab = gradient_table(bvals, bvecs=bvecs)
 
     evals = np.array(([0.0017, 0.0003, 0.0003], [0.0017, 0.0003, 0.0003]))
 
-    multi_tensor(gtab, evals, S0, angles=[(0, 0), (90, 0)],
-                 fractions=[50, 50], snr=SNR)
-    odf = multi_tensor_odf(sphere.vertices, evals, angles=[(0, 0), (90, 0)],
-                           fractions=[50, 50])
+    multi_tensor(
+        gtab, evals, S0=S0, angles=[(0, 0), (90, 0)], fractions=[50, 50], snr=SNR
+    )
+    odf = multi_tensor_odf(
+        sphere.vertices, evals, angles=[(0, 0), (90, 0)], fractions=[50, 50]
+    )
 
     odf2 = minmax_normalize(odf)
     assert_equal(odf2.max(), 1)
     assert_equal(odf2.min(), 0)
 
     odf3 = np.empty(odf.shape)
-    odf3 = minmax_normalize(odf, odf3)
+    odf3 = minmax_normalize(odf, out=odf3)
     assert_equal(odf3.max(), 1)
     assert_equal(odf3.min(), 0)
 
@@ -76,9 +75,9 @@ def test_gfa():
 
     # The following series follows the rule (sqrt(n-1)/((n-1)^2))
     g = gfa(np.hstack([np.ones(9), [0]]))
-    assert_almost_equal(g, np.sqrt(9./81))
+    assert_almost_equal(g, np.sqrt(9.0 / 81))
     g = gfa(np.hstack([np.ones(99), [0]]))
-    assert_almost_equal(g, np.sqrt(99./(99.**2)))
+    assert_almost_equal(g, np.sqrt(99.0 / (99.0**2)))
 
     # All-zeros returns a nan with no warning:
     g = gfa(np.zeros(10))
