@@ -1,21 +1,32 @@
 import warnings
+
 import numpy as np
-from scipy.sparse import coo_matrix
+from scipy.sparse import coo_array
 from scipy.spatial import cKDTree
 
-from dipy.tracking.streamline import set_number_of_points
-from dipy.segment.metric import mean_euclidean_distance
 from dipy.io.stateful_tractogram import StatefulTractogram
+from dipy.segment.metric import mean_euclidean_distance
+from dipy.testing.decorators import warning_for_keywords
+from dipy.tracking.streamline import set_number_of_points
 
 
 class FastStreamlineSearch:
-    def __init__(self, ref_streamlines, max_radius, nb_mpts=4, bin_size=20.0,
-                 resampling=24, bidirectional=True):
-        """ Fast Streamline Search (FFS)
+    @warning_for_keywords()
+    def __init__(
+        self,
+        ref_streamlines,
+        max_radius,
+        *,
+        nb_mpts=4,
+        bin_size=20.0,
+        resampling=24,
+        bidirectional=True,
+    ):
+        """Fast Streamline Search (FFS)
 
         Generate the Binned K-D Tree structure with reference streamlines,
         using streamlines barycenter and mean-points.
-        See [StOnge2022]_ for further details.
+        See :footcite:p:`StOnge2022` for further details.
 
         Parameters
         ----------
@@ -42,16 +53,17 @@ class FastStreamlineSearch:
 
         References
         ----------
-        .. [StOnge2022] St-Onge E. et al. Fast Streamline Search:
-                        An Exact Technique for Diffusion MRI Tractography.
-                        Neuroinformatics, 2022.
+        .. footbibliography::
         """
         if max_radius <= 0.0:
             raise ValueError("max_radius needs to be a positive value")
 
         if resampling < 20:
-            warnings.warn("For accurate results, resampling should be"
-                          " at least >= 10 and preferably >= 20")
+            warnings.warn(
+                "For accurate results, resampling should be"
+                " at least >= 10 and preferably >= 20",
+                stacklevel=2,
+            )
 
         if resampling % nb_mpts != 0:
             raise ValueError("nb_mpts needs to be a factor of resampling")
@@ -71,7 +83,8 @@ class FastStreamlineSearch:
 
         if self.bidirectional:
             self.ref_slines = np.concatenate(
-                [self.ref_slines, np.flip(self.ref_slines, axis=1)])
+                [self.ref_slines, np.flip(self.ref_slines, axis=1)]
+            )
 
         # Compute streamlines barycenter
         barycenters = self._slines_barycenters(self.ref_slines)
@@ -92,8 +105,7 @@ class FastStreamlineSearch:
         # Assign a list of streamlines to each bin
         baryc_tree = cKDTree(barycenters)
         center_dist = bin_size / 2.0 + bin_overlap
-        baryc_bins = baryc_tree.query_ball_point(bins_center, center_dist,
-                                                 p=np.inf)
+        baryc_bins = baryc_tree.query_ball_point(bins_center, center_dist, p=np.inf)
 
         # Compute streamlines mean-points
         meanpts = self._slines_mean_points(self.ref_slines)
@@ -105,11 +117,13 @@ class FastStreamlineSearch:
                 slines_id = np.asarray(baryc_b)
                 self.bin_dict[i] = (slines_id, cKDTree(meanpts[slines_id]))
 
-    def radius_search(self, streamlines, radius, use_negative=True):
-        """ Radius Search using Fast Streamline Search
+    @warning_for_keywords()
+    def radius_search(self, streamlines, radius, *, use_negative=True):
+        """Radius Search using Fast Streamline Search
 
         For each given streamlines, return all reference streamlines
-        within the given radius. See [StOnge2022]_ for further details.
+        within the given radius. See :footcite:p:`StOnge2022` for further
+        details.
 
         Parameters
         ----------
@@ -135,13 +149,13 @@ class FastStreamlineSearch:
 
         References
         ----------
-        .. [StOnge2022] St-Onge E. et al. Fast Streamline Search:
-                        An Exact Technique for Diffusion MRI Tractography.
-                        Neuroinformatics, 2022.
+        .. footbibliography::
         """
         if radius > self.max_radius:
-            raise ValueError("radius should be smaller or equal to the given"
-                             "\n 'max_radius' in FastStreamlineSearch init")
+            raise ValueError(
+                "radius should be smaller or equal to the given"
+                "\n 'max_radius' in FastStreamlineSearch init"
+            )
 
         if isinstance(streamlines, StatefulTractogram):
             streamlines = streamlines.streamlines
@@ -179,8 +193,9 @@ class FastStreamlineSearch:
                     if ref_ids:
                         s_id = slines_id[s]
                         rs_ids = slines_id_ref[ref_ids]
-                        d = mean_euclidean_distance(q_slines[s_id],
-                                                    self.ref_slines[rs_ids])
+                        d = mean_euclidean_distance(
+                            q_slines[s_id], self.ref_slines[rs_ids]
+                        )
 
                         # Return all pairs within the radius
                         in_dist_max = d < radius
@@ -203,11 +218,12 @@ class FastStreamlineSearch:
                 if use_negative:
                     dist[flipped] *= -1.0
 
-            return coo_matrix((dist, (ids_in, ids_ref)),
-                              shape=(q_nb_slines, self.ref_nb_slines))
+            return coo_array(
+                (dist, (ids_in, ids_ref)), shape=(q_nb_slines, self.ref_nb_slines)
+            )
 
         # No results, return an empty sparse matrix
-        return coo_matrix((q_nb_slines, self.ref_nb_slines))
+        return coo_array((q_nb_slines, self.ref_nb_slines))
 
     def _resample(self, streamlines):
         """Resample streamlines"""
@@ -216,7 +232,7 @@ class FastStreamlineSearch:
             if len(sline) < 2:
                 s[i] = sline
             else:
-                s[i] = set_number_of_points(sline, self.resampling)
+                s[i] = set_number_of_points(sline, nb_points=self.resampling)
         return s
 
     def _slines_barycenters(self, slines_arr):
@@ -231,8 +247,10 @@ class FastStreamlineSearch:
 
     def _barycenters_binning(self, barycenters):
         """Bin indices in a list according to their barycenter position"""
-        in_bin = np.logical_and(np.all(barycenters >= self.min_box, axis=1),
-                                np.all(barycenters <= self.max_box, axis=1))
+        in_bin = np.logical_and(
+            np.all(barycenters >= self.min_box, axis=1),
+            np.all(barycenters <= self.max_box, axis=1),
+        )
 
         baryc_to_box = barycenters[in_bin] - self.min_box
         baryc_bins_id = (baryc_to_box // self.bin_size).astype(int)
@@ -244,13 +262,13 @@ class FastStreamlineSearch:
         return u_bin, slines_ids
 
 
-def nearest_from_matrix_row(coo_matrix):
+def nearest_from_matrix_row(coo_array):
     """
     Return the nearest (smallest) for each row given an coup sparse matrix
 
     Parameters
     ----------
-    coo_matrix : scipy COOrdinates sparse matrix (nb_slines x nb_slines_ref)
+    coo_array : scipy COOrdinates sparse array (nb_slines x nb_slines_ref)
         Adjacency matrix containing all neighbors within the given radius
 
     Returns
@@ -262,8 +280,8 @@ def nearest_from_matrix_row(coo_matrix):
     nearest_dist : numpy array (nb_non_empty_row x 1)
         Distance for each nearest match
     """
-    non_zero_ids = np.unique(coo_matrix.row)
-    sparse_matrix = np.abs(coo_matrix.tocsr())
+    non_zero_ids = np.unique(coo_array.row)
+    sparse_matrix = np.abs(coo_array.tocsr())
     upper_limit = np.max(sparse_matrix.data) + 1.0
     sparse_matrix.data = upper_limit - sparse_matrix.data
     nearest_id = np.squeeze(sparse_matrix.argmax(axis=1).data)[non_zero_ids]
@@ -271,13 +289,13 @@ def nearest_from_matrix_row(coo_matrix):
     return non_zero_ids, nearest_id, nearest_dist
 
 
-def nearest_from_matrix_col(coo_matrix):
+def nearest_from_matrix_col(coo_array):
     """
     Return the nearest (smallest) for each column given an coup sparse matrix
 
     Parameters
     ----------
-    coo_matrix : scipy COOrdinates sparse matrix (nb_slines x nb_slines_ref)
+    coo_array : scipy COOrdinates sparse matrix (nb_slines x nb_slines_ref)
         Adjacency matrix containing all neighbors within the given radius
 
     Returns
@@ -289,8 +307,8 @@ def nearest_from_matrix_col(coo_matrix):
     nearest_dist : numpy array (nb_non_empty_col x 1)
         Distance for each nearest match
     """
-    non_zero_ids = np.unique(coo_matrix.col)
-    sparse_matrix = np.abs(coo_matrix.tocsc())
+    non_zero_ids = np.unique(coo_array.col)
+    sparse_matrix = np.abs(coo_array.tocsc())
     upper_limit = np.max(sparse_matrix.data) + 1.0
     sparse_matrix.data = upper_limit - sparse_matrix.data
     nearest_id = np.squeeze(sparse_matrix.argmax(axis=0).data)[non_zero_ids]
