@@ -1,20 +1,20 @@
 from warnings import warn
 
 import numpy as np
+from scipy.ndimage import binary_dilation, generate_binary_structure, median_filter
 
-from dipy.reconst.dti import fractional_anisotropy, color_fa
-
-from scipy.ndimage import median_filter
 try:
     from skimage.filters import threshold_otsu as otsu
 except Exception:
     from dipy.segment.threshold import otsu
 
-from scipy.ndimage import binary_dilation, generate_binary_structure
+from dipy.reconst.dti import color_fa, fractional_anisotropy
+from dipy.segment.utils import remove_holes_and_islands
+from dipy.testing.decorators import warning_for_keywords
 
 
 def multi_median(data, median_radius, numpass):
-    """ Applies median filter multiple times on input data.
+    """Applies median filter multiple times on input data.
 
     Parameters
     ----------
@@ -39,14 +39,14 @@ def multi_median(data, median_radius, numpass):
 
     # Multi pass
     output = np.empty_like(data)
-    for i in range(0, numpass):
+    for _ in range(0, numpass):
         median_filter(data, medarr, output=output)
         data, output = output, data
     return data
 
 
 def applymask(vol, mask):
-    """ Mask vol with mask.
+    """Mask vol with mask.
 
     Parameters
     ----------
@@ -87,13 +87,16 @@ def bounding_box(vol):
     """
     # Find bounds on first dimension
     temp = vol
-    for i in range(vol.ndim - 1):
+    for _ in range(vol.ndim - 1):
         temp = temp.any(-1)
     mins = [temp.argmax()]
     maxs = [len(temp) - temp[::-1].argmax()]
     # Check that vol is not all 0
     if mins[0] == 0 and temp[0] == 0:
-        warn('No data found in volume to bound. Returning empty bounding box.')
+        warn(
+            "No data found in volume to bound. Returning empty bounding box.",
+            stacklevel=2,
+        )
         return [0] * vol.ndim, [0] * vol.ndim
     # Find bounds on remaining dimensions
     if vol.ndim > 1:
@@ -123,8 +126,17 @@ def crop(vol, mins, maxs):
     return vol[tuple(slice(i, j) for i, j in zip(mins, maxs))]
 
 
-def median_otsu(input_volume, vol_idx=None, median_radius=4, numpass=4,
-                autocrop=False, dilate=None):
+@warning_for_keywords()
+def median_otsu(
+    input_volume,
+    *,
+    vol_idx=None,
+    median_radius=4,
+    numpass=4,
+    autocrop=False,
+    dilate=None,
+    finalize_mask=False,
+):
     """Simple brain extraction tool method for images from DWI data.
 
     It uses a median filter smoothing of the input_volumes `vol_idx` and an
@@ -140,20 +152,22 @@ def median_otsu(input_volume, vol_idx=None, median_radius=4, numpass=4,
     ----------
     input_volume : ndarray
         3D or 4D array of the brain volume.
-    vol_idx : None or array, optional.
+    vol_idx : None or array, optional
         1D array representing indices of ``axis=3`` of a 4D `input_volume`.
         None is only an acceptable input if ``input_volume`` is 3D.
-    median_radius : int
-        Radius (in voxels) of the applied median filter (default: 4).
-    numpass: int
-        Number of pass of the median filter (default: 4).
+    median_radius : int, optional
+        Radius (in voxels) of the applied median filter.
+    numpass: int, optional
+        Number of pass of the median filter.
     autocrop: bool, optional
         if True, the masked input_volume will also be cropped using the
         bounding box defined by the masked data. Should be on if DWI is
-        upsampled to 1x1x1 resolution. (default: False).
-
+        upsampled to 1x1x1 resolution.
     dilate : None or int, optional
         number of iterations for binary dilation
+    finalize_mask : bool, optional
+        Whether to remove potential holes or islands.
+        Useful for solving minor errors.
 
     Returns
     -------
@@ -181,7 +195,7 @@ def median_otsu(input_volume, vol_idx=None, median_radius=4, numpass=4,
         used to endorse or promote products derived from this software without
         specific prior written permission.
 
-    THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+    THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR
     IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
     DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
@@ -210,6 +224,9 @@ def median_otsu(input_volume, vol_idx=None, median_radius=4, numpass=4,
         cross = generate_binary_structure(3, 1)
         mask = binary_dilation(mask, cross, iterations=dilate)
 
+    # Correct mask by removing islands and holes
+    if finalize_mask:
+        mask = remove_holes_and_islands(mask)
     # Auto crop the volumes using the mask as input_volume for bounding box
     # computing.
     if autocrop:
@@ -222,7 +239,8 @@ def median_otsu(input_volume, vol_idx=None, median_radius=4, numpass=4,
     return maskedvolume, mask
 
 
-def segment_from_cfa(tensor_fit, roi, threshold, return_cfa=False):
+@warning_for_keywords()
+def segment_from_cfa(tensor_fit, roi, threshold, *, return_cfa=False):
     """
     Segment the cfa inside roi using the values from threshold as bounds.
 
@@ -260,9 +278,7 @@ def segment_from_cfa(tensor_fit, roi, threshold, return_cfa=False):
     cfa = color_fa(FA, tensor_fit.evecs)
     roi = np.asarray(roi, dtype=bool)
 
-    include = ((cfa >= threshold[0::2]) &
-               (cfa <= threshold[1::2]) &
-               roi[..., None])
+    include = (cfa >= threshold[0::2]) & (cfa <= threshold[1::2]) & roi[..., None]
     mask = np.all(include, axis=-1)
 
     if return_cfa:
@@ -294,8 +310,7 @@ def clean_cc_mask(mask):
     # Flood fill algorithm to find contiguous regions.
     labels, numL = label(mask)
 
-    volumes = [len(labels[np.where(labels == l_idx+1)])
-               for l_idx in np.arange(numL)]
+    volumes = [len(labels[np.where(labels == l_idx + 1)]) for l_idx in np.arange(numL)]
     biggest_vol = np.arange(numL)[np.where(volumes == np.max(volumes))] + 1
     new_cc_mask[np.where(labels == biggest_vol)] = 1
 
