@@ -1,25 +1,38 @@
-__all__ = ["MinimumAverageDirectFlipMetric", "Metric", "CosineMetric",
-           "AveragePointwiseEuclideanMetric", "EuclideanMetric", "dist",
-            "mdf", "mean_manhattan_distance", "mean_euclidean_distance"]
+__all__ = [
+    "MinimumAverageDirectFlipMetric",
+    "Metric",
+    "CosineMetric",
+    "AveragePointwiseEuclideanMetric",
+    "EuclideanMetric",
+    "dist",
+    "mdf",
+    "mean_manhattan_distance",
+    "mean_euclidean_distance",
+]
 
 import numpy as np
 
-from dipy.segment.metricspeed import (SumPointwiseEuclideanMetric,
-                                      MinimumAverageDirectFlipMetric,
-                                      AveragePointwiseEuclideanMetric,
-                                      CosineMetric, Metric,
-                                      dist)
+from dipy.segment.metricspeed import (
+    AveragePointwiseEuclideanMetric,
+    CosineMetric,
+    Metric,
+    MinimumAverageDirectFlipMetric,
+    SumPointwiseEuclideanMetric,
+    dist,
+)
 
 # Creates aliases
 EuclideanMetric = SumPointwiseEuclideanMetric
 
 
 def mdf(s1, s2):
-    """ Computes the MDF (Minimum average Direct-Flip) distance
-    [Garyfallidis12]_ between two streamlines.
+    """Computes the MDF (Minimum average Direct-Flip) distance between two
+    streamlines.
 
     Streamlines must have the same number of points.
 
+    See :footcite:p:`Garyfallidis2012a` for a definition of the distance.
+
     Parameters
     ----------
     s1 : 2D array
@@ -34,15 +47,13 @@ def mdf(s1, s2):
 
     References
     ----------
-    .. [Garyfallidis12] Garyfallidis E. et al., QuickBundles a method for
-                        tractography simplification, Frontiers in Neuroscience,
-                        vol 6, no 175, 2012.
+    .. footbibliography::
     """
     return dist(MinimumAverageDirectFlipMetric(), s1, s2)
 
 
 def mean_manhattan_distance(a, b):
-    """ Compute the average Manhattan-L1 distance (MDF without flip)
+    """Compute the average Manhattan-L1 distance (MDF without flip)
 
     Arrays are representing a single streamline or a list of streamlines
     that have the same number of N-dimensional points (two last axis).
@@ -65,7 +76,7 @@ def mean_manhattan_distance(a, b):
 
 
 def mean_euclidean_distance(a, b):
-    """ Compute the average Euclidean-L2 distance (MDF without flip)
+    """Compute the average Euclidean-L2 distance (MDF without flip)
 
     Arrays are representing a single streamline or a list of streamlines
     that have the same number of N-dimensional points (two last axis).
