@@ -1,27 +1,22 @@
-import sys
-import pytest
 import warnings
 
 import numpy as np
-from numpy.testing import assert_equal, assert_almost_equal
+from numpy.testing import assert_almost_equal, assert_equal
 
 from dipy.data import get_fnames
 from dipy.io.streamline import load_tractogram
 from dipy.segment.bundles import RecoBundles
-from dipy.tracking.distances import bundles_distances_mam
-from dipy.tracking.streamline import Streamlines
 from dipy.segment.clustering import qbx_and_merge
 from dipy.testing.decorators import set_random_number_generator
-
-is_big_endian = 'big' in sys.byteorder.lower()
+from dipy.tracking.distances import bundles_distances_mam
+from dipy.tracking.streamline import Streamlines
 
 
 def setup_module():
     global f, f1, f2, f3, fornix
 
-    fname = get_fnames('fornix')
-    fornix = load_tractogram(fname, 'same',
-                             bbox_valid_check=False).streamlines
+    fname = get_fnames(name="fornix")
+    fornix = load_tractogram(fname, "same", bbox_valid_check=False).streamlines
 
     f = Streamlines(fornix)
     f1 = f.copy()
@@ -36,15 +31,12 @@ def setup_module():
     f.extend(f3)
 
 
-@pytest.mark.skipif(is_big_endian,
-                    reason="Little Endian architecture required")
 def test_rb_check_defaults():
-
     rb = RecoBundles(f, greater_than=0, clust_thr=10)
 
-    rec_trans, rec_labels = rb.recognize(model_bundle=f2,
-                                         model_clust_thr=5.,
-                                         reduction_thr=10)
+    rec_trans, rec_labels = rb.recognize(
+        model_bundle=f2, model_clust_thr=5.0, reduction_thr=10
+    )
 
     msg = "Streamlines do not have the same number of points. *"
     with warnings.catch_warnings():
@@ -56,10 +48,12 @@ def test_rb_check_defaults():
         for row in D:
             assert_equal(row.min(), 0)
 
-    refine_trans, refine_labels = rb.refine(model_bundle=f2,
-                                            pruned_streamlines=rec_trans,
-                                            model_clust_thr=5.,
-                                            reduction_thr=10)
+    refine_trans, refine_labels = rb.refine(
+        model_bundle=f2,
+        pruned_streamlines=rec_trans,
+        model_clust_thr=5.0,
+        reduction_thr=10,
+    )
 
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", message=msg, category=UserWarning)
@@ -70,16 +64,12 @@ def test_rb_check_defaults():
         assert_equal(row.min(), 0)
 
 
-@pytest.mark.skipif(is_big_endian,
-                    reason="Little Endian architecture required")
 def test_rb_disable_slr():
-
     rb = RecoBundles(f, greater_than=0, clust_thr=10)
 
-    rec_trans, rec_labels = rb.recognize(model_bundle=f2,
-                                         model_clust_thr=5.,
-                                         reduction_thr=10,
-                                         slr=False)
+    rec_trans, rec_labels = rb.recognize(
+        model_bundle=f2, model_clust_thr=5.0, reduction_thr=10, slr=False
+    )
 
     msg = "Streamlines do not have the same number of points. *"
     with warnings.catch_warnings():
@@ -91,10 +81,12 @@ def test_rb_disable_slr():
         for row in D:
             assert_equal(row.min(), 0)
 
-    refine_trans, refine_labels = rb.refine(model_bundle=f2,
-                                            pruned_streamlines=rec_trans,
-                                            model_clust_thr=5.,
-                                            reduction_thr=10)
+    refine_trans, refine_labels = rb.refine(
+        model_bundle=f2,
+        pruned_streamlines=rec_trans,
+        model_clust_thr=5.0,
+        reduction_thr=10,
+    )
 
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", message=msg, category=UserWarning)
@@ -105,32 +97,28 @@ def test_rb_disable_slr():
         assert_equal(row.min(), 0)
 
 
-@pytest.mark.skipif(is_big_endian,
-                    reason="Little Endian architecture required")
 @set_random_number_generator(42)
 def test_rb_slr_threads(rng):
+    rb_multi = RecoBundles(f, greater_than=0, clust_thr=10, rng=rng)
+    rec_trans_multi_threads, _ = rb_multi.recognize(
+        model_bundle=f2,
+        model_clust_thr=5.0,
+        reduction_thr=10,
+        slr=True,
+        num_threads=None,
+    )
 
-    rb_multi = RecoBundles(f, greater_than=0, clust_thr=10,
-                           rng=rng)
-    rec_trans_multi_threads, _ = rb_multi.recognize(model_bundle=f2,
-                                                    model_clust_thr=5.,
-                                                    reduction_thr=10,
-                                                    slr=True,
-                                                    num_threads=None)
-
-    rb_single = RecoBundles(f, greater_than=0, clust_thr=10,
-                            rng=np.random.default_rng(42))
-    rec_trans_single_thread, _ = rb_single.recognize(model_bundle=f2,
-                                                     model_clust_thr=5.,
-                                                     reduction_thr=10,
-                                                     slr=True,
-                                                     num_threads=1)
+    rb_single = RecoBundles(
+        f, greater_than=0, clust_thr=10, rng=np.random.default_rng(42)
+    )
+    rec_trans_single_thread, _ = rb_single.recognize(
+        model_bundle=f2, model_clust_thr=5.0, reduction_thr=10, slr=True, num_threads=1
+    )
 
     msg = "Streamlines do not have the same number of points. *"
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", message=msg, category=UserWarning)
-        D = bundles_distances_mam(rec_trans_multi_threads,
-                                  rec_trans_single_thread)
+        D = bundles_distances_mam(rec_trans_multi_threads, rec_trans_single_thread)
 
     # check if the bundle is recognized correctly
     # multi-threading prevent an exact match
@@ -138,17 +126,16 @@ def test_rb_slr_threads(rng):
         assert_almost_equal(row.min(), 0, decimal=4)
 
 
-@pytest.mark.skipif(is_big_endian,
-                    reason="Little Endian architecture required")
 def test_rb_no_verbose_and_mam():
-
     rb = RecoBundles(f, greater_than=0, clust_thr=10, verbose=False)
 
-    rec_trans, rec_labels = rb.recognize(model_bundle=f2,
-                                         model_clust_thr=5.,
-                                         reduction_thr=10,
-                                         slr=True,
-                                         pruning_distance='mam')
+    rec_trans, rec_labels = rb.recognize(
+        model_bundle=f2,
+        model_clust_thr=5.0,
+        reduction_thr=10,
+        slr=True,
+        pruning_distance="mam",
+    )
 
     msg = "Streamlines do not have the same number of points. *"
     with warnings.catch_warnings():
@@ -160,10 +147,12 @@ def test_rb_no_verbose_and_mam():
         for row in D:
             assert_equal(row.min(), 0)
 
-    refine_trans, refine_labels = rb.refine(model_bundle=f2,
-                                            pruned_streamlines=rec_trans,
-                                            model_clust_thr=5.,
-                                            reduction_thr=10)
+    refine_trans, refine_labels = rb.refine(
+        model_bundle=f2,
+        pruned_streamlines=rec_trans,
+        model_clust_thr=5.0,
+        reduction_thr=10,
+    )
 
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", message=msg, category=UserWarning)
@@ -174,17 +163,15 @@ def test_rb_no_verbose_and_mam():
         assert_equal(row.min(), 0)
 
 
-@pytest.mark.skipif(is_big_endian,
-                    reason="Little Endian architecture required")
 def test_rb_clustermap():
-
     cluster_map = qbx_and_merge(f, thresholds=[40, 25, 20, 10])
 
-    rb = RecoBundles(f, greater_than=0, less_than=1000000,
-                     cluster_map=cluster_map, clust_thr=10)
-    rec_trans, rec_labels = rb.recognize(model_bundle=f2,
-                                         model_clust_thr=5.,
-                                         reduction_thr=10)
+    rb = RecoBundles(
+        f, greater_than=0, less_than=1000000, cluster_map=cluster_map, clust_thr=10
+    )
+    rec_trans, rec_labels = rb.recognize(
+        model_bundle=f2, model_clust_thr=5.0, reduction_thr=10
+    )
 
     msg = "Streamlines do not have the same number of points. *"
     with warnings.catch_warnings():
@@ -196,10 +183,12 @@ def test_rb_clustermap():
         for row in D:
             assert_equal(row.min(), 0)
 
-    refine_trans, refine_labels = rb.refine(model_bundle=f2,
-                                            pruned_streamlines=rec_trans,
-                                            model_clust_thr=5.,
-                                            reduction_thr=10)
+    refine_trans, refine_labels = rb.refine(
+        model_bundle=f2,
+        pruned_streamlines=rec_trans,
+        model_clust_thr=5.0,
+        reduction_thr=10,
+    )
 
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", message=msg, category=UserWarning)
@@ -210,8 +199,6 @@ def test_rb_clustermap():
         assert_equal(row.min(), 0)
 
 
-@pytest.mark.skipif(is_big_endian,
-                    reason="Little Endian architecture required")
 def test_rb_no_neighb():
     # what if no neighbors are found? No recognition
 
@@ -228,15 +215,17 @@ def test_rb_no_neighb():
 
     rb = RecoBundles(b, greater_than=0, clust_thr=10)
 
-    rec_trans, rec_labels = rb.recognize(model_bundle=b2,
-                                         model_clust_thr=5.,
-                                         reduction_thr=10)
+    rec_trans, rec_labels = rb.recognize(
+        model_bundle=b2, model_clust_thr=5.0, reduction_thr=10
+    )
 
     if len(rec_trans) > 0:
-        refine_trans, refine_labels = rb.refine(model_bundle=b2,
-                                                pruned_streamlines=rec_trans,
-                                                model_clust_thr=5.,
-                                                reduction_thr=10)
+        refine_trans, refine_labels = rb.refine(
+            model_bundle=b2,
+            pruned_streamlines=rec_trans,
+            model_clust_thr=5.0,
+            reduction_thr=10,
+        )
 
         assert_equal(len(refine_labels), 0)
         assert_equal(len(refine_trans), 0)
@@ -246,19 +235,18 @@ def test_rb_no_neighb():
         assert_equal(len(rec_trans), 0)
 
 
-@pytest.mark.skipif(is_big_endian,
-                    reason="Little Endian architecture required")
 def test_rb_reduction_mam():
-
     rb = RecoBundles(f, greater_than=0, clust_thr=10, verbose=True)
 
-    rec_trans, rec_labels = rb.recognize(model_bundle=f2,
-                                         model_clust_thr=5.,
-                                         reduction_thr=10,
-                                         reduction_distance='mam',
-                                         slr=True,
-                                         slr_metric='asymmetric',
-                                         pruning_distance='mam')
+    rec_trans, rec_labels = rb.recognize(
+        model_bundle=f2,
+        model_clust_thr=5.0,
+        reduction_thr=10,
+        reduction_distance="mam",
+        slr=True,
+        slr_metric="asymmetric",
+        pruning_distance="mam",
+    )
 
     msg = "Streamlines do not have the same number of points. *"
     with warnings.catch_warnings():
@@ -270,10 +258,12 @@ def test_rb_reduction_mam():
         for row in D:
             assert_equal(row.min(), 0)
 
-    refine_trans, refine_labels = rb.refine(model_bundle=f2,
-                                            pruned_streamlines=rec_trans,
-                                            model_clust_thr=5.,
-                                            reduction_thr=10)
+    refine_trans, refine_labels = rb.refine(
+        model_bundle=f2,
+        pruned_streamlines=rec_trans,
+        model_clust_thr=5.0,
+        reduction_thr=10,
+    )
 
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", message=msg, category=UserWarning)
