@@ -1,7 +1,10 @@
 import numpy as np
 
+from dipy.testing.decorators import warning_for_keywords
 
-def otsu(image, nbins=256):
+
+@warning_for_keywords()
+def otsu(image, *, nbins=256):
     """
     Return threshold value based on Otsu's method.
     Copied from scikit-image to remove dependency.
@@ -33,15 +36,16 @@ def otsu(image, nbins=256):
     # Clip ends to align class 1 and class 2 variables:
     # The last value of `weight1`/`mean1` should pair with zero values in
     # `weight2`/`mean2`, which do not exist.
-    variance12 = weight1[:-1] * weight2[1:] * (mean1[:-1] - mean2[1:])**2
+    variance12 = weight1[:-1] * weight2[1:] * (mean1[:-1] - mean2[1:]) ** 2
 
     idx = np.argmax(variance12)
     threshold = bin_centers[:-1][idx]
     return threshold
 
 
-def upper_bound_by_rate(data, rate=0.05):
-    r""" Adjusts upper intensity boundary using rates
+@warning_for_keywords()
+def upper_bound_by_rate(data, *, rate=0.05):
+    r"""Adjusts upper intensity boundary using rates
 
     It calculates the image intensity histogram, and based on the rate value it
     decide what is the upperbound value for intensity normalization, usually
@@ -71,7 +75,7 @@ def upper_bound_by_rate(data, rate=0.05):
         m[i, 1] = h[i]
         m[i, 2] = h[i + 1]
 
-    g = sorted(g,reverse = True)
+    g = sorted(g, reverse=True)
     sz = np.size(g)
 
     Index = 0
@@ -87,8 +91,9 @@ def upper_bound_by_rate(data, rate=0.05):
     return high
 
 
-def upper_bound_by_percent(data, percent=1):
-    """ Find the upper bound for visualization of medical images
+@warning_for_keywords()
+def upper_bound_by_percent(data, *, percent=1):
+    """Find the upper bound for visualization of medical images
 
     Calculate the histogram of the image and go right to left until you find
     the bound that contains more than a percentage of the image.
@@ -103,7 +108,7 @@ def upper_bound_by_percent(data, percent=1):
     upper_bound : float
     """
 
-    percent = percent / 100.
+    percent = percent / 100.0
     values, bounds = np.histogram(data, 20)
     total_voxels = np.prod(data.shape)
     agg = 0
