@@ -1,15 +1,18 @@
 import numpy as np
-# import scipy.stats as stats
 
-from dipy.sims.voxel import single_tensor, diffusion_evals
-import dipy.sims.voxel as vox
 from dipy.core.geometry import vec2vec_rotmat
-from dipy.data import get_fnames
 from dipy.core.gradients import gradient_table
+from dipy.data import get_fnames
+import dipy.sims.voxel as vox
+
+# import scipy.stats as stats
+from dipy.sims.voxel import diffusion_evals, single_tensor
+from dipy.testing.decorators import warning_for_keywords
 
 
-def add_noise(vol, snr=1.0, S0=None, noise_type='rician', rng=None):
-    """ Add noise of specified distribution to a 4D array.
+@warning_for_keywords()
+def add_noise(vol, *, snr=1.0, S0=None, noise_type="rician", rng=None):
+    """Add noise of specified distribution to a 4D array.
 
     Parameters
     ----------
@@ -19,14 +22,13 @@ def add_noise(vol, snr=1.0, S0=None, noise_type='rician', rng=None):
     snr : float, optional
         The desired signal-to-noise ratio.  (See notes below.)
     S0 : float, optional
-        Reference signal for specifying `snr` (defaults to 1).
+        Reference signal for specifying `snr`.
     noise_type : string, optional
         The distribution of noise added. Can be either 'gaussian' for Gaussian
         distributed noise, 'rician' for Rice-distributed noise (default) or
         'rayleigh' for a Rayleigh distribution.
     rng : numpy.random.Generator class, optional
         Numpy's random generator for setting seed values when needed.
-        Default is None.
 
     Returns
     -------
@@ -35,16 +37,14 @@ def add_noise(vol, snr=1.0, S0=None, noise_type='rician', rng=None):
 
     Notes
     -----
-    SNR is defined here, following [1]_, as ``S0 / sigma``, where ``sigma`` is
-    the standard deviation of the two Gaussian distributions forming the real
-    and imaginary components of the Rician noise distribution (see [2]_).
+    SNR is defined here, following :footcite:p:`Descoteaux2007`, as
+    ``S0 / sigma``, where ``sigma`` is the standard deviation of the two
+    Gaussian distributions forming the real and imaginary components of the
+    Rician noise distribution (see :footcite:p:`Gudbjartsson1995`).
 
     References
     ----------
-    .. [1] Descoteaux, Angelino, Fitzgibbons and Deriche (2007) Regularized,
-           fast and robust q-ball imaging. MRM, 58: 497-510
-    .. [2] Gudbjartson and Patz (2008). The Rician distribution of noisy MRI
-           data. MRM 34: 910-914.
+    .. footbibliography::
 
     Examples
     --------
@@ -59,18 +59,18 @@ def add_noise(vol, snr=1.0, S0=None, noise_type='rician', rng=None):
         S0 = np.max(vol)
 
     for vox_idx, signal in enumerate(vol_flat):
-        vol_flat[vox_idx] = vox.add_noise(signal, snr=snr, S0=S0,
-                                          noise_type=noise_type, rng=rng)
+        vol_flat[vox_idx] = vox.add_noise(
+            signal, snr=snr, S0=S0, noise_type=noise_type, rng=rng
+        )
 
     return np.reshape(vol_flat, orig_shape)
 
 
 def diff2eigenvectors(dx, dy, dz):
-    """ numerical derivatives 2 eigenvectors
-    """
+    """numerical derivatives 2 eigenvectors"""
     basis = np.eye(3)
     u = np.array([dx, dy, dz])
-    u = u/np.linalg.norm(u)
+    u = u / np.linalg.norm(u)
     R = vec2vec_rotmat(basis[:, 0], u)
     eig0 = u
     eig1 = np.dot(R, basis[:, 1])
@@ -82,18 +82,22 @@ def diff2eigenvectors(dx, dy, dz):
     return eigs, R
 
 
-def orbital_phantom(gtab=None,
-                    evals=diffusion_evals,
-                    func=None,
-                    t=np.linspace(0, 2 * np.pi, 1000),
-                    datashape=(64, 64, 64, 65),
-                    origin=(32, 32, 32),
-                    scale=(25, 25, 25),
-                    angles=np.linspace(0, 2 * np.pi, 32),
-                    radii=np.linspace(0.2, 2, 6),
-                    S0=100.,
-                    snr=None,
-                    rng=None):
+@warning_for_keywords()
+def orbital_phantom(
+    *,
+    gtab=None,
+    evals=diffusion_evals,
+    func=None,
+    t=None,
+    datashape=(64, 64, 64, 65),
+    origin=(32, 32, 32),
+    scale=(25, 25, 25),
+    angles=None,
+    radii=None,
+    S0=100.0,
+    snr=None,
+    rng=None,
+):
     """Create a phantom based on a 3-D orbit ``f(t) -> (x,y,z)``.
 
     Parameters
@@ -150,9 +154,18 @@ def orbital_phantom(gtab=None,
 
     """
 
+    if t is None:
+        t = np.linspace(0, 2 * np.pi, 1000)
+
+    if angles is None:
+        angles = np.linspace(0, 2 * np.pi, 32)
+
+    if radii is None:
+        radii = np.linspace(0.2, 2, 6)
+
     if gtab is None:
-        fimg, fbvals, fbvecs = get_fnames('small_64D')
-        gtab = gradient_table(fbvals, fbvecs)
+        fimg, fbvals, fbvecs = get_fnames(name="small_64D")
+        gtab = gradient_table(fbvals, bvecs=fbvecs)
 
     if func is None:
         x = np.sin(t)
@@ -180,7 +193,7 @@ def orbital_phantom(gtab=None,
 
     for i in range(len(dx)):
         evecs, R = diff2eigenvectors(dx[i], dy[i], dz[i])
-        S = single_tensor(gtab, S0, evals, evecs, snr=None)
+        S = single_tensor(gtab, S0, evals=evals, evecs=evecs, snr=None)
 
         vol[int(x[i]), int(y[i]), int(z[i]), :] += S
 
@@ -197,13 +210,12 @@ def orbital_phantom(gtab=None,
     vol *= S0
 
     if snr is not None:
-        vol = add_noise(vol, snr, S0=S0, noise_type='rician', rng=rng)
+        vol = add_noise(vol, snr=snr, S0=S0, noise_type="rician", rng=rng)
 
     return vol
 
 
 if __name__ == "__main__":
-
     # TODO: this can become a nice tutorial for generating phantoms
 
     def f(t):
