@@ -1,11 +1,11 @@
 import numpy as np
 from numpy import dot
-from dipy.core.geometry import sphere2cart
-from dipy.core.geometry import vec2vec_rotmat
-from dipy.core.gradients import GradientTable
-from dipy.reconst.utils import dki_design_matrix
 from scipy.special import jn
 
+from dipy.core.geometry import sphere2cart, vec2vec_rotmat
+from dipy.reconst.utils import dki_design_matrix
+from dipy.testing.decorators import warning_for_keywords
+
 # Diffusion coefficients for white matter tracts, in mm^2/s
 #
 # Based roughly on values from:
@@ -36,8 +36,9 @@ def _check_directions(angles):
     if angles.shape[-1] == 3:
         sticks = angles
     else:
-        sticks = [sphere2cart(1, np.deg2rad(pair[0]), np.deg2rad(pair[1]))
-                  for pair in angles]
+        sticks = [
+            sphere2cart(1, np.deg2rad(pair[0]), np.deg2rad(pair[1])) for pair in angles
+        ]
         sticks = np.array(sticks)
 
     return sticks
@@ -60,7 +61,7 @@ def _add_rician(sig, noise1, noise2):
     This does the same as abs(sig + complex(noise1, noise2))
 
     """
-    return np.sqrt((sig + noise1) ** 2 + noise2 ** 2)
+    return np.sqrt((sig + noise1) ** 2 + noise2**2)
 
 
 def _add_rayleigh(sig, noise1, noise2):
@@ -69,11 +70,12 @@ def _add_rayleigh(sig, noise1, noise2):
     The Rayleigh distribution is $\sqrt\{Gauss_1^2 + Gauss_2^2}$.
 
     """
-    return sig + np.sqrt(noise1 ** 2 + noise2 ** 2)
+    return sig + np.sqrt(noise1**2 + noise2**2)
 
 
-def add_noise(signal, snr, S0, noise_type='rician', rng=None):
-    r""" Add noise of specified distribution to the signal from a single voxel.
+@warning_for_keywords()
+def add_noise(signal, snr, S0, *, noise_type="rician", rng=None):
+    r"""Add noise of specified distribution to the signal from a single voxel.
 
     Parameters
     ----------
@@ -88,9 +90,9 @@ def add_noise(signal, snr, S0, noise_type='rician', rng=None):
         The distribution of noise added. Can be either 'gaussian' for Gaussian
         distributed noise, 'rician' for Rice-distributed noise (default) or
         'rayleigh' for a Rayleigh distribution.
-    rng : numpy.random.Generator class, optional
-        Numpy's random generator for setting seed values when needed.
-        Default is None.
+    rng : numpy.random.Generator, optional
+        Random number generator for the noise. If ``None``, uses NumPy's default
+        random generator.
 
     Returns
     -------
@@ -99,16 +101,14 @@ def add_noise(signal, snr, S0, noise_type='rician', rng=None):
 
     Notes
     -----
-    SNR is defined here, following [1]_, as ``S0 / sigma``, where ``sigma`` is
-    the standard deviation of the two Gaussian distributions forming the real
-    and imaginary components of the Rician noise distribution (see [2]_).
+    SNR is defined here, following :footcite:p:`Descoteaux2007`, as
+    ``S0 / sigma``, where ``sigma`` is the standard deviation of the two
+    Gaussian distributions forming the real and imaginary components of the
+    Rician noise distribution (see :footcite:p:`Gudbjartsson1995`).
 
     References
     ----------
-    .. [1] Descoteaux, Angelino, Fitzgibbons and Deriche (2007) Regularized,
-           fast and robust q-ball imaging. MRM, 58: 497-510
-    .. [2] Gudbjartson and Patz (2008). The Rician distribution of noisy MRI
-           data. MRM 34: 910-914.
+    .. footbibliography::
 
     Examples
     --------
@@ -124,13 +124,15 @@ def add_noise(signal, snr, S0, noise_type='rician', rng=None):
 
     sigma = S0 / snr
 
-    noise_adder = {'gaussian': _add_gaussian,
-                   'rician': _add_rician,
-                   'rayleigh': _add_rayleigh}
+    noise_adder = {
+        "gaussian": _add_gaussian,
+        "rician": _add_rician,
+        "rayleigh": _add_rayleigh,
+    }
 
     noise1 = rng.normal(0, sigma, size=signal.shape)
 
-    if noise_type == 'gaussian':
+    if noise_type == "gaussian":
         noise2 = None
     else:
         noise2 = rng.normal(0, sigma, size=signal.shape)
@@ -138,9 +140,13 @@ def add_noise(signal, snr, S0, noise_type='rician', rng=None):
     return noise_adder[noise_type](signal, noise1, noise2)
 
 
-def sticks_and_ball(gtab, d=0.0015, S0=1., angles=((0, 0), (90, 0)),
-                    fractions=(35, 35), snr=20):
-    """ Simulate the signal for a Sticks & Ball model.
+@warning_for_keywords()
+def sticks_and_ball(
+    gtab, *, d=0.0015, S0=1.0, angles=((0, 0), (90, 0)), fractions=(35, 35), snr=20
+):
+    """Simulate the signal for a Sticks & Ball model.
+
+    See :footcite:p:`Behrens2007` for a definition of the Sticks & Ball model.
 
     Parameters
     ----------
@@ -169,21 +175,22 @@ def sticks_and_ball(gtab, d=0.0015, S0=1., angles=((0, 0), (90, 0)),
 
     References
     ----------
-    .. [1] Behrens et al., "Probabilistic diffusion
-           tractography with multiple fiber orientations:  what can we gain?",
-           Neuroimage, 2007.
+    .. footbibliography::
 
     """
-    fractions = [f / 100. for f in fractions]
+    fractions = [f / 100.0 for f in fractions]
     f0 = 1 - np.sum(fractions)
     S = np.zeros(len(gtab.bvals))
 
     sticks = _check_directions(angles)
 
-    for (i, g) in enumerate(gtab.bvecs[1:]):
-        S[i + 1] = f0*np.exp(-gtab.bvals[i + 1]*d) + \
-            np.sum([fractions[j]*np.exp(-gtab.bvals[i + 1]*d*np.dot(s, g)**2)
-                   for (j, s) in enumerate(sticks)])
+    for i, g in enumerate(gtab.bvecs[1:]):
+        S[i + 1] = f0 * np.exp(-gtab.bvals[i + 1] * d) + np.sum(
+            [
+                fractions[j] * np.exp(-gtab.bvals[i + 1] * d * np.dot(s, g) ** 2)
+                for (j, s) in enumerate(sticks)
+            ]
+        )
 
         S[i + 1] = S0 * S[i + 1]
 
@@ -194,9 +201,13 @@ def sticks_and_ball(gtab, d=0.0015, S0=1., angles=((0, 0), (90, 0)),
 
 
 def callaghan_perpendicular(q, radius):
-    r""" Calculates the perpendicular diffusion signal E(q) in a cylinder of
-    radius R using the Soderman model [1]_. Assumes that the pulse length
-    is infinitely short and the diffusion time is infinitely long.
+    """Calculates the perpendicular diffusion signal E(q) in a cylinder of
+    radius R using the Soderman model.
+
+    Assumes that the pulse length is infinitely short and the diffusion time is
+    infinitely long.
+
+    See :footcite:p:`Soderman1995` for details about the Soderman model.
 
     Parameters
     ----------
@@ -212,9 +223,7 @@ def callaghan_perpendicular(q, radius):
 
     References
     ----------
-    .. [1] Söderman, Olle, and Bengt Jönsson. "Restricted diffusion in
-           cylindrical geometry." Journal of Magnetic Resonance, Series A
-           117.1 (1995): 94-97.
+    .. footbibliography::
 
     """
     # Eq. [6] in the paper
@@ -225,8 +234,9 @@ def callaghan_perpendicular(q, radius):
     return E
 
 
-def gaussian_parallel(q, tau, D=0.7e-3):
-    r""" Calculates the parallel Gaussian diffusion signal.
+@warning_for_keywords()
+def gaussian_parallel(q, tau, *, D=0.7e-3):
+    r"""Calculates the parallel Gaussian diffusion signal.
 
     Parameters
     ----------
@@ -243,19 +253,32 @@ def gaussian_parallel(q, tau, D=0.7e-3):
         signal attenuation
 
     """
-    return np.exp(-(2 * np.pi * q) ** 2 * tau * D)
+    return np.exp(-((2 * np.pi * q) ** 2) * tau * D)
 
 
-def cylinders_and_ball_soderman(gtab, tau, radii=(5e-3, 5e-3), D=0.7e-3,
-                                S0=1., angles=((0, 0), (90, 0)),
-                                fractions=(35, 35), snr=20):
-    r""" Calculates the three-dimensional signal attenuation E(q) originating
-    from within a cylinder of radius R using the Soderman approximation [1]_.
-    The diffusion signal is assumed to be separable perpendicular and parallel
-    to the cylinder axis [2]_.
+@warning_for_keywords()
+def cylinders_and_ball_soderman(
+    gtab,
+    tau,
+    *,
+    radii=(5e-3, 5e-3),
+    D=0.7e-3,
+    S0=1.0,
+    angles=((0, 0), (90, 0)),
+    fractions=(35, 35),
+    snr=20,
+):
+    """Calculates the three-dimensional signal attenuation E(q) originating
+    from within a cylinder of radius R using the Soderman approximation.
+
+    The diffusion signal is assumed to be separable  perpendicular and parallel
+    to the cylinder axis :footcite:p:`Assaf2004`.
+
     This function is basically an extension of the ball and stick model.
     Setting the radius to zero makes them equivalent.
 
+    See :footcite:p:`Soderman1995` for details about the Soderman model.
+
     Parameters
     ----------
     gtab : GradientTable
@@ -285,19 +308,14 @@ def cylinders_and_ball_soderman(gtab, tau, radii=(5e-3, 5e-3), D=0.7e-3,
 
     References
     ----------
-    .. [1] Söderman, Olle, and Bengt Jönsson. "Restricted diffusion in
-           cylindrical geometry." Journal of Magnetic Resonance, Series A
-           117.1 (1995): 94-97.
-    .. [2] Assaf, Yaniv, et al. "New modeling and experimental framework to
-           characterize hindered and restricted water diffusion in brain white
-           matter." Magnetic Resonance in Medicine 52.5 (2004): 965-978.
+    .. footbibliography::
 
     """
     qvals = np.sqrt(gtab.bvals / tau) / (2 * np.pi)
     qvecs = qvals[:, None] * gtab.bvecs
-    q_norm = np.sqrt(np.einsum('ij,ij->i', qvecs, qvecs))
+    q_norm = np.sqrt(np.einsum("ij,ij->i", qvecs, qvecs))
 
-    fractions = [f / 100. for f in fractions]
+    fractions = [f / 100.0 for f in fractions]
     f0 = 1 - np.sum(fractions)
 
     S = np.zeros(len(gtab.bvals))
@@ -305,9 +323,10 @@ def cylinders_and_ball_soderman(gtab, tau, radii=(5e-3, 5e-3), D=0.7e-3,
 
     for i, f in enumerate(fractions):
         q_par = abs(np.dot(qvecs, sticks[i]))
-        q_perp = np.sqrt(q_norm ** 2 - q_par ** 2)
-        S_cylinder = (callaghan_perpendicular(q_perp, radii[i]) *
-                      gaussian_parallel(q_par, tau, D=D))
+        q_perp = np.sqrt(q_norm**2 - q_par**2)
+        S_cylinder = callaghan_perpendicular(q_perp, radii[i]) * gaussian_parallel(
+            q_par, tau, D=D
+        )
         S += f * S_cylinder
 
     S += f0 * np.exp(-gtab.bvals * D)
@@ -318,8 +337,11 @@ def cylinders_and_ball_soderman(gtab, tau, radii=(5e-3, 5e-3), D=0.7e-3,
     return S, sticks
 
 
-def single_tensor(gtab, S0=1, evals=None, evecs=None, snr=None, rng=None):
-    """ Simulate diffusion-weighted signals with a single tensor.
+@warning_for_keywords()
+def single_tensor(gtab, S0=1, *, evals=None, evecs=None, snr=None, rng=None):
+    """Simulate diffusion-weighted signals with a single tensor.
+
+    See :footcite:p:`Stejskal1965`, :footcite:p:`Descoteaux2008b`.
 
     Parameters
     ----------
@@ -339,6 +361,9 @@ def single_tensor(gtab, S0=1, evals=None, evecs=None, snr=None, rng=None):
         need to be column wise.
     snr : float, optional
         Signal to noise ratio, assuming Rician noise.  None implies no noise.
+    rng : numpy.random.Generator, optional
+        Random number generator for the noise. If ``None``, uses NumPy's default
+        random generator.
 
     Returns
     -------
@@ -349,12 +374,7 @@ def single_tensor(gtab, S0=1, evals=None, evecs=None, snr=None, rng=None):
 
     References
     ----------
-    .. [1] M. Descoteaux, "High Angular Resolution Diffusion MRI: from Local
-           Estimation to Segmentation and Tractography", PhD thesis,
-           University of Nice-Sophia Antipolis, p. 42, 2008.
-    .. [2] E. Stejskal and J. Tanner, "Spin diffusion measurements: spin echos
-           in the presence of a time-dependent field gradient", Journal of
-           Chemical Physics, nr. 42, pp. 288--292, 1965.
+    .. footbibliography::
 
     """
     if rng is None:
@@ -366,7 +386,7 @@ def single_tensor(gtab, S0=1, evals=None, evecs=None, snr=None, rng=None):
     if evecs is None:
         evecs = np.eye(3)
 
-    out_shape = gtab.bvecs.shape[:gtab.bvecs.ndim - 1]
+    out_shape = gtab.bvecs.shape[: gtab.bvecs.ndim - 1]
     gradients = gtab.bvecs.reshape(-1, 3)
 
     R = np.asarray(evecs)
@@ -374,20 +394,29 @@ def single_tensor(gtab, S0=1, evals=None, evecs=None, snr=None, rng=None):
     D = dot(dot(R, np.diag(evals)), R.T)
 
     if gtab.btens is None:
-        for (i, g) in enumerate(gradients):
+        for i, g in enumerate(gradients):
             S[i] = S0 * np.exp(-gtab.bvals[i] * dot(dot(g.T, D), g))
     else:
-        for (i, b) in enumerate(gtab.btens):
-            S[i] = S0 * np.exp(- np.sum(b * D))
+        for i, b in enumerate(gtab.btens):
+            S[i] = S0 * np.exp(-np.sum(b * D))
 
     S = add_noise(S, snr, S0, rng=rng)
 
     return S.reshape(out_shape)
 
 
-def multi_tensor(gtab, mevals, S0=1., angles=((0, 0), (90, 0)),
-                 fractions=(50, 50), snr=20, rng=None):
-    r""" Simulate a Multi-Tensor signal.
+@warning_for_keywords()
+def multi_tensor(
+    gtab,
+    mevals,
+    *,
+    S0=1.0,
+    angles=((0, 0), (90, 0)),
+    fractions=(50, 50),
+    snr=20,
+    rng=None,
+):
+    r"""Simulate a Multi-Tensor signal.
 
     Parameters
     ----------
@@ -408,6 +437,9 @@ def multi_tensor(gtab, mevals, S0=1., angles=((0, 0), (90, 0)),
     snr : float, optional
         Signal to noise ratio, assuming Rician noise.  If set to None, no
         noise is added.
+    rng : numpy.random.Generator, optional
+        Random number generator for the noise. If ``None``, uses NumPy's default
+        random generator.
 
     Returns
     -------
@@ -423,9 +455,9 @@ def multi_tensor(gtab, mevals, S0=1., angles=((0, 0), (90, 0)),
     >>> from dipy.data import get_fnames
     >>> from dipy.core.gradients import gradient_table
     >>> from dipy.io.gradients import read_bvals_bvecs
-    >>> fimg, fbvals, fbvecs = get_fnames('small_101D')
+    >>> fimg, fbvals, fbvecs = get_fnames(name='small_101D')
     >>> bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
-    >>> gtab = gradient_table(bvals, bvecs)
+    >>> gtab = gradient_table(bvals, bvecs=bvecs)
     >>> mevals=np.array(([0.0015, 0.0003, 0.0003],[0.0015, 0.0003, 0.0003]))
     >>> e0 = np.array([1, 0, 0.])
     >>> e1 = np.array([0., 1, 0])
@@ -436,41 +468,52 @@ def multi_tensor(gtab, mevals, S0=1., angles=((0, 0), (90, 0)),
         rng = np.random.default_rng()
 
     if np.round(np.sum(fractions), 2) != 100.0:
-        raise ValueError('Fractions should sum to 100')
+        raise ValueError("Fractions should sum to 100")
 
-    fractions = [f / 100. for f in fractions]
+    fractions = [f / 100.0 for f in fractions]
 
     S = np.zeros(len(gtab.bvals))
 
     sticks = _check_directions(angles)
 
     for i in range(len(fractions)):
-            S = S + fractions[i] * single_tensor(gtab, S0=S0, evals=mevals[i],
-                                                 evecs=all_tensor_evecs(
-                                                     sticks[i]), snr=None)
+        S = S + fractions[i] * single_tensor(
+            gtab, S0=S0, evals=mevals[i], evecs=all_tensor_evecs(sticks[i]), snr=None
+        )
 
     return add_noise(S, snr, S0, rng=rng), sticks
 
 
-def multi_tensor_dki(gtab, mevals, S0=1., angles=((90., 0.), (90., 0.)),
-                     fractions=(50, 50), snr=20):
-    r""" Simulate the diffusion-weight signal, diffusion and kurtosis tensors
+@warning_for_keywords()
+def multi_tensor_dki(
+    gtab,
+    mevals,
+    *,
+    S0=1.0,
+    angles=((90.0, 0.0), (90.0, 0.0)),
+    fractions=(50, 50),
+    snr=20,
+):
+    r"""Simulate the diffusion-weight signal, diffusion and kurtosis tensors
     based on the DKI model
 
+    See :footcite:p:`NetoHenriques2015` for further details.
+
     Parameters
     ----------
     gtab : GradientTable
+        Gradient table.
     mevals : array (K, 3)
         eigenvalues of the diffusion tensor for each individual compartment
-    S0 : float (optional)
+    S0 : float, optional
         Unweighted signal value (b0 signal).
-    angles : array (K,2) or (K,3) (optional)
+    angles : array (K,2) or (K,3), optional
         List of K tensor directions of the diffusion tensor of each compartment
         in polar angles (in degrees) or unit vectors
-    fractions : float (K,) (optional)
+    fractions : float (K,), optional
         Percentage of the contribution of each tensor. The sum of fractions
         should be equal to 100%.
-    snr : float (optional)
+    snr : float, optional
         Signal to noise ratio, assuming Rician noise.  If set to None, no
         noise is added.
 
@@ -498,26 +541,23 @@ def multi_tensor_dki(gtab, mevals, S0=1., angles=((90., 0.), (90., 0.)),
     >>> from dipy.data import get_fnames
     >>> from dipy.core.gradients import gradient_table
     >>> from dipy.io.gradients import read_bvals_bvecs
-    >>> fimg, fbvals, fbvecs = get_fnames('small_64D')
+    >>> fimg, fbvals, fbvecs = get_fnames(name='small_64D')
     >>> bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
     >>> bvals_2s = np.concatenate((bvals, bvals * 2), axis=0)
     >>> bvecs_2s = np.concatenate((bvecs, bvecs), axis=0)
-    >>> gtab = gradient_table(bvals_2s, bvecs_2s)
+    >>> gtab = gradient_table(bvals_2s, bvecs=bvecs_2s)
     >>> mevals = np.array([[0.00099, 0, 0],[0.00226, 0.00087, 0.00087]])
     >>> S, dt, kt =  multi_tensor_dki(gtab, mevals)
 
     References
     ----------
-    .. [1] R. Neto Henriques et al., "Exploring the 3D geometry of the
-           diffusion kurtosis tensor - Impact on the development of robust
-           tractography procedures and novel biomarkers", NeuroImage (2015)
-           111, 85-99.
+    .. footbibliography::
 
     """
     if np.round(np.sum(fractions), 2) != 100.0:
-        raise ValueError('Fractions should sum to 100')
+        raise ValueError("Fractions should sum to 100")
 
-    fractions = [f / 100. for f in fractions]
+    fractions = [f / 100.0 for f in fractions]
 
     # S = np.zeros(len(gtab.bvals))
 
@@ -532,7 +572,7 @@ def multi_tensor_dki(gtab, mevals, S0=1., angles=((90., 0.), (90., 0.)),
     # compute voxel's DT
     DT = np.zeros((3, 3))
     for i in range(len(fractions)):
-        DT = DT + fractions[i]*D_comps[i]
+        DT = DT + fractions[i] * D_comps[i]
     dt = np.array([DT[0][0], DT[0][1], DT[1][1], DT[0][2], DT[1][2], DT[2][2]])
 
     # compute voxel's MD
@@ -540,31 +580,31 @@ def multi_tensor_dki(gtab, mevals, S0=1., angles=((90., 0.), (90., 0.)),
 
     # compute voxel's KT
     kt = np.zeros(15)
-    kt[0] = kurtosis_element(D_comps, fractions, 0, 0, 0, 0, DT, MD)
-    kt[1] = kurtosis_element(D_comps, fractions, 1, 1, 1, 1, DT, MD)
-    kt[2] = kurtosis_element(D_comps, fractions, 2, 2, 2, 2, DT, MD)
-    kt[3] = kurtosis_element(D_comps, fractions, 0, 0, 0, 1, DT, MD)
-    kt[4] = kurtosis_element(D_comps, fractions, 0, 0, 0, 2, DT, MD)
-    kt[5] = kurtosis_element(D_comps, fractions, 0, 1, 1, 1, DT, MD)
-    kt[6] = kurtosis_element(D_comps, fractions, 1, 1, 1, 2, DT, MD)
-    kt[7] = kurtosis_element(D_comps, fractions, 0, 2, 2, 2, DT, MD)
-    kt[8] = kurtosis_element(D_comps, fractions, 1, 2, 2, 2, DT, MD)
-    kt[9] = kurtosis_element(D_comps, fractions, 0, 0, 1, 1, DT, MD)
-    kt[10] = kurtosis_element(D_comps, fractions, 0, 0, 2, 2, DT, MD)
-    kt[11] = kurtosis_element(D_comps, fractions, 1, 1, 2, 2, DT, MD)
-    kt[12] = kurtosis_element(D_comps, fractions, 0, 0, 1, 2, DT, MD)
-    kt[13] = kurtosis_element(D_comps, fractions, 0, 1, 1, 2, DT, MD)
-    kt[14] = kurtosis_element(D_comps, fractions, 0, 1, 2, 2, DT, MD)
+    kt[0] = kurtosis_element(D_comps, fractions, 0, 0, 0, 0, DT=DT, MD=MD)
+    kt[1] = kurtosis_element(D_comps, fractions, 1, 1, 1, 1, DT=DT, MD=MD)
+    kt[2] = kurtosis_element(D_comps, fractions, 2, 2, 2, 2, DT=DT, MD=MD)
+    kt[3] = kurtosis_element(D_comps, fractions, 0, 0, 0, 1, DT=DT, MD=MD)
+    kt[4] = kurtosis_element(D_comps, fractions, 0, 0, 0, 2, DT=DT, MD=MD)
+    kt[5] = kurtosis_element(D_comps, fractions, 0, 1, 1, 1, DT=DT, MD=MD)
+    kt[6] = kurtosis_element(D_comps, fractions, 1, 1, 1, 2, DT=DT, MD=MD)
+    kt[7] = kurtosis_element(D_comps, fractions, 0, 2, 2, 2, DT=DT, MD=MD)
+    kt[8] = kurtosis_element(D_comps, fractions, 1, 2, 2, 2, DT=DT, MD=MD)
+    kt[9] = kurtosis_element(D_comps, fractions, 0, 0, 1, 1, DT=DT, MD=MD)
+    kt[10] = kurtosis_element(D_comps, fractions, 0, 0, 2, 2, DT=DT, MD=MD)
+    kt[11] = kurtosis_element(D_comps, fractions, 1, 1, 2, 2, DT=DT, MD=MD)
+    kt[12] = kurtosis_element(D_comps, fractions, 0, 0, 1, 2, DT=DT, MD=MD)
+    kt[13] = kurtosis_element(D_comps, fractions, 0, 1, 1, 2, DT=DT, MD=MD)
+    kt[14] = kurtosis_element(D_comps, fractions, 0, 1, 2, 2, DT=DT, MD=MD)
 
     # compute S based on the DT and KT
-    S = dki_signal(gtab, dt, kt, S0, snr)
+    S = dki_signal(gtab, dt, kt, S0=S0, snr=snr)
 
     return S, dt, kt
 
 
-def kurtosis_element(D_comps, frac, ind_i, ind_j, ind_k, ind_l, DT=None,
-                     MD=None):
-    r""" Computes the diffusion kurtosis tensor element (with indexes i, j, k
+@warning_for_keywords()
+def kurtosis_element(D_comps, frac, ind_i, ind_j, ind_k, ind_l, *, DT=None, MD=None):
+    r"""Computes the diffusion kurtosis tensor element (with indexes i, j, k
     and l) based on the individual diffusion tensor components of a
     multicompartmental model.
 
@@ -584,32 +624,30 @@ def kurtosis_element(D_comps, frac, ind_i, ind_j, ind_k, ind_l, DT=None,
         Element's index k (0 for x, 1 for y, 2 for z)
     ind_l: int
         Elements index l (0 for x, 1 for y, 2 for z)
-    DT : (3,3) ndarray (optional)
+    DT : (3,3) ndarray, optional
         Voxel's global diffusion tensor.
-    MD : float (optional)
+    MD : float, optional
         Voxel's global mean diffusivity.
 
     Returns
     -------
     wijkl : float
-            kurtosis tensor element of index i, j, k, l
+        kurtosis tensor element of index i, j, k, l
 
     Notes
     -----
-    wijkl is calculated using equation 8 given in [1]_
+    wijkl is calculated using equation 8 given in
+    :footcite:p:`NetoHenriques2015`.
 
     References
     ----------
-    .. [1] R. Neto Henriques et al., "Exploring the 3D geometry of the
-           diffusion kurtosis tensor - Impact on the development of robust
-           tractography procedures and novel biomarkers", NeuroImage (2015)
-           111, 85-99.
+    .. footbibliography::
 
     """
     if DT is None:
         DT = np.zeros((3, 3))
         for i in range(len(frac)):
-            DT = DT + frac[i]*D_comps[i]
+            DT = DT + frac[i] * D_comps[i]
 
     if MD is None:
         MD = (DT[0][0] + DT[1][1] + DT[2][2]) / 3
@@ -618,22 +656,29 @@ def kurtosis_element(D_comps, frac, ind_i, ind_j, ind_k, ind_l, DT=None,
 
     for f in range(len(frac)):
         wijkl = wijkl + frac[f] * (
-                D_comps[f][ind_i][ind_j]*D_comps[f][ind_k][ind_l] +
-                D_comps[f][ind_i][ind_k]*D_comps[f][ind_j][ind_l] +
-                D_comps[f][ind_i][ind_l]*D_comps[f][ind_j][ind_k])
+            D_comps[f][ind_i][ind_j] * D_comps[f][ind_k][ind_l]
+            + D_comps[f][ind_i][ind_k] * D_comps[f][ind_j][ind_l]
+            + D_comps[f][ind_i][ind_l] * D_comps[f][ind_j][ind_k]
+        )
 
-    wijkl = (wijkl - DT[ind_i][ind_j]*DT[ind_k][ind_l] -
-             DT[ind_i][ind_k]*DT[ind_j][ind_l] -
-             DT[ind_i][ind_l]*DT[ind_j][ind_k]) / (MD**2)
+    wijkl = (
+        wijkl
+        - DT[ind_i][ind_j] * DT[ind_k][ind_l]
+        - DT[ind_i][ind_k] * DT[ind_j][ind_l]
+        - DT[ind_i][ind_l] * DT[ind_j][ind_k]
+    ) / (MD**2)
 
     return wijkl
 
 
-def dki_signal(gtab, dt, kt, S0=150, snr=None):
-    r""" Simulated signal based on the diffusion and diffusion kurtosis
+@warning_for_keywords()
+def dki_signal(gtab, dt, kt, *, S0=150, snr=None):
+    r"""Simulated signal based on the diffusion and diffusion kurtosis
     tensors of a single voxel. Simulations are performed assuming the DKI
     model.
 
+    See :footcite:p:`NetoHenriques2015` for further details.
+
     Parameters
     ----------
     gtab : GradientTable
@@ -642,9 +687,9 @@ def dki_signal(gtab, dt, kt, S0=150, snr=None):
         Elements of the diffusion tensor.
     kt : (15, ) ndarray
         Elements of the diffusion kurtosis tensor.
-    S0 : float (optional)
+    S0 : float, optional
         Strength of signal in the presence of no diffusion gradient.
-    snr : float (optional)
+    snr : float, optional
         Signal to noise ratio, assuming Rician noise.  None implies no noise.
 
     Returns
@@ -658,10 +703,7 @@ def dki_signal(gtab, dt, kt, S0=150, snr=None):
 
     References
     ----------
-    .. [1] R. Neto Henriques et al., "Exploring the 3D geometry of the
-           diffusion kurtosis tensor - Impact on the development of robust
-           tractography procedures and novel biomarkers", NeuroImage (2015)
-           111, 85-99.
+    .. footbibliography::
 
     """
     dt = np.array(dt)
@@ -671,7 +713,7 @@ def dki_signal(gtab, dt, kt, S0=150, snr=None):
 
     # define vector of DKI parameters
     MD = (dt[0] + dt[2] + dt[5]) / 3
-    X = np.concatenate((dt, kt*MD*MD, np.array([-np.log(S0)])), axis=0)
+    X = np.concatenate((dt, kt * MD * MD, np.array([-np.log(S0)])), axis=0)
 
     # Compute signals based on the DKI model
     S = np.exp(dot(A, X))
@@ -681,8 +723,11 @@ def dki_signal(gtab, dt, kt, S0=150, snr=None):
     return S
 
 
-def single_tensor_odf(r, evals=None, evecs=None):
-    """ Simulated ODF with a single tensor.
+@warning_for_keywords()
+def single_tensor_odf(r, *, evals=None, evecs=None):
+    """Simulated ODF with a single tensor.
+
+    See :footcite:p:`Aganj2010` for further details.
 
     Parameters
     ----------
@@ -703,10 +748,7 @@ def single_tensor_odf(r, evals=None, evecs=None):
 
     References
     ----------
-    .. [1] Aganj et al., "Reconstruction of the Orientation Distribution
-           Function in Single- and Multiple-Shell q-Ball Imaging Within
-           Constant Solid Angle", Magnetic Resonance in Medicine, nr. 64,
-           pp. 554--566, 2010.
+    .. footbibliography::
 
     """
     if evals is None:
@@ -715,14 +757,14 @@ def single_tensor_odf(r, evals=None, evecs=None):
     if evecs is None:
         evecs = np.eye(3)
 
-    out_shape = r.shape[:r.ndim - 1]
+    out_shape = r.shape[: r.ndim - 1]
 
     R = np.asarray(evecs)
     D = dot(dot(R, np.diag(evals)), R.T)
     Di = np.linalg.inv(D)
     r = r.reshape(-1, 3)
     P = np.zeros(len(r))
-    for (i, u) in enumerate(r):
+    for i, u in enumerate(r):
         P[i] = (dot(dot(u.T, Di), u)) ** (3 / 2)
 
     return (1 / (4 * np.pi * np.prod(evals) ** (1 / 2) * P)).reshape(out_shape)
@@ -785,7 +827,7 @@ def multi_tensor_odf(odf_verts, mevals, angles, fractions):
     >>> odf = multi_tensor_odf(vertices, mevals, angles, [50, 50])
 
     """
-    mf = [f / 100. for f in fractions]
+    mf = [f / 100.0 for f in fractions]
 
     sticks = _check_directions(angles)
 
@@ -795,21 +837,23 @@ def multi_tensor_odf(odf_verts, mevals, angles, fractions):
     for s in sticks:
         mevecs += [all_tensor_evecs(s)]
 
-    for (j, f) in enumerate(mf):
-        odf += f * single_tensor_odf(odf_verts,
-                                     evals=mevals[j], evecs=mevecs[j])
+    for j, f in enumerate(mf):
+        odf += f * single_tensor_odf(odf_verts, evals=mevals[j], evecs=mevecs[j])
     return odf
 
 
-def single_tensor_rtop(evals=None, tau=1.0 / (4 * np.pi ** 2)):
+@warning_for_keywords()
+def single_tensor_rtop(*, evals=None, tau=1.0 / (4 * np.pi**2)):
     """Simulate a Single-Tensor rtop.
 
+    See :footcite:p:`Cheng2012` for further details.
+
     Parameters
     ----------
-    evals : 1D arrays,
+    evals : 1D arrays, optional
         Eigen-values for the tensor.  By default, values typical for prolate
         white matter are used.
-    tau : float,
+    tau : float, optional
         diffusion time. By default the value that makes q=sqrt(b).
 
     Returns
@@ -819,8 +863,7 @@ def single_tensor_rtop(evals=None, tau=1.0 / (4 * np.pi ** 2)):
 
     References
     ----------
-    .. [1] Cheng J., "Estimation and Processing of Ensemble Average Propagator
-           and Its Features in Diffusion MRI", PhD Thesis, 2012.
+    .. footbibliography::
 
     """
     if evals is None:
@@ -830,17 +873,20 @@ def single_tensor_rtop(evals=None, tau=1.0 / (4 * np.pi ** 2)):
     return rtop
 
 
-def multi_tensor_rtop(mf, mevals=None, tau=1 / (4 * np.pi ** 2)):
+@warning_for_keywords()
+def multi_tensor_rtop(mf, *, mevals=None, tau=1 / (4 * np.pi**2)):
     """Simulate a Multi-Tensor rtop.
 
+    See :footcite:p:`Cheng2012` for further details.
+
     Parameters
     ----------
     mf : sequence of floats, bounded [0,1]
         Percentages of the fractions for each tensor.
-    mevals : sequence of 1D arrays,
+    mevals : sequence of 1D arrays, optional
         Eigen-values for each tensor.  By default, values typical for prolate
         white matter are used.
-    tau : float,
+    tau : float, optional
         diffusion time. By default the value that makes q=sqrt(b).
 
     Returns
@@ -850,35 +896,39 @@ def multi_tensor_rtop(mf, mevals=None, tau=1 / (4 * np.pi ** 2)):
 
     References
     ----------
-    .. [1] Cheng J., "Estimation and Processing of Ensemble Average Propagator
-           and Its Features in Diffusion MRI", PhD Thesis, 2012.
+    .. footbibliography::
 
     """
     rtop = 0
 
     if mevals is None:
-        mevals = [None, ] * len(mf)
+        mevals = [
+            None,
+        ] * len(mf)
 
     for j, f in enumerate(mf):
-        rtop += f * single_tensor_rtop(mevals[j], tau=tau)
+        rtop += f * single_tensor_rtop(evals=mevals[j], tau=tau)
     return rtop
 
 
-def single_tensor_pdf(r, evals=None, evecs=None, tau=1 / (4 * np.pi ** 2)):
+@warning_for_keywords()
+def single_tensor_pdf(r, *, evals=None, evecs=None, tau=1 / (4 * np.pi**2)):
     """Simulated ODF with a single tensor.
 
+    See :footcite:p:`Cheng2012` for further details.
+
     Parameters
     ----------
     r : (N,3) or (M,N,3) ndarray
         Measurement positions in (x, y, z), either as a list or on a grid.
-    evals : (3,)
+    evals : (3,), optional
         Eigenvalues of diffusion tensor.  By default, use values typical for
         prolate white matter.
-    evecs : (3, 3) ndarray
+    evecs : (3, 3) ndarray, optional
         Eigenvectors of the tensor.  You can also think of these as the
         rotation matrix that determines the orientation of the diffusion
         tensor.
-    tau : float,
+    tau : float, optional
         diffusion time. By default the value that makes q=sqrt(b).
 
 
@@ -889,8 +939,7 @@ def single_tensor_pdf(r, evals=None, evecs=None, tau=1 / (4 * np.pi ** 2)):
 
     References
     ----------
-    .. [1] Cheng J., "Estimation and Processing of Ensemble Average Propagator
-           and Its Features in Diffusion MRI", PhD Thesis, 2012.
+    .. footbibliography::
 
     """
     if evals is None:
@@ -899,14 +948,14 @@ def single_tensor_pdf(r, evals=None, evecs=None, tau=1 / (4 * np.pi ** 2)):
     if evecs is None:
         evecs = np.eye(3)
 
-    out_shape = r.shape[:r.ndim - 1]
+    out_shape = r.shape[: r.ndim - 1]
 
     R = np.asarray(evecs)
     D = dot(dot(R, np.diag(evals)), R.T)
     Di = np.linalg.inv(D)
     r = r.reshape(-1, 3)
     P = np.zeros(len(r))
-    for (i, u) in enumerate(r):
+    for i, u in enumerate(r):
         P[i] = (-dot(dot(u.T, Di), u)) / (4 * tau)
 
     pdf = (1 / np.sqrt((4 * np.pi * tau) ** 3 * np.prod(evals))) * np.exp(P)
@@ -914,10 +963,12 @@ def single_tensor_pdf(r, evals=None, evecs=None, tau=1 / (4 * np.pi ** 2)):
     return pdf.reshape(out_shape)
 
 
-def multi_tensor_pdf(pdf_points, mevals, angles, fractions,
-                     tau=1 / (4 * np.pi ** 2)):
+@warning_for_keywords()
+def multi_tensor_pdf(pdf_points, mevals, angles, fractions, *, tau=1 / (4 * np.pi**2)):
     """Simulate a Multi-Tensor ODF.
 
+    See :footcite:p:`Cheng2012` for further details.
+
     Parameters
     ----------
     pdf_points : (N, 3) ndarray
@@ -930,7 +981,7 @@ def multi_tensor_pdf(pdf_points, mevals, angles, fractions,
         or cartesian unit coordinates.
     fractions : sequence of floats,
         Percentages of the fractions for each tensor.
-    tau : float,
+    tau : float, optional
         diffusion time. By default the value that makes q=sqrt(b).
 
     Returns
@@ -940,11 +991,10 @@ def multi_tensor_pdf(pdf_points, mevals, angles, fractions,
 
     References
     ----------
-    .. [1] Cheng J., "Estimation and Processing of Ensemble Average Propagator
-           and its Features in Diffusion MRI", PhD Thesis, 2012.
+    .. footbibliography::
 
     """
-    mf = [f / 100. for f in fractions]
+    mf = [f / 100.0 for f in fractions]
 
     sticks = _check_directions(angles)
 
@@ -955,20 +1005,24 @@ def multi_tensor_pdf(pdf_points, mevals, angles, fractions,
         mevecs += [all_tensor_evecs(s)]
 
     for j, f in enumerate(mf):
-        pdf += f * single_tensor_pdf(pdf_points,
-                                     evals=mevals[j], evecs=mevecs[j], tau=tau)
+        pdf += f * single_tensor_pdf(
+            pdf_points, evals=mevals[j], evecs=mevecs[j], tau=tau
+        )
     return pdf
 
 
-def single_tensor_msd(evals=None, tau=1 / (4 * np.pi ** 2)):
+@warning_for_keywords()
+def single_tensor_msd(*, evals=None, tau=1 / (4 * np.pi**2)):
     """Simulate a Multi-Tensor rtop.
 
+    See :footcite:p:`Cheng2012` for further details.
+
     Parameters
     ----------
-    evals : 1D arrays,
+    evals : 1D arrays, optional
         Eigen-values for the tensor.  By default, values typical for prolate
         white matter are used.
-    tau : float,
+    tau : float, optional
         diffusion time. By default the value that makes q=sqrt(b).
 
     Returns
@@ -978,8 +1032,7 @@ def single_tensor_msd(evals=None, tau=1 / (4 * np.pi ** 2)):
 
     References
     ----------
-    .. [1] Cheng J., "Estimation and Processing of Ensemble Average Propagator
-           and Its Features in Diffusion MRI", PhD Thesis, 2012.
+    .. footbibliography::
 
     """
     if evals is None:
@@ -989,17 +1042,20 @@ def single_tensor_msd(evals=None, tau=1 / (4 * np.pi ** 2)):
     return msd
 
 
-def multi_tensor_msd(mf, mevals=None, tau=1 / (4 * np.pi ** 2)):
+@warning_for_keywords()
+def multi_tensor_msd(mf, *, mevals=None, tau=1 / (4 * np.pi**2)):
     """Simulate a Multi-Tensor rtop.
 
+    See :footcite:p:`Cheng2012` for further details.
+
     Parameters
     ----------
     mf : sequence of floats, bounded [0,1]
         Percentages of the fractions for each tensor.
-    mevals : sequence of 1D arrays,
+    mevals : sequence of 1D arrays, optional
         Eigen-values for each tensor.  By default, values typical for prolate
         white matter are used.
-    tau : float,
+    tau : float, optional
         diffusion time. By default the value that makes q=sqrt(b).
 
     Returns
@@ -1009,15 +1065,16 @@ def multi_tensor_msd(mf, mevals=None, tau=1 / (4 * np.pi ** 2)):
 
     References
     ----------
-    .. [1] Cheng J., "Estimation and Processing of Ensemble Average Propagator
-           and Its Features in Diffusion MRI", PhD Thesis, 2012.
+    .. footbibliography::
 
     """
     msd = 0
 
     if mevals is None:
-        mevals = [None, ] * len(mf)
+        mevals = [
+            None,
+        ] * len(mf)
 
     for j, f in enumerate(mf):
-        msd += f * single_tensor_msd(mevals[j], tau=tau)
+        msd += f * single_tensor_msd(evals=mevals[j], tau=tau)
     return msd
