@@ -1,7 +1,7 @@
 import numpy as np
 import numpy.testing as npt
 
-from dipy.stats.analysis import (gaussian_weights, afq_profile)
+from dipy.stats.analysis import afq_profile, gaussian_weights
 from dipy.tracking.streamline import Streamlines
 
 
@@ -13,8 +13,7 @@ def test_gaussian_weights():
 
     # Create a distribution for which we can predict the weights we would
     # expect to get:
-    bundle = Streamlines([np.array([x, y, z]).T + 1,
-                          np.array([x, y, z]).T - 1])
+    bundle = Streamlines([np.array([x, y, z]).T + 1, np.array([x, y, z]).T - 1])
     # In this case, all nodes receives an equal weight of 0.5:
     w = gaussian_weights(bundle, n_points=10)
     npt.assert_almost_equal(w, np.ones((len(bundle), 10)) * 0.5)
@@ -24,10 +23,14 @@ def test_gaussian_weights():
     npt.assert_almost_equal(w, np.ones((len(bundle), 10)))
 
     # Here, some nodes are twice as far from the mean as others
-    bundle = Streamlines([np.array([x, y, z]).T + 2,
-                          np.array([x, y, z]).T + 1,
-                          np.array([x, y, z]).T - 1,
-                          np.array([x, y, z]).T - 2])
+    bundle = Streamlines(
+        [
+            np.array([x, y, z]).T + 2,
+            np.array([x, y, z]).T + 1,
+            np.array([x, y, z]).T - 1,
+            np.array([x, y, z]).T - 2,
+        ]
+    )
     w = gaussian_weights(bundle, n_points=10)
 
     # And their weights should be halved:
@@ -49,15 +52,15 @@ def test_gaussian_weights():
     w = gaussian_weights(Streamlines(bundle_w_id_node), n_points=10)
     # For this case, the result should be a weight of 1/n_streamlines in that
     # node for all streamlines:
-    npt.assert_equal(w[:, 0],
-                     np.ones(len(bundle_w_id_node)) * 1/len(bundle_w_id_node))
+    npt.assert_equal(
+        w[:, 0], np.ones(len(bundle_w_id_node)) * 1 / len(bundle_w_id_node)
+    )
 
     # Test the situation where all the streamlines are copies of each other:
     bundle_w_copies = Streamlines([bundle[0], bundle[0], bundle[0], bundle[0]])
     w = gaussian_weights(bundle_w_copies, n_points=10)
     # In this case, the entire array should be equal to 1/n_streamlines:
-    npt.assert_equal(w,
-                     np.ones(w.shape) * 1/len(bundle_w_id_node))
+    npt.assert_equal(w, np.ones(w.shape) * 1 / len(bundle_w_id_node))
 
     # Test with bundle of length 1:
     bundle_len_1 = Streamlines([bundle[0]])
@@ -72,57 +75,60 @@ def test_gaussian_weights():
 def test_afq_profile():
     data = np.ones((10, 10, 10))
     bundle = Streamlines()
-    bundle.extend(np.array([[[0, 0., 0],
-                             [1, 0., 0.],
-                             [2, 0., 0.]]]))
-    bundle.extend(np.array([[[0, 0., 0.],
-                             [1, 0., 0],
-                             [2, 0,  0.]]]))
+    bundle.extend(np.array([[[0, 0.0, 0], [1, 0.0, 0.0], [2, 0.0, 0.0]]]))
+    bundle.extend(np.array([[[0, 0.0, 0.0], [1, 0.0, 0], [2, 0, 0.0]]]))
 
     profile = afq_profile(data, bundle, np.eye(4))
     npt.assert_equal(profile, np.ones(100))
 
-    profile = afq_profile(data, bundle, np.eye(4), n_points=10,
-                          weights=None)
+    profile = afq_profile(data, bundle, np.eye(4), n_points=10, weights=None)
     npt.assert_equal(profile, np.ones(10))
 
-    profile = afq_profile(data, bundle, np.eye(4),
-                          weights=gaussian_weights, stat=np.median)
+    profile = afq_profile(
+        data, bundle, np.eye(4), weights=gaussian_weights, stat=np.median
+    )
 
     npt.assert_equal(profile, np.ones(100))
 
-    profile = afq_profile(data, bundle, np.eye(4), orient_by=bundle[0],
-                          weights=gaussian_weights, stat=np.median)
+    profile = afq_profile(
+        data,
+        bundle,
+        np.eye(4),
+        orient_by=bundle[0],
+        weights=gaussian_weights,
+        stat=np.median,
+    )
 
     npt.assert_equal(profile, np.ones(100))
 
-    profile = afq_profile(data, bundle, np.eye(4), n_points=10,
-                          weights=None)
+    profile = afq_profile(data, bundle, np.eye(4), n_points=10, weights=None)
     npt.assert_equal(profile, np.ones(10))
 
-    profile = afq_profile(data, bundle, np.eye(4), n_points=10,
-                          weights=np.ones((2, 10)) * 0.5)
+    profile = afq_profile(
+        data, bundle, np.eye(4), n_points=10, weights=np.ones((2, 10)) * 0.5
+    )
     npt.assert_equal(profile, np.ones(10))
 
-    profile = afq_profile(data, bundle, np.eye(4), n_points=10,
-                          stat=np.median)
+    profile = afq_profile(data, bundle, np.eye(4), n_points=10, stat=np.median)
     npt.assert_equal(profile, np.ones(10))
 
     # Disallow setting weights that don't sum to 1 across fibers/nodes:
-    npt.assert_raises(ValueError, afq_profile,
-                      data, bundle, np.eye(4),
-                      n_points=10, weights=np.ones((2, 10)) * 0.6)
+    npt.assert_raises(
+        ValueError,
+        afq_profile,
+        data,
+        bundle,
+        np.eye(4),
+        n_points=10,
+        weights=np.ones((2, 10)) * 0.6,
+    )
 
     # Test using an affine:
     affine = np.eye(4)
     affine[:, 3] = [-1, 100, -20, 1]
     # Transform the streamlines:
     bundle._data = bundle._data + affine[:3, 3]
-    profile = afq_profile(data,
-                          bundle,
-                          affine,
-                          n_points=10,
-                          weights=None)
+    profile = afq_profile(data, bundle, affine, n_points=10, weights=None)
 
     npt.assert_equal(profile, np.ones(10))
 
