@@ -1,4 +1,4 @@
-""" Module to help tests check script output
+"""Module to help tests check script output
 
 Provides class to be instantiated in tests that check scripts.  Usually works
 something like this in a test module::
@@ -12,24 +12,23 @@ Then, in the tests, something like::
     assert_equal(code, 0)
     assert_equal(stdout, b'This script ran OK')
 """
-import sys
-import os
-from os.path import (dirname, join as pjoin, isfile, isdir, realpath, pathsep)
 
-from subprocess import Popen, PIPE
+import os
+from os.path import dirname, isdir, isfile, join as pjoin, pathsep, realpath
+from subprocess import PIPE, Popen
+import sys
 
 try:  # Python 2
-    string_types = basestring,
+    string_types = (basestring,)
 except NameError:  # Python 3
-    string_types = str,
+    string_types = (str,)
 
 
 def _get_package():
-    """ Workaround for missing ``__package__`` in Python 3.2
-    """
-    if '__package__' in globals() and __package__ is not None:
+    """Workaround for missing ``__package__`` in Python 3.2"""
+    if "__package__" in globals() and __package__ is not None:
         return __package__
-    return __name__.split('.', 1)[0]
+    return __name__.split(".", 1)[0]
 
 
 # Same as __package__ for Python 2.6, 2.7 and >= 3.3
@@ -37,22 +36,20 @@ MY_PACKAGE = _get_package()
 
 
 def local_script_dir(script_sdir):
-    """ Get local script directory if running in development dir, else None
-    """
+    """Get local script directory if running in development dir, else None"""
     # Check for presence of scripts in development directory.  ``realpath``
     # allows for the situation where the development directory has been linked
     # into the path.
     package_path = dirname(__import__(MY_PACKAGE).__file__)
-    above_us = realpath(pjoin(package_path, '..'))
+    above_us = realpath(pjoin(package_path, ".."))
     devel_script_dir = pjoin(above_us, script_sdir)
-    if isfile(pjoin(above_us, 'setup.py')) and isdir(devel_script_dir):
+    if isfile(pjoin(above_us, "setup.py")) and isdir(devel_script_dir):
         return devel_script_dir
     return None
 
 
 def local_module_dir(module_name):
-    """ Get local module directory if running in development dir, else None
-    """
+    """Get local module directory if running in development dir, else None"""
     mod = __import__(module_name)
     containing_path = dirname(dirname(realpath(mod.__file__)))
     if containing_path == realpath(os.getcwd()):
@@ -61,18 +58,20 @@ def local_module_dir(module_name):
 
 
 class ScriptRunner:
-    """ Class to run scripts and return output
+    """Class to run scripts and return output
 
     Finds local scripts and local modules if running in the development
     directory, otherwise finds system scripts and modules.
     """
 
-    def __init__(self,
-                 script_sdir='scripts',
-                 module_sdir=MY_PACKAGE,
-                 debug_print_var=None,
-                 output_processor=lambda x: x):
-        """ Init ScriptRunner instance
+    def __init__(
+        self,
+        script_sdir="scripts",
+        module_sdir=MY_PACKAGE,
+        debug_print_var=None,
+        output_processor=lambda x: x,
+    ):
+        """Init ScriptRunner instance
 
         Parameters
         ----------
@@ -93,12 +92,12 @@ class ScriptRunner:
         self.local_script_dir = local_script_dir(script_sdir)
         self.local_module_dir = local_module_dir(module_sdir)
         if debug_print_var is None:
-            debug_print_var = '{0}_DEBUG_PRINT'.format(module_sdir.upper())
+            debug_print_var = f"{module_sdir.upper()}_DEBUG_PRINT"
         self.debug_print = os.environ.get(debug_print_var, False)
         self.output_processor = output_processor
 
     def run_command(self, cmd, check_code=True):
-        """ Run command sequence `cmd` returning exit code, stdout, stderr
+        """Run command sequence `cmd` returning exit code, stdout, stderr
 
         Parameters
         ----------
@@ -127,42 +126,42 @@ class ScriptRunner:
             # wrong incantation for the Python interpreter
             # in the hash bang first line in the source file. So, either way,
             # run the script through the Python interpreter
-            cmd = [sys.executable,
-                   pjoin(self.local_script_dir, cmd[0])] + cmd[1:]
-        elif os.name == 'nt':
+            cmd = [sys.executable, pjoin(self.local_script_dir, cmd[0])] + cmd[1:]
+        elif os.name == "nt":
             # Need .bat file extension for windows
-            cmd[0] += '.bat'
-        if os.name == 'nt':
+            cmd[0] += ".bat"
+        if os.name == "nt":
             # Quote any arguments with spaces. The quotes delimit the arguments
             # on Windows, and the arguments might be files paths with spaces.
             # On Unix the list elements are each separate arguments.
-            cmd = ['"{0}"'.format(c) if ' ' in c else c for c in cmd]
+            cmd = [f'"{c}"' if " " in c else c for c in cmd]
         if self.debug_print:
-            print("Running command '%s'" % cmd)
+            print(f"Running command '{cmd}'")
         env = os.environ
         if self.local_module_dir is not None:
             # module likely comes from the current working directory.
             # We might need that directory on the path if we're running
             # the scripts from a temporary directory
             env = env.copy()
-            pypath = env.get('PYTHONPATH', None)
+            pypath = env.get("PYTHONPATH", None)
             if pypath is None:
-                env['PYTHONPATH'] = self.local_module_dir
+                env["PYTHONPATH"] = self.local_module_dir
             else:
-                env['PYTHONPATH'] = self.local_module_dir + pathsep + pypath
+                env["PYTHONPATH"] = self.local_module_dir + pathsep + pypath
         proc = Popen(cmd, stdout=PIPE, stderr=PIPE, env=env)
         stdout, stderr = proc.communicate()
         if proc.poll() is None:
             proc.terminate()
         if check_code and proc.returncode != 0:
             raise RuntimeError(
-                """Command "{0}" failed with
+                f"""Command "{cmd}" failed with
                 stdout
                 ------
-                {1}
+                {stdout}
                 stderr
                 ------
-                {2}
-                """.format(cmd, stdout, stderr))
+                {stderr}
+                """
+            )
         opp = self.output_processor
         return proc.returncode, opp(stdout), opp(stderr)
