@@ -36,7 +36,7 @@ def _mapping_to_voxel(affine):
     affine = np.array(affine, dtype=float)
     inv_affine = np.linalg.inv(affine)
     lin_T = inv_affine[:3, :3].T.copy()
-    offset = inv_affine[:3, 3] + .5
+    offset = inv_affine[:3, 3] + 0.5
 
     return lin_T, offset
 
@@ -47,6 +47,5 @@ def _to_voxel_coordinates(streamline, lin_T, offset):
     inds = np.dot(streamline, lin_T)
     inds += offset
     if inds.min().round(decimals=6) < 0:
-        raise IndexError('streamline has points that map to negative voxel'
-                         ' indices')
+        raise IndexError("streamline has points that map to negative voxel" " indices")
     return inds.astype(np.intp)
