@@ -1,21 +1,23 @@
 """
 This is an implementation of the Linear Fascicle Evaluation (LiFE) algorithm
-described in:
+described in :footcite:p:`Pestilli2014`.
 
-Pestilli, F., Yeatman, J, Rokem, A. Kay, K. and Wandell B.A. (2014). Validation
-and statistical inference in living connectomes. Nature Methods 11:
-1058-1063. doi:10.1038/nmeth.3098
+References
+----------
+.. footbibliography::
 """
-import numpy as np
-import scipy.sparse as sps
-import scipy.linalg as la
 
-from dipy.reconst.base import ReconstModel, ReconstFit
-from dipy.tracking.utils import unique_rows
-from dipy.tracking.streamline import transform_streamlines
-from dipy.tracking.vox2track import _voxel2streamline
-import dipy.data as dpd
+import numpy as np
+import scipy.linalg as la
+import scipy.sparse as sps
+
 import dipy.core.optimize as opt
+import dipy.data as dpd
+from dipy.reconst.base import ReconstFit, ReconstModel
+from dipy.testing.decorators import warning_for_keywords
+from dipy.tracking.streamline import transform_streamlines
+from dipy.tracking.utils import unique_rows
+from dipy.tracking.vox2track import _voxel2streamline
 
 
 def gradient(f):
@@ -57,15 +59,15 @@ def gradient(f):
     """
     f = np.asanyarray(f)
     N = len(f.shape)  # number of dimensions
-    dx = [1.0]*N
+    dx = [1.0] * N
 
     # use central differences on interior and first differences on endpoints
     outvals = []
 
     # create slice objects --- initially all are [:, :, ..., :]
-    slice1 = [slice(None)]*N
-    slice2 = [slice(None)]*N
-    slice3 = [slice(None)]*N
+    slice1 = [slice(None)] * N
+    slice2 = [slice(None)] * N
+    slice3 = [slice(None)] * N
 
     for axis in range(N):
         # select out appropriate parts for this dimension
@@ -75,17 +77,17 @@ def gradient(f):
         slice3[axis] = slice(None, -2)
 
         # 1D equivalent -- out[1:-1] = (f[2:] - f[:-2])/2.0
-        out[tuple(slice1)] = (f[tuple(slice2)] - f[tuple(slice3)])/2.0
+        out[tuple(slice1)] = (f[tuple(slice2)] - f[tuple(slice3)]) / 2.0
         slice1[axis] = 0
         slice2[axis] = 1
         slice3[axis] = 0
         # 1D equivalent -- out[0] = (f[1] - f[0])
-        out[tuple(slice1)] = (f[tuple(slice2)] - f[tuple(slice3)])
+        out[tuple(slice1)] = f[tuple(slice2)] - f[tuple(slice3)]
         slice1[axis] = -1
         slice2[axis] = -1
         slice3[axis] = -2
         # 1D equivalent -- out[-1] = (f[-1] - f[-2])
-        out[tuple(slice1)] = (f[tuple(slice2)] - f[tuple(slice3)])
+        out[tuple(slice1)] = f[tuple(slice2)] - f[tuple(slice3)]
 
         # divide by step size
         outvals.append(out / dx[axis])
@@ -140,7 +142,8 @@ def grad_tensor(grad, evals):
     return T
 
 
-def streamline_tensors(streamline, evals=(0.001, 0, 0)):
+@warning_for_keywords()
+def streamline_tensors(streamline, *, evals=(0.001, 0, 0)):
     """
     The tensors generated by this fiber.
 
@@ -173,22 +176,25 @@ def streamline_tensors(streamline, evals=(0.001, 0, 0)):
     return tensors
 
 
-def streamline_signal(streamline, gtab, evals=(0.001, 0, 0)):
+@warning_for_keywords()
+def streamline_signal(streamline, gtab, *, evals=(0.001, 0, 0)):
     """
     The signal from a single streamline estimate along each of its nodes.
 
     Parameters
     ----------
     streamline : a single streamline
+        Streamline data.
 
     gtab : GradientTable class instance
+        Gradient table.
 
     evals : array-like of length 3, optional
         The eigenvalues of the canonical tensor used as an estimate of the
         signal generated by each node of the streamline.
     """
     # Gotta have those tensors:
-    tensors = streamline_tensors(streamline, evals)
+    tensors = streamline_tensors(streamline, evals=evals)
     sig = np.empty((len(streamline), np.sum(~gtab.b0s_mask)))
     # Extract them once:
     bvecs = gtab.bvecs[~gtab.b0s_mask]
@@ -206,7 +212,8 @@ class LifeSignalMaker:
     manner.
     """
 
-    def __init__(self, gtab, evals=(0.001, 0, 0), sphere=None):
+    @warning_for_keywords()
+    def __init__(self, gtab, *, evals=(0.001, 0, 0), sphere=None):
         """
         Initialize a signal maker
 
@@ -231,8 +238,7 @@ class LifeSignalMaker:
         self.evals = evals
         # Initialize an empty dict to fill with signals for each of the sphere
         # vertices:
-        self.signal = np.empty((self.sphere.vertices.shape[0],
-                                np.sum(~gtab.b0s_mask)))
+        self.signal = np.empty((self.sphere.vertices.shape[0], np.sum(~gtab.b0s_mask)))
         # We'll need to keep track of what we've already calculated:
         self._calculated = []
 
@@ -261,7 +267,8 @@ class LifeSignalMaker:
         return sig_out
 
 
-def voxel2streamline(streamline, affine, unique_idx=None):
+@warning_for_keywords()
+def voxel2streamline(streamline, affine, *, unique_idx=None):
     """
     Maps voxels to streamlines and streamlines to voxels, for setting up
     the LiFE equations matrix
@@ -274,7 +281,7 @@ def voxel2streamline(streamline, affine, unique_idx=None):
     affine : array_like (4, 4)
         The mapping from voxel coordinates to streamline points.
         The voxel_to_rasmm matrix, typically from a NIFTI file.
-    unique_idx : array (optional).
+    unique_idx : array, optional.
        The unique indices in the streamlines
 
     Returns
@@ -294,8 +301,7 @@ def voxel2streamline(streamline, affine, unique_idx=None):
         all_coords = np.concatenate(transformed_streamline)
         unique_idx = unique_rows(np.round(all_coords))
 
-    return _voxel2streamline(transformed_streamline,
-                             unique_idx.astype(np.intp))
+    return _voxel2streamline(transformed_streamline, unique_idx.astype(np.intp))
 
 
 class FiberModel(ReconstModel):
@@ -305,11 +311,12 @@ class FiberModel(ReconstModel):
 
     Notes
     -----
-    This is an implementation of the LiFE model described in [1]_
+    This is an implementation of the LiFE model described in
+    :footcite:p:`Pestilli2014`.
 
-    [1] Pestilli, F., Yeatman, J, Rokem, A. Kay, K. and Wandell
-        B.A. (2014). Validation and statistical inference in living
-        connectomes. Nature Methods.
+    References
+    ----------
+    .. footbibliography::
     """
 
     def __init__(self, gtab):
@@ -322,7 +329,8 @@ class FiberModel(ReconstModel):
         # Initialize the super-class:
         ReconstModel.__init__(self, gtab)
 
-    def setup(self, streamline, affine, evals=(0.001, 0, 0), sphere=None):
+    @warning_for_keywords()
+    def setup(self, streamline, affine, *, evals=(0.001, 0, 0), sphere=None):
         """
         Set up the necessary components for the LiFE model: the matrix of
         fiber-contributions to the DWI signal, and the coordinates of voxels
@@ -347,9 +355,7 @@ class FiberModel(ReconstModel):
             from :mod:`dipy.data`
         """
         if sphere is not False:
-            SignalMaker = LifeSignalMaker(self.gtab,
-                                          evals=evals,
-                                          sphere=sphere)
+            SignalMaker = LifeSignalMaker(self.gtab, evals=evals, sphere=sphere)
 
         streamline = transform_streamlines(streamline, affine)
         # Assign some local variables, for shorthand:
@@ -358,8 +364,7 @@ class FiberModel(ReconstModel):
         del all_coords
         # We only consider the diffusion-weighted signals:
         n_bvecs = self.gtab.bvals[~self.gtab.b0s_mask].shape[0]
-        v2f, v2fn = voxel2streamline(streamline, np.eye(4),
-                                     unique_idx=vox_coords)
+        v2f, v2fn = voxel2streamline(streamline, np.eye(4), unique_idx=vox_coords)
         # How many fibers in each voxel (this will determine how many
         # components are in the matrix):
         n_unique_f = len(np.hstack(list(v2f.values())))
@@ -370,11 +375,11 @@ class FiberModel(ReconstModel):
         f_matrix_col = np.zeros(n_unique_f * n_bvecs, dtype=np.intp)
 
         fiber_signal = []
-        for s_idx, s in enumerate(streamline):
+        for _, s in enumerate(streamline):
             if sphere is not False:
                 fiber_signal.append(SignalMaker.streamline_signal(s))
             else:
-                fiber_signal.append(streamline_signal(s, self.gtab, evals))
+                fiber_signal.append(streamline_signal(s, self.gtab, evals=evals))
 
         del streamline
         if sphere is not False:
@@ -389,22 +394,21 @@ class FiberModel(ReconstModel):
             for f_idx in v2f[v_idx]:
                 # For each fiber-voxel combination, store the row/column
                 # indices in the pre-allocated linear arrays
-                f_matrix_row[keep_ct:keep_ct+n_bvecs] = mat_row_idx
-                f_matrix_col[keep_ct:keep_ct+n_bvecs] = f_idx
+                f_matrix_row[keep_ct : keep_ct + n_bvecs] = mat_row_idx
+                f_matrix_col[keep_ct : keep_ct + n_bvecs] = f_idx
 
                 vox_fiber_sig = np.zeros(n_bvecs)
                 for node_idx in v2fn[f_idx][v_idx]:
                     # Sum the signal from each node of the fiber in that voxel:
                     vox_fiber_sig += fiber_signal[f_idx][node_idx]
                 # And add the summed thing into the corresponding rows:
-                f_matrix_sig[keep_ct:keep_ct+n_bvecs] += vox_fiber_sig
+                f_matrix_sig[keep_ct : keep_ct + n_bvecs] += vox_fiber_sig
                 keep_ct = keep_ct + n_bvecs
 
         del v2f, v2fn
         # Allocate the sparse matrix, using the more memory-efficient 'csr'
         # format:
-        life_matrix = sps.csr_matrix((f_matrix_sig,
-                                      [f_matrix_row, f_matrix_col]))
+        life_matrix = sps.csr_array((f_matrix_sig, [f_matrix_row, f_matrix_col]))
 
         return life_matrix, vox_coords
 
@@ -427,17 +431,16 @@ class FiberModel(ReconstModel):
         vox_data = data[idx_tuple]
         weighted_signal = vox_data[:, ~self.gtab.b0s_mask]
         b0_signal = np.mean(vox_data[:, self.gtab.b0s_mask], -1)
-        relative_signal = (weighted_signal/b0_signal[:, None])
+        relative_signal = weighted_signal / b0_signal[:, None]
 
         # The mean of the relative signal across directions in each voxel:
         mean_sig = np.mean(relative_signal, -1)
         to_fit = (relative_signal - mean_sig[:, None]).ravel()
         to_fit[np.isnan(to_fit)] = 0
-        return (to_fit, weighted_signal, b0_signal, relative_signal, mean_sig,
-                vox_data)
+        return (to_fit, weighted_signal, b0_signal, relative_signal, mean_sig, vox_data)
 
-    def fit(self, data, streamline, affine, evals=(0.001, 0, 0),
-            sphere=None):
+    @warning_for_keywords()
+    def fit(self, data, streamline, affine, *, evals=(0.001, 0, 0), sphere=None):
         """
         Fit the LiFE FiberModel for data and a set of streamlines associated
         with this data
@@ -451,7 +454,7 @@ class FiberModel(ReconstModel):
         affine : array_like (4, 4)
             The mapping from voxel coordinates to streamline points.
             The voxel_to_rasmm matrix, typically from a NIFTI file.
-        evals : array-like (optional)
+        evals : array-like, optional
             The eigenvalues of the tensor response function used in
             constructing the model signal. Default: [0.001, 0, 0]
         sphere: `dipy.core.Sphere` instance or False, optional
@@ -469,16 +472,32 @@ class FiberModel(ReconstModel):
             affine = np.eye(4)
         sl_len = np.array([len(s) for s in streamline])
         if np.any(sl_len < 2):
-            raise ValueError("Input contains streamlines with only one node."
-            " The LiFE model cannot be fit with these streamlines included.")
-        life_matrix, vox_coords = \
-            self.setup(streamline, affine, evals=evals, sphere=sphere)
-        (to_fit, weighted_signal, b0_signal, relative_signal, mean_sig,
-         vox_data) = self._signals(data, vox_coords)
+            raise ValueError(
+                "Input contains streamlines with only one node."
+                " The LiFE model cannot be fit with these streamlines included."
+            )
+        life_matrix, vox_coords = self.setup(
+            streamline, affine, evals=evals, sphere=sphere
+        )
+        (to_fit, weighted_signal, b0_signal, relative_signal, mean_sig, vox_data) = (
+            self._signals(data, vox_coords)
+        )
         beta = opt.sparse_nnls(to_fit, life_matrix)
-        return FiberFit(self, life_matrix, vox_coords, to_fit, beta,
-                        weighted_signal, b0_signal, relative_signal, mean_sig,
-                        vox_data, streamline, affine, evals)
+        return FiberFit(
+            self,
+            life_matrix,
+            vox_coords,
+            to_fit,
+            beta,
+            weighted_signal,
+            b0_signal,
+            relative_signal,
+            mean_sig,
+            vox_data,
+            streamline,
+            affine,
+            evals,
+        )
 
 
 class FiberFit(ReconstFit):
@@ -486,9 +505,22 @@ class FiberFit(ReconstFit):
     A fit of the LiFE model to diffusion data
     """
 
-    def __init__(self, fiber_model, life_matrix, vox_coords, to_fit, beta,
-                 weighted_signal, b0_signal, relative_signal, mean_sig,
-                 vox_data, streamline, affine, evals):
+    def __init__(
+        self,
+        fiber_model,
+        life_matrix,
+        vox_coords,
+        to_fit,
+        beta,
+        weighted_signal,
+        b0_signal,
+        relative_signal,
+        mean_sig,
+        vox_data,
+        streamline,
+        affine,
+        evals,
+    ):
         """
         Parameters
         ----------
@@ -511,7 +543,8 @@ class FiberFit(ReconstFit):
         self.affine = affine
         self.evals = evals
 
-    def predict(self, gtab=None, S0=None):
+    @warning_for_keywords()
+    def predict(self, *, gtab=None, S0=None):
         """
         Predict the signal
 
@@ -536,20 +569,20 @@ class FiberFit(ReconstFit):
             gtab = self.model.gtab
         else:
             _model = FiberModel(gtab)
-            _matrix, _ = _model.setup(self.streamline,
-                                      self.affine,
-                                      self.evals)
+            _matrix, _ = _model.setup(self.streamline, self.affine, evals=self.evals)
 
-        pred_weighted = np.reshape(opt.spdot(_matrix, self.beta),
-                                   (self.vox_coords.shape[0],
-                                    np.sum(~gtab.b0s_mask)))
+        pred_weighted = np.reshape(
+            opt.spdot(_matrix, self.beta),
+            (self.vox_coords.shape[0], np.sum(~gtab.b0s_mask)),
+        )
 
         pred = np.empty((self.vox_coords.shape[0], gtab.bvals.shape[0]))
         if S0 is None:
             S0 = self.b0_signal
 
         pred[..., gtab.b0s_mask] = S0[:, None]
-        pred[..., ~gtab.b0s_mask] =\
-            (pred_weighted + self.mean_signal[:, None]) * S0[:, None]
+        pred[..., ~gtab.b0s_mask] = (pred_weighted + self.mean_signal[:, None]) * S0[
+            :, None
+        ]
 
         return pred
