@@ -1,17 +1,20 @@
-import random
 from collections.abc import Iterable
+import random
 from warnings import warn
+
 import numpy as np
 
-from dipy.tracking.localtrack import local_tracker, pft_tracker
-from dipy.tracking.stopping_criterion import (AnatomicalStoppingCriterion,
-                                              StreamlineStatus)
+from dipy.testing.decorators import warning_for_keywords
 from dipy.tracking import utils
+from dipy.tracking.localtrack import local_tracker, pft_tracker
+from dipy.tracking.stopping_criterion import (
+    AnatomicalStoppingCriterion,
+    StreamlineStatus,
+)
 from dipy.utils import fast_numpy
 
 
 class LocalTracking:
-
     @staticmethod
     def _get_voxel_size(affine):
         """Computes the voxel sizes of an image from the affine.
@@ -23,18 +26,35 @@ class LocalTracking:
         lin = affine[:3, :3]
         dotlin = np.dot(lin.T, lin)
         # Check that the affine is well behaved
-        if not np.allclose(np.triu(dotlin, 1), 0., atol=1e-5):
-            msg = ("The affine provided seems to contain shearing, data must "
-                   "be acquired or interpolated on a regular grid to be used "
-                   "with `LocalTracking`.")
+        if not np.allclose(np.triu(dotlin, 1), 0.0, atol=1e-5):
+            msg = (
+                "The affine provided seems to contain shearing, data must "
+                "be acquired or interpolated on a regular grid to be used "
+                "with `LocalTracking`."
+            )
             raise ValueError(msg)
         return np.sqrt(dotlin.diagonal())
 
-    def __init__(self, direction_getter, stopping_criterion, seeds, affine,
-                 step_size, max_cross=None, maxlen=500, minlen=2,
-                 fixedstep=True, return_all=True, random_seed=None,
-                 save_seeds=False, unidirectional=False,
-                 randomize_forward_direction=False, initial_directions=None):
+    @warning_for_keywords()
+    def __init__(
+        self,
+        direction_getter,
+        stopping_criterion,
+        seeds,
+        affine,
+        step_size,
+        *,
+        max_cross=None,
+        maxlen=500,
+        minlen=2,
+        fixedstep=True,
+        return_all=True,
+        random_seed=None,
+        save_seeds=False,
+        unidirectional=False,
+        randomize_forward_direction=False,
+        initial_directions=None,
+    ):
         """Creates streamlines by using local fiber-tracking.
 
         Parameters
@@ -104,23 +124,33 @@ class LocalTracking:
             raise ValueError("maxlen must be greater than or equal to minlen")
         if not isinstance(seeds, Iterable):
             raise ValueError("seeds should be (N,3) array.")
-        if (initial_directions is not None and
-                seeds.shape[0] != initial_directions.shape[0]):
-            raise ValueError("initial_directions and seeds must have the "
-                             + "same shape[0].")
-        if (initial_directions is None and unidirectional and
-                not self.randomize_forward_direction):
-            warn("Unidirectional tractography will be performed "
-                 + "without providing initial directions nor "
-                 + "randomizing extracted initial forward "
-                 + "directions. This may introduce directional "
-                 + "biases in the reconstructed streamlines. "
-                 + "See ``initial_directions`` and "
-                 + "``randomize_forward_direction`` parameters.")
+        if (
+            initial_directions is not None
+            and seeds.shape[0] != initial_directions.shape[0]
+        ):
+            raise ValueError(
+                "initial_directions and seeds must have the same shape[0]."
+            )
+        if (
+            initial_directions is None
+            and unidirectional
+            and not self.randomize_forward_direction
+        ):
+            warn(
+                "Unidirectional tractography will be performed "
+                + "without providing initial directions nor "
+                + "randomizing extracted initial forward "
+                + "directions. This may introduce directional "
+                + "biases in the reconstructed streamlines. "
+                + "See ``initial_directions`` and "
+                + "``randomize_forward_direction`` parameters.",
+                stacklevel=2,
+            )
 
         self.affine = affine
-        self._voxel_size = np.ascontiguousarray(self._get_voxel_size(affine),
-                                                dtype=float)
+        self._voxel_size = np.ascontiguousarray(
+            self._get_voxel_size(affine), dtype=float
+        )
         self.step_size = step_size
         self.fixed_stepsize = fixedstep
         self.max_cross = max_cross
@@ -131,21 +161,24 @@ class LocalTracking:
         self.save_seeds = save_seeds
 
     def _tracker(self, seed, first_step, streamline):
-        return local_tracker(self.direction_getter,
-                             self.stopping_criterion,
-                             seed,
-                             first_step,
-                             self._voxel_size,
-                             streamline,
-                             self.step_size,
-                             self.fixed_stepsize)
+        return local_tracker(
+            self.direction_getter,
+            self.stopping_criterion,
+            seed,
+            first_step,
+            self._voxel_size,
+            streamline,
+            self.step_size,
+            self.fixed_stepsize,
+        )
 
     def __iter__(self):
         # Make tracks, move them to point space and return
         track = self._generate_tractogram()
 
-        return utils.transform_tracking_output(track, self.affine,
-                                               save_seeds=self.save_seeds)
+        return utils.transform_tracking_output(
+            track, self.affine, save_seeds=self.save_seeds
+        )
 
     def _generate_tractogram(self):
         """A streamline generator"""
@@ -161,8 +194,9 @@ class LocalTracking:
             s = np.dot(lin, s) + offset
             # Set the random seed in numpy, random and fast_numpy (lic.stdlib)
             if self.random_seed is not None:
-                s_random_seed = hash(np.abs((np.sum(s)) + self.random_seed)) \
-                    % (np.iinfo(np.uint32).max - 1)
+                s_random_seed = hash(np.abs((np.sum(s)) + self.random_seed)) % (
+                    np.iinfo(np.uint32).max - 1
+                )
                 random.seed(s_random_seed)
                 np.random.seed(s_random_seed)
                 fast_numpy.seed(s_random_seed)
@@ -173,8 +207,9 @@ class LocalTracking:
                 # normalize the initial directions.
                 # initial directions with norm 0 are removed.
                 d_ns = np.linalg.norm(self.initial_directions[i, :, :], axis=1)
-                directions = self.initial_directions[i, d_ns > 0, :] \
-                    / d_ns[d_ns > 0, np.newaxis]
+                directions = (
+                    self.initial_directions[i, d_ns > 0, :] / d_ns[d_ns > 0, np.newaxis]
+                )
 
             if len(directions) == 0 and self.return_all:
                 # only the seed position
@@ -186,14 +221,16 @@ class LocalTracking:
             if self.randomize_forward_direction:
                 directions = [d * random.choice([1, -1]) for d in directions]
 
-            directions = directions[:self.max_cross]
+            directions = directions[: self.max_cross]
 
             for first_step in directions:
                 stepsF = stepsB = 1
                 stepsF, stream_status = self._tracker(s, first_step, F)
-                if not (self.return_all
-                        or stream_status in (StreamlineStatus.ENDPOINT,
-                                             StreamlineStatus.OUTSIDEIMAGE)):
+                if not (
+                    self.return_all
+                    or stream_status
+                    in (StreamlineStatus.ENDPOINT, StreamlineStatus.OUTSIDEIMAGE)
+                ):
                     continue
 
                 if not self.unidirectional:
@@ -206,39 +243,62 @@ class LocalTracking:
                         if opposite_step_norm > 0:
                             first_step = opposite_step / opposite_step_norm
                     stepsB, stream_status = self._tracker(s, first_step, B)
-                    if not (self.return_all or
-                            stream_status in (StreamlineStatus.ENDPOINT,
-                                              StreamlineStatus.OUTSIDEIMAGE)):
+                    if not (
+                        self.return_all
+                        or stream_status
+                        in (StreamlineStatus.ENDPOINT, StreamlineStatus.OUTSIDEIMAGE)
+                    ):
                         continue
 
                 if stepsB == 1:
                     streamline = F[:stepsF].copy()
                 else:
-                    parts = (B[stepsB - 1:0:-1], F[:stepsF])
+                    parts = (B[stepsB - 1 : 0 : -1], F[:stepsF])
                     streamline = np.concatenate(parts, axis=0)
 
                 # move to the next streamline if only the seed position
                 # and not return all
                 len_sl = len(streamline)
-                if len_sl >= self.min_length and len_sl <= self.max_length \
-                    or self.return_all:
-                        if self.save_seeds:
-                            yield streamline, s
-                        else:
-                            yield streamline
+                if (
+                    len_sl >= self.min_length
+                    and len_sl <= self.max_length
+                    or self.return_all
+                ):
+                    if self.save_seeds:
+                        yield streamline, s
+                    else:
+                        yield streamline
 
 
 class ParticleFilteringTracking(LocalTracking):
+    @warning_for_keywords()
+    def __init__(
+        self,
+        direction_getter,
+        stopping_criterion,
+        seeds,
+        affine,
+        step_size,
+        *,
+        max_cross=None,
+        maxlen=500,
+        minlen=2,
+        pft_back_tracking_dist=2,
+        pft_front_tracking_dist=1,
+        pft_max_trial=20,
+        particle_count=15,
+        return_all=True,
+        random_seed=None,
+        save_seeds=False,
+        min_wm_pve_before_stopping=0,
+        unidirectional=False,
+        randomize_forward_direction=False,
+        initial_directions=None,
+    ):
+        """A streamline generator using the particle filtering tractography
+        method.
 
-    def __init__(self, direction_getter, stopping_criterion, seeds, affine,
-                 step_size, max_cross=None, maxlen=500, minlen=2,
-                 pft_back_tracking_dist=2, pft_front_tracking_dist=1,
-                 pft_max_trial=20, particle_count=15, return_all=True,
-                 random_seed=None, save_seeds=False,
-                 min_wm_pve_before_stopping=0, unidirectional=False,
-                 randomize_forward_direction=False, initial_directions=None):
-        r"""A streamline generator using the particle filtering tractography
-        method [1]_.
+        See :footcite:p:`Girard2014` for further details about the method.
 
         Parameters
         ----------
@@ -308,46 +368,46 @@ class ParticleFilteringTracking(LocalTracking):
 
         References
         ----------
-        .. [1] Girard, G., Whittingstall, K., Deriche, R., & Descoteaux, M.
-               Towards quantitative connectivity analysis: reducing
-               tractography biases. NeuroImage, 98, 266-278, 2014.
+        .. footbibliography::
         """
 
         if not isinstance(stopping_criterion, AnatomicalStoppingCriterion):
             raise ValueError("expecting AnatomicalStoppingCriterion")
 
-        self.pft_max_nbr_back_steps = int(np.ceil(pft_back_tracking_dist
-                                                  / step_size))
-        self.pft_max_nbr_front_steps = int(np.ceil(pft_front_tracking_dist
-                                                   / step_size))
-        pft_max_steps = (self.pft_max_nbr_back_steps +
-                         self.pft_max_nbr_front_steps)
+        self.pft_max_nbr_back_steps = int(np.ceil(pft_back_tracking_dist / step_size))
+        self.pft_max_nbr_front_steps = int(np.ceil(pft_front_tracking_dist / step_size))
+        pft_max_steps = self.pft_max_nbr_back_steps + self.pft_max_nbr_front_steps
 
-        if (self.pft_max_nbr_front_steps < 0
-                or self.pft_max_nbr_back_steps < 0
-                or pft_max_steps < 1):
+        if (
+            self.pft_max_nbr_front_steps < 0
+            or self.pft_max_nbr_back_steps < 0
+            or pft_max_steps < 1
+        ):
             raise ValueError("The number of PFT steps must be greater than 0.")
 
         if particle_count <= 0:
             raise ValueError("The particle count must be greater than 0.")
 
         if not 0 <= min_wm_pve_before_stopping <= 1:
-            raise ValueError("The min_wm_pve_before_stopping value must be "
-                             "between 0 and 1.")
+            raise ValueError(
+                "The min_wm_pve_before_stopping value must be between 0 and 1."
+            )
 
         self.min_wm_pve_before_stopping = min_wm_pve_before_stopping
         self.directions = np.empty((maxlen + 1, 3), dtype=float)
         self.pft_max_trial = pft_max_trial
         self.particle_count = particle_count
-        self.particle_paths = np.empty((2, self.particle_count,
-                                        pft_max_steps + 1, 3),
-                                       dtype=float)
+        self.particle_paths = np.empty(
+            (2, self.particle_count, pft_max_steps + 1, 3), dtype=float
+        )
         self.particle_weights = np.empty(self.particle_count, dtype=float)
-        self.particle_dirs = np.empty((2, self.particle_count,
-                                       pft_max_steps + 1, 3), dtype=float)
+        self.particle_dirs = np.empty(
+            (2, self.particle_count, pft_max_steps + 1, 3), dtype=float
+        )
         self.particle_steps = np.empty((2, self.particle_count), dtype=np.intp)
-        self.particle_stream_statuses = np.empty((2, self.particle_count),
-                                                 dtype=np.intp)
+        self.particle_stream_statuses = np.empty(
+            (2, self.particle_count), dtype=np.intp
+        )
         super(ParticleFilteringTracking, self).__init__(
             direction_getter=direction_getter,
             stopping_criterion=stopping_criterion,
@@ -363,24 +423,27 @@ class ParticleFilteringTracking(LocalTracking):
             save_seeds=save_seeds,
             unidirectional=unidirectional,
             randomize_forward_direction=randomize_forward_direction,
-            initial_directions=initial_directions)
+            initial_directions=initial_directions,
+        )
 
     def _tracker(self, seed, first_step, streamline):
-        return pft_tracker(self.direction_getter,
-                           self.stopping_criterion,
-                           seed,
-                           first_step,
-                           self._voxel_size,
-                           streamline,
-                           self.directions,
-                           self.step_size,
-                           self.pft_max_nbr_back_steps,
-                           self.pft_max_nbr_front_steps,
-                           self.pft_max_trial,
-                           self.particle_count,
-                           self.particle_paths,
-                           self.particle_dirs,
-                           self.particle_weights,
-                           self.particle_steps,
-                           self.particle_stream_statuses,
-                           self.min_wm_pve_before_stopping)
+        return pft_tracker(
+            self.direction_getter,
+            self.stopping_criterion,
+            seed,
+            first_step,
+            self._voxel_size,
+            streamline,
+            self.directions,
+            self.step_size,
+            self.pft_max_nbr_back_steps,
+            self.pft_max_nbr_front_steps,
+            self.pft_max_trial,
+            self.particle_count,
+            self.particle_paths,
+            self.particle_dirs,
+            self.particle_weights,
+            self.particle_steps,
+            self.particle_stream_statuses,
+            self.min_wm_pve_before_stopping,
+        )
