@@ -1,9 +1,9 @@
-""" Metrics for tracks, where tracks are arrays of points """
+"""Metrics for tracks, where tracks are arrays of points"""
 
-from dipy.utils.deprecator import deprecate_with_version
-from dipy.tracking.streamline import set_number_of_points
 import numpy as np
-from scipy.interpolate import splprep, splev
+from scipy.interpolate import splev, splprep
+
+from dipy.testing.decorators import warning_for_keywords
 
 
 def winding(xyz):
@@ -24,14 +24,14 @@ def winding(xyz):
 
     """
 
-    U, s, V = np.linalg.svd(xyz-np.mean(xyz, axis=0), 0)
+    U, s, V = np.linalg.svd(xyz - np.mean(xyz, axis=0), 0)
     proj = np.dot(U[:, 0:2], np.diag(s[0:2]))
 
     turn = 0
-    for j in range(len(xyz)-1):
+    for j in range(len(xyz) - 1):
         v0 = proj[j]
-        v1 = proj[j+1]
-        v = np.dot(v0, v1)/(np.linalg.norm(v0)*np.linalg.norm(v1))
+        v1 = proj[j + 1]
+        v = np.dot(v0, v1) / (np.linalg.norm(v0) * np.linalg.norm(v1))
         v = np.clip(v, -1, 1)
         tmp = np.arccos(v)
         turn += tmp
@@ -39,8 +39,9 @@ def winding(xyz):
     return np.rad2deg(turn)
 
 
-def length(xyz, along=False):
-    """ Euclidean length of track line
+@warning_for_keywords()
+def length(xyz, *, along=False):
+    """Euclidean length of track line
 
     This will give length in mm if tracks are expressed in world coordinates.
 
@@ -80,7 +81,7 @@ def length(xyz, along=False):
         if along:
             return np.array([0])
         return 0
-    dists = np.sqrt((np.diff(xyz, axis=0)**2).sum(axis=1))
+    dists = np.sqrt((np.diff(xyz, axis=0) ** 2).sum(axis=1))
     if along:
         return np.cumsum(dists)
     return np.sum(dists)
@@ -104,7 +105,7 @@ def bytes(xyz):
 
 
 def midpoint(xyz):
-    """ Midpoint of track
+    """Midpoint of track
 
     Parameters
     ----------
@@ -145,49 +146,22 @@ def midpoint(xyz):
     xyz = np.asarray(xyz)
     n_pts = xyz.shape[0]
     if n_pts == 0:
-        raise ValueError('xyz array cannot be empty')
+        raise ValueError("xyz array cannot be empty")
     if n_pts == 1:
         return xyz.copy().squeeze()
     cumlen = np.zeros(n_pts)
     cumlen[1:] = length(xyz, along=True)
-    midlen = cumlen[-1]/2.0
-    ind = np.where((cumlen-midlen) > 0)[0][0]
-    len0 = cumlen[ind-1]
+    midlen = cumlen[-1] / 2.0
+    ind = np.where((cumlen - midlen) > 0)[0][0]
+    len0 = cumlen[ind - 1]
     len1 = cumlen[ind]
-    Ds = midlen-len0
-    Lambda = Ds/(len1-len0)
-    return Lambda*xyz[ind]+(1-Lambda)*xyz[ind-1]
-
-
-@deprecate_with_version("dipy.tracking.metrics.downsample is deprecated, "
-                        "Please use "
-                        "dipy.tracking.streamline.set_number_of_points instead",
-                        since='1.2', until='1.4')
-def downsample(xyz, n_pols=3):
-    """ downsample for a specific number of points along the streamline
-    Uses the length of the curve. It works in a similar fashion to
-    midpoint and arbitrarypoint but it also reduces the number of segments
-    of a streamline.
-
-    Parameters
-    ----------
-    xyz : array-like shape (N,3)
-       array representing x,y,z of N points in a streamlines
-    n_pol : int
-       integer representing number of points (poles) we need along the curve.
-
-    Returns
-    -------
-    xyz2 : array shape (M,3)
-       array representing x,y,z of M points that where extrapolated. M
-       should be equal to n_pols
-
-    """
-    return set_number_of_points(xyz, n_pols)
+    Ds = midlen - len0
+    Lambda = Ds / (len1 - len0)
+    return Lambda * xyz[ind] + (1 - Lambda) * xyz[ind - 1]
 
 
 def center_of_mass(xyz):
-    """ Center of mass of streamline
+    """Center of mass of streamline
 
     Parameters
     ----------
@@ -214,15 +188,14 @@ def center_of_mass(xyz):
     """
     xyz = np.asarray(xyz)
     if xyz.size == 0:
-        raise ValueError('xyz array cannot be empty')
+        raise ValueError("xyz array cannot be empty")
     return np.mean(xyz, axis=0)
 
 
-def magn(xyz, n=1):
-    """ magnitude of vector
-
-    """
-    mag = np.sum(xyz**2, axis=1)**0.5
+@warning_for_keywords()
+def magn(xyz, *, n=1):
+    """magnitude of vector"""
+    mag = np.sum(xyz**2, axis=1) ** 0.5
     imag = np.where(mag == 0)
     mag[imag] = np.finfo(float).eps
 
@@ -232,7 +205,7 @@ def magn(xyz, n=1):
 
 
 def frenet_serret(xyz):
-    r""" Frenet-Serret Space Curve Invariants
+    r"""Frenet-Serret Space Curve Invariants
 
     Calculates the 3 vector and 2 scalar invariants of a space curve
     defined by vectors r = (x,y,z).  If z is omitted (i.e. the array xyz has
@@ -291,29 +264,29 @@ def frenet_serret(xyz):
     xyz = np.asarray(xyz)
     n_pts = xyz.shape[0]
     if n_pts == 0:
-        raise ValueError('xyz array cannot be empty')
+        raise ValueError("xyz array cannot be empty")
 
     dxyz = np.gradient(xyz)[0]
     ddxyz = np.gradient(dxyz)[0]
     # Tangent
-    T = np.divide(dxyz, magn(dxyz, 3))
+    T = np.divide(dxyz, magn(dxyz, n=3))
     # Derivative of Tangent
     dT = np.gradient(T)[0]
     # Normal
-    N = np.divide(dT, magn(dT, 3))
+    N = np.divide(dT, magn(dT, n=3))
     # Binormal
     B = np.cross(T, N)
     # Curvature
-    k = magn(np.cross(dxyz, ddxyz), 1)/(magn(dxyz, 1)**3)
+    k = magn(np.cross(dxyz, ddxyz), n=1) / (magn(dxyz, n=1) ** 3)
     # Torsion
     # (In matlab was t=dot(-B,N,2))
-    t = np.sum(-B*N, axis=1)
+    t = np.sum(-B * N, axis=1)
     # return T,N,B,k,t,dxyz,ddxyz,dT
     return T, N, B, k, t
 
 
 def mean_curvature(xyz):
-    """ Calculates the mean curvature of a curve
+    """Calculates the mean curvature of a curve
 
     Parameters
     ----------
@@ -346,13 +319,13 @@ def mean_curvature(xyz):
     xyz = np.asarray(xyz)
     n_pts = xyz.shape[0]
     if n_pts == 0:
-        raise ValueError('xyz array cannot be empty')
+        raise ValueError("xyz array cannot be empty")
 
     dxyz = np.gradient(xyz)[0]
     ddxyz = np.gradient(dxyz)[0]
 
     # Curvature
-    k = magn(np.cross(dxyz, ddxyz), 1)/(magn(dxyz, 1)**3)
+    k = magn(np.cross(dxyz, ddxyz), n=1) / (magn(dxyz, n=1) ** 3)
 
     return np.mean(k)
 
@@ -374,7 +347,7 @@ def mean_orientation(xyz):
     xyz = np.asarray(xyz)
     n_pts = xyz.shape[0]
     if n_pts == 0:
-        raise ValueError('xyz array cannot be empty')
+        raise ValueError("xyz array cannot be empty")
 
     dxyz = np.gradient(xyz)[0]
 
@@ -382,7 +355,7 @@ def mean_orientation(xyz):
 
 
 def generate_combinations(items, n):
-    """ Combine sets of size n from items
+    """Combine sets of size n from items
 
     Parameters
     ----------
@@ -407,18 +380,19 @@ def generate_combinations(items, n):
         yield []
     elif n == 2:
         # if n=2 non_recursive
-        for i in range(len(items)-1):
-            for j in range(i+1, len(items)):
+        for i in range(len(items) - 1):
+            for j in range(i + 1, len(items)):
                 yield [i, j]
     else:
         # if n>2 uses recursion
         for i in range(len(items)):
-            for cc in generate_combinations(items[i+1:], n-1):
+            for cc in generate_combinations(items[i + 1 :], n - 1):
                 yield [items[i]] + cc
 
 
-def longest_track_bundle(bundle, sort=False):
-    """ Return longest track or length sorted track indices in `bundle`
+@warning_for_keywords()
+def longest_track_bundle(bundle, *, sort=False):
+    """Return longest track or length sorted track indices in `bundle`
 
     If `sort` == True, return the indices of the sorted tracks in the
     bundle, otherwise return the longest track.
@@ -445,7 +419,7 @@ def longest_track_bundle(bundle, sort=False):
     >>> longest_track_bundle(bundle)
     array([[0, 0, 0],
            [4, 4, 4]])
-    >>> longest_track_bundle(bundle, True) #doctest: +ELLIPSIS
+    >>> longest_track_bundle(bundle, sort=True) #doctest: +ELLIPSIS
     array([0, 1]...)
 
     """
@@ -460,7 +434,7 @@ def longest_track_bundle(bundle, sort=False):
 
 
 def intersect_sphere(xyz, center, radius):
-    """ If any segment of the track is intersecting with a sphere of
+    """If any segment of the track is intersecting with a sphere of
     specific center and radius return True otherwise False
 
     Parameters
@@ -497,44 +471,48 @@ def intersect_sphere(xyz, center, radius):
 
     lt = xyz.shape[0]
 
-    for i in range(lt-1):
+    for i in range(lt - 1):
         # first point
         x1 = xyz[i]
         # second point
-        x2 = xyz[i+1]
+        x2 = xyz[i + 1]
         # do the calculations as given in the Notes
-        x = x2-x1
+        x = x2 - x1
         a = np.inner(x, x)
-        x1c = x1-center
-        b = 2*np.inner(x, x1c)
-        c = (np.inner(center, center)+np.inner(x1, x1)-2*np.inner(center, x1) -
-             radius**2)
-        bb4ac = b*b-4*a*c
+        x1c = x1 - center
+        b = 2 * np.inner(x, x1c)
+        c = (
+            np.inner(center, center)
+            + np.inner(x1, x1)
+            - 2 * np.inner(center, x1)
+            - radius**2
+        )
+        bb4ac = b * b - 4 * a * c
         # print 'bb4ac',bb4ac
-        if abs(a) < np.finfo(float).eps or bb4ac < 0:   # too small segment or
-                                                        # no intersection
+        if abs(a) < np.finfo(float).eps or bb4ac < 0:  # too small segment or
+            # no intersection
             continue
         if bb4ac == 0:  # one intersection point p
-            mu = -b/2*a
-            p = x1+mu*x
+            mu = -b / 2 * a
+            p = x1 + mu * x
             # check if point is inside the segment
             # print 'p',p
-            if np.inner(p-x1, p-x1) <= a:
+            if np.inner(p - x1, p - x1) <= a:
                 return True
         if bb4ac > 0:  # two intersection points p1 and p2
-            mu = (-b+np.sqrt(bb4ac))/(2*a)
-            p1 = x1+mu*x
-            mu = (-b-np.sqrt(bb4ac))/(2*a)
-            p2 = x1+mu*x
+            mu = (-b + np.sqrt(bb4ac)) / (2 * a)
+            p1 = x1 + mu * x
+            mu = (-b - np.sqrt(bb4ac)) / (2 * a)
+            p2 = x1 + mu * x
             # check if points are inside the line segment
             # print 'p1,p2',p1,p2
-            if np.inner(p1-x1, p1-x1) <= a or np.inner(p2-x1, p2-x1) <= a:
+            if np.inner(p1 - x1, p1 - x1) <= a or np.inner(p2 - x1, p2 - x1) <= a:
                 return True
     return False
 
 
 def inside_sphere(xyz, center, radius):
-    r""" If any point of the track is inside a sphere of a specified
+    r"""If any point of the track is inside a sphere of a specified
     center and radius return True otherwise False.  Mathematically this
     can be simply described by $|x-c|\le r$ where $x$ a point $c$ the
     center of the sphere and $r$ the radius of the sphere.
@@ -562,11 +540,11 @@ def inside_sphere(xyz, center, radius):
     >>> inside_sphere(line,sph_cent,sph_radius)
     True
     """
-    return (np.sqrt(np.sum((xyz-center)**2, axis=1)) <= radius).any()
+    return (np.sqrt(np.sum((xyz - center) ** 2, axis=1)) <= radius).any()
 
 
 def inside_sphere_points(xyz, center, radius):
-    r""" If a track intersects with a sphere of a specified center and
+    r"""If a track intersects with a sphere of a specified center and
     radius return the points that are inside the sphere otherwise False.
     Mathematically this can be simply described by $|x-c| \le r$ where $x$
     a point $c$ the center of the sphere and $r$ the radius of the
@@ -595,11 +573,12 @@ def inside_sphere_points(xyz, center, radius):
     >>> inside_sphere_points(line,sph_cent,sph_radius)
     array([[1, 1, 1]])
     """
-    return xyz[(np.sqrt(np.sum((xyz-center)**2, axis=1)) <= radius)]
+    return xyz[(np.sqrt(np.sum((xyz - center) ** 2, axis=1)) <= radius)]
 
 
-def spline(xyz, s=3, k=2, nest=-1):
-    """ Generate B-splines as documented in
+@warning_for_keywords()
+def spline(xyz, *, s=3, k=2, nest=-1):
+    """Generate B-splines as documented in
     https://scipy-cookbook.readthedocs.io/items/Interpolation.html
 
     The scipy.interpolate packages wraps the netlib FITPACK routines
@@ -653,7 +632,7 @@ def spline(xyz, s=3, k=2, nest=-1):
     >>> y+= np.random.normal(scale=0.1, size=y.shape)
     >>> z+= np.random.normal(scale=0.1, size=z.shape)
     >>> xyz=np.vstack((x,y,z)).T
-    >>> xyzn=spline(xyz,3,2,-1)
+    >>> xyzn=spline(xyz,s=3,k=2,nest=-1)
     >>> len(xyzn) > len(xyz)
     True
 
@@ -670,7 +649,7 @@ def spline(xyz, s=3, k=2, nest=-1):
 
 
 def startpoint(xyz):
-    """ First point of the track
+    """First point of the track
 
     Parameters
     ----------
@@ -729,7 +708,7 @@ def endpoint(xyz):
 
 
 def arbitrarypoint(xyz, distance):
-    """ Select an arbitrary point along distance on the track (curve)
+    """Select an arbitrary point along distance on the track (curve)
 
     Parameters
     ----------
@@ -760,35 +739,33 @@ def arbitrarypoint(xyz, distance):
     xyz = np.asarray(xyz)
     n_pts = xyz.shape[0]
     if n_pts == 0:
-        raise ValueError('xyz array cannot be empty')
+        raise ValueError("xyz array cannot be empty")
     if n_pts == 1:
         return xyz.copy().squeeze()
     cumlen = np.zeros(n_pts)
     cumlen[1:] = length(xyz, along=True)
     if cumlen[-1] < distance:
-        raise ValueError('Given distance is bigger than '
-                         'the length of the curve')
-    ind = np.where((cumlen-distance) > 0)[0][0]
-    len0 = cumlen[ind-1]
+        raise ValueError("Given distance is bigger than the length of the curve")
+    ind = np.where((cumlen - distance) > 0)[0][0]
+    len0 = cumlen[ind - 1]
     len1 = cumlen[ind]
-    Ds = distance-len0
-    Lambda = Ds/(len1-len0)
-    return Lambda*xyz[ind]+(1-Lambda)*xyz[ind-1]
+    Ds = distance - len0
+    Lambda = Ds / (len1 - len0)
+    return Lambda * xyz[ind] + (1 - Lambda) * xyz[ind - 1]
 
 
 def _extrap(xyz, cumlen, distance):
-    """ Helper function for extrapolate
-    """
-    ind = np.where((cumlen-distance) > 0)[0][0]
-    len0 = cumlen[ind-1]
+    """Helper function for extrapolate"""
+    ind = np.where((cumlen - distance) > 0)[0][0]
+    len0 = cumlen[ind - 1]
     len1 = cumlen[ind]
-    Ds = distance-len0
-    Lambda = Ds/(len1-len0)
-    return Lambda*xyz[ind]+(1-Lambda)*xyz[ind-1]
+    Ds = distance - len0
+    Lambda = Ds / (len1 - len0)
+    return Lambda * xyz[ind] + (1 - Lambda) * xyz[ind - 1]
 
 
 def principal_components(xyz):
-    """ We use PCA to calculate the 3 principal directions for a track
+    """We use PCA to calculate the 3 principal directions for a track
 
     Parameters
     ----------
@@ -821,7 +798,7 @@ def principal_components(xyz):
 
 
 def midpoint2point(xyz, p):
-    """ Calculate distance from midpoint of a curve to arbitrary point p
+    """Calculate distance from midpoint of a curve to arbitrary point p
 
     Parameters
     ----------
@@ -849,8 +826,4 @@ def midpoint2point(xyz, p):
 
     """
     mid = midpoint(xyz)
-    return np.sqrt(np.sum((xyz-mid)**2))
-
-
-if __name__ == "__main__":
-    pass
+    return np.sqrt(np.sum((xyz - mid) ** 2))
