@@ -47,21 +47,22 @@ And the letters A-D represent the following points in
 
 """
 
-from collections import defaultdict, OrderedDict
+from collections import defaultdict
 from functools import wraps
-from itertools import combinations, groupby
+from itertools import combinations
 from warnings import warn
 
-import numpy as np
 from nibabel.affines import apply_affine
+import numpy as np
 from scipy.spatial.distance import cdist
 
 from dipy.core.geometry import dist_to_corner
+from dipy.testing.decorators import warning_for_keywords
 from dipy.tracking import metrics
-from dipy.tracking.vox2track import _streamlines_in_mask
 
 # Import helper functions shared with vox2track
-from dipy.tracking._utils import (_mapping_to_voxel, _to_voxel_coordinates)
+from dipy.tracking._utils import _mapping_to_voxel, _to_voxel_coordinates
+from dipy.tracking.vox2track import _streamlines_in_mask
 
 
 def density_map(streamlines, affine, vol_dims):
@@ -97,7 +98,7 @@ def density_map(streamlines, affine, vol_dims):
 
     """
     lin_T, offset = _mapping_to_voxel(affine)
-    counts = np.zeros(vol_dims, 'int')
+    counts = np.zeros(vol_dims, "int")
     for sl in streamlines:
         inds = _to_voxel_coordinates(sl, lin_T, offset)
         i, j, k = inds.T
@@ -107,11 +108,18 @@ def density_map(streamlines, affine, vol_dims):
     return counts
 
 
-def connectivity_matrix(streamlines, affine, label_volume,
-                        inclusive=False, symmetric=True,
-                        return_mapping=False,
-                        mapping_as_streamlines=False):
-    """ Count the streamlines that start and end at each label pair.
+@warning_for_keywords()
+def connectivity_matrix(
+    streamlines,
+    affine,
+    label_volume,
+    *,
+    inclusive=False,
+    symmetric=True,
+    return_mapping=False,
+    mapping_as_streamlines=False,
+):
+    """Count the streamlines that start and end at each label pair.
 
     Parameters
     ----------
@@ -150,32 +158,29 @@ def connectivity_matrix(streamlines, affine, label_volume,
 
     # Error checking on label_volume
     kind = label_volume.dtype.kind
-    labels_positive = ((kind == 'u') or
-                       ((kind == 'i') and (label_volume.min() >= 0)))
-    valid_label_volume = (labels_positive and label_volume.ndim == 3)
+    labels_positive = (kind == "u") or ((kind == "i") and (label_volume.min() >= 0))
+    valid_label_volume = labels_positive and label_volume.ndim == 3
     if not valid_label_volume:
-        raise ValueError("label_volume must be a 3d integer array with"
-                         "non-negative label values")
+        raise ValueError(
+            "label_volume must be a 3d integer array with" "non-negative label values"
+        )
 
-    matrix = np.zeros((np.max(label_volume)+1, np.max(label_volume)+1),
-                      dtype=np.int64)
+    matrix = np.zeros(
+        (np.max(label_volume) + 1, np.max(label_volume) + 1), dtype=np.int64
+    )
 
     mapping = defaultdict(list)
     lin_T, offset = _mapping_to_voxel(affine)
 
     if inclusive:
-
         for i, sl in enumerate(streamlines):
-
             sl = _to_voxel_coordinates(sl, lin_T, offset)
             x, y, z = sl.T
             if symmetric:
                 crossed_labels = np.unique(label_volume[x, y, z])
             else:
-                crossed_labels = np.unique(label_volume[x, y, z],
-                                           return_index=True)
-                crossed_labels = crossed_labels[0][np.argsort(
-                    crossed_labels[1])]
+                crossed_labels = np.unique(label_volume[x, y, z], return_index=True)
+                crossed_labels = crossed_labels[0][np.argsort(crossed_labels[1])]
 
             for comb in combinations(crossed_labels, 2):
                 matrix[comb] += 1
@@ -187,7 +192,7 @@ def connectivity_matrix(streamlines, affine, label_volume,
                         mapping[comb].append(i)
 
     else:
-        streamlines_end = np.array([sl[0::len(sl)-1] for sl in streamlines])
+        streamlines_end = np.array([sl[0 :: len(sl) - 1] for sl in streamlines])
         streamlines_end = _to_voxel_coordinates(streamlines_end, lin_T, offset)
         x, y, z = streamlines_end.T
         if symmetric:
@@ -213,7 +218,8 @@ def connectivity_matrix(streamlines, affine, label_volume,
         return matrix
 
 
-def ndbincount(x, weights=None, shape=None):
+@warning_for_keywords()
+def ndbincount(x, *, weights=None, shape=None):
     """Like bincount, but for nd-indices.
 
     Parameters
@@ -309,21 +315,21 @@ def subsegment(streamlines, max_segment_length):
 
     """
     for sl in streamlines:
-        diff = (sl[1:] - sl[:-1])
-        dist = np.sqrt((diff*diff).sum(-1))
-        num_segments = np.ceil(dist/max_segment_length).astype('int')
+        diff = sl[1:] - sl[:-1]
+        dist = np.sqrt((diff * diff).sum(-1))
+        num_segments = np.ceil(dist / max_segment_length).astype("int")
 
-        output_sl = np.empty((num_segments.sum()+1, 3), 'float')
+        output_sl = np.empty((num_segments.sum() + 1, 3), "float")
         output_sl[0] = sl[0]
 
         count = 1
         for ii in range(len(num_segments)):
             ns = num_segments[ii]
             if ns == 1:
-                output_sl[count] = sl[ii+1]
+                output_sl[count] = sl[ii + 1]
                 count += 1
             elif ns > 1:
-                small_d = diff[ii]/ns
+                small_d = diff[ii] / ns
                 point = sl[ii]
                 for _ in range(ns):
                     point = point + small_d
@@ -335,11 +341,12 @@ def subsegment(streamlines, max_segment_length):
             else:
                 # this should never happen because ns should be a positive
                 # int
-                assert(ns >= 0)
+                assert ns >= 0
         yield output_sl
 
 
-def seeds_from_mask(mask, affine, density=(1, 1, 1)):
+@warning_for_keywords()
+def seeds_from_mask(mask, affine, *, density=(1, 1, 1)):
     """Create seeds for fiber tracking from a binary mask.
 
     Seeds points are placed evenly distributed in all voxels of ``mask`` which
@@ -373,13 +380,15 @@ def seeds_from_mask(mask, affine, density=(1, 1, 1)):
     --------
     >>> mask = np.zeros((3,3,3), 'bool')
     >>> mask[0,0,0] = 1
-    >>> seeds_from_mask(mask, np.eye(4), [1,1,1])
+    >>> seeds_from_mask(mask, np.eye(4), density=[1,1,1])
     array([[ 0.,  0.,  0.]])
 
     """
-    mask = np.array(mask, dtype=bool, copy=False, ndmin=3)
+    mask = np.asarray(mask, dtype=bool)
+    if mask.ndim < 1:
+        mask = np.reshape(mask, (3,))
     if mask.ndim != 3:
-        raise ValueError('mask cannot be more than 3d')
+        raise ValueError("mask cannot be more than 3d")
 
     density = np.asarray(density, int)
     if density.size == 1:
@@ -390,10 +399,10 @@ def seeds_from_mask(mask, affine, density=(1, 1, 1)):
         raise ValueError("density should be in integer array of shape (3,)")
 
     # Grid of points between -.5 and .5, centered at 0, with given density
-    grid = np.mgrid[0:density[0], 0:density[1], 0:density[2]]
+    grid = np.mgrid[0 : density[0], 0 : density[1], 0 : density[2]]
     grid = grid.T.reshape((-1, 3))
     grid = grid / density
-    grid += (.5 / density - .5)
+    grid += 0.5 / density - 0.5
 
     where = np.argwhere(mask)
 
@@ -410,8 +419,10 @@ def seeds_from_mask(mask, affine, density=(1, 1, 1)):
     return seeds
 
 
-def random_seeds_from_mask(mask, affine, seeds_count=1,
-                           seed_count_per_voxel=True, random_seed=None):
+@warning_for_keywords()
+def random_seeds_from_mask(
+    mask, affine, *, seeds_count=1, seed_count_per_voxel=True, random_seed=None
+):
     """Create randomly placed seeds for fiber tracking from a binary mask.
 
     Seeds points are placed randomly distributed in voxels of ``mask``
@@ -474,9 +485,11 @@ def random_seeds_from_mask(mask, affine, seeds_count=1,
            [-0.41435083, -0.26318949,  0.30127447]])
 
     """
-    mask = np.array(mask, dtype=bool, copy=False, ndmin=3)
+    mask = np.asarray(mask, dtype=bool)
+    if mask.ndim < 1:
+        mask = np.reshape(mask, (3,))
     if mask.ndim != 3:
-        raise ValueError('mask cannot be more than 3d')
+        raise ValueError("mask cannot be more than 3d")
 
     # Randomize the voxels
     rng = np.random.default_rng(random_seed)
@@ -500,12 +513,11 @@ def random_seeds_from_mask(mask, affine, seeds_count=1,
             # Set the random seed with the current seed, the current value of
             # seeds per voxel and the global random seed.
             if random_seed is not None:
-                s_random_seed = hash((np.sum(s) + 1) * i + random_seed) \
-                    % (2**32 - 1)
+                s_random_seed = hash((np.sum(s) + 1) * i + random_seed) % (2**32 - 1)
                 rng = np.random.default_rng(s_random_seed)
             # Generate random triplet
             grid = rng.random(3)
-            seed = s + grid - .5
+            seed = s + grid - 0.5
             seeds.append(seed)
     seeds = np.asarray(seeds)
 
@@ -529,6 +541,7 @@ def _with_initialize(generator):
     called and the first yield value is ignored.
 
     """
+
     @wraps(generator)
     def helper(*args, **kwargs):
         gen = generator(*args, **kwargs)
@@ -539,7 +552,8 @@ def _with_initialize(generator):
 
 
 @_with_initialize
-def target(streamlines, affine, target_mask, include=True):
+@warning_for_keywords()
+def target(streamlines, affine, target_mask, *, include=True):
     """Filter streamlines based on whether or not they pass through an ROI.
 
     Parameters
@@ -582,14 +596,15 @@ def target(streamlines, affine, target_mask, include=True):
             ind = _to_voxel_coordinates(sl, lin_T, offset)
             i, j, k = ind.T
             state = target_mask[i, j, k]
-        except IndexError:
-            raise ValueError("streamlines points are outside of target_mask")
+        except IndexError as e:
+            raise ValueError("streamlines points are outside of target_mask") from e
         if state.any() == include:
             yield sl
 
 
 @_with_initialize
-def target_line_based(streamlines, affine, target_mask, include=True):
+@warning_for_keywords()
+def target_line_based(streamlines, affine, target_mask, *, include=True):
     """Filter streamlines based on whether or not they pass through a ROI,
     using a line-based algorithm. Mostly used as a replacement of `target`
     for compressed streamlines.
@@ -597,6 +612,9 @@ def target_line_based(streamlines, affine, target_mask, include=True):
     This function never returns single-point streamlines, whatever the
     value of `include`.
 
+    See :footcite:`Bresenham1965` and :footcite:p:`Houde2015` for further
+    details about the method.
+
     Parameters
     ----------
     streamlines : iterable
@@ -619,10 +637,7 @@ def target_line_based(streamlines, affine, target_mask, include=True):
 
     References
     ----------
-    [Bresenham5] Bresenham, Jack Elton. "Algorithm for computer control of a
-                 digital plotter", IBM Systems Journal, vol 4, no. 1, 1965.
-    [Houde15] Houde et al. How to avoid biased streamlines-based metrics for
-              streamlines with variable step sizes, ISMRM 2015.
+    .. footbibliography::
 
     See Also
     --------
@@ -632,8 +647,7 @@ def target_line_based(streamlines, affine, target_mask, include=True):
     """
     target_mask = np.array(target_mask, dtype=np.uint8, copy=True)
     lin_T, offset = _mapping_to_voxel(affine)
-    streamline_index = _streamlines_in_mask(
-        streamlines, target_mask, lin_T, offset)
+    streamline_index = _streamlines_in_mask(streamlines, target_mask, lin_T, offset)
     yield
     # End of initialization
 
@@ -641,7 +655,8 @@ def target_line_based(streamlines, affine, target_mask, include=True):
         yield streamlines[idx]
 
 
-def streamline_near_roi(streamline, roi_coords, tol, mode='any'):
+@warning_for_keywords()
+def streamline_near_roi(streamline, roi_coords, tol, *, mode="any"):
     """Is a streamline near an ROI.
 
     Implements the inner loops of the :func:`near_roi` function.
@@ -685,10 +700,10 @@ def streamline_near_roi(streamline, roi_coords, tol, mode='any'):
     else:
         e_s = "For determining relationship to an array, you can use "
         e_s += "one of the following modes: 'any', 'all', 'both_end',"
-        e_s += "'either_end', but you entered: %s." % mode
+        e_s += f"'either_end', but you entered: {mode}."
         raise ValueError(e_s)
 
-    dist = cdist(s, roi_coords, 'euclidean')
+    dist = cdist(s, roi_coords, "euclidean")
 
     if mode in ("any", "either_end"):
         return np.min(dist) <= tol
@@ -696,8 +711,8 @@ def streamline_near_roi(streamline, roi_coords, tol, mode='any'):
         return np.all(np.min(dist, -1) <= tol)
 
 
-def near_roi(streamlines, affine, region_of_interest, tol=None,
-             mode="any"):
+@warning_for_keywords()
+def near_roi(streamlines, affine, region_of_interest, *, tol=None, mode="any"):
     """Provide filtering criteria for a set of streamlines based on whether
     they fall within a tolerance distance from an ROI.
 
@@ -744,8 +759,8 @@ def near_roi(streamlines, affine, region_of_interest, tol=None,
         tol = dtc
     elif tol < dtc:
         w_s = "Tolerance input provided would create gaps in your"
-        w_s += " inclusion ROI. Setting to: %s" % dtc
-        warn(w_s)
+        w_s += f" inclusion ROI. Setting to: {dtc}"
+        warn(w_s, stacklevel=2)
         tol = dtc
 
     roi_coords = np.array(np.where(region_of_interest)).T
@@ -755,15 +770,13 @@ def near_roi(streamlines, affine, region_of_interest, tol=None,
     if isinstance(streamlines, list):
         out = np.zeros(len(streamlines), dtype=bool)
         for ii, sl in enumerate(streamlines):
-            out[ii] = streamline_near_roi(sl, x_roi_coords, tol=tol,
-                                          mode=mode)
+            out[ii] = streamline_near_roi(sl, x_roi_coords, tol=tol, mode=mode)
         return out
     # If it's a generator, we'll need to generate the output into a list
     else:
         out = []
         for sl in streamlines:
-            out.append(streamline_near_roi(sl, x_roi_coords, tol=tol,
-                                           mode=mode))
+            out.append(streamline_near_roi(sl, x_roi_coords, tol=tol, mode=mode))
 
         return np.array(out, dtype=bool)
 
@@ -785,7 +798,8 @@ def length(streamlines):
     return map(metrics.length, streamlines)
 
 
-def unique_rows(in_array, dtype='f4'):
+@warning_for_keywords()
+def unique_rows(in_array, *, dtype="f4"):
     """Find the unique rows in an array.
 
     Parameters
@@ -818,7 +832,8 @@ def unique_rows(in_array, dtype='f4'):
 
 
 @_with_initialize
-def transform_tracking_output(tracking_output, affine, save_seeds=False):
+@warning_for_keywords()
+def transform_tracking_output(tracking_output, affine, *, save_seeds=False):
     """Apply a linear transformation, given by affine, to streamlines.
 
     Parameters
@@ -831,6 +846,7 @@ def transform_tracking_output(tracking_output, affine, save_seeds=False):
         The voxel_to_rasmm matrix, typically from a NIFTI file.
     save_seeds : bool, optional
         If set, seeds associated to streamlines will be also moved and returned
+
     Returns
     -------
     streamlines : generator
@@ -882,7 +898,10 @@ def reduce_rois(rois, include):
     """
     # throw warning if non bool roi detected
     if not np.all([irois.dtype == bool for irois in rois]):
-        warn("Non-boolean input mask detected. Treating all nonzeros as True.")
+        warn(
+            "Non-boolean input mask detected. Treating all nonzeros as True.",
+            stacklevel=2,
+        )
 
     include_roi = np.zeros(rois[0].shape, dtype=bool)
     exclude_roi = np.zeros(rois[0].shape, dtype=bool)
@@ -917,7 +936,8 @@ except AttributeError:
     minimum_at = _min_at
 
 
-def path_length(streamlines, affine, aoi, fill_value=-1):
+@warning_for_keywords()
+def path_length(streamlines, affine, aoi, *, fill_value=-1):
     """Compute the shortest path, along any streamline, between aoi and
     each voxel.
 
@@ -990,6 +1010,8 @@ def _as_segments(streamline, break_points):
 def max_angle_from_curvature(min_radius_curvature, step_size):
     """Get the maximum deviation angle from the minimum radius curvature.
 
+    See :footcite:p:`Tournier2012` for further details about the method.
+
     Parameters
     ----------
     min_radius_curvature: float
@@ -1005,15 +1027,14 @@ def max_angle_from_curvature(min_radius_curvature, step_size):
 
     References
     ----------
-    For more information:
-    https://onlinelibrary.wiley.com/doi/full/10.1002/ima.22005
+    .. footbibliography::
 
     """
-    max_angle = 2. * np.arcsin(step_size / (2. * min_radius_curvature))
+    max_angle = 2.0 * np.arcsin(step_size / (2.0 * min_radius_curvature))
     if np.isnan(max_angle) or max_angle > np.pi / 2 or max_angle <= 0:
         w_msg = "The max_angle found is outside the interval [0 ; pi/2]."
         w_msg += "max_angle will be set to the default value pi/2"
-        warn(w_msg)
+        warn(w_msg, stacklevel=2)
         max_angle = np.pi / 2.0
     return max_angle
 
@@ -1021,6 +1042,8 @@ def max_angle_from_curvature(min_radius_curvature, step_size):
 def min_radius_curvature_from_angle(max_angle, step_size):
     """Get minimum radius of curvature from a deviation angle.
 
+    See :footcite:p:`Tournier2012` for further details about the method.
+
     Parameters
     ----------
     max_angle: float
@@ -1037,14 +1060,63 @@ def min_radius_curvature_from_angle(max_angle, step_size):
 
     References
     ----------
-    More information:
-    https://onlinelibrary.wiley.com/doi/full/10.1002/ima.22005
+    .. footbibliography::
 
     """
     if np.isnan(max_angle) or max_angle > np.pi / 2 or max_angle <= 0:
         w_msg = "The max_angle found is outside the interval [0 ; pi/2]."
         w_msg += "max_angle will be set to the default value pi/2"
-        warn(w_msg)
+        warn(w_msg, stacklevel=2)
         max_angle = np.pi / 2.0
     min_radius_curvature = step_size / 2 / np.sin(max_angle / 2)
     return min_radius_curvature
+
+
+def seeds_directions_pairs(positions, peaks, *, max_cross=-1):
+    """
+    Pair each seed to the corresponding peaks. If multiple peaks are available
+    the seed is repeated for each.
+
+    Parameters
+    ----------
+    positions : array, (N, 3)
+        Coordinates of the N positions.
+    peaks : array (N, M, 3)
+        Peaks at each position
+    max_cross : int, optional
+        The maximum number of direction to track from each seed in crossing
+        voxels. By default all voxel peaks are used.
+
+    Returns
+    -------
+    seeds : array (K, 3)
+    directions : array (K, 3)
+    """
+
+    if (
+        not len(positions.shape) == 2
+        or not len(peaks.shape) == 3
+        or not positions.shape[0] == peaks.shape[0]
+        or not positions.shape[1] == 3
+        or not peaks.shape[2] == 3
+        or not peaks.shape[1] > 0
+    ):
+        raise ValueError(
+            "The array shapes of the positions and peaks should"
+            " be (N,3) and (N,M,3), respectively."
+        )
+
+    seeds = []
+    directions = []
+
+    for i, s in enumerate(positions):
+        voxel_dirs_norm = np.linalg.norm(peaks[i, :, :], axis=1)
+        voxel_dirs = (
+            peaks[i, voxel_dirs_norm > 0, :]
+            / voxel_dirs_norm[voxel_dirs_norm > 0, np.newaxis]
+        )
+        for d in voxel_dirs[:max_cross, :]:
+            seeds.append(s)
+            directions.append(d)
+
+    return np.array(seeds), np.array(directions)
