@@ -1,14 +1,20 @@
-""" Testing OpenMP utilities
-"""
+"""Testing OpenMP utilities"""
 
 import os
-from dipy.utils.omp import (cpu_count, thread_count, default_threads,
-                            _set_omp_threads, _restore_omp_threads,
-                            have_openmp, determine_num_threads)
 
-import pytest
-from dipy.utils.parallel import has_ray, has_joblib
 from numpy.testing import assert_equal, assert_raises
+import pytest
+
+from dipy.utils.omp import (
+    _restore_omp_threads,
+    _set_omp_threads,
+    cpu_count,
+    default_threads,
+    determine_num_threads,
+    have_openmp,
+    thread_count,
+)
+from dipy.utils.parallel import has_joblib, has_ray
 
 
 def test_set_omp_threads():
@@ -30,12 +36,11 @@ def test_set_omp_threads():
         assert_equal(cpu_count(), 1)
 
 
-@pytest.mark.skipif(has_joblib or has_ray,
-                    reason="joblib and/or ray are installed")
+@pytest.mark.skipif(has_joblib or has_ray, reason="joblib and/or ray are installed")
 def test_default_threads():
     if have_openmp:
         try:
-            expected_threads = int(os.environ.get('OMP_NUM_THREADS', None))
+            expected_threads = int(os.environ.get("OMP_NUM_THREADS", None))
             if expected_threads < 1:
                 raise ValueError("invalid number of threads")
         except (ValueError, TypeError):
@@ -63,5 +68,4 @@ def test_determine_num_threads():
 
     # -2 should be one less than -1 (if there are more than 1 cores)
     if determine_num_threads(-1) > 1:
-        assert_equal(determine_num_threads(-1),
-                     determine_num_threads(-2) + 1)
+        assert_equal(determine_num_threads(-1), determine_num_threads(-2) + 1)
