@@ -1,9 +1,10 @@
-""" Testing volumes """
+"""Testing volumes"""
 
 import numpy as np
 import numpy.testing as npt
 
-from dipy.utils.volume import (adjacency_calc)
+from dipy.utils.volume import adjacency_calc
+
 
 def test_adjacency_calc():
     """
@@ -12,9 +13,8 @@ def test_adjacency_calc():
 
     cutoff = 1.99
     for img_shape in [(50, 50), (50, 50, 5)]:
-
         mask = None
-        adj = adjacency_calc(img_shape, mask, cutoff=cutoff)
+        adj = adjacency_calc(img_shape, mask=mask, cutoff=cutoff)
         # check that adj in the first voxel is correct
         adj[0].sort()
         if len(img_shape) == 2:
@@ -27,7 +27,7 @@ def test_adjacency_calc():
             mask[10:40, 20:30] = 1
         if len(img_shape) == 3:
             mask[10:40, 20:30, :] = 1
-        adj = adjacency_calc(img_shape, mask, cutoff=cutoff)
+        adj = adjacency_calc(img_shape, mask=mask, cutoff=cutoff)
         # check that adj in the first voxel is correct
         if len(img_shape) == 2:
             npt.assert_equal(adj[0], [0, 1, 10, 11])
@@ -35,4 +35,3 @@ def test_adjacency_calc():
             npt.assert_equal(adj[0], [0, 1, 5, 6, 50, 51, 55, 56])
         # test that adj only corresponds to flattened and masked data
         npt.assert_equal(len(adj), mask.sum())
-
