@@ -1,3 +1,4 @@
+import logging
 from warnings import warn
 
 import numpy as np
@@ -53,6 +54,13 @@ HELP_MESSAGE = """
 >> o: hide/show this panel
 """
 
+SHORTCUT_MESSAGE = """
+>> shift + drag: move
+>> ctrl/cmd + drag: rotate
+>> ctrl/cmd + r: reset
+>> o: hide/show this panel
+"""
+
 
 class Horizon:
     @warning_for_keywords()
@@ -179,7 +187,7 @@ class Horizon:
         self.clusters_gt = clusters_gt
         self.world_coords = world_coords
         self.interactive = interactive
-        self.prng = np.random.RandomState(27)
+        self.prng = np.random.default_rng(27)
         self.tractograms = tractograms or []
         self.out_png = out_png
         self.images = images or []
@@ -213,12 +221,13 @@ class Horizon:
         self.__tab_mgr = None
 
         self.__help_visible = True
+        self._shortcut_help_visible = True
 
         # TODO: Move to another class/module
         self.__hide_centroids = True
         self.__select_all = False
 
-        self.__win_size = (0, 0)
+        self._win_size = (0, 0)
 
     # TODO: Move to another class/module
     def __expand(self):
@@ -280,18 +289,27 @@ class Horizon:
 
     def __key_press_events(self, obj, event):
         key = obj.GetKeySym()
+        if key in ("r", "R") and obj.GetControlKey():
+            self._scene.reset_camera_tight()
+            self.show_m.render()
+        if key in ("o", "O"):
+            if self._shortcut_help_visible:
+                self._scene.rm(*self.shortcut_panel.actors)
+                self._shortcut_help_visible = False
+            else:
+                self._scene.add(*self.shortcut_panel.actors)
+                self._shortcut_help_visible = True
+            self.show_m.render()
         # TODO: Move to another class/module
         if self.cluster:
             # retract help panel
             if key in ("o", "O"):
-                panel_size = self.help_panel._get_size()
                 if self.__help_visible:
-                    new_pos = np.array(self.__win_size) - 10
+                    self._scene.rm(*self.help_panel.actors)
                     self.__help_visible = False
                 else:
-                    new_pos = np.array(self.__win_size) - panel_size - 5
+                    self._scene.add(*self.help_panel.actors)
                     self.__help_visible = True
-                self.help_panel._set_position(new_pos)
                 self.show_m.render()
             if key in ("a", "A"):
                 self.__show_all()
@@ -370,14 +388,14 @@ class Horizon:
                 c = cluster_actors[bundle]["cluster"]
                 indices = tractogram_clusters[t][c]
                 saving_streamlines.extend(Streamlines(indices))
-        print("Saving result in tmp.trk")
+        logging.info("Saving result in tmp.trk")
 
         # Using the header of the first of the tractograms
         sft_new = StatefulTractogram(
             saving_streamlines, self.tractograms[0], Space.RASMM
         )
         save_tractogram(sft_new, "tmp.trk", bbox_valid_check=False)
-        print("Saved!")
+        logging.info("Saved!")
 
     # TODO: Move to another class/module
     def __show_all(self):
@@ -407,17 +425,18 @@ class Horizon:
             self.__select_all = True
         self.show_m.render()
 
-    def __win_callback(self, obj, event):
-        if self.__win_size != obj.GetSize():
-            self.__win_size = obj.GetSize()
+    def __win_callback(self, obj, _event):
+        if self._win_size != obj.GetSize():
+            self._win_size = obj.GetSize()
             if len(self.__tabs) > 0:
-                self.__tab_mgr.reposition(self.__win_size)
+                self.__tab_mgr.reposition(self._win_size)
+            panel_size = self.shortcut_panel._get_size()
+            self.shortcut_panel._set_position(
+                (5, self._win_size[1] - panel_size[1] - 5)
+            )
             if self.cluster:
-                if self.__help_visible:
-                    panel_size = self.help_panel._get_size()
-                    new_pos = np.array(self.__win_size) - panel_size - 5
-                else:
-                    new_pos = np.array(self.__win_size) - 10
+                panel_size = self.help_panel._get_size()
+                new_pos = np.array(self._win_size) - panel_size - 5
                 self.help_panel._set_position(new_pos)
 
     def build_scene(self):
@@ -446,6 +465,7 @@ class Horizon:
 
     def build_show(self, scene):
         self._scene = scene
+        self._win_size = self._scene.GetSize()
 
         title = f"Horizon {horizon_version}"
         self.show_m = window.ShowManager(
@@ -516,6 +536,17 @@ class Horizon:
                     ClustersTab(self.__clusters_visualizer, self.cluster_thr)
                 )
 
+        text_block = build_label(SHORTCUT_MESSAGE, font_size=18)
+
+        self.shortcut_panel = ui.Panel2D(
+            size=(260, 115),
+            position=(5, 960),
+            color=(0.8, 0.8, 1.0),
+            opacity=0.2,
+            align="left",
+        )
+        self.shortcut_panel.add_element(text_block.obj, coords=(0.02, 0.01))
+        scene.add(self.shortcut_panel)
         sync_slices = sync_vol = False
         self.images = check_img_dtype(self.images)
         if len(self.images) > 0:
@@ -544,6 +575,7 @@ class Horizon:
                         affine=affine,
                         world_coords=self.world_coords,
                         rgb=self.rgb,
+                        fname=fname,
                     )
                     self.__tabs.append(
                         SlicesTab(
@@ -588,8 +620,6 @@ class Horizon:
                 surf_tab = SurfaceTab(surf_viz, title, fname)
                 self.__tabs.append(surf_tab)
 
-        self.__win_size = scene.GetSize()
-
         if len(self.__tabs) > 0:
             self.__tab_mgr = TabManager(
                 tabs=self.__tabs,
@@ -673,7 +703,7 @@ class Horizon:
             self.show_m.render()
 
         def right_click_cluster_callback(obj, event):
-            print("Cluster Area Selected")
+            logging.info("Cluster Area Selected")
             self.show_m.render()
 
         for cl in self.cla:
