@@ -1,7 +1,11 @@
 from dipy.viz.horizon.visualizer.cluster import ClustersVisualizer
+from dipy.viz.horizon.visualizer.peak import PeaksVisualizer
 from dipy.viz.horizon.visualizer.slice import SlicesVisualizer
 from dipy.viz.horizon.visualizer.surface import SurfaceVisualizer
-from dipy.viz.horizon.visualizer.peak import PeaksVisualizer
 
-__all__ = ['ClustersVisualizer', 'SlicesVisualizer', 'SurfaceVisualizer',
-           'PeaksVisualizer']
+__all__ = [
+    "ClustersVisualizer",
+    "SlicesVisualizer",
+    "SurfaceVisualizer",
+    "PeaksVisualizer",
+]
