@@ -1,11 +1,12 @@
-import warnings
 from os.path import join as pjoin
+import warnings
 
 import numpy as np
 
+from dipy.testing.decorators import warning_for_keywords
 from dipy.utils.optpkg import optional_package
 
-fury, has_fury, setup_module = optional_package('fury', min_version="0.9.0")
+fury, has_fury, setup_module = optional_package("fury", min_version="0.9.0")
 if has_fury:
     from fury.colormap import colormap_lookup_table
     from fury.lib import (
@@ -24,18 +25,16 @@ if has_fury:
         import_fury_shader,
         shader_to_actor,
     )
-    from fury.utils import (
-        apply_affine,
-        numpy_to_vtk_colors,
-        numpy_to_vtk_points
-    )
+    from fury.utils import apply_affine, numpy_to_vtk_colors, numpy_to_vtk_points
 else:
+
     class Actor:
         pass
 
     def calldata_type(func):
         def wrapper(*args, **kwargs):
             return func(*args, **kwargs)
+
         return wrapper
 
     def VTK_OBJECT(*args):
@@ -56,9 +55,7 @@ class PeakActor(Actor):
         Peak values. The shape of the array should be (X, Y, Z, D).
     affine : array, optional
         4x4 transformation array from native coordinates to world coordinates.
-    colors : None or string ('rgb_standard') or tuple (3D or 4D) or
-             array/ndarray (N, 3 or 4) or array/ndarray (K, 3 or 4) or
-             array/ndarray(N, ) or array/ndarray (K, )
+    colors : None or string ('rgb_standard') or tuple (3D or 4D) or array/ndarray (N, 3 or 4) or (K, 3 or 4) or (N, ) or (K, )
         If None a standard orientation colormap is used for every line.
         If one tuple of color is used. Then all streamlines will have the same
         color.
@@ -71,21 +68,22 @@ class PeakActor(Actor):
         If an array (K,) is given, where K is the number of lines then these
         are considered as the values to be used by the colormap.
     lookup_colormap : vtkLookupTable, optional
-        Add a default lookup table to the colormap. Default is None which calls
-        :func:`fury.actor.colormap_lookup_table`.
+        Add a default lookup table to the colormap. Look at
+        :func:`fury.actor.colormap_lookup_table` for more information.
     linewidth : float, optional
-        Line thickness. Default is 1.
+        Line thickness.
     symmetric: bool, optional
         If True, peaks are drawn for both peaks_dirs and -peaks_dirs. Else,
-        peaks are only drawn for directions given by peaks_dirs. Default is
-        True.
+        peaks are only drawn for directions given by peaks_dirs.
 
-    """
+    """  # noqa: E501
 
+    @warning_for_keywords()
     def __init__(
         self,
         directions,
         indices,
+        *,
         values=None,
         affine=None,
         colors=None,
@@ -93,13 +91,12 @@ class PeakActor(Actor):
         linewidth=1,
         symmetric=True,
     ):
-
         if affine is not None:
             w_pos = apply_affine(affine, np.asarray(indices).T)
 
         valid_dirs = directions[indices]
 
-        num_dirs = len(np.where(valid_dirs >= 0)[0])
+        num_dirs = len(np.nonzero(np.abs(valid_dirs).max(axis=-1) > 0)[0])
 
         pnts_per_line = 2
 
@@ -112,7 +109,9 @@ class PeakActor(Actor):
                 xyz = np.asarray(center)
             else:
                 xyz = w_pos[idx, :]
-            valid_peaks = np.where(valid_dirs[idx, :, :] >= 0)[0]
+            valid_peaks = np.nonzero(np.abs(valid_dirs[idx, :, :]).max(axis=-1) > 0.0)[
+                0
+            ]
             for direction in valid_peaks:
                 if values is not None:
                     pv = values[center][direction]
@@ -151,13 +150,13 @@ class PeakActor(Actor):
         self.__mapper.SetInputData(poly_data)
         self.__mapper.ScalarVisibilityOn()
         self.__mapper.SetScalarModeToUsePointFieldData()
-        self.__mapper.SelectColorArray('colors')
+        self.__mapper.SelectColorArray("colors")
         self.__mapper.Update()
 
         self.SetMapper(self.__mapper)
 
-        attribute_to_actor(self, centers_array, 'center')
-        attribute_to_actor(self, diffs_array, 'diff')
+        attribute_to_actor(self, centers_array, "center")
+        attribute_to_actor(self, diffs_array, "diff")
 
         vs_var_dec = """
             in vec3 center;
@@ -171,17 +170,14 @@ class PeakActor(Actor):
             uniform vec3 lowRanges;
             uniform vec3 highRanges;
             """
-        orient_to_rgb = import_fury_shader(pjoin('utils',
-                                                 'orient_to_rgb.glsl'))
+        orient_to_rgb = import_fury_shader(pjoin("utils", "orient_to_rgb.glsl"))
         visible_cross_section = import_fury_shader(
-            pjoin('interaction', 'visible_cross_section.glsl')
+            pjoin("interaction", "visible_cross_section.glsl")
         )
-        visible_range = import_fury_shader(pjoin('interaction',
-                                                 'visible_range.glsl'))
+        visible_range = import_fury_shader(pjoin("interaction", "visible_range.glsl"))
 
         vs_dec = compose_shader([vs_var_dec, orient_to_rgb])
-        fs_dec = compose_shader([fs_var_dec, visible_cross_section,
-                                 visible_range])
+        fs_dec = compose_shader([fs_var_dec, visible_cross_section, visible_range])
 
         vs_impl = """
             centerVertexMCVSOutput = center;
@@ -204,9 +200,9 @@ class PeakActor(Actor):
             }
             """
 
-        shader_to_actor(self, 'vertex', decl_code=vs_dec, impl_code=vs_impl)
-        shader_to_actor(self, 'fragment', decl_code=fs_dec)
-        shader_to_actor(self, 'fragment', impl_code=fs_impl, block='light')
+        shader_to_actor(self, "vertex", decl_code=vs_dec, impl_code=vs_impl)
+        shader_to_actor(self, "fragment", decl_code=fs_dec)
+        shader_to_actor(self, "fragment", impl_code=fs_impl, block="light")
 
         # Color scale with a lookup table
         if colors_are_scalars:
@@ -223,8 +219,8 @@ class PeakActor(Actor):
         if self.__global_opacity >= 0:
             self.GetProperty().SetOpacity(self.__global_opacity)
 
-        self.__min_centers = np.min(indices, axis=1)
-        self.__max_centers = np.max(indices, axis=1)
+        self.__min_centers = np.zeros(shape=(3,))
+        self.__max_centers = np.array(directions.shape[:3])
 
         self.__is_range = True
         self.__low_ranges = self.__min_centers
@@ -238,10 +234,10 @@ class PeakActor(Actor):
     @calldata_type(VTK_OBJECT)
     def __display_peaks_vtk_callback(self, caller, event, calldata=None):
         if calldata is not None:
-            calldata.SetUniformi('isRange', self.__is_range)
-            calldata.SetUniform3f('highRanges', self.__high_ranges)
-            calldata.SetUniform3f('lowRanges', self.__low_ranges)
-            calldata.SetUniform3f('crossSection', self.__cross_section)
+            calldata.SetUniformi("isRange", self.__is_range)
+            calldata.SetUniform3f("highRanges", self.__high_ranges)
+            calldata.SetUniform3f("lowRanges", self.__low_ranges)
+            calldata.SetUniform3f("crossSection", self.__cross_section)
 
     def display_cross_section(self, x, y, z):
         if self.__is_range:
@@ -297,8 +293,10 @@ class PeakActor(Actor):
         return self.__min_centers
 
 
+@warning_for_keywords()
 def peak(
     peaks_dirs,
+    *,
     peaks_values=None,
     mask=None,
     affine=None,
@@ -307,7 +305,7 @@ def peak(
     lookup_colormap=None,
     symmetric=True,
 ):
-    """Visualize peak directions as given from ``peaks_from_model``.
+    """Visualize peak directions as given from ``peaks_from_model`` function.
 
     Parameters
     ----------
@@ -323,8 +321,8 @@ def peak(
         Default None. If None then every peak gets an orientation color
         in similarity to a DEC map.
     lookup_colormap : vtkLookupTable, optional
-        Add a default lookup table to the colormap. Default is None which calls
-        :func:`fury.actor.colormap_lookup_table`.
+        Add a default lookup table to the colormap. Look at
+        :func:`fury.actor.colormap_lookup_table` for more information.
     linewidth : float, optional
         Line thickness. Default is 1.
     symmetric : bool, optional
@@ -341,15 +339,15 @@ def peak(
     """
     if peaks_dirs.ndim != 5:
         raise ValueError(
-            'Invalid peak directions. The shape of the structure '
-            'must be (XxYxZxDx3). Your data has {} dimensions.'
-            ''.format(peaks_dirs.ndim)
+            "Invalid peak directions. The shape of the structure "
+            f"must be (XxYxZxDx3). Your data has {peaks_dirs.ndim} dimensions."
+            ""
         )
     if peaks_dirs.shape[4] != 3:
         raise ValueError(
-            'Invalid peak directions. The shape of the last '
-            'dimension must be 3. Your data has a last dimension '
-            'of {}.'.format(peaks_dirs.shape[4])
+            "Invalid peak directions. The shape of the last "
+            "dimension must be 3. Your data has a last dimension "
+            f"of {peaks_dirs.shape[4]}."
         )
 
     dirs_shape = peaks_dirs.shape
@@ -357,36 +355,37 @@ def peak(
     if peaks_values is not None:
         if peaks_values.ndim != 4:
             raise ValueError(
-                'Invalid peak values. The shape of the structure '
-                'must be (XxYxZxD). Your data has {} dimensions.'
-                ''.format(peaks_values.ndim)
+                "Invalid peak values. The shape of the structure "
+                f"must be (XxYxZxD). Your data has {peaks_values.ndim} dimensions."
             )
         vals_shape = peaks_values.shape
         if vals_shape != dirs_shape[:4]:
             raise ValueError(
-                'Invalid peak values. The shape of the values '
-                'must coincide with the shape of the directions.'
+                "Invalid peak values. The shape of the values "
+                "must coincide with the shape of the directions."
             )
 
     valid_mask = np.abs(peaks_dirs).max(axis=(-2, -1)) > 0
     if mask is not None:
         if mask.ndim != 3:
             warnings.warn(
-                'Invalid mask. The mask must be a 3D array. The '
-                'passed mask has {} dimensions. Ignoring passed '
-                'mask.'.format(mask.ndim),
+                "Invalid mask. The mask must be a 3D array. The "
+                f"passed mask has {mask.ndim} dimensions. Ignoring passed "
+                "mask.",
                 UserWarning,
+                stacklevel=2,
             )
         elif mask.shape != dirs_shape[:3]:
             warnings.warn(
-                'Invalid mask. The shape of the mask must coincide '
-                'with the shape of the directions. Ignoring passed '
-                'mask.',
+                "Invalid mask. The shape of the mask must coincide "
+                "with the shape of the directions. Ignoring passed "
+                "mask.",
                 UserWarning,
+                stacklevel=2,
             )
         else:
             valid_mask = np.logical_and(valid_mask, mask)
-    indices = np.where(valid_mask >= 0)
+    indices = np.where(valid_mask)
 
     return PeakActor(
         peaks_dirs,
@@ -400,7 +399,8 @@ def peak(
     )
 
 
-def _peaks_colors_from_points(points, colors=None, points_per_line=2):
+@warning_for_keywords()
+def _peaks_colors_from_points(points, *, colors=None, points_per_line=2):
     """Return a VTK scalar array containing colors information for each one of
     the peaks according to the policy defined by the parameter colors.
 
@@ -440,7 +440,7 @@ def _peaks_colors_from_points(points, colors=None, points_per_line=2):
     num_lines = num_pnts // points_per_line
     colors_are_scalars = False
     global_opacity = 1
-    if colors is None or colors == 'rgb_standard':
+    if colors is None or colors == "rgb_standard":
         # Automatic RGB colors
         colors = np.asarray((0, 0, 0))
         color_array = numpy_to_vtk_colors(np.tile(255 * colors, (num_pnts, 1)))
@@ -453,8 +453,7 @@ def _peaks_colors_from_points(points, colors=None, points_per_line=2):
         if len(colors) == num_lines:
             pnts_colors = np.repeat(colors, points_per_line, axis=0)
             if colors.ndim == 1:  # Scalar per line
-                color_array = numpy_support.numpy_to_vtk(pnts_colors,
-                                                         deep=True)
+                color_array = numpy_support.numpy_to_vtk(pnts_colors, deep=True)
                 colors_are_scalars = True
             elif colors.ndim == 2:  # RGB(A) color per line
                 global_opacity = 1 if colors.shape[1] == 3 else -1
@@ -467,11 +466,12 @@ def _peaks_colors_from_points(points, colors=None, points_per_line=2):
                 global_opacity = 1 if colors.shape[1] == 3 else -1
                 color_array = numpy_to_vtk_colors(255 * colors)
 
-    color_array.SetName('colors')
+    color_array.SetName("colors")
     return color_array, colors_are_scalars, global_opacity
 
 
-def _points_to_vtk_cells(points, points_per_line=2):
+@warning_for_keywords()
+def _points_to_vtk_cells(points, *, points_per_line=2):
     """Return the VTK cell array for the peaks given the set of points
     coordinates.
 
@@ -504,15 +504,12 @@ def _points_to_vtk_cells(points, points_per_line=2):
     this actor the creation of this array requires a 2 points padding
     between indices.
     """
-    offset = np.asarray(list(range(0, num_pnts + 1, points_per_line)),
-                        dtype=int)
+    offset = np.asarray(list(range(0, num_pnts + 1, points_per_line)), dtype=int)
 
     vtk_array_type = numpy_support.get_vtk_array_type(connectivity.dtype)
     cell_array.SetData(
-        numpy_support.numpy_to_vtk(offset, deep=True,
-                                   array_type=vtk_array_type),
-        numpy_support.numpy_to_vtk(connectivity, deep=True,
-                                   array_type=vtk_array_type),
+        numpy_support.numpy_to_vtk(offset, deep=True, array_type=vtk_array_type),
+        numpy_support.numpy_to_vtk(connectivity, deep=True, array_type=vtk_array_type),
     )
 
     cell_array.SetNumberOfCells(num_cells)
