@@ -1,5 +1,8 @@
 import numpy as np
+
+from dipy.testing.decorators import warning_for_keywords
 from dipy.utils.optpkg import optional_package
+
 matplotlib, has_mpl, setup_module = optional_package("matplotlib")
 plt, _, _ = optional_package("matplotlib.pyplot")
 
@@ -19,7 +22,7 @@ def _tile_plot(imgs, titles, **kwargs):
 
 
 def simple_plot(file_name, title, x, y, xlabel, ylabel):
-    """ Saves the simple plot with given x and y values
+    """Saves the simple plot with given x and y values
 
     Parameters
     ----------
@@ -49,8 +52,11 @@ def simple_plot(file_name, title, x, y, xlabel, ylabel):
     plt.clf()
 
 
-def overlay_images(img0, img1, title0='', title_mid='', title1='', fname=None, **fig_kwargs):
-    r""" Plot two images one on top of the other using red and green channels.
+@warning_for_keywords()
+def overlay_images(
+    img0, img1, *, title0="", title_mid="", title1="", fname=None, **fig_kwargs
+):
+    r"""Plot two images one on top of the other using red and green channels.
 
     Creates a figure containing three images: the first image to the left
     plotted on the red channel of a color image, the second to the right
@@ -67,19 +73,20 @@ def overlay_images(img0, img1, title0='', title_mid='', title1='', fname=None, *
     img1 : array, shape(R, C)
         the image to be plotted on the green channel, to the right of the
         figure
-    title0 : string (optional)
+    title0 : string, optional
         the title to be written on top of the image to the left. By default, no
         title is displayed.
-    title_mid : string (optional)
+    title_mid : string, optional
         the title to be written on top of the middle image. By default, no
         title is displayed.
-    title1 : string (optional)
+    title1 : string, optional
         the title to be written on top of the image to the right. By default,
         no title is displayed.
-    fname : string (optional)
+    fname : string, optional
         the file name to write the resulting figure. If None (default), the
         image is not saved.
-    fig_kwargs: extra parameters for saving figure, e.g. `dpi=300`.
+    fig_kwargs : dict
+        Extra parameters for saving figure, e.g. `dpi=300`.
     """
     # Normalize the input images to [0,255]
     img0 = 255 * ((img0 - img0.min()) / (img0.max() - img0.min()))
@@ -97,12 +104,11 @@ def overlay_images(img0, img1, title0='', title_mid='', title1='', fname=None, *
     overlay[..., 0] = img0
     overlay[..., 1] = img1
 
-    fig = _tile_plot([img0_red, overlay, img1_green],
-                     [title0, title_mid, title1])
+    fig = _tile_plot([img0_red, overlay, img1_green], [title0, title_mid, title1])
 
     # If a file name was given, save the figure
     if fname is not None:
-        fig.savefig(fname, bbox_inches='tight', **fig_kwargs)
+        fig.savefig(fname, bbox_inches="tight", **fig_kwargs)
 
     return fig
 
@@ -132,9 +138,9 @@ def draw_lattice_2d(nrows, ncols, delta):
         R = 1 + (delta + 1) * nrows
         C = 1 + (delta + 1) * ncols
     """
-    lattice = np.ndarray((1 + (delta + 1) * nrows,
-                          1 + (delta + 1) * ncols),
-                         dtype=np.float64)
+    lattice = np.ndarray(
+        (1 + (delta + 1) * nrows, 1 + (delta + 1) * ncols), dtype=np.float64
+    )
 
     # Fill the lattice with "white"
     lattice[...] = 127
@@ -150,10 +156,19 @@ def draw_lattice_2d(nrows, ncols, delta):
     return lattice
 
 
-def plot_2d_diffeomorphic_map(mapping, delta=10, fname=None,
-                              direct_grid_shape=None, direct_grid2world=-1,
-                              inverse_grid_shape=None, inverse_grid2world=-1,
-                              show_figure=True, **fig_kwargs):
+@warning_for_keywords()
+def plot_2d_diffeomorphic_map(
+    mapping,
+    *,
+    delta=10,
+    fname=None,
+    direct_grid_shape=None,
+    direct_grid2world=-1,
+    inverse_grid_shape=None,
+    inverse_grid2world=-1,
+    show_figure=True,
+    **fig_kwargs,
+):
     r"""Draw the effect of warping a regular lattice by a diffeomorphic map.
 
     Draws a diffeomorphic map by showing the effect of the deformation on a
@@ -201,7 +216,8 @@ def plot_2d_diffeomorphic_map(mapping, delta=10, fname=None,
     show_figure : bool, optional
         if True (default), the deformed grids will be plotted using matplotlib,
         else the grids are just returned
-    fig_kwargs: extra parameters for saving figure, e.g. `dpi=300`.
+    fig_kwargs : dict
+        Extra parameters for saving figure, e.g. `dpi=300`.
 
     Returns
     -------
@@ -257,12 +273,18 @@ def plot_2d_diffeomorphic_map(mapping, delta=10, fname=None,
     lattice_out = draw_lattice_2d(
         (inverse_grid_shape[0] + delta) // (delta + 1),
         (inverse_grid_shape[1] + delta) // (delta + 1),
-        delta)
-    lattice_out = lattice_out[0:inverse_grid_shape[0], 0:inverse_grid_shape[1]]
+        delta,
+    )
+    lattice_out = lattice_out[0 : inverse_grid_shape[0], 0 : inverse_grid_shape[1]]
 
     # Warp in the forward direction (sampling it on the input grid)
-    warped_forward = mapping.transform(lattice_out, 'linear', world_to_image,
-                                       direct_grid_shape, direct_grid2world)
+    warped_forward = mapping.transform(
+        lattice_out,
+        interpolation="linear",
+        image_world2grid=world_to_image,
+        out_shape=direct_grid_shape,
+        out_grid2world=direct_grid2world,
+    )
 
     # Now, the world-to-image (image = drawn lattice on the input grid)
     # transformation is the inverse of the input affine
@@ -271,15 +293,21 @@ def plot_2d_diffeomorphic_map(mapping, delta=10, fname=None,
         world_to_image = np.linalg.inv(direct_grid2world)
 
     # Draw the squares on the input grid
-    lattice_in = draw_lattice_2d((direct_grid_shape[0] + delta) // (delta + 1),
-                                 (direct_grid_shape[1] + delta) // (delta + 1),
-                                 delta)
-    lattice_in = lattice_in[0:direct_grid_shape[0], 0:direct_grid_shape[1]]
+    lattice_in = draw_lattice_2d(
+        (direct_grid_shape[0] + delta) // (delta + 1),
+        (direct_grid_shape[1] + delta) // (delta + 1),
+        delta,
+    )
+    lattice_in = lattice_in[0 : direct_grid_shape[0], 0 : direct_grid_shape[1]]
 
     # Warp in the backward direction (sampling it on the output grid)
     warped_backward = mapping.transform_inverse(
-        lattice_in, 'linear', world_to_image, inverse_grid_shape,
-        inverse_grid2world)
+        lattice_in,
+        interpolation="linear",
+        image_world2grid=world_to_image,
+        out_shape=inverse_grid_shape,
+        out_grid2world=inverse_grid2world,
+    )
 
     # Now plot the grids
     if show_figure:
@@ -287,21 +315,22 @@ def plot_2d_diffeomorphic_map(mapping, delta=10, fname=None,
 
         plt.subplot(1, 2, 1).set_axis_off()
         plt.imshow(warped_forward, cmap=plt.cm.gray)
-        plt.title('Direct transform')
+        plt.title("Direct transform")
 
         plt.subplot(1, 2, 2).set_axis_off()
         plt.imshow(warped_backward, cmap=plt.cm.gray)
-        plt.title('Inverse transform')
+        plt.title("Inverse transform")
 
         # Finally, save the figure to disk
         if fname is not None:
-            plt.savefig(fname, bbox_inches='tight', **fig_kwargs)
+            plt.savefig(fname, bbox_inches="tight", **fig_kwargs)
 
     # Return the deformed grids
     return warped_forward, warped_backward
 
 
-def plot_slices(V, slice_indices=None, fname=None, **fig_kwargs):
+@warning_for_keywords()
+def plot_slices(V, *, slice_indices=None, fname=None, **fig_kwargs):
     r"""Plot 3 slices from the given volume: 1 sagittal, 1 coronal and 1 axial
 
     Creates a figure showing the axial, coronal and sagittal slices at the
@@ -312,15 +341,16 @@ def plot_slices(V, slice_indices=None, fname=None, **fig_kwargs):
     ----------
     V : array, shape (S, R, C)
         the 3D volume to extract the slices from
-    slice_indices : array, shape (3,) (optional)
+    slice_indices : array, shape (3,), optional
         the indices of the sagittal (slice_indices[0]), coronal
         (slice_indices[1])
         and axial (slice_indices[2]) slices to be displayed. If None, the
         middle slices along each direction are displayed.
-    fname : string (optional)
+    fname : string, optional
         the name of the file to save the figure to. If None (default), the
         figure is not saved to disk.
-    fig_kwargs: extra parameters for saving figure, e.g. `dpi=300`.
+    fig_kwargs : dict
+        Extra parameters for saving figure, e.g. `dpi=300`.
     """
     if slice_indices is None:
         slice_indices = np.array(V.shape) // 2
@@ -334,19 +364,32 @@ def plot_slices(V, slice_indices=None, fname=None, **fig_kwargs):
     coronal = np.asarray(V[:, slice_indices[1], :]).astype(np.uint8).T
     sagittal = np.asarray(V[slice_indices[0], :, :]).astype(np.uint8).T
 
-    fig = _tile_plot([axial, coronal, sagittal],
-                     ['Axial', 'Coronal', 'Sagittal'],
-                     cmap=plt.cm.gray, origin='lower')
+    fig = _tile_plot(
+        [axial, coronal, sagittal],
+        ["Axial", "Coronal", "Sagittal"],
+        cmap=plt.cm.gray,
+        origin="lower",
+    )
 
     # Save the figure if requested
     if fname is not None:
-        fig.savefig(fname, bbox_inches='tight', **fig_kwargs)
+        fig.savefig(fname, bbox_inches="tight", **fig_kwargs)
 
     return fig
 
 
-def overlay_slices(L, R, slice_index=None, slice_type=1, ltitle='Left',
-                   rtitle='Right', fname=None, **fig_kwargs):
+@warning_for_keywords()
+def overlay_slices(
+    L,
+    R,
+    *,
+    slice_index=None,
+    slice_type=1,
+    ltitle="Left",
+    rtitle="Right",
+    fname=None,
+    **fig_kwargs,
+):
     r"""Plot three overlaid slices from the given volumes.
 
     Creates a figure containing three images: the gray scale k-th slice of
@@ -363,19 +406,19 @@ def overlay_slices(L, R, slice_index=None, slice_type=1, ltitle='Left',
         the first volume to extract the slice from plotted to the left
     R : array, shape (S, R, C)
         the second volume to extract the slice from, plotted to the right
-    slice_index : int (optional)
+    slice_index : int, optional
         the index of the slices (along the axis given by slice_type) to be
         overlaid. If None, the slice along the specified axis is used
-    slice_type : int (optional)
+    slice_type : int, optional
         the type of slice to be extracted:
         0=sagittal, 1=coronal (default), 2=axial.
-    ltitle : string (optional)
+    ltitle : string, optional
         the string to be written as the title of the left image. By default,
         no title is displayed.
-    rtitle : string (optional)
+    rtitle : string, optional
         the string to be written as the title of the right image. By default,
         no title is displayed.
-    fname : string (optional)
+    fname : string, optional
         the name of the file to write the image to. If None (default), the
         figure is not saved to disk.
     fig_kwargs: extra parameters for saving figure, e.g. `dpi=300`.
@@ -419,12 +462,15 @@ def overlay_slices(L, R, slice_index=None, slice_type=1, ltitle='Left',
     colorImage[..., 0] = ll * (ll > ll[0, 0])
     colorImage[..., 1] = rr * (rr > rr[0, 0])
 
-    fig = _tile_plot([ll, colorImage, rr],
-                     [ltitle, 'Overlay', rtitle],
-                     cmap=plt.cm.gray, origin='lower')
+    fig = _tile_plot(
+        [ll, colorImage, rr],
+        [ltitle, "Overlay", rtitle],
+        cmap=plt.cm.gray,
+        origin="lower",
+    )
 
     # Save the figure to disk, if requested
     if fname is not None:
-        fig.savefig(fname, bbox_inches='tight', **fig_kwargs)
+        fig.savefig(fname, bbox_inches="tight", **fig_kwargs)
 
     return fig
