@@ -8,8 +8,15 @@ import warnings
 import numpy as np
 import trx.trx_file_memmap as tmm
 
+from dipy.core.gradients import (
+    extract_b0,
+    extract_dwi_shell,
+    gradient_table,
+    mask_non_weighted_bvals,
+)
 from dipy.core.sphere import Sphere
 from dipy.data import get_sphere
+from dipy.io.gradients import read_bvals_bvecs
 from dipy.io.image import load_nifti, save_nifti
 from dipy.io.peaks import (
     load_pam,
@@ -21,9 +28,13 @@ from dipy.io.streamline import load_tractogram, save_tractogram
 from dipy.reconst.shm import convert_sh_descoteaux_tournier
 from dipy.reconst.utils import convert_tensors
 from dipy.tracking.streamlinespeed import length
+from dipy.utils.optpkg import optional_package
 from dipy.utils.tractogram import concatenate_tractogram
+from dipy.workflows.utils import handle_vol_idx
 from dipy.workflows.workflow import Workflow
 
+ne, have_ne, _ = optional_package("numexpr")
+
 
 class IoInfoFlow(Workflow):
     @classmethod
@@ -194,7 +205,6 @@ class FetchFlow(Workflow):
                 for name, func in getmembers(fetcher_module, isfunction)
                 if name.lower().startswith("fetch_")
                 and func is not fetcher_module.fetch_data
-                if name.lower() not in ["fetch_hbn", "fetch_hcp"]
             }
         )
 
@@ -219,7 +229,19 @@ class FetchFlow(Workflow):
         else:
             return importlib.import_module(module_path)
 
-    def run(self, data_names, out_dir=""):
+    def run(
+        self,
+        data_names,
+        subjects=None,
+        include_optional=False,
+        include_afq=False,
+        hcp_bucket="hcp-openaccess",
+        hcp_profile_name="hcp",
+        hcp_study="HCP_1200",
+        hcp_aws_access_key_id=None,
+        hcp_aws_secret_access_key=None,
+        out_dir="",
+    ):
         """Download files to folder and check their md5 checksums.
 
         To see all available datasets, please type "list" in data_names.
@@ -228,8 +250,27 @@ class FetchFlow(Workflow):
         ----------
         data_names : variable string
             Any number of Nifti1, bvals or bvecs files.
+        subjects : variable string, optional
+            Identifiers of the subjects to download. Used only by the HBN & HCP dataset.
+            For example with HBN dataset: --subject NDARAA948VFH NDAREK918EC2
+        include_optional : bool, optional
+            Include optional datasets.
+        include_afq : bool, optional
+            Whether to include pyAFQ derivatives. Used only by the HBN dataset.
+        hcp_bucket : string, optional
+            The name of the HCP S3 bucket.
+        hcp_profile_name : string, optional
+            The name of the AWS profile used for access.
+        hcp_study : string, optional
+            Which HCP study to grab.
+        hcp_aws_access_key_id : string, optional
+            AWS credentials to HCP AWS S3. Will only be used if `profile_name` is
+            set to False.
+        hcp_aws_secret_access_key : string, optional
+            AWS credentials to HCP AWS S3. Will only be used if `profile_name` is
+            set to False.
         out_dir : string, optional
-            Output directory. (default current directory)
+            Output directory.
 
         """
         if out_dir:
@@ -241,15 +282,20 @@ class FetchFlow(Workflow):
         data_names = [name.lower() for name in data_names]
 
         if "all" in data_names:
+            logging.warning("Skipping HCP and HBN datasets.")
+            available_data.pop("hcp", None)
+            available_data.pop("hbn", None)
             for name, fetcher_function in available_data.items():
+                if name in ["hcp", "hbn"]:
+                    continue
                 logging.info("------------------------------------------")
                 logging.info(f"Fetching at {name}")
                 logging.info("------------------------------------------")
-                fetcher_function()
+                fetcher_function(include_optional=include_optional)
 
         elif "list" in data_names:
             logging.info(
-                "Please, select between the following data names: "
+                "Please, select between the following data names: \n"
                 f"{', '.join(available_data.keys())}"
             )
 
@@ -263,7 +309,41 @@ class FetchFlow(Workflow):
                 logging.info("------------------------------------------")
                 logging.info(f"Fetching at {data_name}")
                 logging.info("------------------------------------------")
-                available_data[data_name]()
+                if data_name == "hcp":
+                    if not subjects:
+                        logging.error(
+                            "Please provide the subjects to download the HCP dataset."
+                        )
+                        continue
+                    try:
+                        available_data[data_name](
+                            subjects=subjects,
+                            bucket=hcp_bucket,
+                            profile_name=hcp_profile_name,
+                            study=hcp_study,
+                            aws_access_key_id=hcp_aws_access_key_id,
+                            aws_secret_access_key=hcp_aws_secret_access_key,
+                        )
+                    except Exception as e:
+                        logging.error(
+                            f"Error while fetching HCP dataset: {str(e)}", exc_info=True
+                        )
+                elif data_name == "hbn":
+                    if not subjects:
+                        logging.error(
+                            "Please provide the subjects to download the HBN dataset."
+                        )
+                        continue
+                    try:
+                        available_data[data_name](
+                            subjects=subjects, include_afq=include_afq
+                        )
+                    except Exception as e:
+                        logging.error(
+                            f"Error while fetching HBN dataset: {str(e)}", exc_info=True
+                        )
+                else:
+                    available_data[data_name](include_optional=include_optional)
 
             nb_success = len(data_names) - len(skipped_names)
             print("\n")
@@ -302,7 +382,7 @@ class SplitFlow(Workflow):
         vol_idx : int, optional
             Index of the 3D volume to extract.
         out_dir : string, optional
-            Output directory. (default current directory)
+            Output directory.
         out_split : string, optional
             Name of the resulting split volume
 
@@ -321,6 +401,249 @@ class SplitFlow(Workflow):
             logging.info(f"Split volume saved as {osplit}")
 
 
+class ExtractB0Flow(Workflow):
+    @classmethod
+    def get_short_name(cls):
+        return "extract_b0"
+
+    def run(
+        self,
+        input_files,
+        bvalues_files,
+        b0_threshold=50,
+        group_contiguous_b0=False,
+        strategy="mean",
+        out_dir="",
+        out_b0="b0.nii.gz",
+    ):
+        """Extract on or multiple b0 volume from the input 4D file.
+
+        Parameters
+        ----------
+        input_files : string
+            Path to the input volumes. This path may contain wildcards to
+            process multiple inputs at once.
+        bvalues_files : string
+            Path to the bvalues files. This path may contain wildcards to use
+            multiple bvalues files at once.
+        b0_threshold : float, optional
+            Threshold used to find b0 volumes.
+        group_contiguous_b0 : bool, optional
+            If True, each contiguous b0 volumes are grouped together.
+        strategy : str, optional
+            The extraction strategy, of either:
+
+                - first: select the first b0 found.
+                - all: select them all.
+                - mean: average them.
+
+            When used in conjunction with the batch parameter set to True, the
+            strategy is applied individually on each continuous set found.
+        out_dir : string, optional
+            Output directory.
+        out_b0 : string, optional
+            Name of the resulting b0 volume.
+
+        """
+        io_it = self.get_io_iterator()
+        for dwi, bval, ob0 in io_it:
+            logging.info("Extracting b0 from {0}".format(dwi))
+            data, affine, image = load_nifti(dwi, return_img=True)
+
+            bvals, bvecs = read_bvals_bvecs(bval, None)
+            # If all b-values are smaller or equal to the b0 threshold, it is
+            # assumed that no thresholding is requested
+            if any(mask_non_weighted_bvals(bvals, b0_threshold)):
+                if b0_threshold < bvals.min():
+                    warnings.warn(
+                        f"b0_threshold (value: {b0_threshold}) is too low, "
+                        "increase your b0_threshold. It should be higher than the "
+                        f"first b0 value ({bvals.min()}).",
+                        stacklevel=2,
+                    )
+
+            bvecs = np.random.randn(bvals.shape[0], 3)
+            norms = np.linalg.norm(bvecs, axis=1, keepdims=True)
+            bvecs = bvecs / norms
+            gtab = gradient_table(bvals, bvecs=bvecs, b0_threshold=b0_threshold)
+            b0s_result = extract_b0(
+                data,
+                gtab.b0s_mask,
+                group_contiguous_b0=group_contiguous_b0,
+                strategy=strategy,
+            )
+
+            if b0s_result.ndim == 3:
+                save_nifti(ob0, b0s_result, affine, hdr=image.header)
+                logging.info("b0 saved as {0}".format(ob0))
+            elif b0s_result.ndim == 4:
+                for i in range(b0s_result.shape[-1]):
+                    save_nifti(
+                        ob0.replace(".nii", f"_{i}.nii"),
+                        b0s_result[..., i],
+                        affine,
+                        hdr=image.header,
+                    )
+                    logging.info(
+                        "b0 saved as {0}".format(ob0.replace(".nii", f"_{i}.nii"))
+                    )
+            else:
+                logging.error("No b0 volumes found")
+
+
+class ExtractShellFlow(Workflow):
+    @classmethod
+    def get_short_name(cls):
+        return "extract_shell"
+
+    def run(
+        self,
+        input_files,
+        bvalues_files,
+        bvectors_files,
+        bvals_to_extract=None,
+        b0_threshold=50,
+        bvecs_tol=0.01,
+        tol=20,
+        group_shells=True,
+        out_dir="",
+        out_shell="shell.nii.gz",
+    ):
+        """Extract shells from the input 4D file.
+
+        Parameters
+        ----------
+        input_files : string
+            Path to the input volumes. This path may contain wildcards to
+            process multiple inputs at once.
+        bvalues_files : string
+            Path to the bvalues files. This path may contain wildcards to use
+            multiple bvalues files at once.
+        bvectors_files : string
+            Path to the bvectors files. This path may contain wildcards to use
+            multiple bvectors files at once.
+        bvals_to_extract : string, optional
+            List of b-values to extract. You can provide a single b-values or a range
+            of b-values separated by a dash. For example, to extract b-values 0, 1,
+            and 2, you can use '0-2'. You can also provide a list of b-values separated
+            by a comma. For example, to extract b-values 0, 1, 2, 8, 10, 11 and 12,
+            you can use '0-2,8,10-12'.
+        b0_threshold : float, optional
+            Threshold used to find b0 volumes.
+        bvecs_tol : float, optional
+            Threshold used to check that norm(bvec) = 1 +/- bvecs_tol
+        tol : int, optional
+            Tolerance range for b-value selection. A value of 20 means volumes with
+            b-values within ±20 units of the specified b-values will be extracted.
+        group_shells : bool, optional
+            If True, extracted volumes are grouped into a single array. If False,
+            returns a list of separate volumes.
+        out_dir : string, optional
+            Output directory.
+        out_shell : string, optional
+            Name of the resulting shell volume.
+
+        """
+        io_it = self.get_io_iterator()
+        if bvals_to_extract is None:
+            logging.error(
+                "Please provide a list of b-values to extract."
+                " e.g: --bvals_to_extract 1000 2000 3000"
+            )
+            sys.exit(1)
+
+        bvals_to_extract = handle_vol_idx(bvals_to_extract)
+
+        for dwi, bval, bvec, oshell in io_it:
+            logging.info("Extracting shell from {0}".format(dwi))
+            data, affine, image = load_nifti(dwi, return_img=True)
+
+            bvals, bvecs = read_bvals_bvecs(bval, bvec)
+            # If all b-values are smaller or equal to the b0 threshold, it is
+            # assumed that no thresholding is requested
+            if any(mask_non_weighted_bvals(bvals, b0_threshold)):
+                if b0_threshold < bvals.min():
+                    warnings.warn(
+                        f"b0_threshold (value: {b0_threshold}) is too low, "
+                        "increase your b0_threshold. It should be higher than the "
+                        f"first b0 value ({bvals.min()}).",
+                        stacklevel=2,
+                    )
+            gtab = gradient_table(
+                bvals, bvecs=bvecs, b0_threshold=b0_threshold, atol=bvecs_tol
+            )
+            indices, shell_data, output_bvals, output_bvecs = extract_dwi_shell(
+                data,
+                gtab,
+                bvals_to_extract,
+                tol=tol,
+                group_shells=group_shells,
+            )
+
+            for i, shell in enumerate(shell_data):
+                shell_value = np.unique(output_bvals[i]).astype(int).astype(str)
+                shell_value = "_".join(shell_value.tolist())
+                save_nifti(
+                    oshell.replace(".nii", f"_{shell_value}.nii"),
+                    shell,
+                    affine,
+                    hdr=image.header,
+                )
+                logging.info(
+                    "b0 saved as {0}".format(
+                        oshell.replace(".nii", f"_{shell_value}.nii")
+                    )
+                )
+
+
+class ExtractVolumeFlow(Workflow):
+    @classmethod
+    def get_short_name(cls):
+        return "extract_volume"
+
+    def run(
+        self, input_files, vol_idx=0, grouped=True, out_dir="", out_vol="volume.nii.gz"
+    ):
+        """Extracts the required volume from the input 4D file.
+
+        Parameters
+        ----------
+        input_files : string
+            Any number of Nifti1 files
+        vol_idx : string, optional
+            Indexes of the 3D volume to extract. Index start from 0. You can provide
+            a single index or a range of indexes separated by a dash. For example,
+            to extract volumes 0, 1, and 2, you can use '0-2'. You can also provide
+            a list of indexes separated by a comma. For example, to extract volumes
+            0, 1, 2, 8, 10, 11 and 12 , you can use '0-2,8,10-12'.
+        grouped : bool, optional
+            If True, extracted volumes are grouped into a single array. If False,
+            save a list of separate volumes.
+        out_dir : string, optional
+            Output directory.
+        out_vol : string, optional
+            Name of the resulting volume.
+
+        """
+        io_it = self.get_io_iterator()
+        vol_idx = handle_vol_idx(vol_idx)
+
+        for fpath, ovol in io_it:
+            logging.info("Extracting volume from {0}".format(fpath))
+            data, affine, image = load_nifti(fpath, return_img=True)
+
+            if grouped:
+                split_vol = data[..., vol_idx]
+                save_nifti(ovol, split_vol, affine, hdr=image.header)
+                logging.info("Volume saved as {0}".format(ovol))
+            else:
+                for i in vol_idx:
+                    fname = ovol.replace(".nii", f"_{i}.nii")
+                    split_vol = data[..., i]
+                    save_nifti(fname, split_vol, affine, hdr=image.header)
+                    logging.info("Volume saved as {0}".format(fname))
+
+
 class ConcatenateTractogramFlow(Workflow):
     @classmethod
     def get_short_name(cls):
@@ -362,7 +685,7 @@ class ConcatenateTractogramFlow(Workflow):
             element in trx_list (Note: delete_groups must be set to True as
             well)
         out_dir : string, optional
-            Output directory. (default current directory)
+            Output directory.
         out_extension : string, optional
             Extension of the resulting tractogram
         out_tractogram : string, optional
@@ -473,7 +796,7 @@ class ConvertTensorsFlow(Workflow):
             Format of the output tensor files. Valid options are 'dipy',
             'mrtrix', 'ants', 'fsl'.
         out_dir : string, optional
-            Output directory. (default current directory)
+            Output directory.
         out_tensor : string, optional
             Name of the resulting tensor file
 
@@ -514,7 +837,7 @@ class ConvertTractogramFlow(Workflow):
         offsets_dtype : string, optional
             Data type of the tractogram offsets, used for vtk files.
         out_dir : string, optional
-            Output directory. (default current directory)
+            Output directory.
         out_tractogram : string, optional
             Name of the resulting tractogram
 
@@ -775,3 +1098,125 @@ class PamToNiftisFlow(Workflow):
                 fname_qa=oqa,
             )
             logging.info(msg)
+
+
+class MathFlow(Workflow):
+    @classmethod
+    def get_short_name(cls):
+        return "math_flow"
+
+    def run(
+        self, operation, input_files, dtype=None, out_dir="", out_file="math_out.nii.gz"
+    ):
+        """Perform mathematical operations on volume input files.
+
+        This workflow allows the user to perform mathematical operations on
+        multiple input files. e.g. to add two volumes together, subtract one:
+        ``dipy_math "vol1 + vol2 - vol3" t1.nii.gz t1_a.nii.gz t1_b.nii.gz``
+        The input files must be in Nifti format and have the same shape.
+
+        Parameters
+        ----------
+        operation : string
+            Mathematical operation to perform. supported operators are:
+                - Bitwise operators (and, or, not, xor): ``&, |, ~, ^``
+                - Comparison operators: ``<, <=, ==, !=, >=, >``
+                - Unary arithmetic operators: ``-``
+                - Binary arithmetic operators: ``+, -, *, /, **, <<, >>``
+            Supported functions are:
+                - ``where(bool, number1, number2) -> number``: number1 if the bool
+                  condition is true, number2 otherwise.
+                - ``{sin,cos,tan}(float|complex) -> float|complex``: trigonometric sine,
+                  cosine or tangent.
+                - ``{arcsin,arccos,arctan}(float|complex) -> float|complex``:
+                  trigonometric inverse sine, cosine or tangent.
+                - ``arctan2(float1, float2) -> float``: trigonometric inverse tangent of
+                  float1/float2.
+                - ``{sinh,cosh,tanh}(float|complex) -> float|complex``: hyperbolic
+                  sine, cosine or tangent.
+                - ``{arcsinh,arccosh,arctanh}(float|complex) -> float|complex``:
+                  hyperbolic inverse sine, cosine or tangent.
+                - ``{log,log10,log1p}(float|complex) -> float|complex``: natural,
+                  base-10 and log(1+x) logarithms.
+                - ``{exp,expm1}(float|complex) -> float|complex``: exponential and
+                  exponential minus one.
+                - ``sqrt(float|complex) -> float|complex``: square root.
+                - ``abs(float|complex) -> float|complex``: absolute value.
+                - ``conj(complex) -> complex``: conjugate value.
+                - ``{real,imag}(complex) -> float``: real or imaginary part of complex.
+                - ``complex(float, float) -> complex``: complex from real and imaginary
+                  parts.
+                - ``contains(np.str, np.str) -> bool``: returns True for every string
+                  in op1 that contains op2.
+        input_files : variable string
+            Any number of Nifti1 files
+        dtype : string, optional
+            Data type of the resulting file.
+        out_dir : string, optional
+            Output directory
+        out_file : string, optional
+            Name of the resulting file to be saved.
+        """
+        vol_dict = {}
+        ref_affine = None
+        ref_shape = None
+        info_msg = ""
+        have_errors = False
+        for i, fname in enumerate(input_files, start=1):
+            if not os.path.isfile(fname):
+                logging.error(f"Input file {fname} does not exist.")
+                raise SystemExit()
+
+            if not (fname.endswith(".nii.gz") or fname.endswith(".nii")):
+                msg = (
+                    f"Wrong volume type: {fname}. Only Nifti files are supported"
+                    " (*.nii or *.nii.gz)."
+                )
+                logging.error(msg)
+                raise SystemExit()
+
+            data, affine = load_nifti(fname)
+            vol_dict[f"vol{i}"] = data
+            info_msg += f"{fname}:\n- vol index: {i}\n- shape: {data.shape}"
+            info_msg += f"\n- affine:\n{affine}\n"
+            if ref_affine is None:
+                ref_affine = affine
+                ref_shape = data.shape
+                continue
+
+            have_errors = (
+                have_errors
+                or not np.all(np.isclose(ref_affine, affine, rtol=1e-05, atol=1e-08))
+                or not np.array_equal(ref_shape, data.shape)
+            )
+
+        if have_errors:
+            logging.warning(info_msg)
+            msg = "All input files must have the same shape and affine matrix."
+            logging.error(msg)
+            raise SystemExit()
+
+        try:
+            res = ne.evaluate(operation, local_dict=vol_dict)
+        except KeyError as e:
+            msg = (
+                f"Impossible key {e} in the operation. You have {len(input_files)}"
+                f" volumes available with the following keys: {list(vol_dict.keys())}"
+            )
+            logging.error(msg)
+            raise SystemExit() from e
+
+        if dtype:
+            try:
+                res = res.astype(dtype)
+            except TypeError as e:
+                msg = (
+                    f"Impossible to cast to {dtype}. Check possible numpy type here:"
+                    "https://numpy.org/doc/stable/reference/arrays.interface.html"
+                )
+                logging.error(msg)
+                raise SystemExit() from e
+
+        out_fname = os.path.join(out_dir, out_file)
+        logging.info(f"Saving result to {out_fname}")
+        save_nifti(out_fname, res, affine)
