@@ -32,9 +32,9 @@ POSSIBILITY OF SUCH DAMAGE.
 
 import textwrap
 
-from dipy.workflows.docstring_parser import NumpyDocString
 import numpy.testing as npt
 
+from dipy.workflows.docstring_parser import NumpyDocString
 
 doc_txt = """\
   numpy.multivariate_normal(mean, cov, shape=None, spam=None)
@@ -161,94 +161,93 @@ doc_yields = NumpyDocString(doc_yields_txt)
 
 
 def test_signature():
-    npt.assert_(doc['Signature'].startswith('numpy.multivariate_normal('))
-    npt.assert_(doc['Signature'].endswith('spam=None)'))
+    npt.assert_(doc["Signature"].startswith("numpy.multivariate_normal("))
+    npt.assert_(doc["Signature"].endswith("spam=None)"))
 
 
 def test_summary():
-    npt.assert_(doc['Summary'][0].startswith('Draw values'))
-    npt.assert_(doc['Summary'][-1].endswith('covariance.'))
+    npt.assert_(doc["Summary"][0].startswith("Draw values"))
+    npt.assert_(doc["Summary"][-1].endswith("covariance."))
 
 
 def test_extended_summary():
-    npt.assert_(doc['Extended Summary'][0].
-                startswith('The multivariate normal'))
+    npt.assert_(doc["Extended Summary"][0].startswith("The multivariate normal"))
 
 
 def test_parameters():
-    npt.assert_equal(len(doc['Parameters']), 3)
-    npt.assert_equal(
-        [n for n, _, _ in doc['Parameters']], ['mean', 'cov', 'shape'])
+    npt.assert_equal(len(doc["Parameters"]), 3)
+    npt.assert_equal([n for n, _, _ in doc["Parameters"]], ["mean", "cov", "shape"])
 
-    arg, arg_type, desc = doc['Parameters'][1]
-    npt.assert_equal(arg_type, '(N, N) ndarray')
-    npt.assert_(desc[0].startswith('Covariance matrix'))
-    npt.assert_equal(doc['Parameters'][0][-1][-2], '   (1+2+3)/3')
+    arg, arg_type, desc = doc["Parameters"][1]
+    npt.assert_equal(arg_type, "(N, N) ndarray")
+    npt.assert_(desc[0].startswith("Covariance matrix"))
+    npt.assert_equal(doc["Parameters"][0][-1][-2], "   (1+2+3)/3")
 
 
 def test_other_parameters():
-    npt.assert_equal(len(doc['Other Parameters']), 1)
-    npt.assert_equal([n for n, _, _ in doc['Other Parameters']], ['spam'])
-    arg, arg_type, desc = doc['Other Parameters'][0]
-    npt.assert_equal(arg_type, 'parrot')
-    npt.assert_(desc[0].startswith('A parrot off its mortal coil'))
+    npt.assert_equal(len(doc["Other Parameters"]), 1)
+    npt.assert_equal([n for n, _, _ in doc["Other Parameters"]], ["spam"])
+    arg, arg_type, desc = doc["Other Parameters"][0]
+    npt.assert_equal(arg_type, "parrot")
+    npt.assert_(desc[0].startswith("A parrot off its mortal coil"))
 
 
 def test_returns():
-    npt.assert_equal(len(doc['Returns']), 2)
-    arg, arg_type, desc = doc['Returns'][0]
-    npt.assert_equal(arg, 'out')
-    npt.assert_equal(arg_type, 'ndarray')
-    npt.assert_(desc[0].startswith('The drawn samples'))
-    npt.assert_(desc[-1].endswith('distribution.'))
+    npt.assert_equal(len(doc["Returns"]), 2)
+    arg, arg_type, desc = doc["Returns"][0]
+    npt.assert_equal(arg, "out")
+    npt.assert_equal(arg_type, "ndarray")
+    npt.assert_(desc[0].startswith("The drawn samples"))
+    npt.assert_(desc[-1].endswith("distribution."))
 
-    arg, arg_type, desc = doc['Returns'][1]
-    npt.assert_equal(arg, 'list of str')
-    npt.assert_equal(arg_type, '')
-    npt.assert_(desc[0].startswith('This is not a real'))
-    npt.assert_(desc[-1].endswith('anonymous return values.'))
+    arg, arg_type, desc = doc["Returns"][1]
+    npt.assert_equal(arg, "list of str")
+    npt.assert_equal(arg_type, "")
+    npt.assert_(desc[0].startswith("This is not a real"))
+    npt.assert_(desc[-1].endswith("anonymous return values."))
 
 
 def test_notes():
-    npt.assert_(doc['Notes'][0].startswith('Instead'))
-    npt.assert_(doc['Notes'][-1].endswith('definite.'))
-    npt.assert_equal(len(doc['Notes']), 17)
+    npt.assert_(doc["Notes"][0].startswith("Instead"))
+    npt.assert_(doc["Notes"][-1].endswith("definite."))
+    npt.assert_equal(len(doc["Notes"]), 17)
 
 
 def test_references():
-    npt.assert_(doc['References'][0].startswith('..'))
-    npt.assert_(doc['References'][-1].endswith('2001.'))
+    npt.assert_(doc["References"][0].startswith(".."))
+    npt.assert_(doc["References"][-1].endswith("2001."))
 
 
 def test_examples():
-    npt.assert_(doc['Examples'][0].startswith('>>>'))
-    npt.assert_(doc['Examples'][-1].endswith('True]'))
+    npt.assert_(doc["Examples"][0].startswith(">>>"))
+    npt.assert_(doc["Examples"][-1].endswith("True]"))
 
 
 def test_index():
-    npt.assert_equal(doc['index']['default'], 'random')
-    npt.assert_equal(len(doc['index']), 2)
-    npt.assert_equal(len(doc['index']['refguide']), 2)
+    npt.assert_equal(doc["index"]["default"], "random")
+    npt.assert_equal(len(doc["index"]), 2)
+    npt.assert_equal(len(doc["index"]["refguide"]), 2)
 
 
 def non_blank_line_by_line_compare(a, b):
     a = textwrap.dedent(a)
     b = textwrap.dedent(b)
-    a = [l.rstrip() for l in a.split('\n') if l.strip()]
-    b = [l.rstrip() for l in b.split('\n') if l.strip()]
+    a = [ell.rstrip() for ell in a.split("\n") if ell.strip()]
+    b = [ell.rstrip() for ell in b.split("\n") if ell.strip()]
     for n, line in enumerate(a):
         if not line == b[n]:
-            raise AssertionError("Lines %s of a and b differ: "
-                                 "\n>>> %s\n<<< %s\n" %
-                                 (n, line, b[n]))
+            raise AssertionError(
+                f"Lines {n} of a and b differ: \n>>> {line}\n<<< {b[n]}\n"
+            )
 
 
 def test_str():
     # doc_txt has the order of Notes and See Also sections flipped.
     # This should be handled automatically, and so, one thing this test does
     # is to make sure that See Also precedes Notes in the output.
-    non_blank_line_by_line_compare(str(doc),
-                                   """numpy.multivariate_normal(mean, cov, shape=None, spam=None)
+    non_blank_line_by_line_compare(
+        str(doc),
+        """numpy.multivariate_normal(mean, cov, shape=None, spam=None)
 
 Draw values from a multivariate normal distribution with specified
 mean and covariance.
@@ -353,7 +352,8 @@ standard deviation:
 [True, True]
 
 .. index:: random
-   :refguide: random;distributions, random;gauss""")
+   :refguide: random;distributions, random;gauss""",
+    )
 
 
 doc2 = NumpyDocString("""
@@ -369,7 +369,8 @@ doc2 = NumpyDocString("""
 
 
 def test_parameters_without_extended_description():
-    npt.assert_equal(len(doc2['Parameters']), 2)
+    npt.assert_equal(len(doc2["Parameters"]), 2)
+
 
 doc3 = NumpyDocString("""
     my_signature(*params, **kwds)
@@ -390,21 +391,22 @@ doc5 = NumpyDocString(
     -----
     SomeWarning
         If needed
-    """)
+    """
+)
 
 
 def test_raises():
-    npt.assert_equal(len(doc5['Raises']), 1)
-    name, _, desc = doc5['Raises'][0]
-    npt.assert_equal(name, 'LinAlgException')
-    npt.assert_equal(desc, ['If array is singular.'])
+    npt.assert_equal(len(doc5["Raises"]), 1)
+    name, _, desc = doc5["Raises"][0]
+    npt.assert_equal(name, "LinAlgException")
+    npt.assert_equal(desc, ["If array is singular."])
 
 
 def test_warns():
-    npt.assert_equal(len(doc5['Warns']), 1)
-    name, _, desc = doc5['Warns'][0]
-    npt.assert_equal(name, 'SomeWarning')
-    npt.assert_equal(desc, ['If needed'])
+    npt.assert_equal(len(doc5["Warns"]), 1)
+    name, _, desc = doc5["Warns"][0]
+    npt.assert_equal(name, "SomeWarning")
+    npt.assert_equal(desc, ["If needed"])
 
 
 def test_see_also():
@@ -423,31 +425,42 @@ def test_see_also():
     :obj:`baz.obj_q`
     :class:`class_j`: fubar
         foobar
-    """)
+    """
+    )
 
-    npt.assert_equal(len(doc6['See Also']), 12)
-    for func, desc, role in doc6['See Also']:
-        if func in ('func_a', 'func_b', 'func_c', 'func_f',
-                    'func_g', 'func_h', 'func_j', 'func_k', 'baz.obj_q'):
+    npt.assert_equal(len(doc6["See Also"]), 12)
+    for func, desc, role in doc6["See Also"]:
+        if func in (
+            "func_a",
+            "func_b",
+            "func_c",
+            "func_f",
+            "func_g",
+            "func_h",
+            "func_j",
+            "func_k",
+            "baz.obj_q",
+        ):
             assert not desc
         else:
             assert desc
 
-        if func == 'func_h':
-            assert role == 'meth'
-        elif func == 'baz.obj_q':
-            assert role == 'obj'
-        elif func == 'class_j':
-            assert role == 'class'
+        if func == "func_h":
+            assert role == "meth"
+        elif func == "baz.obj_q":
+            assert role == "obj"
+        elif func == "class_j":
+            assert role == "class"
         else:
             assert role is None
 
-        if func == 'func_d':
-            assert desc == ['some equivalent func']
-        elif func == 'foo.func_e':
-            assert desc == ['some other func over', 'multiple lines']
-        elif func == 'class_j':
-            assert desc == ['fubar', 'foobar']
+        if func == "func_d":
+            assert desc == ["some equivalent func"]
+        elif func == "foo.func_e":
+            assert desc == ["some other func over", "multiple lines"]
+        elif func == "class_j":
+            assert desc == ["fubar", "foobar"]
+
 
 doc7 = NumpyDocString("""
 
@@ -457,7 +470,7 @@ doc7 = NumpyDocString("""
 
 
 def test_empty_first_line():
-    assert doc7['Summary'][0].startswith('Doc starts')
+    assert doc7["Summary"][0].startswith("Doc starts")
 
 
 def test_duplicate_signature():
@@ -470,9 +483,10 @@ def test_duplicate_signature():
     z(x1, x2)
 
     z(a, theta)
-    """)
+    """
+    )
 
-    assert doc['Signature'].strip() == 'z(a, theta)'
+    assert doc["Signature"].strip() == "z(a, theta)"
 
 
 class_doc_txt = """
