@@ -2,12 +2,15 @@ import inspect
 import logging
 import os
 
-from dipy.workflows.multi_io import io_iterator_
+from dipy.testing.decorators import warning_for_keywords
+from dipy.workflows.multi_io import _io_iterator
 
 
 class Workflow:
-    def __init__(self, output_strategy='absolute', mix_names=False,
-                 force=False, skip=False):
+    @warning_for_keywords()
+    def __init__(
+        self, *, output_strategy="absolute", mix_names=False, force=False, skip=False
+    ):
         """Initialize the basic workflow object.
 
         This object takes care of any workflow operation that is common to all
@@ -33,17 +36,18 @@ class Workflow:
         else:
             frame = frame.frame
 
-        io_it = io_iterator_(frame, self.run,
-                             output_strategy=self._output_strategy,
-                             mix_names=self._mix_names)
+        io_it = _io_iterator(
+            frame,
+            self.run,
+            output_strategy=self._output_strategy,
+            mix_names=self._mix_names,
+        )
 
         # Make a list out of a list of lists
-        self.flat_outputs = [item for sublist in io_it.outputs for item
-                             in sublist]
+        self.flat_outputs = [item for sublist in io_it.outputs for item in sublist]
 
         if io_it.out_keys:
-            self.last_generated_outputs = dict(zip(io_it.out_keys,
-                                                   self.flat_outputs))
+            self.last_generated_outputs = dict(zip(io_it.out_keys, self.flat_outputs))
         else:
             self.last_generated_outputs = self.flat_outputs
 
@@ -52,6 +56,38 @@ class Workflow:
         else:
             return []
 
+    def update_flat_outputs(self, new_flat_outputs, io_it):
+        """Update the flat outputs with new values.
+
+        This method is useful when a workflow needs to update the flat_outputs
+        with new values that were generated in the run method.
+
+        Parameters
+        ----------
+        new_flat_outputs : list
+            List of new values to update the flat_outputs.
+        io_it : IOIterator
+            The IOIterator object that was returned by get_io_iterator.
+        """
+        if len(new_flat_outputs) != len(self.flat_outputs):
+            raise ValueError(
+                "The new flat outputs must have the same length as the "
+                "current flat outputs."
+            )
+        self.flat_outputs = new_flat_outputs
+        if io_it.outputs:
+            size = len(io_it.outputs[-1])
+            io_it.outputs = [
+                self.flat_outputs[i : i + size]
+                for i in range(0, len(self.flat_outputs), size)
+            ]
+
+        if io_it.out_keys:
+            self.last_generated_outputs = dict(zip(io_it.out_keys, self.flat_outputs))
+        else:
+            self.last_generated_outputs = self.flat_outputs
+        self.manage_output_overwrite()
+
     def manage_output_overwrite(self):
         """Check if a file will be overwritten upon processing the inputs.
 
@@ -67,14 +103,17 @@ class Workflow:
 
         if len(duplicates) > 0:
             if self._force_overwrite:
-                logging.info('The following output files are about to be'
-                             ' overwritten.')
+                logging.info(
+                    "The following output files are about to be" " overwritten."
+                )
 
             else:
-                logging.info('The following output files already exist, the '
-                             'workflow will not continue processing any '
-                             'further. Add the --force flag to allow output '
-                             'files overwrite.')
+                logging.info(
+                    "The following output files already exist, the "
+                    "workflow will not continue processing any "
+                    "further. Add the --force flag to allow output "
+                    "files overwrite."
+                )
 
             for dup in duplicates:
                 logging.info(dup)
@@ -90,8 +129,7 @@ class Workflow:
         reached (not implemented in child class or literally called on this
         class)
         """
-        raise Exception('Error: {} does not have a run method.'.
-                        format(self.__class__))
+        raise Exception(f"Error: {self.__class__} does not have a run method.")
 
     def get_sub_runs(self):
         """Return No sub runs since this is a simple workflow."""
