@@ -3,8 +3,8 @@
 BUAN Bundle Assignment Maps Creation
 ====================================
 
-This example explains how we can use BUAN [Chandio2020]_ to create assignment
-maps on a bundle. Divide bundle into N smaller segments.
+This example explains how we can use BUAN :footcite:p:`Chandio2020a` to create
+assignment maps on a bundle. Divide bundle into N smaller segments.
 
 
 First import the necessary modules.
@@ -12,8 +12,7 @@ First import the necessary modules.
 
 import numpy as np
 
-from dipy.data import get_two_hcp842_bundles
-from dipy.data import fetch_bundle_atlas_hcp842
+from dipy.data import fetch_bundle_atlas_hcp842, get_two_hcp842_bundles
 from dipy.io.streamline import load_trk
 from dipy.stats.analysis import assignment_map
 from dipy.viz import actor, window
@@ -29,7 +28,7 @@ atlas_file, atlas_folder = fetch_bundle_atlas_hcp842()
 
 model_af_l_file, model_cst_l_file = get_two_hcp842_bundles()
 
-sft_af_l = load_trk(model_af_l_file, "same", bbox_valid_check=False)
+sft_af_l = load_trk(model_af_l_file, reference="same", bbox_valid_check=False)
 model_af_l = sft_af_l.streamlines
 
 ###############################################################################
@@ -40,11 +39,12 @@ interactive = False
 scene = window.Scene()
 scene.SetBackground(1, 1, 1)
 scene.add(actor.line(model_af_l, fake_tube=True, linewidth=6))
-scene.set_camera(focal_point=(-18.17281532, -19.55606842, 6.92485857),
-                 position=(-360.11, -30.46, -40.44),
-                 view_up=(-0.03, 0.028, 0.89))
-window.record(scene, out_path='af_l_before_assignment_maps.png',
-              size=(600, 600))
+scene.set_camera(
+    focal_point=(-18.17281532, -19.55606842, 6.92485857),
+    position=(-360.11, -30.46, -40.44),
+    view_up=(-0.03, 0.028, 0.89),
+)
+window.record(scene=scene, out_path="af_l_before_assignment_maps.png", size=(600, 600))
 if interactive:
     window.show(scene)
 
@@ -55,7 +55,8 @@ if interactive:
 #
 #
 #
-# Creating 100 bundle assignment maps on AF_L using BUAN [Chandio2020]_
+# Creating 100 bundle assignment maps on AF_L using BUAN
+# :footcite:p:`Chandio2020a`
 
 rng = np.random.default_rng()
 
@@ -76,13 +77,13 @@ interactive = False
 
 scene = window.Scene()
 scene.SetBackground(1, 1, 1)
-scene.add(actor.line(model_af_l, fake_tube=True, colors=disks_color,
-                     linewidth=6))
-scene.set_camera(focal_point=(-18.17281532, -19.55606842, 6.92485857),
-                 position=(-360.11, -30.46, -40.44),
-                 view_up=(-0.03, 0.028, 0.89))
-window.record(scene, out_path='af_l_after_assignment_maps.png',
-              size=(600, 600))
+scene.add(actor.line(model_af_l, fake_tube=True, colors=disks_color, linewidth=6))
+scene.set_camera(
+    focal_point=(-18.17281532, -19.55606842, 6.92485857),
+    position=(-360.11, -30.46, -40.44),
+    view_up=(-0.03, 0.028, 0.89),
+)
+window.record(scene=scene, out_path="af_l_after_assignment_maps.png", size=(600, 600))
 if interactive:
     window.show(scene)
 
@@ -95,8 +96,5 @@ if interactive:
 # References
 # ----------
 #
-# .. [Chandio2020] Chandio, B.Q., Risacher, S.L., Pestilli, F.,
-#         Bullock, D., Yeh, FC., Koudoro, S., Rokem, A., Harezlak, J., and
-#         Garyfallidis, E. Bundle analytics, a computational framework for
-#         investigating the shapes and profiles of brain pathways across
-#         populations. Sci Rep 10, 17149 (2020)
+# .. footbibliography::
+#
