@@ -4,26 +4,32 @@ Nonrigid Bundle Registration with BundleWarp
 ============================================
 
 This example explains how you can nonlinearly register two bundles from two
-different subjects directly in the space of streamlines [Chandio23]_,
-[Chandio20]_.
+different subjects directly in the space of streamlines
+:footcite:p:`Chandio2023`, :footcite:p:`Chandio2020b`.
 
 To show the concept, we will use two pre-saved uncinate fasciculus bundles. The
 algorithm used here is called BundleWarp, streamline-based nonlinear
-registration of white matter tracts [Chandio23]_.
+registration of white matter tracts :footcite:p:`Chandio2023`.
 
 """
-from os.path import join as pjoin
 
-from dipy.align.streamwarp import (bundlewarp, bundlewarp_vector_filed,
-                                   bundlewarp_shape_analysis)
+from os.path import join as pjoin
+from time import time
+
+from dipy.align.streamwarp import (
+    bundlewarp,
+    bundlewarp_shape_analysis,
+    bundlewarp_vector_filed,
+)
 from dipy.data import fetch_bundle_warp_dataset
 from dipy.io.stateful_tractogram import Space, StatefulTractogram
-from dipy.io.streamline import save_tractogram, load_trk
-from dipy.tracking.streamline import (set_number_of_points, unlist_streamlines,
-                                      Streamlines)
-from dipy.viz.streamline import (viz_two_bundles, viz_vector_field,
-                                 viz_displacement_mag)
-from time import time
+from dipy.io.streamline import load_trk, save_tractogram
+from dipy.tracking.streamline import (
+    Streamlines,
+    set_number_of_points,
+    unlist_streamlines,
+)
+from dipy.viz.streamline import viz_displacement_mag, viz_two_bundles, viz_vector_field
 
 ###############################################################################
 # Let's download and load two uncinate fasciculus bundles in the left
@@ -31,20 +37,18 @@ from time import time
 # https://figshare.com/articles/dataset/Test_Bundles_for_DIPY/22557733
 
 bundle_warp_files = fetch_bundle_warp_dataset()
-s_UF_L_path = pjoin(bundle_warp_files[1], 's_UF_L.trk')
-m_UF_L_path = pjoin(bundle_warp_files[1], 'm_UF_L.trk')
+s_UF_L_path = pjoin(bundle_warp_files[1], "s_UF_L.trk")
+m_UF_L_path = pjoin(bundle_warp_files[1], "m_UF_L.trk")
 
-uf_subj1 = load_trk(s_UF_L_path, reference="same",
-                    bbox_valid_check=False).streamlines
-uf_subj2 = load_trk(m_UF_L_path, reference="same",
-                    bbox_valid_check=False).streamlines
+uf_subj1 = load_trk(s_UF_L_path, reference="same", bbox_valid_check=False).streamlines
+uf_subj2 = load_trk(m_UF_L_path, reference="same", bbox_valid_check=False).streamlines
 
 ###############################################################################
 # Let's resample the streamlines so that they both have the same number of
 # points per streamline. Here we will use 20 points.
 
-static = Streamlines(set_number_of_points(uf_subj1, 20))
-moving = Streamlines(set_number_of_points(uf_subj2, 20))
+static = Streamlines(set_number_of_points(uf_subj1, nb_points=20))
+moving = Streamlines(set_number_of_points(uf_subj2, nb_points=20))
 
 ###############################################################################
 # We call ``uf_subj2`` a moving bundle as it will be nonlinearly aligned with
@@ -67,34 +71,37 @@ viz_two_bundles(static, moving, fname="static_and_moving.png")
 
 start = time()
 deformed_bundle, moving_aligned, distances, match_pairs, warp_map = bundlewarp(
-                               static, moving, alpha=0.5, beta=20, max_iter=15)
+    static, moving, alpha=0.5, beta=20, max_iter=15
+)
 end = time()
 
-print("time taken by BundleWarp registration in seconds = ", end-start)
+print("time taken by BundleWarp registration in seconds = ", end - start)
 
 ###############################################################################
 # Let's visualize static bundle in red and moved (warped) in green. Note: You
 # can set interactive=True in visualization functions throughout this tutorial
 # if you prefer to get interactive visualization window.
 
-viz_two_bundles(static, deformed_bundle,
-                fname="static_and_partially_deformed.png")
+viz_two_bundles(static, deformed_bundle, fname="static_and_partially_deformed.png")
 
 ###############################################################################
 # Let's visualize linearly moved bundle in blue and nonlinearly moved bundle in
 # green to see BundleWarp registration improvement over linear SLR
 # registration.
 
-viz_two_bundles(moving_aligned, deformed_bundle,
-                fname="linearly_and_nonlinearly_moved.png", c1=(0, 0, 1))
+viz_two_bundles(
+    moving_aligned,
+    deformed_bundle,
+    fname="linearly_and_nonlinearly_moved.png",
+    c1=(0, 0, 1),
+)
 
 ###############################################################################
 # Now, let's visualize deformation vector field generated by BundleWarp.
 # This shows us visually where and how much and in what directions deformations
 # were added by BundleWarp.
 
-offsets, directions, colors = bundlewarp_vector_filed(moving_aligned,
-                                                      deformed_bundle)
+offsets, directions, colors = bundlewarp_vector_filed(moving_aligned, deformed_bundle)
 
 points_aligned, _ = unlist_streamlines(moving_aligned)
 
@@ -109,8 +116,9 @@ viz_vector_field(points_aligned, directions, colors, offsets, fname)
 # much deformations were introduced after linear registration.
 
 fname = "partially_vectorfield_over_linearly_moved.png"
-viz_vector_field(points_aligned, directions, colors, offsets, fname,
-                 moving_aligned)
+viz_vector_field(
+    points_aligned, directions, colors, offsets, fname, bundle=moving_aligned
+)
 
 ###############################################################################
 # We can also visualize the magnitude of deformations in mm mapped over
@@ -124,8 +132,7 @@ viz_displacement_mag(moving_aligned, offsets, fname, interactive=False)
 # Saving partially warped bundle.
 
 new_tractogram = StatefulTractogram(deformed_bundle, m_UF_L_path, Space.RASMM)
-save_tractogram(new_tractogram, "partially_deformed_bundle.trk",
-                bbox_valid_check=False)
+save_tractogram(new_tractogram, "partially_deformed_bundle.trk", bbox_valid_check=False)
 
 
 ###############################################################################
@@ -135,25 +142,24 @@ save_tractogram(new_tractogram, "partially_deformed_bundle.trk",
 # method. This will save computation time.
 
 start = time()
-deformed_bundle2, moving_aligned, distances, match_pairs, warp_map =  \
-        bundlewarp(static, moving, dist=distances, alpha=0.001, beta=20)
+deformed_bundle2, moving_aligned, distances, match_pairs, warp_map = bundlewarp(
+    static, moving, dist=distances, alpha=0.001, beta=20
+)
 end = time()
 
-print("time taken by BundleWarp registration in seconds = ", end-start)
+print("time taken by BundleWarp registration in seconds = ", end - start)
 
 ###############################################################################
 # Let's visualize static bundle in red and moved (completely warped) in green.
 
-viz_two_bundles(static, deformed_bundle2,
-                fname="static_and_fully_deformed.png")
+viz_two_bundles(static, deformed_bundle2, fname="static_and_fully_deformed.png")
 
 ###############################################################################
 # Now, let's visualize the deformation vector field generated by BundleWarp.
 # This shows us visually where and how much and in what directions deformations
 # were added by BundleWarp to perfectly warp moving bundle to look like static.
 
-offsets, directions, colors = bundlewarp_vector_filed(moving_aligned,
-                                                      deformed_bundle2)
+offsets, directions, colors = bundlewarp_vector_filed(moving_aligned, deformed_bundle2)
 
 points_aligned, _ = unlist_streamlines(moving_aligned)
 
@@ -169,8 +175,9 @@ viz_vector_field(points_aligned, directions, colors, offsets, fname)
 # deforming the moving bundle.
 
 fname = "fully_vectorfield_over_linearly_moved.png"
-viz_vector_field(points_aligned, directions, colors, offsets, fname,
-                 moving_aligned)
+viz_vector_field(
+    points_aligned, directions, colors, offsets, fname, bundle=moving_aligned
+)
 
 ###############################################################################
 # Let's visualize the magnitude of deformations in mm mapped over affinely
@@ -188,24 +195,18 @@ viz_displacement_mag(moving_aligned, offsets, fname, interactive=False)
 # bundle. Segments where we observe higher deformations are the areas where
 # two bundles differ the most in shape.
 
-_, _ = bundlewarp_shape_analysis(moving_aligned, deformed_bundle, no_disks=10,
-                                 plotting=False)
+_, _ = bundlewarp_shape_analysis(
+    moving_aligned, deformed_bundle, no_disks=10, plotting=False
+)
 
 ###############################################################################
 # Saving fully warped bundle.
 
-new_tractogram = StatefulTractogram(deformed_bundle2, m_UF_L_path,
-                                    Space.RASMM)
-save_tractogram(new_tractogram, "fully_deformed_bundle.trk",
-                bbox_valid_check=False)
+new_tractogram = StatefulTractogram(deformed_bundle2, m_UF_L_path, Space.RASMM)
+save_tractogram(new_tractogram, "fully_deformed_bundle.trk", bbox_valid_check=False)
 
 ###############################################################################
 # References
 # ----------
 #
-# .. [Chandio23] Chandio et al., "BundleWarp, streamline-based nonlinear
-#                     registration of white matter tracts."
-#                     bioRxiv (2023): 2023-01.
-# .. [Chandio20] Chandio and Garyfallidis., "StND: Streamline-based non-rigid
-#                     partial-deformation tractography registration." Medical
-#                     Imaging Meets NeurIPS (2020).
+# .. footbibliography::
