@@ -4,55 +4,58 @@ Denoise images using the Marcenko-Pastur PCA algorithm
 ======================================================
 
 The PCA-based denoising algorithm exploits the redundancy across the
-diffusion-weighted images [Manjon2013]_, [Veraart2016a]_. This algorithm has
-been shown to provide an optimal compromise between noise suppression and loss
-of anatomical information for different techniques such as DTI [Manjon2013]_,
-spherical deconvolution [Veraart2016a] and DKI [Henri2018]_.
+diffusion-weighted images :footcite:p:`Manjon2013`, :footcite:p:`Veraart2016b`.
+This algorithm has been shown to provide an optimal compromise between noise
+suppression and loss of anatomical information for different techniques such as
+DTI :footcite:p:`Manjon2013`, spherical deconvolution :footcite:p:`Veraart2016b`
+and DKI :footcite:p:`NetoHenriques2018`.
 
 The basic idea behind the PCA-based denoising algorithms is to remove the
 components of the data that are classified as noise. The Principal Components
 classification can be performed based on prior noise variance estimates
-[Manjon2013]_
-(see :ref:`denoise_localpca<sphx_glr_examples_built_preprocessing_denoise_localpca.py>`)  # noqa E501
-or automatically based on the Marchenko-Pastur distribution [Veraa2016a]_.
-In addition to noise suppression, the PCA algorithm can be used to get the
-standard deviation of the noise [Veraa2016b]_.
+:footcite:p:`Manjon2013`
+(see :ref:`denoise_localpca<sphx_glr_examples_built_preprocessing_denoise_localpca.py>`)
+or automatically based on the Marchenko-Pastur distribution
+:footcite:p:`Veraart2016b`. In addition to noise suppression, the PCA algorithm
+can be used to get the standard deviation of the noise
+:footcite:p:`Veraart2016b`.
 
 In the following example, we show how to denoise diffusion MRI images and
 estimate the noise standard deviation using the PCA algorithm based
-on the Marcenko-Pastur distribution [Veraa2016a]
+on the Marcenko-Pastur distribution :footcite:p:`Veraart2016b`
 
 Let's load the necessary modules
-"""
+"""  # noqa: E501
 
 # load general modules
-import numpy as np
-import matplotlib.pyplot as plt
 from time import time
 
-# load main pca function using Marcenko-Pastur distribution
-from dipy.denoise.localpca import mppca
+import matplotlib.pyplot as plt
+import numpy as np
+
+# load other dipy's functions that will be used for auxiliary analysis
+from dipy.core.gradients import gradient_table
 
 # load functions to fetch data for this example
 from dipy.data import get_fnames
 
-# load other dipy's functions that will be used for auxiliary analysis
-from dipy.core.gradients import gradient_table
-from dipy.io.image import load_nifti, save_nifti
+# load main pca function using Marcenko-Pastur distribution
+from dipy.denoise.localpca import mppca
 from dipy.io.gradients import read_bvals_bvecs
-from dipy.segment.mask import median_otsu
+from dipy.io.image import load_nifti, save_nifti
 import dipy.reconst.dki as dki
+from dipy.segment.mask import median_otsu
 
 ###############################################################################
 # For this example, we use fetch to download a multi-shell dataset which was
 # kindly provided by Hansen and Jespersen (more details about the data are
-# provided in their paper [Hansen2016]_). The total size of the downloaded data
-# is 192 MBytes, however you only need to fetch it once.
+# provided in their paper :footcite:p:`Hansen2016a`). The total size of the
+# downloaded data is 192 MBytes, however you only need to fetch it once.
 
-dwi_fname, dwi_bval_fname, dwi_bvec_fname, _ = get_fnames('cfin_multib')
+dwi_fname, dwi_bval_fname, dwi_bvec_fname, _ = get_fnames(name="cfin_multib")
 data, affine = load_nifti(dwi_fname)
 bvals, bvecs = read_bvals_bvecs(dwi_bval_fname, dwi_bvec_fname)
-gtab = gradient_table(bvals, bvecs)
+gtab = gradient_table(bvals, bvecs=bvecs)
 
 ###############################################################################
 # For the sake of simplicity, we only select two non-zero b-values for this
@@ -66,7 +69,7 @@ sel_b = np.logical_or(np.logical_or(bvals == 0, bvals == 1000), bvals == 2000)
 
 data = data[..., sel_b]
 
-gtab = gradient_table(bvals[sel_b], bvecs[sel_b])
+gtab = gradient_table(bvals[sel_b], bvecs=bvecs[sel_b])
 
 print(data.shape)
 
@@ -102,22 +105,18 @@ orig = data[:, :, sli, gra]
 den = denoised_arr[:, :, sli, gra]
 rms_diff = np.sqrt((orig - den) ** 2)
 
-fig1, ax = plt.subplots(1, 3, figsize=(12, 6),
-                        subplot_kw={'xticks': [], 'yticks': []})
+fig1, ax = plt.subplots(1, 3, figsize=(12, 6), subplot_kw={"xticks": [], "yticks": []})
 
 fig1.subplots_adjust(hspace=0.3, wspace=0.05)
 
-ax.flat[0].imshow(orig.T, cmap='gray', interpolation='none',
-                  origin='lower')
-ax.flat[0].set_title('Original')
-ax.flat[1].imshow(den.T, cmap='gray', interpolation='none',
-                  origin='lower')
-ax.flat[1].set_title('Denoised Output')
-ax.flat[2].imshow(rms_diff.T, cmap='gray', interpolation='none',
-                  origin='lower')
-ax.flat[2].set_title('Residuals')
+ax.flat[0].imshow(orig.T, cmap="gray", interpolation="none", origin="lower")
+ax.flat[0].set_title("Original")
+ax.flat[1].imshow(den.T, cmap="gray", interpolation="none", origin="lower")
+ax.flat[1].set_title("Denoised Output")
+ax.flat[2].imshow(rms_diff.T, cmap="gray", interpolation="none", origin="lower")
+ax.flat[2].set_title("Residuals")
 
-fig1.savefig('denoised_mppca.png')
+fig1.savefig("denoised_mppca.png")
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -131,7 +130,7 @@ fig1.savefig('denoised_mppca.png')
 #
 # Below we show how the denoised data can be saved.
 
-save_nifti('denoised_mppca.nii.gz', denoised_arr, affine)
+save_nifti("denoised_mppca.nii.gz", denoised_arr, affine)
 
 ###############################################################################
 # Additionally, we show how the PCA denoising algorithm affects different
@@ -140,8 +139,9 @@ save_nifti('denoised_mppca.nii.gz', denoised_arr, affine)
 
 dkimodel = dki.DiffusionKurtosisModel(gtab)
 
-maskdata, mask = median_otsu(data, vol_idx=[0, 1], median_radius=4, numpass=2,
-                             autocrop=False, dilate=1)
+maskdata, mask = median_otsu(
+    data, vol_idx=[0, 1], median_radius=4, numpass=2, autocrop=False, dilate=1
+)
 
 dki_orig = dkimodel.fit(data, mask=mask)
 dki_den = dkimodel.fit(denoised_arr, mask=mask)
@@ -154,35 +154,30 @@ FA_orig = dki_orig.fa
 FA_den = dki_den.fa
 MD_orig = dki_orig.md
 MD_den = dki_den.md
-MK_orig = dki_orig.mk(0, 3)
-MK_den = dki_den.mk(0, 3)
+MK_orig = dki_orig.mk(min_kurtosis=0, max_kurtosis=3)
+MK_den = dki_den.mk(min_kurtosis=0, max_kurtosis=3)
 
 
-fig2, ax = plt.subplots(2, 3, figsize=(10, 6),
-                        subplot_kw={'xticks': [], 'yticks': []})
+fig2, ax = plt.subplots(2, 3, figsize=(10, 6), subplot_kw={"xticks": [], "yticks": []})
 
 fig2.subplots_adjust(hspace=0.3, wspace=0.03)
 
-ax.flat[0].imshow(MD_orig[:, :, sli].T, cmap='gray', vmin=0, vmax=2.0e-3,
-                  origin='lower')
-ax.flat[0].set_title('MD (DKI)')
-ax.flat[1].imshow(FA_orig[:, :, sli].T, cmap='gray', vmin=0, vmax=0.7,
-                  origin='lower')
-ax.flat[1].set_title('FA (DKI)')
-ax.flat[2].imshow(MK_orig[:, :, sli].T, cmap='gray', vmin=0, vmax=1.5,
-                  origin='lower')
-ax.flat[2].set_title('AD (DKI)')
-ax.flat[3].imshow(MD_den[:, :, sli].T, cmap='gray', vmin=0, vmax=2.0e-3,
-                  origin='lower')
-ax.flat[3].set_title('MD (DKI)')
-ax.flat[4].imshow(FA_den[:, :, sli].T, cmap='gray', vmin=0, vmax=0.7,
-                  origin='lower')
-ax.flat[4].set_title('FA (DKI)')
-ax.flat[5].imshow(MK_den[:, :, sli].T, cmap='gray', vmin=0, vmax=1.5,
-                  origin='lower')
-ax.flat[5].set_title('AD (DKI)')
+ax.flat[0].imshow(
+    MD_orig[:, :, sli].T, cmap="gray", vmin=0, vmax=2.0e-3, origin="lower"
+)
+ax.flat[0].set_title("MD (DKI)")
+ax.flat[1].imshow(FA_orig[:, :, sli].T, cmap="gray", vmin=0, vmax=0.7, origin="lower")
+ax.flat[1].set_title("FA (DKI)")
+ax.flat[2].imshow(MK_orig[:, :, sli].T, cmap="gray", vmin=0, vmax=1.5, origin="lower")
+ax.flat[2].set_title("AD (DKI)")
+ax.flat[3].imshow(MD_den[:, :, sli].T, cmap="gray", vmin=0, vmax=2.0e-3, origin="lower")
+ax.flat[3].set_title("MD (DKI)")
+ax.flat[4].imshow(FA_den[:, :, sli].T, cmap="gray", vmin=0, vmax=0.7, origin="lower")
+ax.flat[4].set_title("FA (DKI)")
+ax.flat[5].imshow(MK_den[:, :, sli].T, cmap="gray", vmin=0, vmax=1.5, origin="lower")
+ax.flat[5].set_title("AD (DKI)")
 plt.show()
-fig2.savefig('denoised_dki.png')
+fig2.savefig("denoised_dki.png")
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -194,7 +189,7 @@ fig2.savefig('denoised_dki.png')
 #
 #
 # Noise standard deviation estimation using the Marchenko-Pastur PCA algorithm
-# ===========================================================================
+# ============================================================================
 #
 # As mentioned above, the Marcenko-Pastur PCA algorithm can also be used to
 # estimate the image's noise standard deviation (std). The noise std
@@ -206,11 +201,11 @@ denoised_arr, sigma = mppca(data, patch_radius=2, return_sigma=True)
 ###############################################################################
 # Let's plot the noise standard deviation estimate:
 
-fig3 = plt.figure('PCA Noise standard deviation estimation')
-plt.imshow(sigma[..., sli].T, cmap='gray', origin='lower')
-plt.axis('off')
+fig3 = plt.figure("PCA Noise standard deviation estimation")
+plt.imshow(sigma[..., sli].T, cmap="gray", origin="lower")
+plt.axis("off")
 plt.show()
-fig3.savefig('pca_sigma.png')
+fig3.savefig("pca_sigma.png")
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -239,19 +234,5 @@ print(snr)
 # References
 # ----------
 #
-# .. [Manjon2013] Manjon JV, Coupe P, Concha L, Buades A, Collins DL "Diffusion
-#                 Weighted Image Denoising Using Overcomplete Local PCA" (2013)
-#                 PLoS ONE 8(9): e73021. doi:10.1371/journal.pone.0073021.
+# .. footbibliography::
 #
-# .. [Veraa2016a] Veraart J, Fieremans E, Novikov DS. 2016. Diffusion MRI noise
-#                 mapping using random matrix theory. Magnetic Resonance in
-#                 Medicine. doi: 10.1002/mrm.26059.
-#
-# .. [Henri2018] Henriques, R., 2018. Advanced Methods for Diffusion MRI Data
-#                Analysis and their Application to the Healthy Ageing Brain
-#                (Doctoral thesis). https://doi.org/10.17863/CAM.29356
-#
-# .. [Veraa2016b] Veraart J, Novikov DS, Christiaens D, Ades-aron B, Sijbers,
-#                 Fieremans E, 2016. Denoising of Diffusion MRI using random
-#                 matrix theory. Neuroimage 142:394-406.
-#                 doi: 10.1016/j.neuroimage.2016.08.016
