@@ -15,59 +15,70 @@ with brain tissue atrophy that occurs in several brain pathologies and aging).
 
 A way to remove this free water influences is to expand the DTI model to take
 into account an extra compartment representing the contributions of free water
-diffusion [Pasternak2009]_. The expression of the expanded DTI model is shown
-below:
+diffusion :footcite:p:`Pasternak2009`. The expression of the expanded DTI model
+is shown below:
 
 .. math::
 
-    S(\mathbf{g}, b) = S_0(1-f)e^{-b\mathbf{g}^T \mathbf{D}
-    \mathbf{g}}+S_0fe^{-b D_{iso}}
+    S(\\mathbf{g}, b) = S_0(1-f)e^{-b\\mathbf{g}^T \\mathbf{D}
+    \\mathbf{g}}+S_0fe^{-b D_{iso}}
 
-where $\mathbf{g}$ and $b$ are diffusion gradient direction and weighted (more
+where $\\mathbf{g}$ and $b$ are diffusion gradient direction and weighted (more
 information see :ref:`sphx_glr_examples_built_reconstruction_reconst_dti.py`),
-$S(\mathbf{g}, b)$ is thebdiffusion-weighted signal measured, $S_0$ is the
-signal in a measurement with no diffusion weighting, $\mathbf{D}$ is the
+$S(\\mathbf{g}, b)$ is thebdiffusion-weighted signal measured, $S_0$ is the
+signal in a measurement with no diffusion weighting, $\\mathbf{D}$ is the
 diffusion tensor, $f$ the volume fraction of the free water component, and
 $D_{iso}$ is the isotropic value of the free water diffusion (normally set to
 $3.0 \times 10^{-3} mm^{2}s^{-1}$).
 
 In this example, we show how to process a diffusion weighting dataset using an
-adapted version of the free water elimination proposed by [Hoy2014]_.
+adapted version of the free water elimination proposed by :footcite:p:`Hoy2014`.
 
 The full details of Dipy's free water DTI implementation was published in
-[Henriques2017]_. Please cite this work if you use this algorithm.
+:footcite:p:`NetoHenriques2017`. Please cite this work if you use this
+algorithm.
 
 Let's start by importing the relevant modules:
 """
 
-import numpy as np
-import dipy.reconst.fwdti as fwdti
-import dipy.reconst.dti as dti
-import matplotlib.pyplot as plt
-from dipy.data import fetch_hbn
 import os.path as op
+
+import matplotlib.pyplot as plt
 import nibabel as nib
+import numpy as np
+
 from dipy.core.gradients import gradient_table
+from dipy.data import fetch_hbn
+import dipy.reconst.dti as dti
+import dipy.reconst.fwdti as fwdti
 
 ###############################################################################
 # Without spatial constrains the free water elimination model cannot be solved
-# in data acquired from one non-zero b-value [Hoy2014]_. Therefore, here we
-# download a dataset that was acquired with multiple b-values.
+# in data acquired from one non-zero b-value :footcite:p:`Hoy2014`. Therefore,
+# here we download a dataset that was acquired with multiple b-values.
 
 data_path = fetch_hbn(["NDARAA948VFH"])[1]
 dwi_path = op.join(
-       data_path, "derivatives", "qsiprep", "sub-NDARAA948VFH",
-       "ses-HBNsiteRU", "dwi")
+    data_path, "derivatives", "qsiprep", "sub-NDARAA948VFH", "ses-HBNsiteRU", "dwi"
+)
 
-img = nib.load(op.join(
-       dwi_path,
-       "sub-NDARAA948VFH_ses-HBNsiteRU_acq-64dir_space-T1w_desc-preproc_dwi.nii.gz"))
+img = nib.load(
+    op.join(
+        dwi_path,
+        "sub-NDARAA948VFH_ses-HBNsiteRU_acq-64dir_space-T1w_desc-preproc_dwi.nii.gz",
+    )
+)
 
 gtab = gradient_table(
-       op.join(dwi_path,
-"sub-NDARAA948VFH_ses-HBNsiteRU_acq-64dir_space-T1w_desc-preproc_dwi.bval"),
-       op.join(dwi_path,
-"sub-NDARAA948VFH_ses-HBNsiteRU_acq-64dir_space-T1w_desc-preproc_dwi.bvec"))
+    op.join(
+        dwi_path,
+        "sub-NDARAA948VFH_ses-HBNsiteRU_acq-64dir_space-T1w_desc-preproc_dwi.bval",
+    ),
+    bvecs=op.join(
+        dwi_path,
+        "sub-NDARAA948VFH_ses-HBNsiteRU_acq-64dir_space-T1w_desc-preproc_dwi.bvec",
+    ),
+)
 
 data = np.asarray(img.dataobj)
 
@@ -77,8 +88,11 @@ data = np.asarray(img.dataobj)
 # remove the background of the image and avoid unnecessary calculations.
 
 mask_img = nib.load(
-       op.join(dwi_path,
-"sub-NDARAA948VFH_ses-HBNsiteRU_acq-64dir_space-T1w_desc-brain_mask.nii.gz"))
+    op.join(
+        dwi_path,
+        "sub-NDARAA948VFH_ses-HBNsiteRU_acq-64dir_space-T1w_desc-brain_mask.nii.gz",
+    )
+)
 
 ###############################################################################
 # Moreover, for illustration purposes we process only one slice of the data.
@@ -129,42 +143,36 @@ dti_MD = dtifit.md
 # estimated volume fraction of the free water contamination is shown on
 # panel G.
 
-fig1, ax = plt.subplots(2, 4, figsize=(12, 6),
-                        subplot_kw={'xticks': [], 'yticks': []})
+fig1, ax = plt.subplots(2, 4, figsize=(12, 6), subplot_kw={"xticks": [], "yticks": []})
 
 fig1.subplots_adjust(hspace=0.3, wspace=0.05)
-ax.flat[0].imshow(FA[:, :, 0].T, origin='lower',
-                  cmap='gray', vmin=0, vmax=1)
-ax.flat[0].set_title('A) fwDTI FA')
-ax.flat[1].imshow(dti_FA[:, :, 0].T, origin='lower',
-                  cmap='gray', vmin=0, vmax=1)
-ax.flat[1].set_title('B) standard DTI FA')
+ax.flat[0].imshow(FA[:, :, 0].T, origin="lower", cmap="gray", vmin=0, vmax=1)
+ax.flat[0].set_title("A) fwDTI FA")
+ax.flat[1].imshow(dti_FA[:, :, 0].T, origin="lower", cmap="gray", vmin=0, vmax=1)
+ax.flat[1].set_title("B) standard DTI FA")
 
 FAdiff = abs(FA[:, :, 0] - dti_FA[:, :, 0])
-ax.flat[2].imshow(FAdiff.T, cmap='gray', origin='lower', vmin=0, vmax=1)
-ax.flat[2].set_title('C) FA difference')
+ax.flat[2].imshow(FAdiff.T, cmap="gray", origin="lower", vmin=0, vmax=1)
+ax.flat[2].set_title("C) FA difference")
 
-ax.flat[3].axis('off')
+ax.flat[3].axis("off")
 
-ax.flat[4].imshow(MD[:, :, 0].T, origin='lower',
-                  cmap='gray', vmin=0, vmax=2.5e-3)
-ax.flat[4].set_title('D) fwDTI MD')
-ax.flat[5].imshow(dti_MD[:, :, 0].T, origin='lower',
-                  cmap='gray', vmin=0, vmax=2.5e-3)
-ax.flat[5].set_title('E) standard DTI MD')
+ax.flat[4].imshow(MD[:, :, 0].T, origin="lower", cmap="gray", vmin=0, vmax=2.5e-3)
+ax.flat[4].set_title("D) fwDTI MD")
+ax.flat[5].imshow(dti_MD[:, :, 0].T, origin="lower", cmap="gray", vmin=0, vmax=2.5e-3)
+ax.flat[5].set_title("E) standard DTI MD")
 
 MDdiff = abs(MD[:, :, 0] - dti_MD[:, :, 0])
-ax.flat[6].imshow(MDdiff.T, origin='lower', cmap='gray', vmin=0, vmax=2.5e-3)
-ax.flat[6].set_title('F) MD difference')
+ax.flat[6].imshow(MDdiff.T, origin="lower", cmap="gray", vmin=0, vmax=2.5e-3)
+ax.flat[6].set_title("F) MD difference")
 
 F = fwdtifit.f
 
-ax.flat[7].imshow(F[:, :, 0].T, origin='lower',
-                  cmap='gray', vmin=0, vmax=1)
-ax.flat[7].set_title('G) free water volume')
+ax.flat[7].imshow(F[:, :, 0].T, origin="lower", cmap="gray", vmin=0, vmax=1)
+ax.flat[7].set_title("G) free water volume")
 
 plt.show()
-fig1.savefig('In_vivo_free_water_DTI_and_standard_DTI_measures.png')
+fig1.savefig("In_vivo_free_water_DTI_and_standard_DTI_measures.png")
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -195,23 +203,20 @@ dti_FA[F > 0.7] = 0
 # Above we reproduce the plots of the in vivo FA from the two DTI fits and
 # where we can see that the inflated FA values were practically removed:
 
-fig1, ax = plt.subplots(1, 3, figsize=(9, 3),
-                        subplot_kw={'xticks': [], 'yticks': []})
+fig1, ax = plt.subplots(1, 3, figsize=(9, 3), subplot_kw={"xticks": [], "yticks": []})
 
 fig1.subplots_adjust(hspace=0.3, wspace=0.05)
-ax.flat[0].imshow(FA[:, :, 0].T, origin='lower',
-                  cmap='gray', vmin=0, vmax=1)
-ax.flat[0].set_title('A) fwDTI FA')
-ax.flat[1].imshow(dti_FA[:, :, 0].T, origin='lower',
-                  cmap='gray', vmin=0, vmax=1)
-ax.flat[1].set_title('B) standard DTI FA')
+ax.flat[0].imshow(FA[:, :, 0].T, origin="lower", cmap="gray", vmin=0, vmax=1)
+ax.flat[0].set_title("A) fwDTI FA")
+ax.flat[1].imshow(dti_FA[:, :, 0].T, origin="lower", cmap="gray", vmin=0, vmax=1)
+ax.flat[1].set_title("B) standard DTI FA")
 
 FAdiff = abs(FA[:, :, 0] - dti_FA[:, :, 0])
-ax.flat[2].imshow(FAdiff.T, cmap='gray', origin='lower', vmin=0, vmax=1)
-ax.flat[2].set_title('C) FA difference')
+ax.flat[2].imshow(FAdiff.T, cmap="gray", origin="lower", vmin=0, vmax=1)
+ax.flat[2].set_title("C) FA difference")
 
 plt.show()
-fig1.savefig('In_vivo_free_water_DTI_and_standard_DTI_corrected.png')
+fig1.savefig("In_vivo_free_water_DTI_and_standard_DTI_corrected.png")
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -224,16 +229,6 @@ fig1.savefig('In_vivo_free_water_DTI_and_standard_DTI_corrected.png')
 #
 # References
 # ----------
-# .. [Pasternak2009] Pasternak, O., Sochen, N., Gur, Y., Intrator, N., Assaf,
-#    Y., 2009. Free water elimination and mapping from diffusion MRI. Magn.
-#    Reson. Med. 62(3): 717-30. doi: 10.1002/mrm.22055.
 #
-# .. [Hoy2014] Hoy, A.R., Koay, C.G., Kecskemeti, S.R., Alexander, A.L., 2014.
-#    Optimization of a free water elimination two-compartmental model for
-#    diffusion tensor imaging. NeuroImage 103, 323-333. doi:
-#    10.1016/j.neuroimage.2014.09.053
+# .. footbibliography::
 #
-# .. [Henriques2017] Henriques, R.N., Rokem, A., Garyfallidis, E., St-Jean, S.,
-#    Peterson E.T., Correia, M.M., 2017. [Re] Optimization of a free water
-#    elimination two-compartment model for diffusion tensor imaging.
-#    ReScience volume 3, issue 1, article number 2
