@@ -3,7 +3,7 @@
 Reconstruct with Generalized Q-Sampling Imaging
 ===============================================
 
-We show how to apply Generalized Q-Sampling Imaging [Yeh2010]_
+We show how to apply Generalized Q-Sampling Imaging :footcite:p:`Yeh2010`
 to diffusion MRI datasets. You can think of GQI as an analytical version of
 DSI orientation distribution function (ODF) (Garyfallidis, PhD thesis, 2012).
 
@@ -11,17 +11,18 @@ First import the necessary modules:
 """
 
 import numpy as np
+
 from dipy.core.gradients import gradient_table
 from dipy.data import get_fnames, get_sphere
+from dipy.direction import peaks_from_model
 from dipy.io.gradients import read_bvals_bvecs
 from dipy.io.image import load_nifti
 from dipy.reconst.gqi import GeneralizedQSamplingModel
-from dipy.direction import peaks_from_model
 
 ###############################################################################
 # Download and get the data filenames for this tutorial.
 
-fraw, fbval, fbvec = get_fnames('taiwan_ntu_dsi')
+fraw, fbval, fbvec = get_fnames(name="taiwan_ntu_dsi")
 
 ###############################################################################
 # img contains a nibabel Nifti1Image object (data) and gtab contains a
@@ -34,10 +35,9 @@ fraw, fbval, fbvec = get_fnames('taiwan_ntu_dsi')
 
 data, affine, voxel_size = load_nifti(fraw, return_voxsize=True)
 bvals, bvecs = read_bvals_bvecs(fbval, fbvec)
-bvecs[1:] = (bvecs[1:] /
-                 np.sqrt(np.sum(bvecs[1:] * bvecs[1:], axis=1))[:, None])
-gtab = gradient_table(bvals, bvecs)
-print('data.shape (%d, %d, %d, %d)' % data.shape)
+bvecs[1:] = bvecs[1:] / np.sqrt(np.sum(bvecs[1:] * bvecs[1:], axis=1))[:, None]
+gtab = gradient_table(bvals, bvecs=bvecs)
+print(f"data.shape {data.shape}")
 
 ###############################################################################
 # This dataset has anisotropic voxel sizes, therefore reslicing is necessary.
@@ -60,27 +60,29 @@ gqfit = gqmodel.fit(dataslice, mask=mask)
 ###############################################################################
 # Load an ODF reconstruction sphere
 
-sphere = get_sphere('repulsion724')
+sphere = get_sphere(name="repulsion724")
 
 ###############################################################################
 # Calculate the ODFs with this specific sphere
 
 ODF = gqfit.odf(sphere)
 
-print('ODF.shape (%d, %d, %d)' % ODF.shape)
+print(f"ODF.shape {ODF.shape}")
 
 ###############################################################################
 # Using ``peaks_from_model`` we can find the main peaks of the ODFs and other
 # properties.
 
-gqpeaks = peaks_from_model(model=gqmodel,
-                           data=dataslice,
-                           sphere=sphere,
-                           relative_peak_threshold=.5,
-                           min_separation_angle=25,
-                           mask=mask,
-                           return_odf=False,
-                           normalize_peaks=True)
+gqpeaks = peaks_from_model(
+    model=gqmodel,
+    data=dataslice,
+    sphere=sphere,
+    relative_peak_threshold=0.5,
+    min_separation_angle=25,
+    mask=mask,
+    return_odf=False,
+    normalize_peaks=True,
+)
 
 gqpeak_values = gqpeaks.peak_values
 
@@ -94,20 +96,22 @@ gqpeak_indices = gqpeaks.peak_indices
 
 GFA = gqpeaks.gfa
 
-print('GFA.shape (%d, %d)' % GFA.shape)
+print(f"GFA.shape {GFA.shape}")
 
 ###############################################################################
 # With parameter ``return_odf=True`` we can obtain the ODF using
 # ``gqpeaks.ODF``
 
-gqpeaks = peaks_from_model(model=gqmodel,
-                           data=dataslice,
-                           sphere=sphere,
-                           relative_peak_threshold=.5,
-                           min_separation_angle=25,
-                           mask=mask,
-                           return_odf=True,
-                           normalize_peaks=True)
+gqpeaks = peaks_from_model(
+    model=gqmodel,
+    data=dataslice,
+    sphere=sphere,
+    relative_peak_threshold=0.5,
+    min_separation_angle=25,
+    mask=mask,
+    return_odf=True,
+    normalize_peaks=True,
+)
 
 ###############################################################################
 # This ODF will be of course identical to the ODF calculated above as long as
@@ -122,5 +126,6 @@ print(np.sum(gqpeaks.odf != ODF) == 0)
 #
 # References
 # ----------
-# .. [Yeh2010] Yeh, F-C et al., Generalized Q-sampling imaging, IEEE
-#    Transactions on Medical Imaging, vol 29, no 9, 2010.
+#
+# .. footbibliography::
+#
