@@ -1,12 +1,12 @@
-"""
-============================
-Intravoxel incoherent motion
-============================
+r"""
+===================================
+Intravoxel incoherent motion (IVIM)
+===================================
 The intravoxel incoherent motion (IVIM) model describes diffusion
 and perfusion in the signal acquired with a diffusion MRI sequence
 that contains multiple low b-values. The IVIM model can be understood
-as an adaptation of the work of Stejskal and Tanner [Stejskal65]_
-in biological tissue, and was proposed by Le Bihan [LeBihan84]_.
+as an adaptation of the work of Stejskal and Tanner :footcite:p:`Stejskal1965`
+in biological tissue, and was proposed by Le Bihan :footcite:p:`LeBihan1988`.
 The model assumes two compartments: a slow moving compartment,
 where particles diffuse in a Brownian fashion as a consequence of thermal
 energy, and a fast moving compartment (the vascular compartment), where
@@ -14,7 +14,7 @@ blood moves as a consequence of a pressure gradient. In the first compartment,
 the diffusion coefficient is $\mathbf{D}$ while in the second compartment, a
 pseudo diffusion term $\mathbf{D^*}$ is introduced that describes the
 displacement of the blood elements in an assumed randomly laid out vascular
-network, at the macroscopic level. According to [LeBihan84]_,
+network, at the macroscopic level. According to :footcite:p:`LeBihan1988`,
 $\mathbf{D^*}$ is greater than $\mathbf{D}$.
 
 The IVIM model expresses the MRI signal as follows:
@@ -35,11 +35,11 @@ coefficients. First, we import all relevant modules:
 
 import matplotlib.pyplot as plt
 
-from dipy.reconst.ivim import IvimModel
 from dipy.core.gradients import gradient_table
 from dipy.data import get_fnames
 from dipy.io.gradients import read_bvals_bvecs
 from dipy.io.image import load_nifti_data
+from dipy.reconst.ivim import IvimModel
 
 ###############################################################################
 # We get an IVIM dataset using DIPY_'s data fetcher ``read_ivim``.
@@ -50,7 +50,7 @@ from dipy.io.image import load_nifti_data
 # of b-values. In order to use this model the data should contain signals
 # measured at 0 bvalue.
 
-fraw, fbval, fbvec = get_fnames('ivim')
+fraw, fbval, fbvec = get_fnames(name="ivim")
 
 ###############################################################################
 # The gtab contains a GradientTable object (information about the gradients
@@ -59,8 +59,8 @@ fraw, fbval, fbvec = get_fnames('ivim')
 
 data = load_nifti_data(fraw)
 bvals, bvecs = read_bvals_bvecs(fbval, fbvec)
-gtab = gradient_table(bvals, bvecs, b0_threshold=0)
-print('data.shape (%d, %d, %d, %d)' % data.shape)
+gtab = gradient_table(bvals, bvecs=bvecs, b0_threshold=0)
+print(f"data.shape {data.shape}")
 
 ###############################################################################
 # The data has 54 slices, with 256-by-256 voxels in each slice. The fourth
@@ -70,8 +70,7 @@ print('data.shape (%d, %d, %d, %d)' % data.shape)
 z = 33
 b = 0
 
-plt.imshow(data[:, :, z, b].T, origin='lower', cmap='gray',
-           interpolation='nearest')
+plt.imshow(data[:, :, z, b].T, origin="lower", cmap="gray", interpolation="nearest")
 plt.axhline(y=100)
 plt.axvline(x=170)
 plt.savefig("ivim_data_slice.png")
@@ -94,8 +93,9 @@ x1, x2 = 90, 155
 y1, y2 = 90, 170
 data_slice = data[x1:x2, y1:y2, z, :]
 
-plt.imshow(data[x1:x2, y1:y2, z, b].T, origin='lower',
-           cmap="gray", interpolation='nearest')
+plt.imshow(
+    data[x1:x2, y1:y2, z, b].T, origin="lower", cmap="gray", interpolation="nearest"
+)
 plt.savefig("CSF_slice.png")
 plt.close()
 
@@ -128,7 +128,7 @@ plt.close()
 # For brevity, we focus on a small section of the slice as selected above,
 # to fit the IVIM model. First, we instantiate the IvimModel object.
 
-ivimmodel = IvimModel(gtab, fit_method='trr')
+ivimmodel = IvimModel(gtab, fit_method="trr")
 
 ###############################################################################
 # To fit the model, call the `fit` method and pass the data for fitting.
@@ -145,7 +145,7 @@ ivimfit = ivimmodel.fit(data_slice)
 # order : $\mathbf{S_{0}, f, D^*, D}$.
 
 ivimparams = ivimfit.model_params
-print("ivimparams.shape : {}".format(ivimparams.shape))
+print(f"ivimparams.shape : {ivimparams.shape}")
 
 ###############################################################################
 # As we see, we have a 20x20 slice at the height z = 33. Thus we
@@ -175,12 +175,18 @@ print(estimated_params)
 def plot_map(raw_data, variable, limits, filename):
     fig, ax = plt.subplots(1)
     lower, upper = limits
-    ax.set_title('Map for {}'.format(variable))
-    im = ax.imshow(raw_data.T, origin='lower', clim=(lower, upper),
-                   cmap="gray", interpolation='nearest')
+    ax.set_title(f"Map for {variable}")
+    im = ax.imshow(
+        raw_data.T,
+        origin="lower",
+        clim=(lower, upper),
+        cmap="gray",
+        interpolation="nearest",
+    )
     fig.colorbar(im)
     fig.savefig(filename)
 
+
 ###############################################################################
 # Let us get the various plots with `fit_method = 'trr'` so that we can
 # visualize them in one page
@@ -195,10 +201,10 @@ plot_map(ivimfit.D, "D", (0, 0.001), "diffusion_coeff.png")
 ###############################################################################
 # Next, we will fit the same model with a more refined optimization process
 # with `fit_method='VarPro'` (for "Variable Projection"). The VarPro computes
-# the IVIM parameters using the MIX approach [Farooq16]_. This algorithm uses
-# three different optimizers. It starts with a differential evolution
-# algorithm and fits the parameters in the power of exponentials. Then the
-# fitted parameters in the first step are utilized to make a linear convex
+# the IVIM parameters using the MIX approach :footcite:p:`Farooq2016`. This
+# algorithm uses three different optimizers. It starts with a differential
+# evolution algorithm and fits the parameters in the power of exponentials. Then
+# the fitted parameters in the first step are utilized to make a linear convex
 # problem. Using a convex optimization, the volume fractions are determined.
 # The last step is non-linear least-squares fitting on all the parameters.
 # The results of the first and second optimizers are utilized as the initial
@@ -210,9 +216,9 @@ plot_map(ivimfit.D, "D", (0, 0.001), "diffusion_coeff.png")
 # simultaneously. Making use of the three step optimization mentioned above
 # increases the convergence basin for fitting the multi-exponential functions
 # of microstructure models. This method has been described in further detail
-# in [Fadnavis19]_ and [Farooq16]_.
+# in :footcite:p:`Fadnavis2019` and :footcite:p:`Farooq2016`.
 
-ivimmodel_vp = IvimModel(gtab, fit_method='VarPro')
+ivimmodel_vp = IvimModel(gtab, fit_method="VarPro")
 ivimfit_vp = ivimmodel_vp.fit(data_slice)
 
 ###############################################################################
@@ -237,8 +243,7 @@ print(estimated_params)
 
 fig, ax = plt.subplots(1)
 
-ax.scatter(gtab.bvals, data_slice[i, j, :],
-           color="green", label="Measured signal")
+ax.scatter(gtab.bvals, data_slice[i, j, :], color="green", label="Measured signal")
 
 ivim_trr_predict = ivimfit.predict(gtab)[i, j, :]
 
@@ -246,11 +251,19 @@ ax.plot(gtab.bvals, ivim_trr_predict, label="trr prediction")
 
 S0_est, f_est, D_star_est, D_est = ivimfit.model_params[i, j, :]
 
-text_fit = """trr param estimates: \n S0={:06.3f} f={:06.4f}\n
-            D*={:06.5f} D={:06.5f}""".format(S0_est, f_est, D_star_est, D_est)
+trr_pro_param_est = (
+    f"S0={S0_est:06.3f} f={f_est:06.4f}\n" f"D*={D_star_est:06.5f} D={D_est:06.5f}"
+)
+text_fit = f"""trr param estimates:\n {trr_pro_param_est}"""
 
-ax.text(0.65, 0.80, text_fit, horizontalalignment='center',
-        verticalalignment='center', transform=plt.gca().transAxes)
+ax.text(
+    0.65,
+    0.80,
+    text_fit,
+    horizontalalignment="center",
+    verticalalignment="center",
+    transform=plt.gca().transAxes,
+)
 
 ivim_predict_vp = ivimfit_vp.predict(gtab)[i, j, :]
 ax.plot(gtab.bvals, ivim_predict_vp, label="VarPro prediction")
@@ -260,13 +273,21 @@ ax.set_ylabel("Signals")
 
 S0_est, f_est, D_star_est, D_est = ivimfit_vp.model_params[i, j, :]
 
-text_fit = """VarPro param estimates: \n S0={:06.3f} f={:06.4f}\n
-            D*={:06.5f} D={:06.5f}""".format(S0_est, f_est, D_star_est, D_est)
+var_pro_param_est = (
+    f"S0={S0_est:06.3f} f={f_est:06.4f}\n" f"D*={D_star_est:06.5f} D={D_est:06.5f}"
+)
+text_fit = f"""VarPro param estimates:\n{var_pro_param_est}"""
 
-ax.text(0.65, 0.50, text_fit, horizontalalignment='center',
-        verticalalignment='center', transform=plt.gca().transAxes)
+ax.text(
+    0.65,
+    0.50,
+    text_fit,
+    horizontalalignment="center",
+    verticalalignment="center",
+    transform=plt.gca().transAxes,
+)
 
-fig.legend(loc='upper right')
+fig.legend(loc="upper right")
 fig.savefig("ivim_voxel_plot.png")
 
 ###############################################################################
@@ -279,37 +300,41 @@ fig.savefig("ivim_voxel_plot.png")
 # visualize them in one page
 
 plt.figure()
-plot_map(ivimfit_vp.S0_predicted, "Heatmap of S0 predicted from the fit",
-         (0, 10000), "predicted_S0.png")
-plot_map(data_slice[..., 0], "Heatmap of measured signal at bvalue = 0",
-         (0, 10000), "measured_S0.png")
-plot_map(ivimfit_vp.perfusion_fraction, "Heatmap of perfusion fraction values "
-         "predicted from the fit", (0, 1), "perfusion_fraction.png")
-plot_map(ivimfit_vp.D_star, "D* - Heatmap of perfusion coefficients predicted "
-         "from the fit", (0, 0.01), "perfusion_coeff.png")
-plot_map(ivimfit_vp.D, "D - Heatmap of diffusion coefficients predicted from "
-         "the fit", (0, 0.001), "diffusion_coeff.png")
+plot_map(
+    ivimfit_vp.S0_predicted,
+    "Heatmap of S0 predicted from the fit",
+    (0, 10000),
+    "predicted_S0.png",
+)
+plot_map(
+    data_slice[..., 0],
+    "Heatmap of measured signal at bvalue = 0",
+    (0, 10000),
+    "measured_S0.png",
+)
+plot_map(
+    ivimfit_vp.perfusion_fraction,
+    "Heatmap of perfusion fraction values predicted from the fit",
+    (0, 1),
+    "perfusion_fraction.png",
+)
+plot_map(
+    ivimfit_vp.D_star,
+    "D* - Heatmap of perfusion coefficients predicted from the fit",
+    (0, 0.01),
+    "perfusion_coeff.png",
+)
+plot_map(
+    ivimfit_vp.D,
+    "D - Heatmap of diffusion coefficients predicted from the fit",
+    (0, 0.001),
+    "diffusion_coeff.png",
+)
 
 
 ###############################################################################
 # References
 # ----------
 #
-# .. [Stejskal65] Stejskal, E. O.; Tanner, J. E. (1 January 1965).
-#                 "Spin Diffusion Measurements: Spin Echoes in the Presence
-#                 of a Time-Dependent Field Gradient". The Journal of Chemical
-#                 Physics 42 (1): 288. Bibcode: 1965JChPh..42..288S.
-#                 doi:10.1063/1.1695690.
+# .. footbibliography::
 #
-# .. [LeBihan84] Le Bihan, Denis, et al. "Separation of diffusion
-#                and perfusion in intravoxel incoherent motion MR
-#                imaging." Radiology 168.2 (1988): 497-505.
-#
-# .. [Fadnavis19] Fadnavis, Shreyas et.al. "MicroLearn: Framework for machine
-#                learning, reconstruction, optimization and microstructure
-#                modeling, Proceedings of: International Society of Magnetic
-#                Resonance in Medicine (ISMRM), Montreal, Canada, 2019.
-#
-# .. [Farooq16] Farooq, Hamza, et al. "Microstructure Imaging of Crossing (MIX)
-#                White Matter Fibers from diffusion MRI." Scientific reports 6
-#                (2016).
