@@ -6,53 +6,55 @@ Mean signal diffusion kurtosis imaging (MSDKI)
 Diffusion Kurtosis Imaging (DKI) is one of the conventional ways to estimate
 the degree of non-Gaussian diffusion
 (see :ref:`sphx_glr_examples_built_reconstruction_reconst_dki.py`)
-[Jensen2005]_. However, a limitation of DKI is that its measures are highly
-sensitive to noise and image artefacts. For instance, due to the low radial
-diffusivities, standard kurtosis estimates in regions of well-aligned voxel may
-be corrupted by implausible low or even negative values.
+:footcite:p:`Jensen2005`. However, a limitation of DKI is that its measures are
+highly sensitive to noise and image artefacts. For instance, due to the low
+radial diffusivities, standard kurtosis estimates in regions of well-aligned
+voxel may be corrupted by implausible low or even negative values.
 
 A way to overcome this issue is to characterize kurtosis from average signals
 across all directions acquired for each data b-value (also known as
-powder-averaged signals). Moreover, as previously pointed [NetoHe2015]_,
-standard kurtosis measures (e.g. radial, axial and standard mean kurtosis)
-do not only depend on microstructural properties but also on mesoscopic
-properties such as fiber dispersion or the intersection angle of crossing
-fibers. In contrary, the kurtosis from powder-average signals has the advantage
-of not depending on the fiber distribution functions [NetoHe2018]_,
-[NetoHe2019]_.
+powder-averaged signals). Moreover, as previously pointed
+:footcite:p:`NetoHenriques2015`, standard kurtosis measures (e.g. radial, axial
+and standard mean kurtosis) do not only depend on microstructural properties but
+also on mesoscopic properties such as fiber dispersion or the intersection angle
+of crossing fibers. In contrary, the kurtosis from powder-average signals has
+the advantage of not depending on the fiber distribution functions
+:footcite:p:`NetoHenriques2019`, :footcite:p:`NetoHenriques2021a`
 
 In short, in this tutorial we show how to characterize non-Gaussian diffusion
 in a more precise way and decoupled from confounding effects of tissue
 dispersion and crossing.
 
 In the first part of this example, we illustrate the properties of the measures
-obtained from the mean signal diffusion kurtosis imaging (MSDKI) [NetoHe2018]_
-using synthetic data. Secondly, the mean signal diffusion kurtosis imaging will
-be applied to in-vivo MRI data. Finally, we show how MSDKI provides the same
+obtained from the mean signal diffusion kurtosis imaging (MSDKI)
+:footcite:p:`NetoHenriques2018`, :footcite:p:`NetoHenriques2021a` using
+synthetic data. Secondly, the mean signal diffusion kurtosis imaging will be
+applied to in-vivo MRI data. Finally, we show how MSDKI provides the same
 information than common microstructural models such as the spherical mean
-technique [NetoHe2019]_, [Kaden2016b]_.
+technique :footcite:p:`NetoHenriques2019`, :footcite:p:`Kaden2016b`.
 
 Let's import all relevant modules:
 """
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
-# Reconstruction modules
-import dipy.reconst.dki as dki
-import dipy.reconst.msdki as msdki
-
-# For simulations
-from dipy.sims.voxel import multi_tensor
 from dipy.core.gradients import gradient_table
-from dipy.core.sphere import disperse_charges, HemiSphere
+from dipy.core.sphere import HemiSphere, disperse_charges
 
 # For in-vivo data
 from dipy.data import get_fnames
 from dipy.io.gradients import read_bvals_bvecs
 from dipy.io.image import load_nifti
+
+# Reconstruction modules
+import dipy.reconst.dki as dki
+import dipy.reconst.msdki as msdki
 from dipy.segment.mask import median_otsu
 
+# For simulations
+from dipy.sims.voxel import multi_tensor
+
 ###############################################################################
 # Testing MSDKI in synthetic data
 # ===============================
@@ -63,13 +65,17 @@ from dipy.segment.mask import median_otsu
 # this example, simulations are produced based on the sum of four diffusion
 # tensors to represent the intra- and extra-cellular spaces of two fiber
 # populations. The parameters of these tensors are adjusted according to
-# [NetoHe2015]_ (see also
+# :footcite:p:`NetoHenriques2015` (see also
 # :ref:`sphx_glr_examples_built_simulations_simulate_dki.py`).
 
-mevals = np.array([[0.00099, 0, 0],
-                   [0.00226, 0.00087, 0.00087],
-                   [0.00099, 0, 0],
-                   [0.00226, 0.00087, 0.00087]])
+mevals = np.array(
+    [
+        [0.00099, 0, 0],
+        [0.00226, 0.00087, 0.00087],
+        [0.00099, 0, 0],
+        [0.00226, 0.00087, 0.00087],
+    ]
+)
 
 ###############################################################################
 # For the acquisition parameters of the synthetic data, we use 60 gradient
@@ -95,7 +101,7 @@ directions = hsph_updated.vertices
 bvals = np.hstack((np.zeros(2), 1000 * np.ones(n_pts), 2000 * np.ones(n_pts)))
 bvecs = np.vstack((np.zeros((2, 3)), directions, directions))
 
-gtab = gradient_table(bvals, bvecs)
+gtab = gradient_table(bvals, bvecs=bvecs)
 
 ###############################################################################
 # Simulations are looped for different intra- and extra-cellular water
@@ -120,8 +126,9 @@ for f_i in range(f.size):
         angles = [(ang[a_i], 0.0), (ang[a_i], 0.0), (0.0, 0.0), (0.0, 0.0)]
 
         # producing signals using Dipy's function multi_tensor
-        signal, sticks = multi_tensor(gtab, mevals, S0=100, angles=angles,
-                                      fractions=fractions, snr=None)
+        signal, sticks = multi_tensor(
+            gtab, mevals, S0=100, angles=angles, fractions=fractions, snr=None
+        )
         dwi[f_i, a_i, :] = signal
 
 ###############################################################################
@@ -155,7 +162,7 @@ dki_model = dki.DiffusionKurtosisModel(gtab)
 dki_fit = dki_model.fit(dwi)
 
 MD = dki_fit.md
-MK = dki_fit.mk(0, 3)
+MK = dki_fit.mk(min_kurtosis=0, max_kurtosis=3)
 
 ###############################################################################
 # Now we plot the results as a function of the ground truth intersection
@@ -164,29 +171,25 @@ MK = dki_fit.mk(0, 3)
 fig1, axs = plt.subplots(nrows=2, ncols=2, figsize=(10, 10))
 
 for f_i in range(f.size):
-    axs[0, 0].plot(ang, MSD[f_i], linewidth=1.0,
-                   label='$F: %.2f$' % f[f_i])
-    axs[0, 1].plot(ang, MSK[f_i], linewidth=1.0,
-                   label='$F: %.2f$' % f[f_i])
-    axs[1, 0].plot(ang, MD[f_i], linewidth=1.0,
-                   label='$F: %.2f$' % f[f_i])
-    axs[1, 1].plot(ang, MK[f_i], linewidth=1.0,
-                   label='$F: %.2f$' % f[f_i])
+    axs[0, 0].plot(ang, MSD[f_i], linewidth=1.0, label=f"$F: {f[f_i]:.2f}$")
+    axs[0, 1].plot(ang, MSK[f_i], linewidth=1.0, label=f"$F: {f[f_i]:.2f}$")
+    axs[1, 0].plot(ang, MD[f_i], linewidth=1.0, label=f"$F: {f[f_i]:.2f}$")
+    axs[1, 1].plot(ang, MK[f_i], linewidth=1.0, label=f"$F: {f[f_i]:.2f}$")
 
 # Adjust properties of the first panel of the figure
-axs[0, 0].set_xlabel('Intersection angle')
-axs[0, 0].set_ylabel('MSD')
-axs[0, 1].set_xlabel('Intersection angle')
-axs[0, 1].set_ylabel('MSK')
-axs[0, 1].legend(loc='center left', bbox_to_anchor=(1, 0.5))
-axs[1, 0].set_xlabel('Intersection angle')
-axs[1, 0].set_ylabel('MD')
-axs[1, 1].set_xlabel('Intersection angle')
-axs[1, 1].set_ylabel('MK')
-axs[1, 1].legend(loc='center left', bbox_to_anchor=(1, 0.5))
+axs[0, 0].set_xlabel("Intersection angle")
+axs[0, 0].set_ylabel("MSD")
+axs[0, 1].set_xlabel("Intersection angle")
+axs[0, 1].set_ylabel("MSK")
+axs[0, 1].legend(loc="center left", bbox_to_anchor=(1, 0.5))
+axs[1, 0].set_xlabel("Intersection angle")
+axs[1, 0].set_ylabel("MD")
+axs[1, 1].set_xlabel("Intersection angle")
+axs[1, 1].set_ylabel("MK")
+axs[1, 1].legend(loc="center left", bbox_to_anchor=(1, 0.5))
 
 plt.show()
-fig1.savefig('MSDKI_simulations.png')
+fig1.savefig("MSDKI_simulations.png")
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -218,14 +221,14 @@ fig1.savefig('MSDKI_simulations.png')
 # (see :ref:`sphx_glr_examples_built_reconstruction_reconst_dki.py`), we use
 # fetch to download a multi-shell dataset which was kindly provided by Hansen
 # and Jespersen (more details about the data are provided in their paper
-# [Hansen2016]_). The total size of the downloaded data is 192 MBytes, however
-# you only need to fetch it once.
+# :footcite:p:`Hansen2016a`). The total size of the downloaded data is 192
+# MBytes, however you only need to fetch it once.
 
-fraw, fbval, fbvec, t1_fname = get_fnames('cfin_multib')
+fraw, fbval, fbvec, t1_fname = get_fnames(name="cfin_multib")
 
 data, affine = load_nifti(fraw)
 bvals, bvecs = read_bvals_bvecs(fbval, fbvec)
-gtab = gradient_table(bvals, bvecs)
+gtab = gradient_table(bvals, bvecs=bvecs)
 
 ###############################################################################
 # Before fitting the data, we perform some data pre-processing. For
@@ -236,8 +239,9 @@ gtab = gradient_table(bvals, bvecs)
 # :ref:`sphx_glr_examples_built_preprocessing_denoise_nlmeans.py` or the
 # local pca :ref:`sphx_glr_examples_built_preprocessing_denoise_localpca.py`).
 
-maskdata, mask = median_otsu(data, vol_idx=[0, 1], median_radius=4, numpass=2,
-                             autocrop=False, dilate=1)
+maskdata, mask = median_otsu(
+    data, vol_idx=[0, 1], median_radius=4, numpass=2, autocrop=False, dilate=1
+)
 
 ###############################################################################
 # Now that we have loaded and pre-processed the data we can go forward
@@ -266,33 +270,36 @@ dki_model = dki.DiffusionKurtosisModel(gtab)
 dki_fit = dki_model.fit(data, mask=mask)
 
 MD = dki_fit.md
-MK = dki_fit.mk(0, 3)
+MK = dki_fit.mk(min_kurtosis=0, max_kurtosis=3)
 
 ###############################################################################
 # Let's now visualize the data using matplotlib for a selected axial slice.
 
 axial_slice = 9
 
-fig2, ax = plt.subplots(2, 2, figsize=(6, 6),
-                        subplot_kw={'xticks': [], 'yticks': []})
+fig2, ax = plt.subplots(2, 2, figsize=(6, 6), subplot_kw={"xticks": [], "yticks": []})
 
 fig2.subplots_adjust(hspace=0.3, wspace=0.05)
 
-im0 = ax.flat[0].imshow(MSD[:, :, axial_slice].T * 1000, cmap='gray',
-                        vmin=0, vmax=2, origin='lower')
-ax.flat[0].set_title('MSD (MSDKI)')
+im0 = ax.flat[0].imshow(
+    MSD[:, :, axial_slice].T * 1000, cmap="gray", vmin=0, vmax=2, origin="lower"
+)
+ax.flat[0].set_title("MSD (MSDKI)")
 
-im1 = ax.flat[1].imshow(MSK[:, :, axial_slice].T, cmap='gray',
-                        vmin=0, vmax=2, origin='lower')
-ax.flat[1].set_title('MSK (MSDKI)')
+im1 = ax.flat[1].imshow(
+    MSK[:, :, axial_slice].T, cmap="gray", vmin=0, vmax=2, origin="lower"
+)
+ax.flat[1].set_title("MSK (MSDKI)")
 
-im2 = ax.flat[2].imshow(MD[:, :, axial_slice].T * 1000, cmap='gray',
-                        vmin=0, vmax=2, origin='lower')
-ax.flat[2].set_title('MD (DKI)')
+im2 = ax.flat[2].imshow(
+    MD[:, :, axial_slice].T * 1000, cmap="gray", vmin=0, vmax=2, origin="lower"
+)
+ax.flat[2].set_title("MD (DKI)")
 
-im3 = ax.flat[3].imshow(MK[:, :, axial_slice].T, cmap='gray',
-                        vmin=0, vmax=2, origin='lower')
-ax.flat[3].set_title('MK (DKI)')
+im3 = ax.flat[3].imshow(
+    MK[:, :, axial_slice].T, cmap="gray", vmin=0, vmax=2, origin="lower"
+)
+ax.flat[3].set_title("MK (DKI)")
 
 fig2.colorbar(im0, ax=ax.flat[0])
 fig2.colorbar(im1, ax=ax.flat[1])
@@ -300,7 +307,7 @@ fig2.colorbar(im2, ax=ax.flat[2])
 fig2.colorbar(im3, ax=ax.flat[3])
 
 plt.show()
-fig2.savefig('MSDKI_invivo.png')
+fig2.savefig("MSDKI_invivo.png")
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -310,21 +317,23 @@ fig2.savefig('MSDKI_invivo.png')
 #
 # This figure shows that the contrast of in-vivo MSD and MSK maps (upper
 # panels) are similar to the contrast of MD and MSK maps (lower panels);
-# however, in the upper part we insure that direct contributions of fiber
+# however, in the upper part we ensure that direct contributions of fiber
 # dispersion were removed. The upper panels also reveal that MSDKI measures
 # are let sensitive to noise artefacts than standard DKI measures (as pointed
-# by [NetoHe2018]_), particularly one can observe that MSK maps always present
-# positive values in brain white matter regions, while implausible negative
-# kurtosis values are present in the MK maps in the same regions.
+# by :footcite:p:`NetoHenriques2018`), particularly one can observe that MSK
+# maps always present positive values in brain white matter regions, while
+# implausible negative kurtosis values are present in the MK maps in the same
+# regions.
 #
 # Relationship between MSDKI and SMT2
 # ===================================
-# As showed in [NetoHe2019]_, MSDKI captures the same information than the
-# spherical mean technique (SMT) microstructural models [Kaden2016b]_. In this
-# way, the SMT model parameters can be directly computed from MSDKI.
-# For instance, the axonal volume fraction (f), the intrisic diffusivity (di),
-# and the microscopic anisotropy of the SMT 2-compartmental model [NetoHe2019]_
-# can be extracted using the following lines of code:
+# As showed in :footcite:p:`NetoHenriques2019`, MSDKI captures the same
+# information than the spherical mean technique (SMT) microstructural models
+# :footcite:p:`Kaden2016b`. In this way, the SMT model parameters can be
+# directly computed from MSDKI. For instance, the axonal volume fraction (f),
+# the intrinsic diffusivity (di), and the microscopic anisotropy of the SMT
+# 2-compartmental model :footcite:p:`NetoHenriques2019` can be extracted using
+# the following lines of code:
 
 F = msdki_fit.smt2f
 DI = msdki_fit.smt2di
@@ -333,22 +342,24 @@ uFA2 = msdki_fit.smt2uFA
 ###############################################################################
 # The SMT2 model parameters extracted from MSDKI are displayed below:
 
-fig3, ax = plt.subplots(1, 3, figsize=(9, 2.5),
-                        subplot_kw={'xticks': [], 'yticks': []})
+fig3, ax = plt.subplots(1, 3, figsize=(9, 2.5), subplot_kw={"xticks": [], "yticks": []})
 
 fig3.subplots_adjust(hspace=0.4, wspace=0.1)
 
-im0 = ax.flat[0].imshow(F[:, :, axial_slice].T,
-                        cmap='gray', vmin=0, vmax=1, origin='lower')
-ax.flat[0].set_title('SMT2 f (MSDKI)')
+im0 = ax.flat[0].imshow(
+    F[:, :, axial_slice].T, cmap="gray", vmin=0, vmax=1, origin="lower"
+)
+ax.flat[0].set_title("SMT2 f (MSDKI)")
 
-im1 = ax.flat[1].imshow(DI[:, :, axial_slice].T * 1000, cmap='gray',
-                        vmin=0, vmax=2, origin='lower')
-ax.flat[1].set_title('SMT2 di (MSDKI)')
+im1 = ax.flat[1].imshow(
+    DI[:, :, axial_slice].T * 1000, cmap="gray", vmin=0, vmax=2, origin="lower"
+)
+ax.flat[1].set_title("SMT2 di (MSDKI)")
 
-im2 = ax.flat[2].imshow(uFA2[:, :, axial_slice].T, cmap='gray',
-                        vmin=0, vmax=1, origin='lower')
-ax.flat[2].set_title('SMT2 uFA (MSDKI)')
+im2 = ax.flat[2].imshow(
+    uFA2[:, :, axial_slice].T, cmap="gray", vmin=0, vmax=1, origin="lower"
+)
+ax.flat[2].set_title("SMT2 uFA (MSDKI)")
 
 fig3.colorbar(im0, ax=ax.flat[0])
 fig3.colorbar(im1, ax=ax.flat[1])
@@ -356,14 +367,15 @@ fig3.colorbar(im2, ax=ax.flat[2])
 
 
 plt.show()
-fig3.savefig('MSDKI_SMT2_invivo.png')
+fig3.savefig("MSDKI_SMT2_invivo.png")
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
 #
 # SMT2 model quantities extracted from MSDKI. From left to right, the figure
 # shows the axonal volume fraction (f), the intrinsic diffusivity (di), and
-# the microscopic anisotropy of the SMT 2-compartmental model [NetoHe2019]_.
+# the microscopic anisotropy of the SMT 2-compartmental model
+# :footcite:p:`NetoHenriques2019`.
 #
 #
 # The similar contrast of SMT2 f-parameter maps in comparison to MSK (first
@@ -371,35 +383,15 @@ fig3.savefig('MSDKI_SMT2_invivo.png')
 # captures the same tissue information but on different scales (but rescaled
 # to values between 0 and 1).  It is important to note that SMT model
 # parameters estimates should be used with care, because the SMT model was
-# shown to be invalid NetoHe2019]_. For instance, although SMT2 parameter f
-# and uFA may be a useful normalization of the degree of non-Gaussian
-# diffusion (note than both metrics have a range between 0 and 1), these
-# cannot be interpreted as a real biophysical estimates of axonal water
+# shown to be invalid:footcite:p:`NetoHenriques2019`. For instance, although
+# SMT2 parameter f and uFA may be a useful normalization of the degree of
+# non-Gaussian diffusion (note than both metrics have a range between 0 and 1),
+# these cannot be interpreted as a real biophysical estimates of axonal water
 # fraction and tissue microscopic anisotropy.
 #
 #
 # References
 # ----------
-# .. [Jensen2005] Jensen JH, Helpern JA, Ramani A, Lu H, Kaczynski K (2005).
-#                 Diffusional Kurtosis Imaging: The Quantification of
-#                 Non_Gaussian Water Diffusion by Means of Magnetic Resonance
-#                 Imaging. Magnetic Resonance in Medicine 53: 1432-1440
-# .. [NetoHe2015] Neto Henriques R, Correia MM, Nunes RG, Ferreira HA (2015).
-#                 Exploring the 3D geometry of the diffusion kurtosis tensor -
-#                 Impact on the development of robust tractography procedures
-#                 and novel biomarkers, NeuroImage 111: 85-99
-# .. [NetoHe2018] Henriques RN, 2018. Advanced Methods for Diffusion MRI Data
-#                 Analysis and their Application to the Healthy Ageing Brain
-#                 (Doctoral thesis). Downing College, University of Cambridge.
-#                 https://doi.org/10.17863/CAM.29356
-# .. [NetoHe2019] Neto Henriques R, Jespersen SN, Shemesh N (2019). Microscopic
-#                 anisotropy misestimation in spherical‐mean single diffusion
-#                 encoding MRI. Magnetic Resonance in Medicine (In press).
-#                 doi: 10.1002/mrm.27606
-# .. [Kaden2016b] Kaden E, Kelm ND, Carson RP, Does MD, Alexander DC (2016)
-#                 Multi-compartment microscopic diffusion imaging. NeuroImage
-#                 139: 346-359.
-# .. [Hansen2016] Hansen, B, Jespersen, SN (2016). Data for evaluation of fast
-#                 kurtosis strategies, b-value optimization and exploration of
-#                 diffusion MRI contrast. Scientific Data 3: 160072
-#                 doi:10.1038/sdata.2016.72
+#
+# .. footbibliography::
+#
