@@ -11,11 +11,12 @@ Let's import some standard packages.
 """
 
 import numpy as np
-from dipy.core.sphere import disperse_charges, Sphere, HemiSphere
+
+from dipy.core.sphere import HemiSphere, Sphere, disperse_charges
 from dipy.data import get_sphere
 from dipy.reconst.shm import sf_to_sh, sh_to_sf
 from dipy.sims.voxel import multi_tensor_odf
-from dipy.viz import window, actor
+from dipy.viz import actor, window
 
 ###############################################################################
 # We can first create some random points on a ``HemiSphere`` using spherical
@@ -43,8 +44,7 @@ sphere = Sphere(xyz=np.vstack((hsph_updated.vertices, -hsph_updated.vertices)))
 # use DIPY_ to simulate a signal and ODF, see
 # :ref:`sphx_glr_examples_built_simulations_simulate_multi_tensor.py`.
 
-mevals = np.array([[0.0015, 0.00015, 0.00015],
-                   [0.0015, 0.00015, 0.00015]])
+mevals = np.array([[0.0015, 0.00015, 0.00015], [0.0015, 0.00015, 0.00015]])
 angles = [(0, 0), (60, 0)]
 odf = multi_tensor_odf(sphere.vertices, mevals, angles, [50, 50])
 
@@ -58,8 +58,8 @@ odf_actor = actor.odf_slicer(odf[None, None, None, :], sphere=sphere)
 odf_actor.RotateX(90)
 scene.add(odf_actor)
 
-print('Saving illustration as symm_signal.png')
-window.record(scene, out_path='symm_signal.png', size=(300, 300))
+print("Saving illustration as symm_signal.png")
+window.record(scene=scene, out_path="symm_signal.png", size=(300, 300))
 if interactive:
     window.show(scene)
 
@@ -77,11 +77,11 @@ if interactive:
 # order of 8.
 
 # Change this value to try out other bases
-sh_basis = 'descoteaux07'
+sh_basis = "descoteaux07"
 # Change this value to try other maximum orders
 sh_order_max = 8
 
-sh_coeffs = sf_to_sh(odf, sphere, sh_order_max, sh_basis)
+sh_coeffs = sf_to_sh(odf, sphere, sh_order_max=sh_order_max, basis_type=sh_basis)
 
 ###############################################################################
 # ``sh_coeffs`` is an array containing the SH coefficients multiplying the SH
@@ -89,16 +89,18 @@ sh_coeffs = sf_to_sh(odf, sphere, sh_order_max, sh_basis)
 # reconstruct our original signal. We will now reproject our signal on a high
 # resolution sphere using ``sh_to_sf``.
 
-high_res_sph = get_sphere('symmetric724').subdivide(2)
-reconst = sh_to_sf(sh_coeffs, high_res_sph, sh_order_max, sh_basis)
+high_res_sph = get_sphere(name="symmetric724").subdivide(n=2)
+reconst = sh_to_sf(
+    sh_coeffs, high_res_sph, sh_order_max=sh_order_max, basis_type=sh_basis
+)
 
 scene.clear()
 odf_actor = actor.odf_slicer(reconst[None, None, None, :], sphere=high_res_sph)
 odf_actor.RotateX(90)
 scene.add(odf_actor)
 
-print('Saving output as symm_reconst.png')
-window.record(scene, out_path='symm_reconst.png', size=(300, 300))
+print("Saving output as symm_reconst.png")
+window.record(scene=scene, out_path="symm_reconst.png", size=(300, 300))
 if interactive:
     window.show(scene)
 
@@ -125,8 +127,8 @@ odf_actor = actor.odf_slicer(asym_odf[None, None, None, :], sphere=sphere)
 odf_actor.RotateX(90)
 scene.add(odf_actor)
 
-print('Saving output as asym_signal.png')
-window.record(scene, out_path='asym_signal.png', size=(300, 300))
+print("Saving output as asym_signal.png")
+window.record(scene=scene, out_path="asym_signal.png", size=(300, 300))
 if interactive:
     window.show(scene)
 
@@ -139,16 +141,18 @@ if interactive:
 #
 # Let's try to reconstruct this SF using a symmetric SH basis.
 
-sh_coeffs = sf_to_sh(asym_odf, sphere, sh_order_max, sh_basis)
-reconst = sh_to_sf(sh_coeffs, high_res_sph, sh_order_max, sh_basis)
+sh_coeffs = sf_to_sh(asym_odf, sphere, sh_order_max=sh_order_max, basis_type=sh_basis)
+reconst = sh_to_sf(
+    sh_coeffs, high_res_sph, sh_order_max=sh_order_max, basis_type=sh_basis
+)
 
 scene.clear()
 odf_actor = actor.odf_slicer(reconst[None, None, None, :], sphere=high_res_sph)
 odf_actor.RotateX(90)
 scene.add(odf_actor)
 
-print('Saving output as asym_reconst.png')
-window.record(scene, out_path='asym_reconst.png', size=(300, 300))
+print("Saving output as asym_reconst.png")
+window.record(scene=scene, out_path="asym_reconst.png", size=(300, 300))
 if interactive:
     window.show(scene)
 
@@ -164,18 +168,24 @@ if interactive:
 # demonstrate it using the ``descoteaux07`` full SH basis by setting
 # ``full_basis=true``.
 
-sh_coeffs = sf_to_sh(asym_odf, sphere, sh_order_max,
-                     sh_basis, full_basis=True)
-reconst = sh_to_sf(sh_coeffs, high_res_sph, sh_order_max,
-                   sh_basis, full_basis=True)
+sh_coeffs = sf_to_sh(
+    asym_odf, sphere, sh_order_max=sh_order_max, basis_type=sh_basis, full_basis=True
+)
+reconst = sh_to_sf(
+    sh_coeffs,
+    high_res_sph,
+    sh_order_max=sh_order_max,
+    basis_type=sh_basis,
+    full_basis=True,
+)
 
 scene.clear()
 odf_actor = actor.odf_slicer(reconst[None, None, None, :], sphere=high_res_sph)
 odf_actor.RotateX(90)
 scene.add(odf_actor)
 
-print('Saving output as asym_reconst_full.png')
-window.record(scene, out_path='asym_reconst_full.png', size=(300, 300))
+print("Saving output as asym_reconst_full.png")
+window.record(scene=scene, out_path="asym_reconst_full.png", size=(300, 300))
 if interactive:
     window.show(scene)
 
