@@ -13,13 +13,13 @@ example, some groups of participants (e.g. young children, patient groups,
 etc.) are particularly prone to motion and differences in tensor parameters and
 derived statistics (such as FA) due to motion would be confounded with actual
 differences in the physical properties of the white matter. An example of this
-was shown in a paper by Yendiki et al. [Yendiki2013]_.
+was shown in a paper by :footcite:t:`Yendiki2014`.
 
 One of the strategies to deal with this problem is to apply an automatic method
 for detecting outliers in the data, excluding these outliers and refitting the
 model without the presence of these outliers. This is often referred to as
 "robust model fitting". One of the common algorithms for robust tensor fitting
-is called RESTORE, and was first proposed by Chang et al. [Chang2005]_.
+is called RESTORE, and was first proposed by :footcite:p:`Chang2005`.
 
 In the following example, we will demonstrate how to use RESTORE on a simulated
 dataset, which we will corrupt by adding intermittent noise.
@@ -36,16 +36,16 @@ We start by importing a few of the libraries we will use.
   visualizations:
 """
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
 from dipy.core.gradients import gradient_table
 import dipy.data as dpd
 import dipy.denoise.noise_estimate as ne
-from dipy.io.image import load_nifti
 from dipy.io.gradients import read_bvals_bvecs
+from dipy.io.image import load_nifti
 import dipy.reconst.dti as dti
-from dipy.viz import window, actor
+from dipy.viz import actor, window
 
 # Enables/disables interactive visualization
 interactive = False
@@ -55,19 +55,18 @@ interactive = False
 # dataset of a single subject. The size of this dataset is 87 MBytes. You only
 # need to fetch once.
 
-hardi_fname, hardi_bval_fname, hardi_bvec_fname = dpd.get_fnames(
-    'stanford_hardi')
+hardi_fname, hardi_bval_fname, hardi_bvec_fname = dpd.get_fnames(name="stanford_hardi")
 data, affine = load_nifti(hardi_fname)
 
 bvals, bvecs = read_bvals_bvecs(hardi_bval_fname, hardi_bvec_fname)
-gtab = gradient_table(bvals, bvecs)
+gtab = gradient_table(bvals, bvecs=bvecs)
 
 ###############################################################################
 # We initialize a DTI model class instance using the gradient table used in
 # the measurement. By default, ``dti.TensorModel`` will use a weighted
-# least-squares algorithm (described in [Chang2005]_) to fit the parameters of
-# the model. We initialize this model as a baseline for comparison of
-# noise-corrupted models:
+# least-squares algorithm (described in :footcite:p:`Chang2005`) to fit the
+# parameters of the model. We initialize this model as a baseline for
+# comparison of noise-corrupted models:
 
 dti_wls = dti.TensorModel(gtab)
 
@@ -100,9 +99,10 @@ sphere = dpd.default_sphere
 # We visualize the ODFs in the ROI using ``dipy.viz`` module:
 
 scene = window.Scene()
-scene.add(actor.tensor_slicer(evals1, evecs1, scalar_colors=cfa1,
-                              sphere=sphere, scale=0.3))
-window.record(scene, out_path='tensor_ellipsoids_wls.png', size=(600, 600))
+scene.add(
+    actor.tensor_slicer(evals1, evecs1, scalar_colors=cfa1, sphere=sphere, scale=0.3)
+)
+window.record(scene=scene, out_path="tensor_ellipsoids_wls.png", size=(600, 600))
 if interactive:
     window.show(scene)
 
@@ -131,10 +131,10 @@ evecs2 = fit_wls_noisy.evecs
 cfa2 = dti.color_fa(fa2, evecs2)
 
 scene = window.Scene()
-scene.add(actor.tensor_slicer(evals2, evecs2, scalar_colors=cfa2,
-                              sphere=sphere, scale=0.3))
-window.record(scene, out_path='tensor_ellipsoids_wls_noisy.png',
-              size=(600, 600))
+scene.add(
+    actor.tensor_slicer(evals2, evecs2, scalar_colors=cfa2, sphere=sphere, scale=0.3)
+)
+window.record(scene=scene, out_path="tensor_ellipsoids_wls_noisy.png", size=(600, 600))
 if interactive:
     window.show(scene)
 
@@ -158,7 +158,7 @@ sigma = ne.estimate_sigma(data)
 # algorithm to identify the outliers in each voxel and is given as an input
 # when initializing the TensorModel object:
 
-dti_restore = dti.TensorModel(gtab, fit_method='RESTORE', sigma=sigma)
+dti_restore = dti.TensorModel(gtab, fit_method="RESTORE", sigma=sigma)
 fit_restore_noisy = dti_restore.fit(noisy_data)
 fa3 = fit_restore_noisy.fa
 evals3 = fit_restore_noisy.evals
@@ -166,11 +166,13 @@ evecs3 = fit_restore_noisy.evecs
 cfa3 = dti.color_fa(fa3, evecs3)
 
 scene = window.Scene()
-scene.add(actor.tensor_slicer(evals3, evecs3, scalar_colors=cfa3,
-                              sphere=sphere, scale=0.3))
-print('Saving illustration as tensor_ellipsoids_restore_noisy.png')
-window.record(scene, out_path='tensor_ellipsoids_restore_noisy.png',
-              size=(600, 600))
+scene.add(
+    actor.tensor_slicer(evals3, evecs3, scalar_colors=cfa3, sphere=sphere, scale=0.3)
+)
+print("Saving illustration as tensor_ellipsoids_restore_noisy.png")
+window.record(
+    scene=scene, out_path="tensor_ellipsoids_restore_noisy.png", size=(600, 600)
+)
 if interactive:
     window.show(scene)
 
@@ -183,16 +185,17 @@ if interactive:
 # The tensor field looks rather restored to its noiseless state in this
 # image, but to convince ourselves further that this did the right thing, we
 # will compare  the distribution of FA in this region relative to the
-# baseline, using the RESTORE estimate and the WLS estimate [Chung2006]_.
+# baseline, using the RESTORE estimate and the WLS estimate
+# :footcite:p:`Chung2006`.
 
 fig_hist, ax = plt.subplots(1)
-ax.hist(np.ravel(fa2), color='b', histtype='step', label='WLS')
-ax.hist(np.ravel(fa3), color='r', histtype='step', label='RESTORE')
-ax.hist(np.ravel(fa1), color='g', histtype='step', label='Original')
-ax.set_xlabel('Fractional Anisotropy')
-ax.set_ylabel('Count')
+ax.hist(np.ravel(fa2), color="b", histtype="step", label="WLS")
+ax.hist(np.ravel(fa3), color="r", histtype="step", label="RESTORE")
+ax.hist(np.ravel(fa1), color="g", histtype="step", label="Original")
+ax.set_xlabel("Fractional Anisotropy")
+ax.set_ylabel("Count")
 plt.legend()
-fig_hist.savefig('dti_fa_distributions.png')
+fig_hist.savefig("dti_fa_distributions.png")
 
 ###############################################################################
 # This demonstrates that RESTORE can recover a distribution of FA that more
@@ -208,13 +211,5 @@ fig_hist.savefig('dti_fa_distributions.png')
 # References
 # ----------
 #
-# .. [Yendiki2013] Yendiki, A, Koldewynb, K, Kakunooria, S, Kanwisher, N, and
-#    Fischl, B. (2013). Spurious group differences due to head motion in a
-#    diffusion MRI study. Neuroimage.
+# .. footbibliography::
 #
-# .. [Chang2005] Chang, L-C, Jones, DK and Pierpaoli, C (2005). RESTORE: robust
-#    estimation of tensors by outlier rejection. MRM, 53: 1088-95.
-#
-# .. [Chung2006] Chung, SW, Lu, Y, Henry, R-G, (2006). Comparison of bootstrap
-#    approaches for estimation of uncertainties of DTI parameters. NeuroImage
-#    33, 531-541.
