@@ -7,7 +7,8 @@ This page lists available metrics that can be used by the tractography
 clustering framework. For every metric a brief description is provided
 explaining: what it does, when it's useful and how to use it. If you are not
 familiar with the tractography clustering framework, check this tutorial
-:ref:`clustering-framework`.
+:ref:`clustering-framework`. See :footcite:p:`Garyfallidis2012a` for more
+information on the metrics.
 
 .. contents:: Available Metrics
     :local:
@@ -15,14 +16,18 @@ familiar with the tractography clustering framework, check this tutorial
 
 Let's start by importing the necessary modules.
 """
+
 import numpy as np
 
 from dipy.segment.clustering import QuickBundles
-from dipy.segment.metric import (
-    AveragePointwiseEuclideanMetric, SumPointwiseEuclideanMetric, CosineMetric)
 from dipy.segment.featurespeed import VectorOfEndpointsFeature
+from dipy.segment.metric import (
+    AveragePointwiseEuclideanMetric,
+    CosineMetric,
+    SumPointwiseEuclideanMetric,
+)
 from dipy.tracking.streamline import set_number_of_points
-from dipy.viz import window, actor, colormap
+from dipy.viz import actor, colormap, window
 
 ###############################################################################
 # .. note::
@@ -36,11 +41,12 @@ def get_streamlines():
     from dipy.data import get_fnames
     from dipy.io.streamline import load_tractogram
 
-    fname = get_fnames('fornix')
-    fornix = load_tractogram(fname, 'same', bbox_valid_check=False)
+    fname = get_fnames(name="fornix")
+    fornix = load_tractogram(fname, "same", bbox_valid_check=False)
 
     return fornix.streamlines
 
+
 ###############################################################################
 # .. _clustering-examples-AveragePointwiseEuclideanMetric:
 #
@@ -70,7 +76,7 @@ streamlines = set_number_of_points(streamlines, nb_points=12)
 
 # Create the instance of `AveragePointwiseEuclideanMetric` to use.
 metric = AveragePointwiseEuclideanMetric()
-qb = QuickBundles(threshold=10., metric=metric)
+qb = QuickBundles(threshold=10.0, metric=metric)
 clusters = qb.cluster(streamlines)
 
 print("Nb. clusters:", len(clusters))
@@ -99,7 +105,7 @@ streamlines = set_number_of_points(streamlines, nb_points=nb_points)
 
 # Create the instance of `SumPointwiseEuclideanMetric` to use.
 metric = SumPointwiseEuclideanMetric()
-qb = QuickBundles(threshold=10.*nb_points, metric=metric)
+qb = QuickBundles(threshold=10.0 * nb_points, metric=metric)
 clusters = qb.cluster(streamlines)
 
 print("Nb. clusters:", len(clusters))
@@ -138,8 +144,8 @@ for cluster, color in zip(clusters, colormap):
 scene = window.Scene()
 scene.clear()
 scene.SetBackground(0, 0, 0)
-scene.add(actor.streamtube(streamlines, colormap_full))
-window.record(scene, out_path='cosine_metric.png', size=(600, 600))
+scene.add(actor.streamtube(streamlines, colors=colormap_full))
+window.record(scene=scene, out_path="cosine_metric.png", size=(600, 600))
 if interactive:
     window.show(scene)
 
@@ -152,6 +158,5 @@ if interactive:
 # References
 # ----------
 #
-# .. [Garyfallidis12] Garyfallidis E. et al., QuickBundles a method for
-#    tractography simplification, Frontiers in Neuroscience, vol 6, no 175,
-#    2012.
+# .. footbibliography::
+#
