@@ -21,39 +21,41 @@ colored-FA (CFA) map. In this example, we will use voxels from the CC, which
 have the characteristic of being highly red in the CFA map since they are
 mainly oriented in the left-right direction. We know that the DW image closest
 to the X-direction will be the one with the most attenuated diffusion signal.
-This is the strategy adopted in several recent papers (see [Descoteaux2011]_
-and [Jones2013]_). It gives a good indication of the quality of the DWI data.
+This is the strategy adopted in several recent papers (see
+:footcite:p:`Descoteaux2011` and :footcite:p:`Jones2013`). It gives a good
+indication of the quality of the DWI data.
 
-First, we compute the tensor model in a brain mask (see the :ref:`reconst_dti`
-example for further explanations).
+First, we compute the tensor model in a brain mask (see the
+:ref:`sphx_glr_examples_built_reconstruction_reconst_dti.py` example for further
+explanations).
 
 Let's load the necessary modules:
 """
 
+import matplotlib.pyplot as plt
 import numpy as np
 from scipy.ndimage import binary_dilation
-import matplotlib.pyplot as plt
 
 from dipy.core.gradients import gradient_table
 from dipy.data import get_fnames
 from dipy.io.gradients import read_bvals_bvecs
 from dipy.io.image import load_nifti, save_nifti
-from dipy.segment.mask import median_otsu, segment_from_cfa, bounding_box
 from dipy.reconst.dti import TensorModel
+from dipy.segment.mask import bounding_box, median_otsu, segment_from_cfa
 
 ###############################################################################
 # Then, we fetch and load a specific dataset with 64 gradient directions:
 
-hardi_fname, hardi_bval_fname, hardi_bvec_fname = get_fnames('stanford_hardi')
+hardi_fname, hardi_bval_fname, hardi_bvec_fname = get_fnames(name="stanford_hardi")
 
 data, affine = load_nifti(hardi_fname)
 bvals, bvecs = read_bvals_bvecs(hardi_bval_fname, hardi_bvec_fname)
-gtab = gradient_table(bvals, bvecs)
+gtab = gradient_table(bvals, bvecs=bvecs)
 
-print('Computing brain mask...')
+print("Computing brain mask...")
 b0_mask, mask = median_otsu(data, vol_idx=[0])
 
-print('Computing tensors...')
+print("Computing tensors...")
 tenmodel = TensorModel(gtab)
 tensorfit = tenmodel.fit(data, mask=mask)
 
@@ -70,7 +72,7 @@ tensorfit = tenmodel.fit(data, mask=mask)
 # The following lines perform these two operations and then saves the
 # computed mask.
 
-print('Computing worst-case/best-case SNR using the corpus callosum...')
+print("Computing worst-case/best-case SNR using the corpus callosum...")
 
 threshold = (0.6, 1, 0, 0.1, 0, 0.1)
 CC_box = np.zeros_like(data[..., 0])
@@ -82,29 +84,30 @@ diff = (maxs - mins) // 4
 bounds_min = mins + diff
 bounds_max = maxs - diff
 
-CC_box[bounds_min[0]:bounds_max[0],
-       bounds_min[1]:bounds_max[1],
-       bounds_min[2]:bounds_max[2]] = 1
+CC_box[
+    bounds_min[0] : bounds_max[0],
+    bounds_min[1] : bounds_max[1],
+    bounds_min[2] : bounds_max[2],
+] = 1
 
-mask_cc_part, cfa = segment_from_cfa(tensorfit, CC_box, threshold,
-                                     return_cfa=True)
+mask_cc_part, cfa = segment_from_cfa(tensorfit, CC_box, threshold, return_cfa=True)
 
-save_nifti('cfa_CC_part.nii.gz', (cfa*255).astype(np.uint8), affine)
-save_nifti('mask_CC_part.nii.gz', mask_cc_part.astype(np.uint8), affine)
+save_nifti("cfa_CC_part.nii.gz", (cfa * 255).astype(np.uint8), affine)
+save_nifti("mask_CC_part.nii.gz", mask_cc_part.astype(np.uint8), affine)
 
 region = 40
-fig = plt.figure('Corpus callosum segmentation')
+fig = plt.figure("Corpus callosum segmentation")
 plt.subplot(1, 2, 1)
 plt.title("Corpus callosum (CC)")
-plt.axis('off')
+plt.axis("off")
 red = cfa[..., 0]
 plt.imshow(np.rot90(red[region, ...]))
 
 plt.subplot(1, 2, 2)
 plt.title("CC mask used for SNR computation")
-plt.axis('off')
+plt.axis("off")
 plt.imshow(np.rot90(mask_cc_part[region, ...]))
-fig.savefig("CC_segmentation.png", bbox_inches='tight')
+fig.savefig("CC_segmentation.png", bbox_inches="tight")
 
 ###############################################################################
 # Now that we are happy with our crude CC mask that selected voxels in the
@@ -117,19 +120,20 @@ mean_signal = np.mean(data[mask_cc_part], axis=0)
 # Now, we need a good background estimation. We will reuse the brain mask
 # computed before and invert it to catch the outside of the brain. This could
 # also be determined manually with a ROI in the background.
+#
 # .. warning::
 #
-# Certain MR manufacturers mask out the outside of the brain with 0's.
-# One thus has to be careful how the noise ROI is defined].
+#    Certain MR manufacturers mask out the outside of the brain with 0's.
+#    One thus has to be careful how the noise ROI is defined.
 
 mask_noise = binary_dilation(mask, iterations=10)
-mask_noise[..., :mask_noise.shape[-1]//2] = 1
+mask_noise[..., : mask_noise.shape[-1] // 2] = 1
 mask_noise = ~mask_noise
 
-save_nifti('mask_noise.nii.gz', mask_noise.astype(np.uint8), affine)
+save_nifti("mask_noise.nii.gz", mask_noise.astype(np.uint8), affine)
 
 noise_std = np.std(data[mask_noise, :])
-print('Noise standard deviation sigma= ', noise_std)
+print("Noise standard deviation sigma= ", noise_std)
 
 ###############################################################################
 # We can now compute the SNR for each DWI. For example, report SNR
@@ -139,17 +143,16 @@ print('Noise standard deviation sigma= ', noise_std)
 # Exclude null bvecs from the search
 idx = np.sum(gtab.bvecs, axis=-1) == 0
 gtab.bvecs[idx] = np.inf
-axis_X = np.argmin(np.sum((gtab.bvecs-np.array([1, 0, 0]))**2, axis=-1))
-axis_Y = np.argmin(np.sum((gtab.bvecs-np.array([0, 1, 0]))**2, axis=-1))
-axis_Z = np.argmin(np.sum((gtab.bvecs-np.array([0, 0, 1]))**2, axis=-1))
+axis_X = np.argmin(np.sum((gtab.bvecs - np.array([1, 0, 0])) ** 2, axis=-1))
+axis_Y = np.argmin(np.sum((gtab.bvecs - np.array([0, 1, 0])) ** 2, axis=-1))
+axis_Z = np.argmin(np.sum((gtab.bvecs - np.array([0, 0, 1])) ** 2, axis=-1))
 
 for direction in [0, axis_X, axis_Y, axis_Z]:
-    SNR = mean_signal[direction]/noise_std
+    SNR = mean_signal[direction] / noise_std
     if direction == 0:
-        print("SNR for the b=0 image is :", SNR)
+        print(f"SNR for the b=0 image is : {SNR}")
     else:
-        print("SNR for direction", direction, " ",
-              gtab.bvecs[direction], "is :", SNR)
+        print(f"SNR for direction {direction} {gtab.bvecs[direction]} is : {SNR}")
 
 ###############################################################################
 # Since the CC is aligned with the X axis, the lowest SNR is for that gradient
@@ -164,10 +167,5 @@ for direction in [0, axis_X, axis_Y, axis_Z]:
 # References
 # ----------
 #
-# .. [Descoteaux2011] Descoteaux, M., Deriche, R., Le Bihan, D., Mangin, J.-F.,
-#    and Poupon, C. Multiple q-shell diffusion propagator imaging. Medical
-#    Image Analysis, 15(4), 603, 2011.
+# .. footbibliography::
 #
-# .. [Jones2013] Jones, D. K., Knosche, T. R., & Turner, R. White Matter
-#    Integrity, Fiber Count, and Other Fallacies: The Dos and Don'ts of
-#    Diffusion MRI. NeuroImage, 73, 239, 2013.
