@@ -3,25 +3,25 @@
 Symmetric Diffeomorphic Registration in 2D
 ==========================================
 This example explains how to register 2D images using the Symmetric
-Normalization (SyN) algorithm proposed by Avants et al. [Avants09]_
-(also implemented in the ANTs software [Avants11]_)
+Normalization (SyN) algorithm proposed by :footcite:t:`Avants2008` (also
+implemented in the ANTs software :footcite:p:`Avants2009`)
 
 We will perform the classic Circle-To-C experiment for diffeomorphic
 registration
 """
 
 import numpy as np
-from dipy.align.imwarp import SymmetricDiffeomorphicRegistration
-from dipy.align.metrics import SSDMetric, CCMetric
+
 import dipy.align.imwarp as imwarp
+from dipy.align.imwarp import SymmetricDiffeomorphicRegistration
+from dipy.align.metrics import CCMetric, SSDMetric
 from dipy.data import get_fnames
 from dipy.io.image import load_nifti_data
 from dipy.segment.mask import median_otsu
 from dipy.viz import regtools
 
-
-fname_moving = get_fnames('reg_o')
-fname_static = get_fnames('reg_c')
+fname_moving = get_fnames(name="reg_o")
+fname_static = get_fnames(name="reg_c")
 
 moving = np.load(fname_moving)
 static = np.load(fname_static)
@@ -31,8 +31,14 @@ static = np.load(fname_static)
 # image, we can plot them on top of each other with different channels to see
 # where the differences are located
 
-regtools.overlay_images(static, moving, 'Static', 'Overlay', 'Moving',
-                        'input_images.png')
+regtools.overlay_images(
+    static,
+    moving,
+    title0="Static",
+    title_mid="Overlay",
+    title1="Moving",
+    fname="input_images.png",
+)
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -60,7 +66,7 @@ metric = SSDMetric(dim)
 
 level_iters = [200, 100, 50, 25]
 
-sdr = SymmetricDiffeomorphicRegistration(metric, level_iters, inv_iter=50)
+sdr = SymmetricDiffeomorphicRegistration(metric, level_iters=level_iters, inv_iter=50)
 
 ###############################################################################
 # Now we execute the optimization, which returns a DiffeomorphicMap object,
@@ -73,7 +79,7 @@ mapping = sdr.optimize(static, moving)
 # It is a good idea to visualize the resulting deformation map to make sure
 # the result is reasonable (at least, visually)
 
-regtools.plot_2d_diffeomorphic_map(mapping, 10, 'diffeomorphic_map.png')
+regtools.plot_2d_diffeomorphic_map(mapping, delta=10, fname="diffeomorphic_map.png")
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -85,9 +91,15 @@ regtools.plot_2d_diffeomorphic_map(mapping, 10, 'diffeomorphic_map.png')
 # Now let's warp the moving image and see if it gets similar to the static
 # image
 
-warped_moving = mapping.transform(moving, 'linear')
-regtools.overlay_images(static, warped_moving, 'Static', 'Overlay',
-                        'Warped moving', 'direct_warp_result.png')
+warped_moving = mapping.transform(moving, interpolation="linear")
+regtools.overlay_images(
+    static,
+    warped_moving,
+    title0="Static",
+    title_mid="Overlay",
+    title1="Warped moving",
+    fname="direct_warp_result.png",
+)
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -100,9 +112,15 @@ regtools.overlay_images(static, warped_moving, 'Static', 'Overlay',
 # And we can also apply the inverse mapping to verify that the warped static
 # image is similar to the moving image
 
-warped_static = mapping.transform_inverse(static, 'linear')
-regtools.overlay_images(warped_static, moving, 'Warped static', 'Overlay',
-                        'Moving', 'inverse_warp_result.png')
+warped_static = mapping.transform_inverse(static, interpolation="linear")
+regtools.overlay_images(
+    warped_static,
+    moving,
+    title0="Warped static",
+    title_mid="Overlay",
+    title1="Moving",
+    fname="inverse_warp_result.png",
+)
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -128,14 +146,19 @@ def callback_CC(sdr, status):
         wmoving = sdr.metric.moving_image
         wstatic = sdr.metric.static_image
         # draw the images on top of each other with different colors
-        regtools.overlay_images(wmoving, wstatic, 'Warped moving', 'Overlay',
-                                'Warped static')
+        regtools.overlay_images(
+            wmoving,
+            wstatic,
+            title0="Warped moving",
+            title_mid="Overlay",
+            title1="Warped static",
+        )
 
 
 ###############################################################################
 # Now we are ready to configure and run the registration. First load the data
 
-t1_name, b0_name = get_fnames('syn_data')
+t1_name, b0_name = get_fnames(name="syn_data")
 data = load_nifti_data(b0_name)
 
 ###############################################################################
@@ -158,13 +181,13 @@ moving = b0_mask[:, :, 38]
 
 sigma_diff = 3.0
 radius = 4
-metric = CCMetric(2, sigma_diff, radius)
+metric = CCMetric(2, sigma_diff=sigma_diff, radius=radius)
 
 ###############################################################################
 # Let's use a scale space of 3 levels
 
 level_iters = [100, 50, 25]
-sdr = SymmetricDiffeomorphicRegistration(metric, level_iters)
+sdr = SymmetricDiffeomorphicRegistration(metric, level_iters=level_iters)
 sdr.callback = callback_CC
 
 ###############################################################################
@@ -178,16 +201,28 @@ warped = mapping.transform(moving)
 # We can see the effect of the warping by switching between the images before
 # and after registration
 
-regtools.overlay_images(static, moving, 'Static', 'Overlay', 'Moving',
-                        't1_slices_input.png')
+regtools.overlay_images(
+    static,
+    moving,
+    title0="Static",
+    title_mid="Overlay",
+    title1="Moving",
+    fname="t1_slices_input.png",
+)
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
 #
 # Input images.
 
-regtools.overlay_images(static, warped, 'Static', 'Overlay', 'Warped moving',
-                        't1_slices_res.png')
+regtools.overlay_images(
+    static,
+    warped,
+    title0="Static",
+    title_mid="Overlay",
+    title1="Warped moving",
+    fname="t1_slices_res.png",
+)
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -200,8 +235,14 @@ regtools.overlay_images(static, warped, 'Static', 'Overlay', 'Warped moving',
 # And we can apply the inverse warping too
 
 inv_warped = mapping.transform_inverse(static)
-regtools.overlay_images(inv_warped, moving, 'Warped static', 'Overlay',
-                        'moving', 't1_slices_res2.png')
+regtools.overlay_images(
+    inv_warped,
+    moving,
+    title0="Warped static",
+    title_mid="Overlay",
+    title1="moving",
+    fname="t1_slices_res2.png",
+)
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -213,7 +254,7 @@ regtools.overlay_images(inv_warped, moving, 'Warped static', 'Overlay',
 #
 # Finally, let's see the deformation
 
-regtools.plot_2d_diffeomorphic_map(mapping, 5, 'diffeomorphic_map_b0s.png')
+regtools.plot_2d_diffeomorphic_map(mapping, delta=5, fname="diffeomorphic_map_b0s.png")
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -224,10 +265,5 @@ regtools.plot_2d_diffeomorphic_map(mapping, 5, 'diffeomorphic_map_b0s.png')
 # References
 # ----------
 #
-# .. [Avants09] Avants, B. B., Epstein, C. L., Grossman, M., & Gee, J. C.
-#    (2009). Symmetric Diffeomorphic Image Registration with Cross-Correlation:
-#    Evaluating Automated Labeling of Elderly and Neurodegenerative Brain,
-#    12(1), 26-41.
+# .. footbibliography::
 #
-# .. [Avants11] Avants, B. B., Tustison, N., & Song, G. (2011). Advanced
-#    Normalization Tools (ANTS), 1-35.
