@@ -3,8 +3,8 @@
 Symmetric Diffeomorphic Registration in 3D
 ==========================================
 This example explains how to register 3D volumes using the Symmetric
-Normalization (SyN) algorithm proposed by Avants et al. [Avants09]_
-(also implemented in the ANTs software [Avants11]_)
+Normalization (SyN) algorithm proposed by :footcite:t:`Avants2008` (also
+implemented in the ANTs software :footcite:p:`Avants2009`)
 
 We will register two 3D volumes from the same modality using SyN with the Cross
 -Correlation (CC) metric.
@@ -12,6 +12,7 @@ We will register two 3D volumes from the same modality using SyN with the Cross
 
 import numpy as np
 
+from dipy.align import read_mapping, write_mapping
 from dipy.align.imaffine import AffineMap
 from dipy.align.imwarp import SymmetricDiffeomorphicRegistration
 from dipy.align.metrics import CCMetric
@@ -24,7 +25,7 @@ from dipy.viz import regtools
 # Let's fetch two b0 volumes, the first one will be the b0 from the Stanford
 # HARDI dataset
 
-hardi_fname, hardi_bval_fname, hardi_bvec_fname = get_fnames('stanford_hardi')
+hardi_fname, hardi_bval_fname, hardi_bvec_fname = get_fnames(name="stanford_hardi")
 
 stanford_b0, stanford_b0_affine = load_nifti(hardi_fname)
 stanford_b0 = np.squeeze(stanford_b0)[..., 0]
@@ -32,15 +33,15 @@ stanford_b0 = np.squeeze(stanford_b0)[..., 0]
 ###############################################################################
 # The second one will be the same b0 we used for the 2D registration tutorial
 
-t1_fname, b0_fname = get_fnames('syn_data')
+t1_fname, b0_fname = get_fnames(name="syn_data")
 syn_b0, syn_b0_affine = load_nifti(b0_fname)
 
 ###############################################################################
 # We first remove the skull from the b0's
 
-stanford_b0_masked, stanford_b0_mask = median_otsu(stanford_b0,
-                                                   median_radius=4,
-                                                   numpass=4)
+stanford_b0_masked, stanford_b0_mask = median_otsu(
+    stanford_b0, median_radius=4, numpass=4
+)
 syn_b0_masked, syn_b0_mask = median_otsu(syn_b0, median_radius=4, numpass=4)
 
 static = stanford_b0_masked
@@ -53,10 +54,13 @@ moving_affine = syn_b0_affine
 # images
 
 pre_align = np.array(
-   [[1.02783543e+00, -4.83019053e-02, -6.07735639e-02, -2.57654118e+00],
-    [4.34051706e-03, 9.41918267e-01, -2.66525861e-01, 3.23579799e+01],
-    [5.34288908e-02, 2.90262026e-01, 9.80820307e-01, -1.46216651e+01],
-    [0.00000000e+00, 0.00000000e+00, 0.00000000e+00, 1.00000000e+00]])
+    [
+        [1.02783543e00, -4.83019053e-02, -6.07735639e-02, -2.57654118e00],
+        [4.34051706e-03, 9.41918267e-01, -2.66525861e-01, 3.23579799e01],
+        [5.34288908e-02, 2.90262026e-01, 9.80820307e-01, -1.46216651e01],
+        [0.00000000e00, 0.00000000e00, 0.00000000e00, 1.00000000e00],
+    ]
+)
 
 ###############################################################################
 # As we did in the 2D example, we would like to visualize (some slices of) the
@@ -65,17 +69,28 @@ pre_align = np.array(
 # the moving image on the static grid. We create an AffineMap to transform the
 # moving image towards the static image
 
-affine_map = AffineMap(pre_align,
-                       static.shape, static_affine,
-                       moving.shape, moving_affine)
+affine_map = AffineMap(
+    pre_align,
+    domain_grid_shape=static.shape,
+    domain_grid2world=static_affine,
+    codomain_grid_shape=moving.shape,
+    codomain_grid2world=moving_affine,
+)
 
 resampled = affine_map.transform(moving)
 
 ###############################################################################
 # plot the overlapped middle slices of the volumes
 
-regtools.overlay_slices(static, resampled, None, 1, 'Static', 'Moving',
-                        'input_3d.png')
+regtools.overlay_slices(
+    static,
+    resampled,
+    slice_index=None,
+    slice_type=1,
+    ltitle="Static",
+    rtitle="Moving",
+    fname="input_3d.png",
+)
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -97,7 +112,7 @@ metric = CCMetric(3)
 # resolution.
 
 level_iters = [10, 10, 5]
-sdr = SymmetricDiffeomorphicRegistration(metric, level_iters)
+sdr = SymmetricDiffeomorphicRegistration(metric, level_iters=level_iters)
 
 ###############################################################################
 # Execute the optimization, which returns a DiffeomorphicMap object,
@@ -105,7 +120,13 @@ sdr = SymmetricDiffeomorphicRegistration(metric, level_iters)
 # moving domains. We provide the pre-aligning matrix that brings the moving
 # image closer to the static image
 
-mapping = sdr.optimize(static, moving, static_affine, moving_affine, pre_align)
+mapping = sdr.optimize(
+    static,
+    moving,
+    static_grid2world=static_affine,
+    moving_grid2world=moving_affine,
+    prealign=pre_align,
+)
 
 ###############################################################################
 # Now let's warp the moving image and see if it gets similar to the static
@@ -116,8 +137,15 @@ warped_moving = mapping.transform(moving)
 ###############################################################################
 # We plot the overlapped middle slices
 
-regtools.overlay_slices(static, warped_moving, None, 1, 'Static',
-                        'Warped moving', 'warped_moving.png')
+regtools.overlay_slices(
+    static,
+    warped_moving,
+    slice_index=None,
+    slice_type=1,
+    ltitle="Static",
+    rtitle="Warped moving",
+    fname="warped_moving.png",
+)
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -131,8 +159,15 @@ regtools.overlay_slices(static, warped_moving, None, 1, 'Static',
 # image is similar to the moving image
 
 warped_static = mapping.transform_inverse(static)
-regtools.overlay_slices(warped_static, moving, None, 1, 'Warped static',
-                        'Moving', 'warped_static.png')
+regtools.overlay_slices(
+    warped_static,
+    moving,
+    slice_index=None,
+    slice_type=1,
+    ltitle="Warped static",
+    rtitle="Moving",
+    fname="warped_static.png",
+)
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
@@ -142,13 +177,21 @@ regtools.overlay_slices(warped_static, moving, None, 1, 'Warped static',
 # resolution.
 #
 #
+# If you wish, you can also save the transformation to a file, so that it can
+# be applied to other images in the future. This can be done with the
+# `write_mapping` function. The data in the file will be organized with shape
+# (X, Y, Z, 3, 2), such that the forward mapping in each voxel is in
+# data[i, j, k, :, 0] and the backward mapping in each voxel is in
+# data[i, j, k, :, 1]
+
+write_mapping(mapping, "mapping.nii.gz")
+# To read the mapping back, use the `read_mapping` function
+saved_mapping = read_mapping("mapping.nii.gz", hardi_fname, b0_fname)
+
+
+###############################################################################
 # References
 # ----------
 #
-# .. [Avants09] Avants, B. B., Epstein, C. L., Grossman, M., & Gee, J. C.
-#    (2009). Symmetric Diffeomorphic Image Registration with Cross-Correlation:
-#    Evaluating Automated Labeling of Elderly and Neurodegenerative Brain,
-#    12(1), 26-41.
+# .. footbibliography::
 #
-# .. [Avants11] Avants, B. B., Tustison, N., & Song, G. (2011). Advanced
-#    Normalization Tools (ANTS), 1-35.
