@@ -11,46 +11,49 @@ Let's start by importing the relevant modules.
 """
 
 from dipy.core.gradients import gradient_table
-from dipy.reconst.shm import CsaOdfModel
 from dipy.data import default_sphere, get_fnames
 from dipy.direction import peaks_from_model
 from dipy.io.gradients import read_bvals_bvecs
 from dipy.io.image import load_nifti, load_nifti_data
-from dipy.tracking.stopping_criterion import ThresholdStoppingCriterion
+from dipy.reconst.shm import CsaOdfModel
 from dipy.tracking import utils
 from dipy.tracking.local_tracking import LocalTracking
+from dipy.tracking.stopping_criterion import ThresholdStoppingCriterion
 from dipy.tracking.streamline import Streamlines
-from dipy.viz import actor, window, colormap as cmap
+from dipy.viz import actor, colormap as cmap, window
 
 ###############################################################################
 # First, we need to generate some streamlines. For a more complete
 # description of these steps, please refer to the CSA Probabilistic Tracking
 # Tutorial.
 
-hardi_fname, hardi_bval_fname, hardi_bvec_fname = get_fnames('stanford_hardi')
-label_fname = get_fnames('stanford_labels')
+hardi_fname, hardi_bval_fname, hardi_bvec_fname = get_fnames(name="stanford_hardi")
+label_fname = get_fnames(name="stanford_labels")
 
 data, affine, hardi_img = load_nifti(hardi_fname, return_img=True)
 labels = load_nifti_data(label_fname)
 bvals, bvecs = read_bvals_bvecs(hardi_bval_fname, hardi_bvec_fname)
-gtab = gradient_table(bvals, bvecs)
+gtab = gradient_table(bvals, bvecs=bvecs)
 
 white_matter = (labels == 1) | (labels == 2)
 
 csa_model = CsaOdfModel(gtab, sh_order_max=6)
-csa_peaks = peaks_from_model(csa_model, data, default_sphere,
-                             relative_peak_threshold=.8,
-                             min_separation_angle=45,
-                             mask=white_matter)
+csa_peaks = peaks_from_model(
+    csa_model,
+    data,
+    default_sphere,
+    relative_peak_threshold=0.8,
+    min_separation_angle=45,
+    mask=white_matter,
+)
 
-stopping_criterion = ThresholdStoppingCriterion(csa_peaks.gfa, .25)
+stopping_criterion = ThresholdStoppingCriterion(csa_peaks.gfa, 0.25)
 
 seed_mask = labels == 2
 seeds = utils.seeds_from_mask(seed_mask, affine, density=[1, 1, 1])
 
 # Initialization of LocalTracking. The computation happens in the next step.
-streamlines = LocalTracking(csa_peaks, stopping_criterion, seeds, affine,
-                            step_size=2)
+streamlines = LocalTracking(csa_peaks, stopping_criterion, seeds, affine, step_size=2)
 
 # Compute streamlines and store as a list.
 streamlines = Streamlines(streamlines)
@@ -58,7 +61,7 @@ streamlines = Streamlines(streamlines)
 ###############################################################################
 # We will create a streamline actor from the streamlines.
 
-streamlines_actor = actor.line(streamlines, cmap.line_colors(streamlines))
+streamlines_actor = actor.line(streamlines, colors=cmap.line_colors(streamlines))
 
 ###############################################################################
 # Next, we create a surface actor from the corpus callosum seed ROI. We
@@ -69,8 +72,9 @@ streamlines_actor = actor.line(streamlines, cmap.line_colors(streamlines))
 surface_opacity = 0.5
 surface_color = [0, 1, 1]
 
-seedroi_actor = actor.contour_from_roi(seed_mask, affine,
-                                       surface_color, surface_opacity)
+seedroi_actor = actor.contour_from_roi(
+    seed_mask, affine=affine, color=surface_color, opacity=surface_opacity
+)
 
 ###############################################################################
 # Next, we initialize a ''Scene'' object and add both actors
@@ -88,7 +92,7 @@ interactive = False
 if interactive:
     window.show(scene)
 
-window.record(scene, out_path='contour_from_roi_tutorial.png', size=(1200, 900))
+window.record(scene=scene, out_path="contour_from_roi_tutorial.png", size=(1200, 900))
 
 ###############################################################################
 # .. rst-class:: centered small fst-italic fw-semibold
