@@ -19,16 +19,16 @@ import shutil
 
 ###############################################################################
 # ``shutil`` Will be used for sample file manipulation.
-
 from dipy.workflows.workflow import Workflow
 
 ###############################################################################
 # ``Workflow`` is the base class that will be extended to create our workflow.
 
-class AppendTextFlow(Workflow):
 
-    def run(self, input_files, text_to_append='dipy', out_dir='',
-            out_file='append.txt'):
+class AppendTextFlow(Workflow):
+    def run(
+        self, input_files, text_to_append="dipy", out_dir="", out_file="append.txt"
+    ):
         """
         Parameters
         ----------
@@ -64,13 +64,12 @@ class AppendTextFlow(Workflow):
         io_it = self.get_io_iterator()
 
         for in_file, out_file in io_it:
-
             shutil.copy(in_file, out_file)
 
-            with open(out_file, 'a') as myfile:
-
+            with open(out_file, "a") as myfile:
                 myfile.write(text_to_append)
 
+
 ###############################################################################
 # Use self.get_io_iterator() in every workflow you create. This creates
 # an ``IOIterator`` object that create output file names and directory
@@ -86,6 +85,7 @@ class AppendTextFlow(Workflow):
 #
 # This is it for the workflow! Now to be able to call it easily via command
 # line, you need to add this workflow in 2 different files:
+#
 # - ``<dipy_root>/pyproject.toml``: open this file and add the following line
 #   to the ``[project.scripts]`` section:
 #   ``dipy_append_text = "dipy.workflows.cli:run"``
