@@ -3,9 +3,9 @@
 """
 
 # stdlib imports
-import sys
-import re
 from os.path import join as pjoin
+import re
+import sys
 
 # local imports
 from apigen import ApiDocWriter
@@ -17,7 +17,7 @@ from packaging.version import Version
 
 
 def abort(error):
-    print('*WARNING* API documentation not generated: %s' % error)
+    print(f'*WARNING* API documentation not generated: {error}')
     exit()
 
 
@@ -37,7 +37,7 @@ if __name__ == '__main__':
     try:
         __import__(package)
     except ImportError as e:
-        abort("Can not import " + package)
+        abort(f"Can not import {package}")
 
     # NOTE: with the new versioning scheme, this check is not needed anymore
     # Also, this might be needed if we do not use spin to generate the docs
@@ -71,14 +71,29 @@ if __name__ == '__main__':
                                         r'^\.utils.*',
                                         r'\.stats\.resampling.*$',
                                         r'\.info.*$',
-                                        r'\.pkg_info.*$',
                                         r'\.__config__.*$',
                                         ]
     docwriter.object_skip_patterns += [
         r'.*FetcherError.*$',
         r'.*urlopen.*',
         r'.*add_callback.*',
+        r'.*Logger.*',
+        r'.*logger.*',
+        # Global variable. Must be enable in the future when using Typing.
+        r'.*hemi_icosahedron.*',
+        r'.*unit_octahedron.*',
+        r'.*unit_icosahedron.*',
+        r'.*default_sphere.*',
+        r'.*small_sphere.*',
+        r'.*icosahedron_faces.*',
+        r'.*icosahedron_vertices.*',
+        r'.*octahedron_faces.*',
+        r'.*octahedron_vertices.*',
+        r'.*diffusion_evals.*',
+        r'.*DATA_DIR.*',
+        r'.*RegistrationStages.*',
+        r'.*VerbosityLevels.*',
     ]
     docwriter.write_api_docs(outdir)
     docwriter.write_index(outdir, 'index', relative_to=outdir)
-    print('%d files written' % len(docwriter.written_modules))
+    print(f'{len(docwriter.written_modules)} files written')
