@@ -7,7 +7,7 @@ set -ex
 
 echo "Display Python version"
 python -c "import sys; print(sys.version)"
-python -m pip install -U pip setuptools>=30.3.0 wheel
+python -m pip install -U pip 'setuptools~=69.5' wheel
 
 
 echo "Install Dependencies"
@@ -17,7 +17,9 @@ else
     PIPI="pip install --timeout=60 "
 
     if [ "$USE_PRE" == "1" ] || [ "$USE_PRE" == true ]; then
-        PIPI="$PIPI --extra-index-url=$PRE_WHEELS --pre";
+        # --index-url takes priority over --extra-index-url, so that packages, and
+        # their dependencies, with versions available in the nightly channel will be installed before falling back to the Python Package Index.
+        PIPI="$PIPI --pre --index-url $PRE_WHEELS --extra-index-url https://pypi.org/simple";
     fi
 
     $PIPI pytest==8.0.0
