@@ -8,6 +8,7 @@ set -ex
 echo "Run the tests"
 
 # Change into an innocuous directory and find tests from installation
+mkdir for_testing_results
 mkdir for_testing
 cd for_testing
 # We need the setup.cfg for the pytest settings
@@ -17,12 +18,17 @@ echo "backend : agg" > matplotlibrc
 if [ "$COVERAGE" == "1" ] || [ "$COVERAGE" == true ]; then
     cp ../.coveragerc .;
     cp ../.codecov.yml .;
+    chmod -R a-w .
     # Run the tests and check for test coverage.
-    coverage run -m pytest -c pyproject.toml -svv --doctest-modules --verbose --durations=10 --pyargs dipy
+    coverage run --data-file=../for_testing_results/.coverage -m pytest -o cache_dir=../for_testing_results -c pyproject.toml -svv --doctest-modules --verbose --durations=10 --pyargs dipy
+    chmod -R a+w .
+    cd ../for_testing_results
     coverage report -m  # Generate test coverage report.
     coverage xml  # Generate coverage report in xml format for codecov upload.
 else
-    pytest -c pyproject.toml -svv --doctest-modules --verbose --durations=10 --pyargs dipy
+    chmod -R a-w .
+    pytest -o cache_dir=../for_testing_results -c pyproject.toml -svv --doctest-modules --verbose --durations=10 --pyargs dipy
+    chmod -R a+w .
 fi
 cd ..
-set +ex
\ No newline at end of file
+set +ex
